// ==============================================================
//                ORBITER MODULE: ApolloSaturn
//
// ApolloSaturn.h
// Class interface for Apollo Saturn vessel class module
// ==============================================================

#ifndef __ApolloSaturn_H
#define __ApolloSaturn_H

#include "orbitersdk.h"


const double FHATCH_OPERATING_SPEED = 0.1;
// Opening/closing speed of outer airlock (1/sec)
// => cycle = 10 sec

const int nsurf = 4; // number of bitmap handles

// ==========================================================
// Interface for derived vessel class: ApolloSaturn
// ==========================================================

class ApolloSaturn: public VESSEL {
public:
	ApolloSaturn (OBJHANDLE hObj, int fmodel);
	~ApolloSaturn ();
	void LoadState (FILEHANDLE scn, VESSELSTATUS *vs);
	void SaveState (FILEHANDLE scn);
	void SetClassCaps (FILEHANDLE cfg);
	void DefineAnimations ();
	void ReleaseSurfaces();
	void Timestep (double simt);
	enum DoorStatus { DOOR_CLOSED, DOOR_OPEN, DOOR_CLOSING, DOOR_OPENING } nose_status, gear_status, lock_status;
	void ActivateAirlock (DoorStatus action);
	double hatch_proc;     // logical status
	UINT anim_hatch;     // handle for airlock animation

#endif // !__ApolloSaturn_H