// ==============================================================
// ORBITER vessel module: Saturn1Abort
// ==============================================================

#include "orbitersdk.h"
#include "stdio.h"

const VECTOR3 OFS_STAGE1 =  { 0, 0, -8.935};
const VECTOR3 OFS_STAGE2 =  { 0, 0, 9.25-12.25};
const VECTOR3 OFS_STAGE21 =  { 1.85,1.85,24.5-12.25};
const VECTOR3 OFS_STAGE22 =  { -1.85,1.85,24.5-12.25};
const VECTOR3 OFS_STAGE23 =  { 1.85,-1.85,24.5-12.25};
const VECTOR3 OFS_STAGE24 =  { -1.85,-1.85,24.5-12.25};


static int refcount = 0;
static MESHHANDLE hsat5stg1;
static MESHHANDLE hsat5intstg;
static MESHHANDLE hsat5stg2;
static MESHHANDLE hsat5stg3;
static MESHHANDLE hsat5stg31;
static MESHHANDLE hsat5stg32;
static MESHHANDLE hsat5stg33;
static MESHHANDLE hsat5stg34;
static MESHHANDLE hsat5tower;
static MESHHANDLE hSM;
double TCPO=0;
double Offset1st;
const double SMVO = -0.14;
const double STG0O= 0;
const double STG1O= 10.25;
const double STG2O= 20;
UINT stage = 0;
int status = 0;

void SetFirstStage (VESSEL *vessel)
{

	vessel->SetSize (55);
	vessel->SetEmptyMass (704000.0);
	vessel->SetMaxFuelMass (2396000);
	vessel->SetFuelMass(2396000);
	//vessel->SetISP (ISP_FIRST_VAC);
	vessel->SetISP (2303.05);
	//slThrust = CalcSeaLevelThrust(THRUST_FIRST_VAC,ISP_FIRST_VAC,ISP_FIRST_SL, 407100);
	//vacThrust = THRUST_FIRST_VAC;
	vessel->SetMaxThrust (ENGINE_MAIN,0 );//slThrust
	vessel->SetMaxThrust (ENGINE_RETRO, 0);
	vessel->SetMaxThrust (ENGINE_HOVER, 0);
	vessel->SetMaxThrust (ENGINE_ATTITUDE, 0);
	vessel->SetPMI (_V(1147,1147,216.68));
	vessel->SetCrossSections (_V(1129,1133,152.4));
	vessel->SetCW (0.1, 0.3, 1.4, 1.4);
	vessel->SetRotDrag (_V(0.7,0.7,1.2));
	vessel->SetPitchMomentScale (0);
	vessel->SetBankMomentScale (0);
	vessel->SetLiftCoeffFunc (0); 
	vessel->ClearMeshes();
	vessel->ClearExhaustRefs();
	vessel->ClearAttExhaustRefs();
	vessel->ShiftCentreOfMass (_V(0,0,STG0O));
	double TCP=-107.0+STG0O-TCPO;
	vessel->SetTouchdownPoints (_V(0,-1.0,0), _V(-.7,.7,0), _V(.7,.7,0));
	VECTOR3 mesh_dir=_V(0,0,-54+STG0O);
	vessel->AddMesh (hsat5stg1, &mesh_dir);
	mesh_dir=_V(0,0,-30.5+STG0O);
	vessel->AddMesh (hsat5intstg, &mesh_dir);
	mesh_dir=_V(0,0,-17.2+STG0O);
	vessel->AddMesh (hsat5stg2, &mesh_dir);
	mesh_dir=_V(0,0,2.+STG0O);
	vessel->AddMesh (hsat5stg3, &mesh_dir);
	mesh_dir=_V(-1.48,-1.48,14.55+STG0O);
	vessel->AddMesh (hsat5stg31, &mesh_dir);
	mesh_dir=_V(1.48,-1.48,14.55+STG0O);
	vessel->AddMesh (hsat5stg32, &mesh_dir);
	mesh_dir=_V(1.48,1.48,14.55+STG0O);
    vessel->AddMesh (hsat5stg33, &mesh_dir);
	mesh_dir=_V(-1.48,1.48,14.55+STG0O);
    vessel->AddMesh (hsat5stg34, &mesh_dir);
	mesh_dir=_V(0,SMVO,19.1+STG0O);
	vessel->AddMesh (hSM, &mesh_dir);
	mesh_dir=_V(0,0,23.5+STG0O);
	Offset1st = -80.1+STG0O;
	VECTOR3 m_exhaust_pos1= {3,3,Offset1st};
    VECTOR3 m_exhaust_pos2= {-3,-3,Offset1st};
	VECTOR3 m_exhaust_pos3= {-3,3,Offset1st};
	VECTOR3 m_exhaust_pos4= {3,-3,Offset1st};
	VECTOR3 m_exhaust_pos5= {0,0,Offset1st};
    
	VECTOR3 m_exhaust_ref = {0,0,-1};
	vessel->AddExhaustRef (EXHAUST_MAIN, m_exhaust_pos1, 120.0, 5.80, &m_exhaust_ref);
	vessel->AddExhaustRef (EXHAUST_MAIN, m_exhaust_pos2, 120.0, 5.80, &m_exhaust_ref);
	vessel->AddExhaustRef (EXHAUST_MAIN, m_exhaust_pos3, 120.0, 5.80, &m_exhaust_ref);
	vessel->AddExhaustRef (EXHAUST_MAIN, m_exhaust_pos4, 120.0, 5.80, &m_exhaust_ref);
	vessel->AddExhaustRef (EXHAUST_MAIN, m_exhaust_pos5, 120.0, 5.80, &m_exhaust_ref);
	vessel->SetCameraOffset (_V(-1,1.0,32.4+STG0O));
	status = 0;
}



// ==============================================================
// API interface
// ==============================================================
DLLCLBK void ovcSaveState (VESSEL *vessel, FILEHANDLE scn)

{
	vessel->SaveDefaultState (scn);
}


DLLCLBK VESSEL *ovcInit (OBJHANDLE hvessel, int flightmodel)
{
if (!refcount++) {
		hsat5stg1 = oapiLoadMeshGlobal ("sat5stg1");
		hsat5intstg = oapiLoadMeshGlobal ("sat5intstg");
		hsat5stg2 = oapiLoadMeshGlobal ("sat5stg2");
		hsat5stg3 = oapiLoadMeshGlobal ("sat5stg3");
		hsat5stg31 = oapiLoadMeshGlobal ("sat5stg31");
		hsat5stg32 = oapiLoadMeshGlobal ("sat5stg32");
		hsat5stg33 = oapiLoadMeshGlobal ("sat5stg33");
		hsat5stg34 = oapiLoadMeshGlobal ("sat5stg34");
		hSM = oapiLoadMeshGlobal ("nSaturn1_SM");
		
	}
	return new VESSEL (hvessel, flightmodel);
}

DLLCLBK void ovcSetClassCaps (VESSEL *vessel, FILEHANDLE cfg)
{
	SetFirstStage (vessel);
}

