// ==============================================================
// ORBITER vessel module: Saturn1Abort
// ==============================================================

#include "orbitersdk.h"
#include "stdio.h"

const VECTOR3 OFS_STAGE1 =  { 0, 0, -8.935};
const VECTOR3 OFS_STAGE2 =  { 0, 0, 9.25-12.25};
const VECTOR3 OFS_STAGE21 =  { 1.85,1.85,24.5-12.25};
const VECTOR3 OFS_STAGE22 =  { -1.85,1.85,24.5-12.25};
const VECTOR3 OFS_STAGE23 =  { 1.85,-1.85,24.5-12.25};
const VECTOR3 OFS_STAGE24 =  { -1.85,-1.85,24.5-12.25};


static int refcount = 0;
static MESHHANDLE hSat1stg1;
static MESHHANDLE hSat1stg2;
static MESHHANDLE hSat1stg20;
static MESHHANDLE hSat1stg21;
static MESHHANDLE hSat1stg22;
static MESHHANDLE hSat1stg23;
static MESHHANDLE hSat1stg24;
static MESHHANDLE hSat1tower;
static MESHHANDLE hSM;
UINT stage = 0;
int status = 0;

void SetFirstStage (VESSEL *vessel)
{
	vessel->SetSize (25);
	vessel->SetCOG_elev (21.2);
	vessel->SetEmptyMass (185500.0);
	vessel->SetMaxFuelMass (407100);
	vessel->SetFuelMass(407100);
	//vessel->SetISP (ISP_FIRST_VAC);
	vessel->SetISP (2795);
	//slThrust = CalcSeaLevelThrust(THRUST_FIRST_VAC,ISP_FIRST_VAC,ISP_FIRST_SL, 407100);
	//vacThrust = THRUST_FIRST_VAC;
	vessel->SetMaxThrust (ENGINE_MAIN, 0);//slThrust
	vessel->SetMaxThrust (ENGINE_RETRO, 0);
	vessel->SetMaxThrust (ENGINE_HOVER, 0);
	vessel->SetMaxThrust (ENGINE_ATTITUDE, 3e4);
	vessel->SetPMI (_V(140,145,28));
	vessel->SetCrossSections (_V(395,380,115));
	vessel->SetCW (0.1, 0.3, 1.4, 1.4);
	vessel->SetRotDrag (_V(0.7,0.7,1.2));
	vessel->SetPitchMomentScale (0);
	vessel->SetBankMomentScale (0);
	vessel->SetLiftCoeffFunc (0); 
	vessel->ClearMeshes();
	vessel->ClearExhaustRefs();
	vessel->ClearAttExhaustRefs();
	//vessel->ShiftCentreOfMass (_V(0,0,8.935));
	vessel->SetTouchdownPoints (_V(0,-1.0,-22.185), _V(-.7,.7,-22.185), _V(.7,.7,-22.185));
	VECTOR3 mesh_dir=_V(0,0,-8.935);
	vessel->AddMesh (hSat1stg1, &mesh_dir);
    mesh_dir=_V(0,0,9.25);
	vessel->AddMesh (hSat1stg2, &mesh_dir);
	mesh_dir=_V(1.85,1.85,24.5);
    vessel->AddMesh (hSat1stg21, &mesh_dir);
	mesh_dir=_V(-1.85,1.85,24.5);
    vessel->AddMesh (hSat1stg22, &mesh_dir);
	mesh_dir=_V(1.85,-1.85,24.5);
    vessel->AddMesh (hSat1stg23, &mesh_dir);
	mesh_dir=_V(-1.85,-1.85,24.5);
    vessel->AddMesh (hSat1stg24, &mesh_dir);
	mesh_dir=_V(0,0,30.15);
	vessel->AddMesh (hSM, &mesh_dir);
	mesh_dir=_V(0,0,34.40);
	VECTOR3 m_exhaust_pos1= {2,0,-23.5};
    VECTOR3 m_exhaust_pos2= {-2,0,-23.5};
	VECTOR3 m_exhaust_pos3= {0,2,-23.5};
	VECTOR3 m_exhaust_pos4= {0,-2,-23.5};
	VECTOR3 m_exhaust_ref = {0,0,-1};
	vessel->AddExhaustRef (EXHAUST_MAIN, m_exhaust_pos1, 30.0, 1.25, &m_exhaust_ref);
	vessel->AddExhaustRef (EXHAUST_MAIN, m_exhaust_pos2, 30.0, 1.25, &m_exhaust_ref);
	vessel->AddExhaustRef (EXHAUST_MAIN, m_exhaust_pos3, 30.0, 1.25, &m_exhaust_ref);
	vessel->AddExhaustRef (EXHAUST_MAIN, m_exhaust_pos4, 30.0, 1.25, &m_exhaust_ref);
	vessel->SetCameraOffset (_V(-1,1.0,34.15));
	status = 0;
	vessel->SetEngineLevel(ENGINE_MAIN,0);
}
void SetSecondStage (VESSEL *vessel)
{
	UINT meshidx;
	vessel->SetSize (15);
	vessel->SetCOG_elev (15.225);
	vessel->SetEmptyMass (21500);
	vessel->SetMaxFuelMass (106000);
	vessel->SetFuelMass(106000);
	//vessel->SetISP (ISP_SECOND_VAC);
	vessel->SetISP (4160);
	//slThrust = CalcSeaLevelThrust(THRUST_SECOND_VAC,ISP_SECOND_VAC,ISP_SECOND_SL, 106000);
	//vacThrust = THRUST_SECOND_VAC;
	//vessel->SetMaxThrust (ENGINE_MAIN, slThrust);
	vessel->SetMaxThrust (ENGINE_MAIN, 981000);
	vessel->SetMaxThrust (ENGINE_RETRO, 0);
	vessel->SetMaxThrust (ENGINE_HOVER, 0);
	vessel->SetMaxThrust (ENGINE_ATTITUDE, 5e3);
	vessel->SetEngineLevel(ENGINE_MAIN, 1.0);
	vessel->SetPMI (_V(94,94,20));
	vessel->SetCrossSections (_V(267,267,97));
	vessel->SetCW (0.1, 0.3, 1.4, 1.4);
	vessel->SetRotDrag (_V(0.7,0.7,1.2));
	vessel->SetPitchMomentScale (0);
	vessel->SetBankMomentScale (0);
	vessel->SetLiftCoeffFunc (0); 
    vessel->ClearMeshes();
    vessel->ClearExhaustRefs();
    vessel->ClearAttExhaustRefs();
	vessel->ShiftCentreOfMass (_V(0,0,12.25));
	VECTOR3 mesh_dir=_V(0,0,9.25-12.25);
    vessel->AddMesh (hSat1stg2, &mesh_dir);
	mesh_dir=_V(1.85,1.85,24.5-12.25);
    vessel->AddMesh (hSat1stg21, &mesh_dir);
	mesh_dir=_V(-1.85,1.85,24.5-12.25);
    vessel->AddMesh (hSat1stg22, &mesh_dir);
	mesh_dir=_V(1.85,-1.85,24.5-12.25);
    vessel->AddMesh (hSat1stg23, &mesh_dir);
	mesh_dir=_V(-1.85,-1.85,24.5-12.25);
    vessel->AddMesh (hSat1stg24, &mesh_dir);
	mesh_dir=_V(0,0,31.15-12.25);
	vessel->AddMesh (hSM, &mesh_dir);
	mesh_dir=_V(0,0,34.40-12.25);
	status = 1;
}



// ==============================================================
// API interface
// ==============================================================


DLLCLBK VESSEL *ovcInit (OBJHANDLE hvessel, int flightmodel)
{
if (!refcount++) {
		hSat1stg1 = oapiLoadMeshGlobal ("sat1stg1");
		hSat1stg2 = oapiLoadMeshGlobal ("sat1stg2");
		hSat1stg20 = oapiLoadMeshGlobal ("sat1stg20");
		hSat1stg21 = oapiLoadMeshGlobal ("sat1stg21");
		hSat1stg22 = oapiLoadMeshGlobal ("sat1stg22");
		hSat1stg23 = oapiLoadMeshGlobal ("sat1stg23");
		hSat1stg24 = oapiLoadMeshGlobal ("sat1stg24");
		hSM = oapiLoadMeshGlobal ("Saturn1_SM");
	}
	return new VESSEL (hvessel, flightmodel);
}

DLLCLBK void ovcSetClassCaps (VESSEL *vessel, FILEHANDLE cfg)
{
	SetFirstStage (vessel);
}

