// ==============================================================
// ORBITER vessel module: Saturn V Module Parked/Docked mode
// ==============================================================
#include "Orbitersdk.h"
#include "stdio.h"
#include "math.h"
#include "OrbiterSoundSDK.h"
#include "resource.h"


#define LOADBMP(id) (LoadBitmap (g_Param.hDLL, MAKEINTRESOURCE (id)))

// ==============================================================
// Global parameters
// ==============================================================
typedef struct {
	HINSTANCE hDLL;
	HFONT font[2];
	DWORD col[4];
	HBRUSH brush[4];
	HPEN pen[4];
} GDIParams;

GDIParams g_Param;

const int nsurf = 19; // number of bitmap handles
SURFHANDLE srf[nsurf];  // handles for panel bitmaps
PROPELLANT_HANDLE ph_Dsc, ph_Asc, ph_rcslm0,ph_rcslm1; // handles for propellant resources
THRUSTER_HANDLE th_hover[1];               // handles for orbiter main engines
THRUSTER_HANDLE th_att_rot[24], th_att_lin[24];                 // handles for SPS engines
THGROUP_HANDLE thg_hover;		          // handles for thruster groups

static const Sclick=19;
static const Sctdw=21;
static const StageS=22;
static const S5P100=23;
static const Scontact=24;
static const SDMode=25;
static const SHMode=26;
static const SLEVA=27;
static const SAbort=28;
static double actualVEL;
static double actualALT;
static double actualFUEL;
static double aVAcc;
static double aVSpeed;
static double aHAcc;
static double ALTN1;
static double SPEEDN1;
static double VSPEEDN1;
static double aTime;
double AtempP ;
double AtempY ;
double AtempR ; 
static bool bAbort =false;
static bool RCS_Full=true;
static bool Eds=true;
static bool KEY1=false;
static bool KEY2=false;
static bool KEY3=false;
static bool KEY4=false;
static bool KEY5=false;
static bool KEY6=false;
static bool KEY7=false;
static bool KEY8=false;
static bool KEY9=false;
static bool toggleRCS =false;
bool FIRSTCSM=false;
static bool StartGimbal=false;
static bool Cswitch1=false;
static bool Cswitch2=false;
static bool Cswitch3=false;
static bool Cswitch4=false;
static bool Cswitch5=false;
static bool Cswitch6=false;
static bool Cswitch7=false;
static bool Cswitch8=false;
static bool Cswitch9=false;
static bool Sswitch1=false;
static bool Sswitch2=false;
static bool Sswitch3=false;
static bool Sswitch4=false;
static bool Sswitch5=false;
static bool Sswitch6=false;
static bool Sswitch7=false;
static bool Sswitch8=false;
static bool Sswitch9=false;
static bool RPswitch1=false;
static bool RPswitch2=false;
static bool RPswitch3=false;
static bool RPswitch4=false;
static bool RPswitch5=false;
static bool RPswitch6=false;
static bool RPswitch7=false;
static bool RPswitch8=false;
static bool RPswitch9=false;
static bool RPswitch10=false;
static bool RPswitch11=false;
static bool RPswitch12=false;
static bool RPswitch13=false;
static bool RPswitch14=false;
static bool RPswitch15=false;
static bool RPswitch16=false;
static bool RPswitch17=false;
static bool LPswitch1=false;
static bool LPswitch2=false;
static bool LPswitch3=false;
static bool LPswitch4=false;
static bool LPswitch5=false;
static bool LPswitch6=false;
static bool LPswitch7=false;
static bool SPSswitch=false;
static bool EDSswitch=true;

static bool LAUNCHIND[8];
static bool ABORT_IND=false;
static bool ENGIND[7];
static int VERB;
static int NOUN;
static int DPROG;
static double R1;
static double R2;
static double R3;
static bool DKey0;
static bool DKey1;
static bool DKey2;
static bool DKey3;
static bool DKey4;
static bool DKey5;
static bool DKey6;
static bool DKey7;
static bool DKey8;
static bool DKey9;
static bool DKeyP;
static bool DKeyM;
static bool DKeyENTR;
static bool DKeyCLR;
static bool DKeyVERB;
static bool DKeyNOUN;
static bool DKeyRESET;
static bool DKeySTBY;
static bool DKeyKRLS;

	
const double N   = 1.0;
const double kN  = 1000.0;
const double KGF = N*G;
const double SEC = 1.0*G;
const double KG  = 1.0;
static double countdown;
const VECTOR3 OFS_STAGE1 =  { 0, 0, -8.935};
const VECTOR3 OFS_STAGE2 =  { 0, 0, 9.25-12.25};
const VECTOR3 OFS_STAGE21 =  { 1.85,1.85,24.5-12.25};
const VECTOR3 OFS_STAGE22 =  { -1.85,1.85,24.5-12.25};
const VECTOR3 OFS_STAGE23 =  { 1.85,-1.85,24.5-12.25};
const VECTOR3 OFS_STAGE24 =  { -1.85,-1.85,24.5-12.25};
static bool high=false;
static bool bToggleHatch=false;
static bool bModeDocked=false;
static bool bModeHover=false;
static bool HatchOpen=false;
static bool bManualSeparate=false;
static bool ToggleEva=false;
static bool EVA_IP=false;
static int refcount = 0;
static bool lmpview=true;
static bool cdrview=true;
static bool velDISP=false;
static bool startimer=false;
static bool bABort = false;
static bool ContactOK = false;
const int TO_EVA=1;
static MESHHANDLE hLMPKD ;
static MESHHANDLE hLMVessel ;
static MESHHANDLE hLMDescent;
static MESHHANDLE hLMAscent ;
static MESHHANDLE hLMAscent2 ;
static MESHHANDLE hAstro1 ;
static OBJHANDLE hLEVA;
static OBJHANDLE hdsc;
UINT stage = 0;
int status = 0;

//Begin code


void ResetThrusters(VESSEL *vessel){
	vessel->SetAttitudeRotLevel(0, 0);
	vessel->SetAttitudeRotLevel(1, 0);
	vessel->SetAttitudeRotLevel(2, 0);
	vessel->SetAttitudeLinLevel(0, 0);
	vessel->SetAttitudeLinLevel(1, 0);
	vessel->SetAttitudeLinLevel(2, 0);
	vessel->ActivateNavmode(NAVMODE_KILLROT);	
	
}
void AttitudeLaunch1(VESSEL *vessel)
{
	//Original code function by Richard Craig From MErcury Sample by Rob CONLEY
	// Modification for NASSP specific needs by JL Rocca-Serra
	VECTOR3 ang_vel;
	vessel->GetAngularVel(ang_vel);// gets current angular velocity for stabilizer and rate control
// variables to store each component deflection vector	
	VECTOR3 rollvectorl={0.0,0.0,0.0};
	VECTOR3 rollvectorr={0.0,0.0,0.0};
	VECTOR3 pitchvector={0.0,0.0,0.0};
	VECTOR3 yawvector={0.0,0.0,0.0};
	VECTOR3 yawvectorm={0.0,0.0,0.0};
	VECTOR3 pitchvectorm={0.0,0.0,0.0};
//************************************************************
// variables to store Manual control levels for each axis
	double tempP = 0.0;
	double tempY = 0.0;
	double tempR = 0.0; 
//************************************************************
// Variables to store correction factors for rate control
	double rollcorrect = 0.0;
	double yawcorrect= 0.0;
	double pitchcorrect = 0.0;
//************************************************************
// gets manual control levels in each axis, this code copied directly from Rob Conley's Mercury Atlas	
	if (LPswitch6){tempP = vessel->GetManualControlLevel(THGROUP_ATT_PITCHDOWN, MANCTRL_ANYDEVICE, MANCTRL_ANYMODE) - vessel->GetManualControlLevel(THGROUP_ATT_PITCHUP, MANCTRL_ANYDEVICE, MANCTRL_ANYMODE);}
	if (LPswitch7){tempR = vessel->GetManualControlLevel(THGROUP_ATT_BANKLEFT, MANCTRL_ANYDEVICE, MANCTRL_ANYMODE) - vessel->GetManualControlLevel(THGROUP_ATT_BANKRIGHT, MANCTRL_ANYDEVICE, MANCTRL_ANYMODE);}
	
	
	//sprintf (oapiDebugString(), "roll input: %f, roll vel: %f,pitch input: %f, pitch vel: %f", tempR, ang_vel.z,tempP, ang_vel.x);
	
//*************************************************************
//Creates correction factors for rate control in each axis as a function of input level
// and current angular velocity. Varies from 1 to 0 as angular velocity approaches command level
// multiplied by maximum rate desired
	if(tempR != 0.0)	{
		rollcorrect = (1/(fabs(tempR)*0.175))*((fabs(tempR)*0.175)-fabs(ang_vel.z));
			if((tempR > 0 && ang_vel.z > 0) || (tempR < 0 && ang_vel.z < 0))	{
						rollcorrect = 1;
					}
	}
	if(tempP != 0.0)	{
		pitchcorrect = (1/(fabs(tempP)*0.275))*((fabs(tempP)*0.275)-fabs(ang_vel.x));
		if((tempP > 0 && ang_vel.x > 0) || (tempP < 0 && ang_vel.x < 0))	{
						pitchcorrect = 1;
					}
	}
	
//*************************************************************	
// Create deflection vectors in each axis
	pitchvector = _V(0.0,0.0,0.05*tempP*pitchcorrect);
	pitchvectorm = _V(0.0,0.0,-0.2*tempP*pitchcorrect);
	yawvector = _V(0.05*tempY*yawcorrect,0.0,0.0);
	yawvectorm = _V(0.05*tempY*yawcorrect,0.0,0.0);
	rollvectorl = _V(0.0,0.60*tempR*rollcorrect,0.0);
	rollvectorr = _V(0.60*tempR*rollcorrect,0.0,0.0);

//*************************************************************
// create opposite vectors for "gyro stabilization" if command levels are 0
	if(tempP==0.0) {
		
		pitchvectorm=_V(0.0,0.0,-0.8*ang_vel.x*3);
	}
	if(tempR==0.0) {
		
		rollvectorr=_V(0.8*ang_vel.z*3,0.0,0.0);
	}
	
//**************************************************************	
// Sets thrust vectors by simply adding up all the axis deflection vectors and the 
// "neutral" default vector
	vessel->SetThrusterDir(th_hover[0],pitchvectorm+rollvectorr+_V( 0,1,0));//4
//	sprintf (oapiDebugString(), "pitch vector: %f, roll vel: %f", tempP, ang_vel.z);

}
void AddRCS_LM(VESSEL *vessel,double TRANZ)
{
UINT atthand;
	const double ATTCOOR = 0;
	const double ATTCOOR2 = 1.53;
	const double ATTZ = 2.85;
	const double TRANCOOR = 0;
	const double TRANCOOR2 = 0.1;
	const double ATTWIDTH=.2;
	const double ATTHEIGHT=.5;
	const double TRANWIDTH=.2;
	const double TRANHEIGHT=1;
	const double RCSOFFSET=0.75;
	const double RCSOFFSETM=0.30;
	const double RCSOFFSETM2=0.47;

		//lin Forward
		
		VECTOR3 m_exhaust_pos2= _V(ATTCOOR2+0.1,-ATTCOOR2-0.1,TRANZ+RCSOFFSET-0.6);
		VECTOR3 m_exhaust_pos3= _V(-ATTCOOR2-0.1,-ATTCOOR2-0.1,TRANZ+RCSOFFSET-0.6);
		VECTOR3 m_exhaust_pos4= _V(ATTCOOR2+0.1,ATTCOOR2+0.1,TRANZ+RCSOFFSET-0.6);
		VECTOR3 m_exhaust_pos5= _V(-ATTCOOR2-0.1,ATTCOOR2+0.1,TRANZ+RCSOFFSET-0.6);
		VECTOR3 m_exhaust_ref2 = _V(0.35,-0.35,-1);
		VECTOR3 m_exhaust_ref3 = _V(-0.35,-0.35,-1);
		VECTOR3 m_exhaust_ref4 = _V(0.35,0.35,-1);
		VECTOR3 m_exhaust_ref5 = _V(-0.35,0.35,-1);
		
		atthand = vessel->AddAttExhaustRef(m_exhaust_pos2,m_exhaust_ref2,ATTWIDTH,ATTHEIGHT);
		vessel->AddAttExhaustMode(atthand,ATTMODE_LIN,2,0);
		atthand = vessel->AddAttExhaustRef(m_exhaust_pos3,m_exhaust_ref3,ATTWIDTH,ATTHEIGHT);
		vessel->AddAttExhaustMode(atthand,ATTMODE_LIN,2,0);
		atthand = vessel->AddAttExhaustRef(m_exhaust_pos4,m_exhaust_ref4,ATTWIDTH,ATTHEIGHT);
		vessel->AddAttExhaustMode(atthand,ATTMODE_LIN,2,0);
		atthand = vessel->AddAttExhaustRef(m_exhaust_pos5,m_exhaust_ref5,ATTWIDTH,ATTHEIGHT);
		vessel->AddAttExhaustMode(atthand,ATTMODE_LIN,2,0);
	
		//lin backward
		
		m_exhaust_pos2= _V(ATTCOOR2+0.1,ATTCOOR2+0.1,TRANZ+RCSOFFSET);
		m_exhaust_pos3= _V(-ATTCOOR2-0.1,ATTCOOR2+0.1,TRANZ+RCSOFFSET);
		m_exhaust_pos4= _V(ATTCOOR2+0.1,-ATTCOOR2-0.1,TRANZ+RCSOFFSET);
		m_exhaust_pos5= _V(-ATTCOOR2-0.1,-ATTCOOR2-0.1,TRANZ+RCSOFFSET);
		m_exhaust_ref2 = _V(0,0.0,1);
		m_exhaust_ref3 = _V(0,0.0,1);
		m_exhaust_ref4 = _V(0,0.0,1);
		m_exhaust_ref5 = _V(0,0.0,1);
		atthand = vessel->AddAttExhaustRef(m_exhaust_pos2,m_exhaust_ref2,ATTWIDTH,ATTHEIGHT);
		vessel->AddAttExhaustMode(atthand,ATTMODE_LIN,2,1);
		atthand = vessel->AddAttExhaustRef(m_exhaust_pos3,m_exhaust_ref3,ATTWIDTH,ATTHEIGHT);
		vessel->AddAttExhaustMode(atthand,ATTMODE_LIN,2,1);
		atthand = vessel->AddAttExhaustRef(m_exhaust_pos4,m_exhaust_ref4,ATTWIDTH,ATTHEIGHT);
		vessel->AddAttExhaustMode(atthand,ATTMODE_LIN,2,1);
		atthand = vessel->AddAttExhaustRef(m_exhaust_pos5,m_exhaust_ref5,ATTWIDTH,ATTHEIGHT);
		vessel->AddAttExhaustMode(atthand,ATTMODE_LIN,2,1);
		
		//lin Left
		
		m_exhaust_pos2= _V(-ATTCOOR2-0.27,-ATTCOOR2,TRANZ+RCSOFFSETM2);
		m_exhaust_pos3= _V(-ATTCOOR2-0.27,ATTCOOR2,TRANZ+RCSOFFSETM2);
		m_exhaust_ref2 = _V(-1,1,0);
		m_exhaust_ref3 = _V(-1,-1,0);
		atthand = vessel->AddAttExhaustRef(m_exhaust_pos2,m_exhaust_ref2,ATTWIDTH,ATTHEIGHT);
		vessel->AddAttExhaustMode(atthand,ATTMODE_LIN,0,0);
		atthand = vessel->AddAttExhaustRef(m_exhaust_pos3,m_exhaust_ref3,ATTWIDTH,ATTHEIGHT);
		vessel->AddAttExhaustMode(atthand,ATTMODE_LIN,0,0);
		
		//lin right
		
		m_exhaust_pos2= _V(ATTCOOR2+0.27,-ATTCOOR2,TRANZ+RCSOFFSETM2);
		m_exhaust_pos3= _V(ATTCOOR2+0.27,ATTCOOR2,TRANZ+RCSOFFSETM2);
		m_exhaust_ref2 = _V(1,1,0);
		m_exhaust_ref3 = _V(1,-1,0);
		atthand = vessel->AddAttExhaustRef(m_exhaust_pos2,m_exhaust_ref2,ATTWIDTH,ATTHEIGHT);
		vessel->AddAttExhaustMode(atthand,ATTMODE_LIN,0,1);
		atthand = vessel->AddAttExhaustRef(m_exhaust_pos3,m_exhaust_ref3,ATTWIDTH,ATTHEIGHT);
		vessel->AddAttExhaustMode(atthand,ATTMODE_LIN,0,1);
		
		//lin down
		
		m_exhaust_pos2= _V(ATTCOOR2,ATTCOOR2+0.27,TRANZ+RCSOFFSETM2);
		m_exhaust_pos3= _V(-ATTCOOR2,ATTCOOR2+0.27,TRANZ+RCSOFFSETM2);
		m_exhaust_ref2 = _V(-1,1,0);
		m_exhaust_ref3 = _V(1,1,0);
		atthand = vessel->AddAttExhaustRef(m_exhaust_pos2,m_exhaust_ref2,ATTWIDTH,ATTHEIGHT);
		vessel->AddAttExhaustMode(atthand,ATTMODE_LIN,1,0);
		atthand = vessel->AddAttExhaustRef(m_exhaust_pos3,m_exhaust_ref3,ATTWIDTH,ATTHEIGHT);
		vessel->AddAttExhaustMode(atthand,ATTMODE_LIN,1,0);
		//lin up
		m_exhaust_pos2= _V(ATTCOOR2,-ATTCOOR2-0.27,TRANZ+RCSOFFSETM2);
		m_exhaust_pos3= _V(-ATTCOOR2,-ATTCOOR2-0.27,TRANZ+RCSOFFSETM2);
		m_exhaust_ref2 = _V(-1,-1,0);
		m_exhaust_ref3 = _V(1,-1,0);
		atthand = vessel->AddAttExhaustRef(m_exhaust_pos2,m_exhaust_ref2,ATTWIDTH,ATTHEIGHT);
		vessel->AddAttExhaustMode(atthand,ATTMODE_LIN,1,1);
		atthand = vessel->AddAttExhaustRef(m_exhaust_pos3,m_exhaust_ref3,ATTWIDTH,ATTHEIGHT);
		vessel->AddAttExhaustMode(atthand,ATTMODE_LIN,1,1);
		
		//Rot up
		
		m_exhaust_pos2= _V(ATTCOOR2+0.1,ATTCOOR2+0.1,TRANZ+RCSOFFSET);
		m_exhaust_pos3= _V(-ATTCOOR2-0.1,ATTCOOR2+0.1,TRANZ+RCSOFFSET);
		m_exhaust_pos4= _V(ATTCOOR2+0.1,-ATTCOOR2-0.1,TRANZ+RCSOFFSET-0.6);
		m_exhaust_pos5= _V(-ATTCOOR2-0.1,-ATTCOOR2-0.1,TRANZ+RCSOFFSET-0.6);
		m_exhaust_ref2 = _V(0,0.0,1);
		m_exhaust_ref3 = _V(0,0.0,1);
		m_exhaust_ref4 = _V(0.35,-0.35,-1);
		m_exhaust_ref5 = _V(-0.35,-0.35,-1);
		atthand = vessel->AddAttExhaustRef(m_exhaust_pos2,m_exhaust_ref2,ATTWIDTH,ATTHEIGHT);
		vessel->AddAttExhaustMode(atthand,ATTMODE_ROT,0,0);
		atthand = vessel->AddAttExhaustRef(m_exhaust_pos3,m_exhaust_ref3,ATTWIDTH,ATTHEIGHT);
		vessel->AddAttExhaustMode(atthand,ATTMODE_ROT,0,0);
		atthand = vessel->AddAttExhaustRef(m_exhaust_pos4,m_exhaust_ref4,ATTWIDTH,ATTHEIGHT);
		vessel->AddAttExhaustMode(atthand,ATTMODE_ROT,0,0);
		atthand = vessel->AddAttExhaustRef(m_exhaust_pos5,m_exhaust_ref5,ATTWIDTH,ATTHEIGHT);
		vessel->AddAttExhaustMode(atthand,ATTMODE_ROT,0,0);
		
		//Rot down
		m_exhaust_pos2= _V(ATTCOOR2+0.1,-ATTCOOR2-0.1,TRANZ+RCSOFFSET);
		m_exhaust_pos3= _V(-ATTCOOR2-0.1,-ATTCOOR2-0.1,TRANZ+RCSOFFSET);
		m_exhaust_pos4= _V(ATTCOOR2+0.1,ATTCOOR2+0.1,TRANZ+RCSOFFSET-0.6);
		m_exhaust_pos5= _V(-ATTCOOR2-0.1,ATTCOOR2+0.1,TRANZ+RCSOFFSET-0.6);
		m_exhaust_ref2 = _V(0,0.0,1);
		m_exhaust_ref3 = _V(0,0.0,1);
		m_exhaust_ref4 = _V(0.35,0.35,-1);
		m_exhaust_ref5 = _V(-0.35,0.35,-1);
		atthand = vessel->AddAttExhaustRef(m_exhaust_pos2,m_exhaust_ref2,ATTWIDTH,ATTHEIGHT);
		vessel->AddAttExhaustMode(atthand,ATTMODE_ROT,0,1);
		atthand = vessel->AddAttExhaustRef(m_exhaust_pos3,m_exhaust_ref3,ATTWIDTH,ATTHEIGHT);
		vessel->AddAttExhaustMode(atthand,ATTMODE_ROT,0,1);
		atthand = vessel->AddAttExhaustRef(m_exhaust_pos4,m_exhaust_ref4,ATTWIDTH,ATTHEIGHT);
		vessel->AddAttExhaustMode(atthand,ATTMODE_ROT,0,1);
		atthand = vessel->AddAttExhaustRef(m_exhaust_pos5,m_exhaust_ref5,ATTWIDTH,ATTHEIGHT);
		vessel->AddAttExhaustMode(atthand,ATTMODE_ROT,0,1);
		
		
		//Rot left
		
		m_exhaust_pos2= _V(-ATTCOOR2-0.1,ATTCOOR2+0.1,TRANZ+RCSOFFSET);
		m_exhaust_pos3= _V(-ATTCOOR2-0.1,-ATTCOOR2-0.1,TRANZ+RCSOFFSET);
		m_exhaust_pos4= _V(ATTCOOR2+0.1,-ATTCOOR2-0.1,TRANZ+RCSOFFSET-0.6);
		m_exhaust_pos5= _V(ATTCOOR2+0.1,ATTCOOR2+0.1,TRANZ+RCSOFFSET-0.6);
		m_exhaust_ref2 = _V(0,0.0,1);
		m_exhaust_ref3 = _V(0,0.0,1);
		m_exhaust_ref4 = _V(0.35,-0.35,-1);
		m_exhaust_ref5 = _V(0.35,0.35,-1);
		atthand = vessel->AddAttExhaustRef(m_exhaust_pos2,m_exhaust_ref2,ATTWIDTH,ATTHEIGHT);
		vessel->AddAttExhaustMode(atthand,ATTMODE_ROT,1,0);
		atthand = vessel->AddAttExhaustRef(m_exhaust_pos3,m_exhaust_ref3,ATTWIDTH,ATTHEIGHT);
		vessel->AddAttExhaustMode(atthand,ATTMODE_ROT,1,0);
		atthand = vessel->AddAttExhaustRef(m_exhaust_pos4,m_exhaust_ref4,ATTWIDTH,ATTHEIGHT);
		vessel->AddAttExhaustMode(atthand,ATTMODE_ROT,1,0);
		atthand = vessel->AddAttExhaustRef(m_exhaust_pos5,m_exhaust_ref5,ATTWIDTH,ATTHEIGHT);
		vessel->AddAttExhaustMode(atthand,ATTMODE_ROT,1,0);
		
		//Rot right
		
		m_exhaust_pos2= _V(ATTCOOR2+0.1,ATTCOOR2+0.1,TRANZ+RCSOFFSET);
		m_exhaust_pos3= _V(ATTCOOR2+0.1,-ATTCOOR2-0.1,TRANZ+RCSOFFSET);
		m_exhaust_pos4= _V(-ATTCOOR2-0.1,-ATTCOOR2-0.1,TRANZ+RCSOFFSET-0.6);
		m_exhaust_pos5= _V(-ATTCOOR2-0.1,ATTCOOR2+0.1,TRANZ+RCSOFFSET-0.6);
		m_exhaust_ref2 = _V(0,0.0,1);
		m_exhaust_ref3 = _V(0,0.0,1);
		m_exhaust_ref4 = _V(-0.35,-0.35,-1);
		m_exhaust_ref5 = _V(-0.35,0.35,-1);
		atthand = vessel->AddAttExhaustRef(m_exhaust_pos2,m_exhaust_ref2,ATTWIDTH,ATTHEIGHT);
		vessel->AddAttExhaustMode(atthand,ATTMODE_ROT,1,1);
		atthand = vessel->AddAttExhaustRef(m_exhaust_pos3,m_exhaust_ref3,ATTWIDTH,ATTHEIGHT);
		vessel->AddAttExhaustMode(atthand,ATTMODE_ROT,1,1);
		atthand = vessel->AddAttExhaustRef(m_exhaust_pos4,m_exhaust_ref4,ATTWIDTH,ATTHEIGHT);
		vessel->AddAttExhaustMode(atthand,ATTMODE_ROT,1,1);
		atthand = vessel->AddAttExhaustRef(m_exhaust_pos5,m_exhaust_ref5,ATTWIDTH,ATTHEIGHT);
		vessel->AddAttExhaustMode(atthand,ATTMODE_ROT,1,1);
		
	
		//Roll left

		m_exhaust_pos2= _V(ATTCOOR2+0.27,ATTCOOR2,TRANZ+RCSOFFSETM2);
		m_exhaust_pos3= _V(-ATTCOOR2-0.27,-ATTCOOR2,TRANZ+RCSOFFSETM2);
		m_exhaust_pos4= _V(ATTCOOR2,-ATTCOOR2-0.27,TRANZ+RCSOFFSETM2);
		m_exhaust_ref2 = _V(1,-1,0);
		m_exhaust_ref3 = _V(-1,1,0);
		m_exhaust_ref4 = _V(-1,-1,0);
		m_exhaust_pos5= _V(-ATTCOOR2,ATTCOOR2+0.27,TRANZ+RCSOFFSETM2);
		m_exhaust_ref5 = _V(1,1,0);
		
		atthand = vessel->AddAttExhaustRef(m_exhaust_pos2,m_exhaust_ref2,ATTWIDTH,ATTHEIGHT);
		vessel->AddAttExhaustMode(atthand,ATTMODE_ROT,2,1);
		atthand = vessel->AddAttExhaustRef(m_exhaust_pos3,m_exhaust_ref3,ATTWIDTH,ATTHEIGHT);
		vessel->AddAttExhaustMode(atthand,ATTMODE_ROT,2,1);
		atthand = vessel->AddAttExhaustRef(m_exhaust_pos4,m_exhaust_ref4,ATTWIDTH,ATTHEIGHT);
		vessel->AddAttExhaustMode(atthand,ATTMODE_ROT,2,1);
		atthand = vessel->AddAttExhaustRef(m_exhaust_pos5,m_exhaust_ref5,ATTWIDTH,ATTHEIGHT);
		vessel->AddAttExhaustMode(atthand,ATTMODE_ROT,2,1);
		//Roll right
		m_exhaust_pos2= _V(-ATTCOOR2-0.27,ATTCOOR2,TRANZ+RCSOFFSETM2);
		m_exhaust_pos3= _V(ATTCOOR2+0.27,-ATTCOOR2,TRANZ+RCSOFFSETM2);
		m_exhaust_pos4= _V(ATTCOOR2,ATTCOOR2+0.27,TRANZ+RCSOFFSETM2);
		m_exhaust_pos5= _V(-ATTCOOR2,-ATTCOOR2-0.27,TRANZ+RCSOFFSETM2);
		m_exhaust_ref2 = _V(-1,-1,0);
		m_exhaust_ref3 = _V(1,1,0);
		m_exhaust_ref4 = _V(-1,1,0);
		m_exhaust_ref5 = _V(1,-1,0);
		
		atthand = vessel->AddAttExhaustRef(m_exhaust_pos2,m_exhaust_ref2,ATTWIDTH,ATTHEIGHT);
		vessel->AddAttExhaustMode(atthand,ATTMODE_ROT,2,0);
		atthand = vessel->AddAttExhaustRef(m_exhaust_pos3,m_exhaust_ref3,ATTWIDTH,ATTHEIGHT);
		vessel->AddAttExhaustMode(atthand,ATTMODE_ROT,2,0);
		atthand = vessel->AddAttExhaustRef(m_exhaust_pos4,m_exhaust_ref4,ATTWIDTH,ATTHEIGHT);
		vessel->AddAttExhaustMode(atthand,ATTMODE_ROT,2,0);
		atthand = vessel->AddAttExhaustRef(m_exhaust_pos5,m_exhaust_ref5,ATTWIDTH,ATTHEIGHT);
		vessel->AddAttExhaustMode(atthand,ATTMODE_ROT,2,0);



}
void AddRCS_LM2(VESSEL *vessel,double TRANZ)
{
UINT atthand;
	const double ATTCOOR = 0;
	const double ATTCOOR2 = 1.53;
	const double ATTCOORY2 = 1.53+.28;
	const double ATTZ = 2.85;
	const double TRANCOOR = 0;
	const double TRANCOOR2 = 0.1;
	const double ATTWIDTH=.2;
	const double ATTHEIGHT=.5;
	const double TRANWIDTH=.2;
	const double TRANHEIGHT=1;
	const double RCSOFFSET=0.75;
	const double RCSOFFSETM=0.30;
	const double RCSOFFSETM2=0.47;
	const double LM2VOFS=0.28;
	
		int i;
	
	int MaxThrust=120;
				
	th_att_lin[0]=vessel-> CreateThruster (_V(2,2,-2), _V(1,0,1),120, ph_rcslm1,15000, 15000);
	th_att_lin[1]=vessel-> CreateThruster (_V(-2,2,-2), _V(-1,0,1),MaxThrust, ph_rcslm1,15000, 15000);
	th_att_lin[2]=vessel-> CreateThruster (_V(2,-2,-2), _V(1,0,1),MaxThrust, ph_rcslm1,15000, 15000);
	th_att_lin[3]=vessel-> CreateThruster (_V(-2,-2,-2), _V(-1,0,1),MaxThrust, ph_rcslm1,15000, 15000);
	th_att_lin[4]=vessel-> CreateThruster (_V(2,2,2), _V(1,0,-1),120, ph_rcslm1,15000, 15000);
	th_att_lin[5]=vessel-> CreateThruster (_V(-2,2,2), _V(-1,0,-1),MaxThrust, ph_rcslm1,15000, 15000);
	th_att_lin[6]=vessel-> CreateThruster (_V(2,-2,2), _V(1,0,-1),MaxThrust, ph_rcslm1,15000, 15000);
	th_att_lin[7]=vessel-> CreateThruster (_V(-2,-2,2), _V(-1,0,-1),MaxThrust, ph_rcslm1,15000, 15000);
	vessel->CreateThrusterGroup (th_att_lin,   4, THGROUP_ATT_FORWARD);
	vessel->CreateThrusterGroup (th_att_lin+4, 4, THGROUP_ATT_BACK);
	
	
	
	th_att_rot[2]=vessel-> CreateThruster (_V(2,2,-2), _V(0,0,1),120, ph_rcslm1,15000, 15000);
	th_att_rot[4]=vessel-> CreateThruster (_V(-2,2,-2), _V(0,0,1),MaxThrust, ph_rcslm1,15000, 15000);
	th_att_rot[3]=vessel-> CreateThruster (_V(2,-2,-2), _V(0,0,1),MaxThrust, ph_rcslm1,15000, 15000);
	th_att_rot[5]=vessel-> CreateThruster (_V(-2,-2,-2), _V(0,0,1),MaxThrust, ph_rcslm1,15000, 15000);
	th_att_rot[7]=vessel-> CreateThruster (_V(2,2,2), _V(0,0,-1),120, ph_rcslm1,15000, 15000);
	th_att_rot[0]=vessel-> CreateThruster (_V(-2,2,2), _V(0,0,-1),MaxThrust, ph_rcslm1,15000, 15000);
	th_att_rot[6]=vessel-> CreateThruster (_V(2,-2,2), _V(0,0,-1),MaxThrust, ph_rcslm1,15000, 15000);
	th_att_rot[1]=vessel-> CreateThruster (_V(-2,-2,2), _V(0,0,-1),MaxThrust, ph_rcslm1,15000, 15000);
	vessel->CreateThrusterGroup (th_att_rot,   4, THGROUP_ATT_YAWLEFT);
	vessel->CreateThrusterGroup (th_att_rot+4,   4, THGROUP_ATT_YAWRIGHT);
	
	th_att_lin[8]=vessel-> CreateThruster (_V(2,2,2), _V(-1,0,0),120, ph_rcslm1,15000, 15000);
	th_att_lin[9]=vessel-> CreateThruster (_V(2,-2,2), _V(-1,0,0),MaxThrust, ph_rcslm1,15000, 15000);
	th_att_lin[10]=vessel-> CreateThruster (_V(2,2,-2), _V(-1,0,0),MaxThrust, ph_rcslm1,15000, 15000);
	th_att_lin[11]=vessel-> CreateThruster (_V(2,-2,-2), _V(-1,0,0),MaxThrust, ph_rcslm1,15000, 15000);
	th_att_lin[12]=vessel-> CreateThruster (_V(-2,2,2), _V(1,0,0),120, ph_rcslm1,15000, 15000);
	th_att_lin[13]=vessel-> CreateThruster (_V(-2,2,-2), _V(1,0,0),MaxThrust, ph_rcslm1,15000, 15000);
	th_att_lin[14]=vessel-> CreateThruster (_V(-2,-2,2), _V(1,0,0),MaxThrust, ph_rcslm1,15000, 15000);
	th_att_lin[15]=vessel-> CreateThruster (_V(-2,-2,-2), _V(1,0,0),MaxThrust, ph_rcslm1,15000, 15000);
	
	th_att_lin[16]=vessel-> CreateThruster (_V(2,-2,2), _V(0,1,0),120, ph_rcslm1,15000, 15000);
	th_att_lin[17]=vessel-> CreateThruster (_V(-2,-2,2), _V(0,1,0),MaxThrust, ph_rcslm1,15000, 15000);
	th_att_lin[18]=vessel-> CreateThruster (_V(2,-2,-2), _V(0,1,0),MaxThrust, ph_rcslm1,15000, 15000);
	th_att_lin[19]=vessel-> CreateThruster (_V(-2,-2,-2), _V(0,1,0),MaxThrust, ph_rcslm1,15000, 15000);
	th_att_lin[20]=vessel-> CreateThruster (_V(2,2,2), _V(0,-1,0),120, ph_rcslm1,15000, 15000);
	th_att_lin[21]=vessel-> CreateThruster (_V(-2,2,2), _V(0,-1,0),MaxThrust, ph_rcslm1,15000, 15000);
	th_att_lin[22]=vessel-> CreateThruster (_V(2,2,-2), _V(0,-1,0),MaxThrust, ph_rcslm1,15000, 15000);
	th_att_lin[23]=vessel-> CreateThruster (_V(-2,2,-2), _V(0,-1,0),MaxThrust, ph_rcslm1,15000, 15000);
	
	vessel->CreateThrusterGroup (th_att_lin+16,   4, THGROUP_ATT_UP);
	vessel->CreateThrusterGroup (th_att_lin+20,   4, THGROUP_ATT_DOWN);
	vessel->CreateThrusterGroup (th_att_lin+12,  4 , THGROUP_ATT_RIGHT);
	vessel->CreateThrusterGroup (th_att_lin+8, 4, THGROUP_ATT_LEFT);
	
	th_att_rot[8]=vessel-> CreateThruster (_V(2,2,-2), _V(0,-1,0),120, ph_rcslm1,15000, 15000);
	th_att_rot[9]=vessel-> CreateThruster (_V(-2,2,-2), _V(0,-1,0),MaxThrust, ph_rcslm1,15000, 15000);
	th_att_rot[12]=vessel-> CreateThruster (_V(2,2,2), _V(0,-1,0),120, ph_rcslm1,15000, 15000);
	th_att_rot[13]=vessel-> CreateThruster (_V(-2,2,2), _V(0,-1,0),MaxThrust, ph_rcslm1,15000, 15000);
	
	th_att_rot[15]=vessel-> CreateThruster (_V(2,-2,-2), _V(0,1,0),MaxThrust, ph_rcslm1,15000, 15000);
	th_att_rot[14]=vessel-> CreateThruster (_V(-2,-2,-2), _V(0,1,0),MaxThrust, ph_rcslm1,15000, 15000);
	th_att_rot[10]=vessel-> CreateThruster (_V(2,-2,2), _V(0,1,0),MaxThrust, ph_rcslm1,15000, 15000);
	th_att_rot[11]=vessel-> CreateThruster (_V(-2,-2,2), _V(0,1,0),MaxThrust, ph_rcslm1,15000, 15000);
	
	vessel->CreateThrusterGroup (th_att_rot+12,   4, THGROUP_ATT_PITCHDOWN);
	vessel->CreateThrusterGroup (th_att_rot+8,   4, THGROUP_ATT_PITCHUP);
	
	th_att_rot[16]=vessel-> CreateThruster (_V(2,2,-2), _V(0,-1,0),120, ph_rcslm1,15000, 15000);
	th_att_rot[17]=vessel-> CreateThruster (_V(2,2,2), _V(0,-1,0),120, ph_rcslm1,15000, 15000);
	th_att_rot[18]=vessel-> CreateThruster (_V(-2,-2,2), _V(0,1,0),MaxThrust, ph_rcslm1,15000, 15000);
	th_att_rot[19]=vessel-> CreateThruster (_V(-2,-2,-2), _V(0,1,0),MaxThrust, ph_rcslm1,15000, 15000);
	th_att_rot[23]=vessel-> CreateThruster (_V(-2,2,2), _V(0,-1,0),MaxThrust, ph_rcslm1,15000, 15000);
	th_att_rot[22]=vessel-> CreateThruster (_V(2,-2,-2), _V(0,1,0),MaxThrust, ph_rcslm1,15000, 15000);
	th_att_rot[20]=vessel-> CreateThruster (_V(-2,2,-2), _V(0,-1,0),MaxThrust, ph_rcslm1,15000, 15000);
	th_att_rot[21]=vessel-> CreateThruster (_V(2,-2,2), _V(0,1,0),MaxThrust, ph_rcslm1,15000, 15000);
	
	vessel->CreateThrusterGroup (th_att_rot+20,   4, THGROUP_ATT_BANKLEFT);
	vessel->CreateThrusterGroup (th_att_rot+16,   4, THGROUP_ATT_BANKRIGHT);
	
	SURFHANDLE tex = oapiRegisterExhaustTexture ("Exhaust_atrcs");//"Exhaust2"
	//for (i = 0; i < 24; i++) vessel->AddExhaust (th_att_lin[i], 1.2, 0.18,tex);
	//for (i = 0; i < 24; i++) vessel->AddExhaust (th_att_rot[i], 1.2, 0.18,tex);
	//return;

		//lin Forward
		
		VECTOR3 m_exhaust_pos2= _V(ATTCOOR2+0.1,-ATTCOORY2-0.1+LM2VOFS,TRANZ+RCSOFFSET-0.6);
		VECTOR3 m_exhaust_pos3= _V(-ATTCOOR2-0.1,-ATTCOORY2-0.1+LM2VOFS,TRANZ+RCSOFFSET-0.6);
		VECTOR3 m_exhaust_pos4= _V(ATTCOOR2+0.1,ATTCOOR2-.28+0.1+LM2VOFS,TRANZ+RCSOFFSET-0.6);
		VECTOR3 m_exhaust_pos5= _V(-ATTCOOR2-0.1,ATTCOOR2-.28+0.1+LM2VOFS,TRANZ+RCSOFFSET-0.6);
		VECTOR3 m_exhaust_ref2 = _V(0.35,-0.35,-1);
		VECTOR3 m_exhaust_ref3 = _V(-0.35,-0.35,-1);
		VECTOR3 m_exhaust_ref4 = _V(0.35,0.35,-1);
		VECTOR3 m_exhaust_ref5 = _V(-0.35,0.35,-1);
		
		atthand = vessel->AddAttExhaustRef(m_exhaust_pos2,m_exhaust_ref2,ATTWIDTH,ATTHEIGHT);
		vessel->AddAttExhaustMode(atthand,ATTMODE_LIN,2,0);
		atthand = vessel->AddAttExhaustRef(m_exhaust_pos3,m_exhaust_ref3,ATTWIDTH,ATTHEIGHT);
		vessel->AddAttExhaustMode(atthand,ATTMODE_LIN,2,0);
		atthand = vessel->AddAttExhaustRef(m_exhaust_pos4,m_exhaust_ref4,ATTWIDTH,ATTHEIGHT);
		vessel->AddAttExhaustMode(atthand,ATTMODE_LIN,2,0);
		atthand = vessel->AddAttExhaustRef(m_exhaust_pos5,m_exhaust_ref5,ATTWIDTH,ATTHEIGHT);
		vessel->AddAttExhaustMode(atthand,ATTMODE_LIN,2,0);
	
		//lin backward
		
		m_exhaust_pos2= _V(ATTCOOR2+0.1,ATTCOOR2-.28+0.1+LM2VOFS,TRANZ+RCSOFFSET);
		m_exhaust_pos3= _V(-ATTCOOR2-0.1,ATTCOOR2-.28+0.1+LM2VOFS,TRANZ+RCSOFFSET);
		m_exhaust_pos4= _V(ATTCOOR2+0.1,-ATTCOORY2-0.1+LM2VOFS,TRANZ+RCSOFFSET);
		m_exhaust_pos5= _V(-ATTCOOR2-0.1,-ATTCOORY2-0.1+LM2VOFS,TRANZ+RCSOFFSET);
		m_exhaust_ref2 = _V(0,0.0,1);
		m_exhaust_ref3 = _V(0,0.0,1);
		m_exhaust_ref4 = _V(0,0.0,1);
		m_exhaust_ref5 = _V(0,0.0,1);
		atthand = vessel->AddAttExhaustRef(m_exhaust_pos2,m_exhaust_ref2,ATTWIDTH,ATTHEIGHT);
		vessel->AddAttExhaustMode(atthand,ATTMODE_LIN,2,1);
		atthand = vessel->AddAttExhaustRef(m_exhaust_pos3,m_exhaust_ref3,ATTWIDTH,ATTHEIGHT);
		vessel->AddAttExhaustMode(atthand,ATTMODE_LIN,2,1);
		atthand = vessel->AddAttExhaustRef(m_exhaust_pos4,m_exhaust_ref4,ATTWIDTH,ATTHEIGHT);
		vessel->AddAttExhaustMode(atthand,ATTMODE_LIN,2,1);
		atthand = vessel->AddAttExhaustRef(m_exhaust_pos5,m_exhaust_ref5,ATTWIDTH,ATTHEIGHT);
		vessel->AddAttExhaustMode(atthand,ATTMODE_LIN,2,1);
		
		//lin Left
		
		m_exhaust_pos2= _V(-ATTCOOR2-0.27,-ATTCOORY2+LM2VOFS,TRANZ+RCSOFFSETM2);
		m_exhaust_pos3= _V(-ATTCOOR2-0.27,ATTCOOR2-.28+LM2VOFS,TRANZ+RCSOFFSETM2);
		m_exhaust_ref2 = _V(-1,1,0);
		m_exhaust_ref3 = _V(-1,-1,0);
		atthand = vessel->AddAttExhaustRef(m_exhaust_pos2,m_exhaust_ref2,ATTWIDTH,ATTHEIGHT);
		vessel->AddAttExhaustMode(atthand,ATTMODE_LIN,0,0);
		atthand = vessel->AddAttExhaustRef(m_exhaust_pos3,m_exhaust_ref3,ATTWIDTH,ATTHEIGHT);
		vessel->AddAttExhaustMode(atthand,ATTMODE_LIN,0,0);
		
		//lin right
		
		m_exhaust_pos2= _V(ATTCOOR2+0.27,-ATTCOORY2+LM2VOFS,TRANZ+RCSOFFSETM2);
		m_exhaust_pos3= _V(ATTCOOR2+0.27,ATTCOOR2-.28+LM2VOFS,TRANZ+RCSOFFSETM2);
		m_exhaust_ref2 = _V(1,1,0);
		m_exhaust_ref3 = _V(1,-1,0);
		atthand = vessel->AddAttExhaustRef(m_exhaust_pos2,m_exhaust_ref2,ATTWIDTH,ATTHEIGHT);
		vessel->AddAttExhaustMode(atthand,ATTMODE_LIN,0,1);
		atthand = vessel->AddAttExhaustRef(m_exhaust_pos3,m_exhaust_ref3,ATTWIDTH,ATTHEIGHT);
		vessel->AddAttExhaustMode(atthand,ATTMODE_LIN,0,1);
		
		//lin down
		
		m_exhaust_pos2= _V(ATTCOOR2,ATTCOOR2-.28+0.27+LM2VOFS,TRANZ+RCSOFFSETM2);
		m_exhaust_pos3= _V(-ATTCOOR2,ATTCOOR2-.28+0.27+LM2VOFS,TRANZ+RCSOFFSETM2);
		m_exhaust_ref2 = _V(-1,1,0);
		m_exhaust_ref3 = _V(1,1,0);
		atthand = vessel->AddAttExhaustRef(m_exhaust_pos2,m_exhaust_ref2,ATTWIDTH,ATTHEIGHT);
		vessel->AddAttExhaustMode(atthand,ATTMODE_LIN,1,0);
		atthand = vessel->AddAttExhaustRef(m_exhaust_pos3,m_exhaust_ref3,ATTWIDTH,ATTHEIGHT);
		vessel->AddAttExhaustMode(atthand,ATTMODE_LIN,1,0);
		//lin up
		m_exhaust_pos2= _V(ATTCOOR2,-ATTCOORY2-0.27+LM2VOFS,TRANZ+RCSOFFSETM2);
		m_exhaust_pos3= _V(-ATTCOOR2,-ATTCOORY2-0.27+LM2VOFS,TRANZ+RCSOFFSETM2);
		m_exhaust_ref2 = _V(-1,-1,0);
		m_exhaust_ref3 = _V(1,-1,0);
		atthand = vessel->AddAttExhaustRef(m_exhaust_pos2,m_exhaust_ref2,ATTWIDTH,ATTHEIGHT);
		vessel->AddAttExhaustMode(atthand,ATTMODE_LIN,1,1);
		atthand = vessel->AddAttExhaustRef(m_exhaust_pos3,m_exhaust_ref3,ATTWIDTH,ATTHEIGHT);
		vessel->AddAttExhaustMode(atthand,ATTMODE_LIN,1,1);
		
		//Rot up
		
		m_exhaust_pos2= _V(ATTCOOR2+0.1,ATTCOOR2-.28+0.1+LM2VOFS,TRANZ+RCSOFFSET);
		m_exhaust_pos3= _V(-ATTCOOR2-0.1,ATTCOOR2-.28+0.1+LM2VOFS,TRANZ+RCSOFFSET);
		m_exhaust_pos4= _V(ATTCOOR2+0.1,-ATTCOORY2-0.1+LM2VOFS,TRANZ+RCSOFFSET-0.6);
		m_exhaust_pos5= _V(-ATTCOOR2-0.1,-ATTCOORY2-0.1+LM2VOFS,TRANZ+RCSOFFSET-0.6);
		m_exhaust_ref2 = _V(0,0.0,1);
		m_exhaust_ref3 = _V(0,0.0,1);
		m_exhaust_ref4 = _V(0.35,-0.35,-1);
		m_exhaust_ref5 = _V(-0.35,-0.35,-1);
		atthand = vessel->AddAttExhaustRef(m_exhaust_pos2,m_exhaust_ref2,ATTWIDTH,ATTHEIGHT);
		vessel->AddAttExhaustMode(atthand,ATTMODE_ROT,0,0);
		atthand = vessel->AddAttExhaustRef(m_exhaust_pos3,m_exhaust_ref3,ATTWIDTH,ATTHEIGHT);
		vessel->AddAttExhaustMode(atthand,ATTMODE_ROT,0,0);
		atthand = vessel->AddAttExhaustRef(m_exhaust_pos4,m_exhaust_ref4,ATTWIDTH,ATTHEIGHT);
		vessel->AddAttExhaustMode(atthand,ATTMODE_ROT,0,0);
		atthand = vessel->AddAttExhaustRef(m_exhaust_pos5,m_exhaust_ref5,ATTWIDTH,ATTHEIGHT);
		vessel->AddAttExhaustMode(atthand,ATTMODE_ROT,0,0);
		
		//Rot down
		m_exhaust_pos2= _V(ATTCOOR2+0.1,-ATTCOORY2-0.1+LM2VOFS,TRANZ+RCSOFFSET);
		m_exhaust_pos3= _V(-ATTCOOR2-0.1,-ATTCOORY2-0.1+LM2VOFS,TRANZ+RCSOFFSET);
		m_exhaust_pos4= _V(ATTCOOR2+0.1,ATTCOOR2-.28+0.1+LM2VOFS,TRANZ+RCSOFFSET-0.6);
		m_exhaust_pos5= _V(-ATTCOOR2-0.1,ATTCOOR2-.28+0.1+LM2VOFS,TRANZ+RCSOFFSET-0.6);
		m_exhaust_ref2 = _V(0,0.0,1);
		m_exhaust_ref3 = _V(0,0.0,1);
		m_exhaust_ref4 = _V(0.35,0.35,-1);
		m_exhaust_ref5 = _V(-0.35,0.35,-1);
		atthand = vessel->AddAttExhaustRef(m_exhaust_pos2,m_exhaust_ref2,ATTWIDTH,ATTHEIGHT);
		vessel->AddAttExhaustMode(atthand,ATTMODE_ROT,0,1);
		atthand = vessel->AddAttExhaustRef(m_exhaust_pos3,m_exhaust_ref3,ATTWIDTH,ATTHEIGHT);
		vessel->AddAttExhaustMode(atthand,ATTMODE_ROT,0,1);
		atthand = vessel->AddAttExhaustRef(m_exhaust_pos4,m_exhaust_ref4,ATTWIDTH,ATTHEIGHT);
		vessel->AddAttExhaustMode(atthand,ATTMODE_ROT,0,1);
		atthand = vessel->AddAttExhaustRef(m_exhaust_pos5,m_exhaust_ref5,ATTWIDTH,ATTHEIGHT);
		vessel->AddAttExhaustMode(atthand,ATTMODE_ROT,0,1);
		
		
		//Rot left
		
		m_exhaust_pos2= _V(-ATTCOOR2-0.1,ATTCOOR2-.28+0.1+LM2VOFS,TRANZ+RCSOFFSET);
		m_exhaust_pos3= _V(-ATTCOOR2-0.1,-ATTCOORY2-0.1+LM2VOFS,TRANZ+RCSOFFSET);
		m_exhaust_pos4= _V(ATTCOOR2+0.1,-ATTCOORY2-0.1+LM2VOFS,TRANZ+RCSOFFSET-0.6);
		m_exhaust_pos5= _V(ATTCOOR2+0.1,ATTCOOR2-.28+0.1+LM2VOFS,TRANZ+RCSOFFSET-0.6);
		m_exhaust_ref2 = _V(0,0.0,1);
		m_exhaust_ref3 = _V(0,0.0,1);
		m_exhaust_ref4 = _V(0.35,-0.35,-1);
		m_exhaust_ref5 = _V(0.35,0.35,-1);
		atthand = vessel->AddAttExhaustRef(m_exhaust_pos2,m_exhaust_ref2,ATTWIDTH,ATTHEIGHT);
		vessel->AddAttExhaustMode(atthand,ATTMODE_ROT,1,0);
		atthand = vessel->AddAttExhaustRef(m_exhaust_pos3,m_exhaust_ref3,ATTWIDTH,ATTHEIGHT);
		vessel->AddAttExhaustMode(atthand,ATTMODE_ROT,1,0);
		atthand = vessel->AddAttExhaustRef(m_exhaust_pos4,m_exhaust_ref4,ATTWIDTH,ATTHEIGHT);
		vessel->AddAttExhaustMode(atthand,ATTMODE_ROT,1,0);
		atthand = vessel->AddAttExhaustRef(m_exhaust_pos5,m_exhaust_ref5,ATTWIDTH,ATTHEIGHT);
		vessel->AddAttExhaustMode(atthand,ATTMODE_ROT,1,0);
		
		//Rot right
		
		m_exhaust_pos2= _V(ATTCOOR2+0.1,ATTCOOR2-.28+0.1+LM2VOFS,TRANZ+RCSOFFSET);
		m_exhaust_pos3= _V(ATTCOOR2+0.1,-ATTCOORY2-0.1+LM2VOFS,TRANZ+RCSOFFSET);
		m_exhaust_pos4= _V(-ATTCOOR2-0.1,-ATTCOORY2-0.1+LM2VOFS,TRANZ+RCSOFFSET-0.6);
		m_exhaust_pos5= _V(-ATTCOOR2-0.1,ATTCOOR2-.28+0.1+LM2VOFS,TRANZ+RCSOFFSET-0.6);
		m_exhaust_ref2 = _V(0,0.0,1);
		m_exhaust_ref3 = _V(0,0.0,1);
		m_exhaust_ref4 = _V(-0.35,-0.35,-1);
		m_exhaust_ref5 = _V(-0.35,0.35,-1);
		atthand = vessel->AddAttExhaustRef(m_exhaust_pos2,m_exhaust_ref2,ATTWIDTH,ATTHEIGHT);
		vessel->AddAttExhaustMode(atthand,ATTMODE_ROT,1,1);
		atthand = vessel->AddAttExhaustRef(m_exhaust_pos3,m_exhaust_ref3,ATTWIDTH,ATTHEIGHT);
		vessel->AddAttExhaustMode(atthand,ATTMODE_ROT,1,1);
		atthand = vessel->AddAttExhaustRef(m_exhaust_pos4,m_exhaust_ref4,ATTWIDTH,ATTHEIGHT);
		vessel->AddAttExhaustMode(atthand,ATTMODE_ROT,1,1);
		atthand = vessel->AddAttExhaustRef(m_exhaust_pos5,m_exhaust_ref5,ATTWIDTH,ATTHEIGHT);
		vessel->AddAttExhaustMode(atthand,ATTMODE_ROT,1,1);
		
	
		//Roll left

		m_exhaust_pos2= _V(ATTCOOR2+0.27,ATTCOOR2-.28+LM2VOFS,TRANZ+RCSOFFSETM2);
		m_exhaust_pos3= _V(-ATTCOOR2-0.27,-ATTCOORY2+LM2VOFS,TRANZ+RCSOFFSETM2);
		m_exhaust_pos4= _V(ATTCOOR2,-ATTCOORY2-0.27+LM2VOFS,TRANZ+RCSOFFSETM2);
		m_exhaust_ref2 = _V(1,-1,0);
		m_exhaust_ref3 = _V(-1,1,0);
		m_exhaust_ref4 = _V(-1,-1,0);
		m_exhaust_pos5= _V(-ATTCOOR2,ATTCOOR2-.28+0.27+LM2VOFS,TRANZ+RCSOFFSETM2);
		m_exhaust_ref5 = _V(1,1,0);
		
		atthand = vessel->AddAttExhaustRef(m_exhaust_pos2,m_exhaust_ref2,ATTWIDTH,ATTHEIGHT);
		vessel->AddAttExhaustMode(atthand,ATTMODE_ROT,2,1);
		atthand = vessel->AddAttExhaustRef(m_exhaust_pos3,m_exhaust_ref3,ATTWIDTH,ATTHEIGHT);
		vessel->AddAttExhaustMode(atthand,ATTMODE_ROT,2,1);
		atthand = vessel->AddAttExhaustRef(m_exhaust_pos4,m_exhaust_ref4,ATTWIDTH,ATTHEIGHT);
		vessel->AddAttExhaustMode(atthand,ATTMODE_ROT,2,1);
		atthand = vessel->AddAttExhaustRef(m_exhaust_pos5,m_exhaust_ref5,ATTWIDTH,ATTHEIGHT);
		vessel->AddAttExhaustMode(atthand,ATTMODE_ROT,2,1);
		//Roll right
		m_exhaust_pos2= _V(-ATTCOOR2-0.27,ATTCOOR2-.28+LM2VOFS,TRANZ+RCSOFFSETM2);
		m_exhaust_pos3= _V(ATTCOOR2+0.27,-ATTCOORY2+LM2VOFS,TRANZ+RCSOFFSETM2);
		m_exhaust_pos4= _V(ATTCOOR2,ATTCOOR2-.28+0.27+LM2VOFS,TRANZ+RCSOFFSETM2);
		m_exhaust_pos5= _V(-ATTCOOR2,-ATTCOORY2-0.27+LM2VOFS,TRANZ+RCSOFFSETM2);
		m_exhaust_ref2 = _V(-1,-1,0);
		m_exhaust_ref3 = _V(1,1,0);
		m_exhaust_ref4 = _V(-1,1,0);
		m_exhaust_ref5 = _V(1,-1,0);
		
		atthand = vessel->AddAttExhaustRef(m_exhaust_pos2,m_exhaust_ref2,ATTWIDTH,ATTHEIGHT);
		vessel->AddAttExhaustMode(atthand,ATTMODE_ROT,2,0);
		atthand = vessel->AddAttExhaustRef(m_exhaust_pos3,m_exhaust_ref3,ATTWIDTH,ATTHEIGHT);
		vessel->AddAttExhaustMode(atthand,ATTMODE_ROT,2,0);
		atthand = vessel->AddAttExhaustRef(m_exhaust_pos4,m_exhaust_ref4,ATTWIDTH,ATTHEIGHT);
		vessel->AddAttExhaustMode(atthand,ATTMODE_ROT,2,0);
		atthand = vessel->AddAttExhaustRef(m_exhaust_pos5,m_exhaust_ref5,ATTWIDTH,ATTHEIGHT);
		vessel->AddAttExhaustMode(atthand,ATTMODE_ROT,2,0);



}
void AddRCS_LMH(VESSEL *vessel,double TRANZ)
{
	
	UINT atthand;
	const double ATTCOOR = 0;
	const double ATTCOOR2 = 1.53;
	const double ATTZ = 2.85;
	const double TRANCOOR = 0;
	const double TRANCOOR2 = 0.1;
	const double ATTWIDTH=.2;
	const double ATTHEIGHT=.5;
	const double TRANWIDTH=.2;
	const double TRANHEIGHT=1;
	const double RCSOFFSET=0.75;
	const double RCSOFFSETM=0.30;
	const double RCSOFFSETM2=0.47;

	int i;
	
	int MaxThrust=120;
				
	th_att_lin[0]=vessel-> CreateThruster (_V(2,2,-2), _V(1,0,1),120, ph_rcslm1,15000, 15000);
	th_att_lin[1]=vessel-> CreateThruster (_V(-2,2,-2), _V(-1,0,1),MaxThrust, ph_rcslm1,15000, 15000);
	th_att_lin[2]=vessel-> CreateThruster (_V(2,-2,-2), _V(1,0,1),MaxThrust, ph_rcslm1,15000, 15000);
	th_att_lin[3]=vessel-> CreateThruster (_V(-2,-2,-2), _V(-1,0,1),MaxThrust, ph_rcslm1,15000, 15000);
	th_att_lin[4]=vessel-> CreateThruster (_V(2,2,2), _V(1,0,-1),120, ph_rcslm1,15000, 15000);
	th_att_lin[5]=vessel-> CreateThruster (_V(-2,2,2), _V(-1,0,-1),MaxThrust, ph_rcslm1,15000, 15000);
	th_att_lin[6]=vessel-> CreateThruster (_V(2,-2,2), _V(1,0,-1),MaxThrust, ph_rcslm1,15000, 15000);
	th_att_lin[7]=vessel-> CreateThruster (_V(-2,-2,2), _V(-1,0,-1),MaxThrust, ph_rcslm1,15000, 15000);
	vessel->CreateThrusterGroup (th_att_lin,   4, THGROUP_ATT_FORWARD);
	vessel->CreateThrusterGroup (th_att_lin+4, 4, THGROUP_ATT_BACK);
	
	
	
	th_att_rot[2]=vessel-> CreateThruster (_V(2,2,-2), _V(0,0,1),120, ph_rcslm1,15000, 15000);
	th_att_rot[4]=vessel-> CreateThruster (_V(-2,2,-2), _V(0,0,1),MaxThrust, ph_rcslm1,15000, 15000);
	th_att_rot[3]=vessel-> CreateThruster (_V(2,-2,-2), _V(0,0,1),MaxThrust, ph_rcslm1,15000, 15000);
	th_att_rot[5]=vessel-> CreateThruster (_V(-2,-2,-2), _V(0,0,1),MaxThrust, ph_rcslm1,15000, 15000);
	th_att_rot[7]=vessel-> CreateThruster (_V(2,2,2), _V(0,0,-1),120, ph_rcslm1,15000, 15000);
	th_att_rot[0]=vessel-> CreateThruster (_V(-2,2,2), _V(0,0,-1),MaxThrust, ph_rcslm1,15000, 15000);
	th_att_rot[6]=vessel-> CreateThruster (_V(2,-2,2), _V(0,0,-1),MaxThrust, ph_rcslm1,15000, 15000);
	th_att_rot[1]=vessel-> CreateThruster (_V(-2,-2,2), _V(0,0,-1),MaxThrust, ph_rcslm1,15000, 15000);
	vessel->CreateThrusterGroup (th_att_rot,   4, THGROUP_ATT_YAWLEFT);
	vessel->CreateThrusterGroup (th_att_rot+4,   4, THGROUP_ATT_YAWRIGHT);
	
	th_att_lin[8]=vessel-> CreateThruster (_V(2,2,2), _V(-1,0,0),120, ph_rcslm1,15000, 15000);
	th_att_lin[9]=vessel-> CreateThruster (_V(2,-2,2), _V(-1,0,0),MaxThrust, ph_rcslm1,15000, 15000);
	th_att_lin[10]=vessel-> CreateThruster (_V(2,2,-2), _V(-1,0,0),MaxThrust, ph_rcslm1,15000, 15000);
	th_att_lin[11]=vessel-> CreateThruster (_V(2,-2,-2), _V(-1,0,0),MaxThrust, ph_rcslm1,15000, 15000);
	th_att_lin[12]=vessel-> CreateThruster (_V(-2,2,2), _V(1,0,0),120, ph_rcslm1,15000, 15000);
	th_att_lin[13]=vessel-> CreateThruster (_V(-2,2,-2), _V(1,0,0),MaxThrust, ph_rcslm1,15000, 15000);
	th_att_lin[14]=vessel-> CreateThruster (_V(-2,-2,2), _V(1,0,0),MaxThrust, ph_rcslm1,15000, 15000);
	th_att_lin[15]=vessel-> CreateThruster (_V(-2,-2,-2), _V(1,0,0),MaxThrust, ph_rcslm1,15000, 15000);
	
	th_att_lin[16]=vessel-> CreateThruster (_V(2,-2,2), _V(0,1,0),120, ph_rcslm1,15000, 15000);
	th_att_lin[17]=vessel-> CreateThruster (_V(-2,-2,2), _V(0,1,0),MaxThrust, ph_rcslm1,15000, 15000);
	th_att_lin[18]=vessel-> CreateThruster (_V(2,-2,-2), _V(0,1,0),MaxThrust, ph_rcslm1,15000, 15000);
	th_att_lin[19]=vessel-> CreateThruster (_V(-2,-2,-2), _V(0,1,0),MaxThrust, ph_rcslm1,15000, 15000);
	th_att_lin[20]=vessel-> CreateThruster (_V(2,2,2), _V(0,-1,0),120, ph_rcslm1,15000, 15000);
	th_att_lin[21]=vessel-> CreateThruster (_V(-2,2,2), _V(0,-1,0),MaxThrust, ph_rcslm1,15000, 15000);
	th_att_lin[22]=vessel-> CreateThruster (_V(2,2,-2), _V(0,-1,0),MaxThrust, ph_rcslm1,15000, 15000);
	th_att_lin[23]=vessel-> CreateThruster (_V(-2,2,-2), _V(0,-1,0),MaxThrust, ph_rcslm1,15000, 15000);
	
	vessel->CreateThrusterGroup (th_att_lin+16,   4, THGROUP_ATT_UP);
	vessel->CreateThrusterGroup (th_att_lin+20,   4, THGROUP_ATT_DOWN);
	vessel->CreateThrusterGroup (th_att_lin+12,  4 , THGROUP_ATT_RIGHT);
	vessel->CreateThrusterGroup (th_att_lin+8, 4, THGROUP_ATT_LEFT);
	
	th_att_rot[8]=vessel-> CreateThruster (_V(2,2,-2), _V(0,-1,0),120, ph_rcslm1,15000, 15000);
	th_att_rot[9]=vessel-> CreateThruster (_V(-2,2,-2), _V(0,-1,0),MaxThrust, ph_rcslm1,15000, 15000);
	th_att_rot[12]=vessel-> CreateThruster (_V(2,2,2), _V(0,-1,0),120, ph_rcslm1,15000, 15000);
	th_att_rot[13]=vessel-> CreateThruster (_V(-2,2,2), _V(0,-1,0),MaxThrust, ph_rcslm1,15000, 15000);
	
	th_att_rot[15]=vessel-> CreateThruster (_V(2,-2,-2), _V(0,1,0),MaxThrust, ph_rcslm1,15000, 15000);
	th_att_rot[14]=vessel-> CreateThruster (_V(-2,-2,-2), _V(0,1,0),MaxThrust, ph_rcslm1,15000, 15000);
	th_att_rot[10]=vessel-> CreateThruster (_V(2,-2,2), _V(0,1,0),MaxThrust, ph_rcslm1,15000, 15000);
	th_att_rot[11]=vessel-> CreateThruster (_V(-2,-2,2), _V(0,1,0),MaxThrust, ph_rcslm1,15000, 15000);
	
	vessel->CreateThrusterGroup (th_att_rot+12,   4, THGROUP_ATT_PITCHDOWN);
	vessel->CreateThrusterGroup (th_att_rot+8,   4, THGROUP_ATT_PITCHUP);
	
	th_att_rot[16]=vessel-> CreateThruster (_V(2,2,-2), _V(0,-1,0),120, ph_rcslm1,15000, 15000);
	th_att_rot[17]=vessel-> CreateThruster (_V(2,2,2), _V(0,-1,0),120, ph_rcslm1,15000, 15000);
	th_att_rot[18]=vessel-> CreateThruster (_V(-2,-2,2), _V(0,1,0),MaxThrust, ph_rcslm1,15000, 15000);
	th_att_rot[19]=vessel-> CreateThruster (_V(-2,-2,-2), _V(0,1,0),MaxThrust, ph_rcslm1,15000, 15000);
	th_att_rot[23]=vessel-> CreateThruster (_V(-2,2,2), _V(0,-1,0),MaxThrust, ph_rcslm1,15000, 15000);
	th_att_rot[22]=vessel-> CreateThruster (_V(2,-2,-2), _V(0,1,0),MaxThrust, ph_rcslm1,15000, 15000);
	th_att_rot[20]=vessel-> CreateThruster (_V(-2,2,-2), _V(0,-1,0),MaxThrust, ph_rcslm1,15000, 15000);
	th_att_rot[21]=vessel-> CreateThruster (_V(2,-2,2), _V(0,1,0),MaxThrust, ph_rcslm1,15000, 15000);
	
	vessel->CreateThrusterGroup (th_att_rot+20,   4, THGROUP_ATT_BANKLEFT);
	vessel->CreateThrusterGroup (th_att_rot+16,   4, THGROUP_ATT_BANKRIGHT);
	
		//lin Forward
		
		VECTOR3 m_exhaust_pos2= _V(ATTCOOR2,ATTCOOR2-0.33,TRANZ+RCSOFFSET-0.6);
		VECTOR3 m_exhaust_pos3= _V(-ATTCOOR2,ATTCOOR2-0.33,TRANZ+RCSOFFSET-0.6);
		VECTOR3 m_exhaust_ref2 = _V(-1,0,-1);
		VECTOR3 m_exhaust_ref3 = _V(1,0,-1);
		//just for vector init
		VECTOR3 m_exhaust_pos4= _V(ATTCOOR2+0.1,-ATTCOOR2-0.1,TRANZ+RCSOFFSET);
		VECTOR3 m_exhaust_pos5= _V(-ATTCOOR2-0.1,-ATTCOOR2-0.1,TRANZ+RCSOFFSET);
		VECTOR3 m_exhaust_ref4 = _V(0,0.0,1);
		VECTOR3 m_exhaust_ref5 = _V(0,0.0,1);
		
		atthand = vessel->AddAttExhaustRef(m_exhaust_pos2,m_exhaust_ref2,ATTWIDTH,ATTHEIGHT);
		vessel->AddAttExhaustMode(atthand,ATTMODE_LIN,2,0);
		atthand = vessel->AddAttExhaustRef(m_exhaust_pos3,m_exhaust_ref3,ATTWIDTH,ATTHEIGHT);
		vessel->AddAttExhaustMode(atthand,ATTMODE_LIN,2,0);
		
		//lin backward
		
		m_exhaust_pos2= _V(ATTCOOR2,ATTCOOR2-0.33,TRANZ+RCSOFFSET+2.9);
		m_exhaust_pos3= _V(-ATTCOOR2,ATTCOOR2-0.33,TRANZ+RCSOFFSET+2.9);
		m_exhaust_ref2 = _V(-1,0,1);
		m_exhaust_ref3 = _V(1,0,1);
		atthand = vessel->AddAttExhaustRef(m_exhaust_pos2,m_exhaust_ref2,ATTWIDTH,ATTHEIGHT);
		vessel->AddAttExhaustMode(atthand,ATTMODE_LIN,2,1);
		atthand = vessel->AddAttExhaustRef(m_exhaust_pos3,m_exhaust_ref3,ATTWIDTH,ATTHEIGHT);
		vessel->AddAttExhaustMode(atthand,ATTMODE_LIN,2,1);
		
		//lin Right
		
		m_exhaust_pos2= _V(-ATTCOOR2-0.33,ATTCOOR2-0.33,TRANZ+RCSOFFSETM2);
		m_exhaust_pos3= _V(-ATTCOOR2-0.33,ATTCOOR2-0.33,TRANZ+RCSOFFSETM2+2.9);
		m_exhaust_ref2 = _V(-1,0,0.75);
		m_exhaust_ref3 = _V(-1,0,-0.75);
		atthand = vessel->AddAttExhaustRef(m_exhaust_pos2,m_exhaust_ref2,ATTWIDTH,ATTHEIGHT);
		vessel->AddAttExhaustMode(atthand,ATTMODE_LIN,0,0);
		atthand = vessel->AddAttExhaustRef(m_exhaust_pos3,m_exhaust_ref3,ATTWIDTH,ATTHEIGHT);
		vessel->AddAttExhaustMode(atthand,ATTMODE_LIN,0,0);
		
		//lin Left
		
		m_exhaust_pos2= _V(ATTCOOR2+0.33,ATTCOOR2-0.33,TRANZ+RCSOFFSETM2);
		m_exhaust_pos3= _V(ATTCOOR2+0.33,ATTCOOR2-0.33,TRANZ+RCSOFFSETM2+2.9);
		m_exhaust_ref2 = _V(1,0,0.75);
		m_exhaust_ref3 = _V(1,0,-0.75);
		atthand = vessel->AddAttExhaustRef(m_exhaust_pos2,m_exhaust_ref2,ATTWIDTH,ATTHEIGHT);
		vessel->AddAttExhaustMode(atthand,ATTMODE_LIN,0,1);
		atthand = vessel->AddAttExhaustRef(m_exhaust_pos3,m_exhaust_ref3,ATTWIDTH,ATTHEIGHT);
		vessel->AddAttExhaustMode(atthand,ATTMODE_LIN,0,1);
		
		//lin up
		
		m_exhaust_pos2= _V(ATTCOOR2+.1,ATTCOOR2-0.1,TRANZ+RCSOFFSETM2-0.22);
		m_exhaust_pos3= _V(-ATTCOOR2-.1,ATTCOOR2-0.1,TRANZ+RCSOFFSETM2-0.22);
		m_exhaust_pos4= _V(ATTCOOR2+.1,ATTCOOR2-0.1,TRANZ+RCSOFFSETM2-0.22+3.3);
		m_exhaust_pos5= _V(-ATTCOOR2-.1,ATTCOOR2-0.1,TRANZ+RCSOFFSETM2-0.22+3.3);
		m_exhaust_ref2 = _V(0,1,0);
		m_exhaust_ref3 = _V(0,1,0);
		m_exhaust_ref4 = _V(0,1,0);
		m_exhaust_ref5 = _V(0,1,0);
		atthand = vessel->AddAttExhaustRef(m_exhaust_pos2,m_exhaust_ref2,ATTWIDTH,ATTHEIGHT);
		vessel->AddAttExhaustMode(atthand,ATTMODE_LIN,1,1);
		atthand = vessel->AddAttExhaustRef(m_exhaust_pos3,m_exhaust_ref3,ATTWIDTH,ATTHEIGHT);
		vessel->AddAttExhaustMode(atthand,ATTMODE_LIN,1,1);
		atthand = vessel->AddAttExhaustRef(m_exhaust_pos4,m_exhaust_ref4,ATTWIDTH,ATTHEIGHT);
		vessel->AddAttExhaustMode(atthand,ATTMODE_LIN,1,1);
		atthand = vessel->AddAttExhaustRef(m_exhaust_pos5,m_exhaust_ref5,ATTWIDTH,ATTHEIGHT);
		vessel->AddAttExhaustMode(atthand,ATTMODE_LIN,1,1);
		//lin down
		m_exhaust_pos2= _V(ATTCOOR2+.1,ATTCOOR2-.6,TRANZ+RCSOFFSETM2-0.22);
		m_exhaust_pos3= _V(-ATTCOOR2-.1,ATTCOOR2-.6,TRANZ+RCSOFFSETM2-0.22);
		m_exhaust_pos4= _V(ATTCOOR2+.1,ATTCOOR2-.6,TRANZ+RCSOFFSETM2-0.22+3.3);
		m_exhaust_pos5= _V(-ATTCOOR2-.1,ATTCOOR2-.6,TRANZ+RCSOFFSETM2-0.22+3.3);
		m_exhaust_ref2 = _V(0.35,-1,-0.35);
		m_exhaust_ref3 = _V(-0.35,-1,-0.35);
		m_exhaust_ref4 = _V(0.35,-1,0.35);
		m_exhaust_ref5 = _V(-0.35,-1,0.35);
		atthand = vessel->AddAttExhaustRef(m_exhaust_pos2,m_exhaust_ref2,ATTWIDTH,ATTHEIGHT);
		vessel->AddAttExhaustMode(atthand,ATTMODE_LIN,1,0);
		atthand = vessel->AddAttExhaustRef(m_exhaust_pos3,m_exhaust_ref3,ATTWIDTH,ATTHEIGHT);
		vessel->AddAttExhaustMode(atthand,ATTMODE_LIN,1,0);
		atthand = vessel->AddAttExhaustRef(m_exhaust_pos4,m_exhaust_ref4,ATTWIDTH,ATTHEIGHT);
		vessel->AddAttExhaustMode(atthand,ATTMODE_LIN,1,0);
		atthand = vessel->AddAttExhaustRef(m_exhaust_pos5,m_exhaust_ref5,ATTWIDTH,ATTHEIGHT);
		vessel->AddAttExhaustMode(atthand,ATTMODE_LIN,1,0);
		//Rot up
		
		m_exhaust_pos2= _V(ATTCOOR2+.1,ATTCOOR2-0.1,TRANZ+RCSOFFSETM2-0.22);
		m_exhaust_pos3= _V(-ATTCOOR2-.1,ATTCOOR2-0.1,TRANZ+RCSOFFSETM2-0.22);
		m_exhaust_ref2 = _V(0,1,0);
		m_exhaust_ref3 = _V(0,1,0);
		m_exhaust_pos4= _V(ATTCOOR2+.1,ATTCOOR2-.6,TRANZ+RCSOFFSETM2-0.22+3.3);
		m_exhaust_pos5= _V(-ATTCOOR2-.1,ATTCOOR2-.6,TRANZ+RCSOFFSETM2-0.22+3.3);
		m_exhaust_ref4 = _V(0.35,-1,0.35);
		m_exhaust_ref5 = _V(-0.35,-1,0.35);
		
	
		atthand = vessel->AddAttExhaustRef(m_exhaust_pos2,m_exhaust_ref2,ATTWIDTH,ATTHEIGHT);
		vessel->AddAttExhaustMode(atthand,ATTMODE_ROT,0,0);
		atthand = vessel->AddAttExhaustRef(m_exhaust_pos3,m_exhaust_ref3,ATTWIDTH,ATTHEIGHT);
		vessel->AddAttExhaustMode(atthand,ATTMODE_ROT,0,0);
		atthand = vessel->AddAttExhaustRef(m_exhaust_pos4,m_exhaust_ref4,ATTWIDTH,ATTHEIGHT);
		vessel->AddAttExhaustMode(atthand,ATTMODE_ROT,0,0);
		atthand = vessel->AddAttExhaustRef(m_exhaust_pos5,m_exhaust_ref5,ATTWIDTH,ATTHEIGHT);
		vessel->AddAttExhaustMode(atthand,ATTMODE_ROT,0,0);
		
		//Rot down
		m_exhaust_pos4= _V(ATTCOOR2+.1,ATTCOOR2-0.1,TRANZ+RCSOFFSETM2-0.22+3.3);
		m_exhaust_pos5= _V(-ATTCOOR2-.1,ATTCOOR2-0.1,TRANZ+RCSOFFSETM2-0.22+3.3);
		m_exhaust_ref4 = _V(0,1,0);
		m_exhaust_ref5 = _V(0,1,0);
		
		
		m_exhaust_pos2= _V(ATTCOOR2+.1,ATTCOOR2-.6,TRANZ+RCSOFFSETM2-0.22);
		m_exhaust_pos3= _V(-ATTCOOR2-.1,ATTCOOR2-.6,TRANZ+RCSOFFSETM2-0.22);
		m_exhaust_ref2 = _V(0.35,-1,-0.35);
		m_exhaust_ref3 = _V(-0.35,-1,-0.35);
		atthand = vessel->AddAttExhaustRef(m_exhaust_pos2,m_exhaust_ref2,ATTWIDTH,ATTHEIGHT);
		vessel->AddAttExhaustMode(atthand,ATTMODE_ROT,0,1);
		atthand = vessel->AddAttExhaustRef(m_exhaust_pos3,m_exhaust_ref3,ATTWIDTH,ATTHEIGHT);
		vessel->AddAttExhaustMode(atthand,ATTMODE_ROT,0,1);
		atthand = vessel->AddAttExhaustRef(m_exhaust_pos4,m_exhaust_ref4,ATTWIDTH,ATTHEIGHT);
		vessel->AddAttExhaustMode(atthand,ATTMODE_ROT,0,1);
		atthand = vessel->AddAttExhaustRef(m_exhaust_pos5,m_exhaust_ref5,ATTWIDTH,ATTHEIGHT);
		vessel->AddAttExhaustMode(atthand,ATTMODE_ROT,0,1);
		
		
		//Rot left
		
		m_exhaust_pos2= _V(ATTCOOR2+0.33,ATTCOOR2-0.33,TRANZ+RCSOFFSETM2+2.9);
		m_exhaust_ref2 = _V(1,0,-1);
		m_exhaust_pos3= _V(ATTCOOR2,ATTCOOR2-0.33,TRANZ+RCSOFFSET-0.6);
		m_exhaust_ref3 = _V(-1,0,-1);
		m_exhaust_pos4= _V(-ATTCOOR2-0.33,ATTCOOR2-0.33,TRANZ+RCSOFFSETM2);
		m_exhaust_ref4 = _V(-1,0,1);
		m_exhaust_pos5= _V(-ATTCOOR2,ATTCOOR2-0.33,TRANZ+RCSOFFSET+2.9);
		m_exhaust_ref5 = _V(1,0,1);
		atthand = vessel->AddAttExhaustRef(m_exhaust_pos2,m_exhaust_ref2,ATTWIDTH,ATTHEIGHT);
		vessel->AddAttExhaustMode(atthand,ATTMODE_ROT,1,0);
		atthand = vessel->AddAttExhaustRef(m_exhaust_pos3,m_exhaust_ref3,ATTWIDTH,ATTHEIGHT);
		vessel->AddAttExhaustMode(atthand,ATTMODE_ROT,1,0);
		atthand = vessel->AddAttExhaustRef(m_exhaust_pos4,m_exhaust_ref4,ATTWIDTH,ATTHEIGHT);
		vessel->AddAttExhaustMode(atthand,ATTMODE_ROT,1,0);
		atthand = vessel->AddAttExhaustRef(m_exhaust_pos5,m_exhaust_ref5,ATTWIDTH,ATTHEIGHT);
		vessel->AddAttExhaustMode(atthand,ATTMODE_ROT,1,0);
		
		//Rot right
		
		m_exhaust_pos2= _V(-ATTCOOR2-0.33,ATTCOOR2-0.33,TRANZ+RCSOFFSETM2+2.9);
		m_exhaust_ref2 = _V(-1,0,-1);
		m_exhaust_pos3= _V(-ATTCOOR2,ATTCOOR2-0.33,TRANZ+RCSOFFSET-0.6);
		m_exhaust_ref3 = _V(1,0,-1);
		m_exhaust_pos4= _V(ATTCOOR2+0.33,ATTCOOR2-0.33,TRANZ+RCSOFFSETM2);
		m_exhaust_ref4 = _V(1,0,1);
		m_exhaust_pos5= _V(ATTCOOR2,ATTCOOR2-0.33,TRANZ+RCSOFFSET+2.9);
		m_exhaust_ref5 = _V(-1,0,1);
		
		atthand = vessel->AddAttExhaustRef(m_exhaust_pos2,m_exhaust_ref2,ATTWIDTH,ATTHEIGHT);
		vessel->AddAttExhaustMode(atthand,ATTMODE_ROT,1,1);
		atthand = vessel->AddAttExhaustRef(m_exhaust_pos3,m_exhaust_ref3,ATTWIDTH,ATTHEIGHT);
		vessel->AddAttExhaustMode(atthand,ATTMODE_ROT,1,1);
		atthand = vessel->AddAttExhaustRef(m_exhaust_pos4,m_exhaust_ref4,ATTWIDTH,ATTHEIGHT);
		vessel->AddAttExhaustMode(atthand,ATTMODE_ROT,1,1);
		atthand = vessel->AddAttExhaustRef(m_exhaust_pos5,m_exhaust_ref5,ATTWIDTH,ATTHEIGHT);
		vessel->AddAttExhaustMode(atthand,ATTMODE_ROT,1,1);
		
	
		//Roll left

		m_exhaust_pos2= _V(ATTCOOR2+.1,ATTCOOR2-0.1,TRANZ+RCSOFFSETM2-0.22);
		m_exhaust_pos4= _V(ATTCOOR2+.1,ATTCOOR2-0.1,TRANZ+RCSOFFSETM2-0.22+3.3);
		m_exhaust_ref2 = _V(0,1,0);
		m_exhaust_ref4 = _V(0,1,0);
		
		
		
		
		m_exhaust_pos3= _V(-ATTCOOR2-.1,ATTCOOR2-.6,TRANZ+RCSOFFSETM2-0.22);
		m_exhaust_pos5= _V(-ATTCOOR2-.1,ATTCOOR2-.6,TRANZ+RCSOFFSETM2-0.22+3.3);
		m_exhaust_ref3 = _V(-0.35,-1,-0.35);
		m_exhaust_ref5 = _V(-0.35,-1,0.35);
		
		atthand = vessel->AddAttExhaustRef(m_exhaust_pos2,m_exhaust_ref2,ATTWIDTH,ATTHEIGHT);
		vessel->AddAttExhaustMode(atthand,ATTMODE_ROT,2,0);
		atthand = vessel->AddAttExhaustRef(m_exhaust_pos3,m_exhaust_ref3,ATTWIDTH,ATTHEIGHT);
		vessel->AddAttExhaustMode(atthand,ATTMODE_ROT,2,0);
		atthand = vessel->AddAttExhaustRef(m_exhaust_pos4,m_exhaust_ref4,ATTWIDTH,ATTHEIGHT);
		vessel->AddAttExhaustMode(atthand,ATTMODE_ROT,2,0);
		atthand = vessel->AddAttExhaustRef(m_exhaust_pos5,m_exhaust_ref5,ATTWIDTH,ATTHEIGHT);
		vessel->AddAttExhaustMode(atthand,ATTMODE_ROT,2,0);
		//Roll right
		
		m_exhaust_pos3= _V(-ATTCOOR2-.1,ATTCOOR2-0.1,TRANZ+RCSOFFSETM2-0.22);
		m_exhaust_pos5= _V(-ATTCOOR2-.1,ATTCOOR2-0.1,TRANZ+RCSOFFSETM2-0.22+3.3);
		m_exhaust_ref3 = _V(0,1,0);
		m_exhaust_ref5 = _V(0,1,0);
		m_exhaust_pos2= _V(ATTCOOR2+.1,ATTCOOR2-.6,TRANZ+RCSOFFSETM2-0.22);
		m_exhaust_pos4= _V(ATTCOOR2+.1,ATTCOOR2-.6,TRANZ+RCSOFFSETM2-0.22+3.3);
		m_exhaust_ref2 = _V(0.35,-1,-0.35);
		m_exhaust_ref4 = _V(0.35,-1,0.35);
		
		
		atthand = vessel->AddAttExhaustRef(m_exhaust_pos2,m_exhaust_ref2,ATTWIDTH,ATTHEIGHT);
		vessel->AddAttExhaustMode(atthand,ATTMODE_ROT,2,1);
		atthand = vessel->AddAttExhaustRef(m_exhaust_pos3,m_exhaust_ref3,ATTWIDTH,ATTHEIGHT);
		vessel->AddAttExhaustMode(atthand,ATTMODE_ROT,2,1);
		atthand = vessel->AddAttExhaustRef(m_exhaust_pos4,m_exhaust_ref4,ATTWIDTH,ATTHEIGHT);
		vessel->AddAttExhaustMode(atthand,ATTMODE_ROT,2,1);
		atthand = vessel->AddAttExhaustRef(m_exhaust_pos5,m_exhaust_ref5,ATTWIDTH,ATTHEIGHT);
		vessel->AddAttExhaustMode(atthand,ATTMODE_ROT,2,1);



}
void AddRCS_LMH2(VESSEL *vessel,double TRANZ)
{
UINT atthand;
	const double ATTCOOR = 0;
	const double ATTCOOR2 = 1.53;
	const double ATTZ = 2.85;
	const double TRANCOOR = 0;
	const double TRANCOOR2 = 0.1;
	const double ATTWIDTH=.2;
	const double ATTHEIGHT=.5;
	const double TRANWIDTH=.2;
	const double TRANHEIGHT=1;
	const double RCSOFFSET=0.75;
	const double RCSOFFSETM=0.30;
	const double RCSOFFSETM2=0.47;
int i;
	
	int MaxThrust=120;
				
	th_att_lin[0]=vessel-> CreateThruster (_V(2,2,-2), _V(1,0,1),120, ph_rcslm1,15000, 15000);
	th_att_lin[1]=vessel-> CreateThruster (_V(-2,2,-2), _V(-1,0,1),MaxThrust, ph_rcslm1,15000, 15000);
	th_att_lin[2]=vessel-> CreateThruster (_V(2,-2,-2), _V(1,0,1),MaxThrust, ph_rcslm1,15000, 15000);
	th_att_lin[3]=vessel-> CreateThruster (_V(-2,-2,-2), _V(-1,0,1),MaxThrust, ph_rcslm1,15000, 15000);
	th_att_lin[4]=vessel-> CreateThruster (_V(2,2,2), _V(1,0,-1),120, ph_rcslm1,15000, 15000);
	th_att_lin[5]=vessel-> CreateThruster (_V(-2,2,2), _V(-1,0,-1),MaxThrust, ph_rcslm1,15000, 15000);
	th_att_lin[6]=vessel-> CreateThruster (_V(2,-2,2), _V(1,0,-1),MaxThrust, ph_rcslm1,15000, 15000);
	th_att_lin[7]=vessel-> CreateThruster (_V(-2,-2,2), _V(-1,0,-1),MaxThrust, ph_rcslm1,15000, 15000);
	vessel->CreateThrusterGroup (th_att_lin,   4, THGROUP_ATT_FORWARD);
	vessel->CreateThrusterGroup (th_att_lin+4, 4, THGROUP_ATT_BACK);
	
	
	
	th_att_rot[2]=vessel-> CreateThruster (_V(2,2,-2), _V(0,0,1),120, ph_rcslm1,15000, 15000);
	th_att_rot[4]=vessel-> CreateThruster (_V(-2,2,-2), _V(0,0,1),MaxThrust, ph_rcslm1,15000, 15000);
	th_att_rot[3]=vessel-> CreateThruster (_V(2,-2,-2), _V(0,0,1),MaxThrust, ph_rcslm1,15000, 15000);
	th_att_rot[5]=vessel-> CreateThruster (_V(-2,-2,-2), _V(0,0,1),MaxThrust, ph_rcslm1,15000, 15000);
	th_att_rot[7]=vessel-> CreateThruster (_V(2,2,2), _V(0,0,-1),120, ph_rcslm1,15000, 15000);
	th_att_rot[0]=vessel-> CreateThruster (_V(-2,2,2), _V(0,0,-1),MaxThrust, ph_rcslm1,15000, 15000);
	th_att_rot[6]=vessel-> CreateThruster (_V(2,-2,2), _V(0,0,-1),MaxThrust, ph_rcslm1,15000, 15000);
	th_att_rot[1]=vessel-> CreateThruster (_V(-2,-2,2), _V(0,0,-1),MaxThrust, ph_rcslm1,15000, 15000);
	vessel->CreateThrusterGroup (th_att_rot,   4, THGROUP_ATT_YAWLEFT);
	vessel->CreateThrusterGroup (th_att_rot+4,   4, THGROUP_ATT_YAWRIGHT);
	
	th_att_lin[8]=vessel-> CreateThruster (_V(2,2,2), _V(-1,0,0),120, ph_rcslm1,15000, 15000);
	th_att_lin[9]=vessel-> CreateThruster (_V(2,-2,2), _V(-1,0,0),MaxThrust, ph_rcslm1,15000, 15000);
	th_att_lin[10]=vessel-> CreateThruster (_V(2,2,-2), _V(-1,0,0),MaxThrust, ph_rcslm1,15000, 15000);
	th_att_lin[11]=vessel-> CreateThruster (_V(2,-2,-2), _V(-1,0,0),MaxThrust, ph_rcslm1,15000, 15000);
	th_att_lin[12]=vessel-> CreateThruster (_V(-2,2,2), _V(1,0,0),120, ph_rcslm1,15000, 15000);
	th_att_lin[13]=vessel-> CreateThruster (_V(-2,2,-2), _V(1,0,0),MaxThrust, ph_rcslm1,15000, 15000);
	th_att_lin[14]=vessel-> CreateThruster (_V(-2,-2,2), _V(1,0,0),MaxThrust, ph_rcslm1,15000, 15000);
	th_att_lin[15]=vessel-> CreateThruster (_V(-2,-2,-2), _V(1,0,0),MaxThrust, ph_rcslm1,15000, 15000);
	
	th_att_lin[16]=vessel-> CreateThruster (_V(2,-2,2), _V(0,1,0),120, ph_rcslm1,15000, 15000);
	th_att_lin[17]=vessel-> CreateThruster (_V(-2,-2,2), _V(0,1,0),MaxThrust, ph_rcslm1,15000, 15000);
	th_att_lin[18]=vessel-> CreateThruster (_V(2,-2,-2), _V(0,1,0),MaxThrust, ph_rcslm1,15000, 15000);
	th_att_lin[19]=vessel-> CreateThruster (_V(-2,-2,-2), _V(0,1,0),MaxThrust, ph_rcslm1,15000, 15000);
	th_att_lin[20]=vessel-> CreateThruster (_V(2,2,2), _V(0,-1,0),120, ph_rcslm1,15000, 15000);
	th_att_lin[21]=vessel-> CreateThruster (_V(-2,2,2), _V(0,-1,0),MaxThrust, ph_rcslm1,15000, 15000);
	th_att_lin[22]=vessel-> CreateThruster (_V(2,2,-2), _V(0,-1,0),MaxThrust, ph_rcslm1,15000, 15000);
	th_att_lin[23]=vessel-> CreateThruster (_V(-2,2,-2), _V(0,-1,0),MaxThrust, ph_rcslm1,15000, 15000);
	
	vessel->CreateThrusterGroup (th_att_lin+16,   4, THGROUP_ATT_UP);
	vessel->CreateThrusterGroup (th_att_lin+20,   4, THGROUP_ATT_DOWN);
	vessel->CreateThrusterGroup (th_att_lin+12,  4 , THGROUP_ATT_RIGHT);
	vessel->CreateThrusterGroup (th_att_lin+8, 4, THGROUP_ATT_LEFT);
	
	th_att_rot[8]=vessel-> CreateThruster (_V(2,2,-2), _V(0,-1,0),120, ph_rcslm1,15000, 15000);
	th_att_rot[9]=vessel-> CreateThruster (_V(-2,2,-2), _V(0,-1,0),MaxThrust, ph_rcslm1,15000, 15000);
	th_att_rot[12]=vessel-> CreateThruster (_V(2,2,2), _V(0,-1,0),120, ph_rcslm1,15000, 15000);
	th_att_rot[13]=vessel-> CreateThruster (_V(-2,2,2), _V(0,-1,0),MaxThrust, ph_rcslm1,15000, 15000);
	
	th_att_rot[15]=vessel-> CreateThruster (_V(2,-2,-2), _V(0,1,0),MaxThrust, ph_rcslm1,15000, 15000);
	th_att_rot[14]=vessel-> CreateThruster (_V(-2,-2,-2), _V(0,1,0),MaxThrust, ph_rcslm1,15000, 15000);
	th_att_rot[10]=vessel-> CreateThruster (_V(2,-2,2), _V(0,1,0),MaxThrust, ph_rcslm1,15000, 15000);
	th_att_rot[11]=vessel-> CreateThruster (_V(-2,-2,2), _V(0,1,0),MaxThrust, ph_rcslm1,15000, 15000);
	
	vessel->CreateThrusterGroup (th_att_rot+12,   4, THGROUP_ATT_PITCHDOWN);
	vessel->CreateThrusterGroup (th_att_rot+8,   4, THGROUP_ATT_PITCHUP);
	
	th_att_rot[16]=vessel-> CreateThruster (_V(2,2,-2), _V(0,-1,0),120, ph_rcslm1,15000, 15000);
	th_att_rot[17]=vessel-> CreateThruster (_V(2,2,2), _V(0,-1,0),120, ph_rcslm1,15000, 15000);
	th_att_rot[18]=vessel-> CreateThruster (_V(-2,-2,2), _V(0,1,0),MaxThrust, ph_rcslm1,15000, 15000);
	th_att_rot[19]=vessel-> CreateThruster (_V(-2,-2,-2), _V(0,1,0),MaxThrust, ph_rcslm1,15000, 15000);
	th_att_rot[23]=vessel-> CreateThruster (_V(-2,2,2), _V(0,-1,0),MaxThrust, ph_rcslm1,15000, 15000);
	th_att_rot[22]=vessel-> CreateThruster (_V(2,-2,-2), _V(0,1,0),MaxThrust, ph_rcslm1,15000, 15000);
	th_att_rot[20]=vessel-> CreateThruster (_V(-2,2,-2), _V(0,-1,0),MaxThrust, ph_rcslm1,15000, 15000);
	th_att_rot[21]=vessel-> CreateThruster (_V(2,-2,2), _V(0,1,0),MaxThrust, ph_rcslm1,15000, 15000);
	
	vessel->CreateThrusterGroup (th_att_rot+20,   4, THGROUP_ATT_BANKLEFT);
	vessel->CreateThrusterGroup (th_att_rot+16,   4, THGROUP_ATT_BANKRIGHT);
	
	SURFHANDLE tex = oapiRegisterExhaustTexture ("Exhaust_atrcs");//"Exhaust2"
	//for (i = 0; i < 24; i++) vessel->AddExhaust (th_att_lin[i], 1.2, 0.18,tex);
	//for (i = 0; i < 24; i++) vessel->AddExhaust (th_att_rot[i], 1.2, 0.18,tex);
	//return;

		//lin Forward
		
		VECTOR3 m_exhaust_pos2= _V(ATTCOOR2,ATTCOOR2-0.33-1.6,TRANZ+RCSOFFSET-0.6);
		VECTOR3 m_exhaust_pos3= _V(-ATTCOOR2,ATTCOOR2-0.33-1.6,TRANZ+RCSOFFSET-0.6);
		VECTOR3 m_exhaust_ref2 = _V(-1,0,-1);
		VECTOR3 m_exhaust_ref3 = _V(1,0,-1);
		//just for vector init
		VECTOR3 m_exhaust_pos4= _V(ATTCOOR2+0.1,-ATTCOOR2-0.1,TRANZ+RCSOFFSET);
		VECTOR3 m_exhaust_pos5= _V(-ATTCOOR2-0.1,-ATTCOOR2-0.1,TRANZ+RCSOFFSET);
		VECTOR3 m_exhaust_ref4 = _V(0,0.0,1);
		VECTOR3 m_exhaust_ref5 = _V(0,0.0,1);
		
		atthand = vessel->AddAttExhaustRef(m_exhaust_pos2,m_exhaust_ref2,ATTWIDTH,ATTHEIGHT);
		vessel->AddAttExhaustMode(atthand,ATTMODE_LIN,2,0);
		atthand = vessel->AddAttExhaustRef(m_exhaust_pos3,m_exhaust_ref3,ATTWIDTH,ATTHEIGHT);
		vessel->AddAttExhaustMode(atthand,ATTMODE_LIN,2,0);
		
		//lin backward
		
		m_exhaust_pos2= _V(ATTCOOR2,ATTCOOR2-0.33-1.6,TRANZ+RCSOFFSET+2.9);
		m_exhaust_pos3= _V(-ATTCOOR2,ATTCOOR2-0.33-1.6,TRANZ+RCSOFFSET+2.9);
		m_exhaust_ref2 = _V(-1,0,1);
		m_exhaust_ref3 = _V(1,0,1);
		atthand = vessel->AddAttExhaustRef(m_exhaust_pos2,m_exhaust_ref2,ATTWIDTH,ATTHEIGHT);
		vessel->AddAttExhaustMode(atthand,ATTMODE_LIN,2,1);
		atthand = vessel->AddAttExhaustRef(m_exhaust_pos3,m_exhaust_ref3,ATTWIDTH,ATTHEIGHT);
		vessel->AddAttExhaustMode(atthand,ATTMODE_LIN,2,1);
		
		//lin Right
		
		m_exhaust_pos2= _V(-ATTCOOR2-0.33,ATTCOOR2-0.33-1.6,TRANZ+RCSOFFSETM2);
		m_exhaust_pos3= _V(-ATTCOOR2-0.33,ATTCOOR2-0.33-1.6,TRANZ+RCSOFFSETM2+2.9);
		m_exhaust_ref2 = _V(-1,0,0.75);
		m_exhaust_ref3 = _V(-1,0,-0.75);
		atthand = vessel->AddAttExhaustRef(m_exhaust_pos2,m_exhaust_ref2,ATTWIDTH,ATTHEIGHT);
		vessel->AddAttExhaustMode(atthand,ATTMODE_LIN,0,0);
		atthand = vessel->AddAttExhaustRef(m_exhaust_pos3,m_exhaust_ref3,ATTWIDTH,ATTHEIGHT);
		vessel->AddAttExhaustMode(atthand,ATTMODE_LIN,0,0);
		
		//lin Left
		
		m_exhaust_pos2= _V(ATTCOOR2+0.33,ATTCOOR2-0.33-1.6,TRANZ+RCSOFFSETM2);
		m_exhaust_pos3= _V(ATTCOOR2+0.33,ATTCOOR2-0.33-1.6,TRANZ+RCSOFFSETM2+2.9);
		m_exhaust_ref2 = _V(1,0,0.75);
		m_exhaust_ref3 = _V(1,0,-0.75);
		atthand = vessel->AddAttExhaustRef(m_exhaust_pos2,m_exhaust_ref2,ATTWIDTH,ATTHEIGHT);
		vessel->AddAttExhaustMode(atthand,ATTMODE_LIN,0,1);
		atthand = vessel->AddAttExhaustRef(m_exhaust_pos3,m_exhaust_ref3,ATTWIDTH,ATTHEIGHT);
		vessel->AddAttExhaustMode(atthand,ATTMODE_LIN,0,1);
		
		//lin up
		
		m_exhaust_pos2= _V(ATTCOOR2+.1,ATTCOOR2-0.1-1.6,TRANZ+RCSOFFSETM2-0.22);
		m_exhaust_pos3= _V(-ATTCOOR2-.1,ATTCOOR2-0.1-1.6,TRANZ+RCSOFFSETM2-0.22);
		m_exhaust_pos4= _V(ATTCOOR2+.1,ATTCOOR2-0.1-1.6,TRANZ+RCSOFFSETM2-0.22+3.3);
		m_exhaust_pos5= _V(-ATTCOOR2-.1,ATTCOOR2-0.1-1.6,TRANZ+RCSOFFSETM2-0.22+3.3);
		m_exhaust_ref2 = _V(0,1,0);
		m_exhaust_ref3 = _V(0,1,0);
		m_exhaust_ref4 = _V(0,1,0);
		m_exhaust_ref5 = _V(0,1,0);
		atthand = vessel->AddAttExhaustRef(m_exhaust_pos2,m_exhaust_ref2,ATTWIDTH,ATTHEIGHT);
		vessel->AddAttExhaustMode(atthand,ATTMODE_LIN,1,1);
		atthand = vessel->AddAttExhaustRef(m_exhaust_pos3,m_exhaust_ref3,ATTWIDTH,ATTHEIGHT);
		vessel->AddAttExhaustMode(atthand,ATTMODE_LIN,1,1);
		atthand = vessel->AddAttExhaustRef(m_exhaust_pos4,m_exhaust_ref4,ATTWIDTH,ATTHEIGHT);
		vessel->AddAttExhaustMode(atthand,ATTMODE_LIN,1,1);
		atthand = vessel->AddAttExhaustRef(m_exhaust_pos5,m_exhaust_ref5,ATTWIDTH,ATTHEIGHT);
		vessel->AddAttExhaustMode(atthand,ATTMODE_LIN,1,1);
		//lin down
		m_exhaust_pos2= _V(ATTCOOR2+.1,ATTCOOR2-.6-1.6,TRANZ+RCSOFFSETM2-0.22);
		m_exhaust_pos3= _V(-ATTCOOR2-.1,ATTCOOR2-.6-1.6,TRANZ+RCSOFFSETM2-0.22);
		m_exhaust_pos4= _V(ATTCOOR2+.1,ATTCOOR2-.6-1.6,TRANZ+RCSOFFSETM2-0.22+3.3);
		m_exhaust_pos5= _V(-ATTCOOR2-.1,ATTCOOR2-.6-1.6,TRANZ+RCSOFFSETM2-0.22+3.3);
		m_exhaust_ref2 = _V(0.0,-1,-0.0);
		m_exhaust_ref3 = _V(-0.,-1,-0.0);
		m_exhaust_ref4 = _V(0.0,-1,0.0);
		m_exhaust_ref5 = _V(-0.0,-1,0.0);
		atthand = vessel->AddAttExhaustRef(m_exhaust_pos2,m_exhaust_ref2,ATTWIDTH,ATTHEIGHT);
		vessel->AddAttExhaustMode(atthand,ATTMODE_LIN,1,0);
		atthand = vessel->AddAttExhaustRef(m_exhaust_pos3,m_exhaust_ref3,ATTWIDTH,ATTHEIGHT);
		vessel->AddAttExhaustMode(atthand,ATTMODE_LIN,1,0);
		atthand = vessel->AddAttExhaustRef(m_exhaust_pos4,m_exhaust_ref4,ATTWIDTH,ATTHEIGHT);
		vessel->AddAttExhaustMode(atthand,ATTMODE_LIN,1,0);
		atthand = vessel->AddAttExhaustRef(m_exhaust_pos5,m_exhaust_ref5,ATTWIDTH,ATTHEIGHT);
		vessel->AddAttExhaustMode(atthand,ATTMODE_LIN,1,0);
		//Rot up
		
		m_exhaust_pos2= _V(ATTCOOR2+.1,ATTCOOR2-0.1-1.6,TRANZ+RCSOFFSETM2-0.22);
		m_exhaust_pos3= _V(-ATTCOOR2-.1,ATTCOOR2-0.1-1.6,TRANZ+RCSOFFSETM2-0.22);
		m_exhaust_ref2 = _V(0,1,0);
		m_exhaust_ref3 = _V(0,1,0);
		m_exhaust_pos4= _V(ATTCOOR2+.1,ATTCOOR2-.6-1.6,TRANZ+RCSOFFSETM2-0.22+3.3);
		m_exhaust_pos5= _V(-ATTCOOR2-.1,ATTCOOR2-.6-1.6,TRANZ+RCSOFFSETM2-0.22+3.3);
		m_exhaust_ref4 = _V(0.0,-1,0.0);
		m_exhaust_ref5 = _V(-0.0,-1,0.0);
		
	
		atthand = vessel->AddAttExhaustRef(m_exhaust_pos2,m_exhaust_ref2,ATTWIDTH,ATTHEIGHT);
		vessel->AddAttExhaustMode(atthand,ATTMODE_ROT,0,0);
		atthand = vessel->AddAttExhaustRef(m_exhaust_pos3,m_exhaust_ref3,ATTWIDTH,ATTHEIGHT);
		vessel->AddAttExhaustMode(atthand,ATTMODE_ROT,0,0);
		atthand = vessel->AddAttExhaustRef(m_exhaust_pos4,m_exhaust_ref4,ATTWIDTH,ATTHEIGHT);
		vessel->AddAttExhaustMode(atthand,ATTMODE_ROT,0,0);
		atthand = vessel->AddAttExhaustRef(m_exhaust_pos5,m_exhaust_ref5,ATTWIDTH,ATTHEIGHT);
		vessel->AddAttExhaustMode(atthand,ATTMODE_ROT,0,0);
		
		//Rot down
		m_exhaust_pos4= _V(ATTCOOR2+.1,ATTCOOR2-0.1-1.6,TRANZ+RCSOFFSETM2-0.22+3.3);
		m_exhaust_pos5= _V(-ATTCOOR2-.1,ATTCOOR2-0.1-1.6,TRANZ+RCSOFFSETM2-0.22+3.3);
		m_exhaust_ref4 = _V(0,1,0);
		m_exhaust_ref5 = _V(0,1,0);
		
		
		m_exhaust_pos2= _V(ATTCOOR2+.1,ATTCOOR2-.6-1.6,TRANZ+RCSOFFSETM2-0.22);
		m_exhaust_pos3= _V(-ATTCOOR2-.1,ATTCOOR2-.6-1.6,TRANZ+RCSOFFSETM2-0.22);
		m_exhaust_ref2 = _V(0.0,-1,-0.0);
		m_exhaust_ref3 = _V(-0.0,-1,-0.0);
		atthand = vessel->AddAttExhaustRef(m_exhaust_pos2,m_exhaust_ref2,ATTWIDTH,ATTHEIGHT);
		vessel->AddAttExhaustMode(atthand,ATTMODE_ROT,0,1);
		atthand = vessel->AddAttExhaustRef(m_exhaust_pos3,m_exhaust_ref3,ATTWIDTH,ATTHEIGHT);
		vessel->AddAttExhaustMode(atthand,ATTMODE_ROT,0,1);
		atthand = vessel->AddAttExhaustRef(m_exhaust_pos4,m_exhaust_ref4,ATTWIDTH,ATTHEIGHT);
		vessel->AddAttExhaustMode(atthand,ATTMODE_ROT,0,1);
		atthand = vessel->AddAttExhaustRef(m_exhaust_pos5,m_exhaust_ref5,ATTWIDTH,ATTHEIGHT);
		vessel->AddAttExhaustMode(atthand,ATTMODE_ROT,0,1);
		
		
		//Rot left
		
		m_exhaust_pos2= _V(ATTCOOR2+0.33,ATTCOOR2-0.33-1.6,TRANZ+RCSOFFSETM2+2.9);
		m_exhaust_ref2 = _V(1,0,-1);
		m_exhaust_pos3= _V(ATTCOOR2,ATTCOOR2-0.33-1.6,TRANZ+RCSOFFSET-0.6);
		m_exhaust_ref3 = _V(-1,0,-1);
		m_exhaust_pos4= _V(-ATTCOOR2-0.33,ATTCOOR2-0.33-1.6,TRANZ+RCSOFFSETM2);
		m_exhaust_ref4 = _V(-1,0,1);
		m_exhaust_pos5= _V(-ATTCOOR2,ATTCOOR2-0.33-1.6,TRANZ+RCSOFFSET+2.9);
		m_exhaust_ref5 = _V(1,0,1);
		atthand = vessel->AddAttExhaustRef(m_exhaust_pos2,m_exhaust_ref2,ATTWIDTH,ATTHEIGHT);
		vessel->AddAttExhaustMode(atthand,ATTMODE_ROT,1,0);
		atthand = vessel->AddAttExhaustRef(m_exhaust_pos3,m_exhaust_ref3,ATTWIDTH,ATTHEIGHT);
		vessel->AddAttExhaustMode(atthand,ATTMODE_ROT,1,0);
		atthand = vessel->AddAttExhaustRef(m_exhaust_pos4,m_exhaust_ref4,ATTWIDTH,ATTHEIGHT);
		vessel->AddAttExhaustMode(atthand,ATTMODE_ROT,1,0);
		atthand = vessel->AddAttExhaustRef(m_exhaust_pos5,m_exhaust_ref5,ATTWIDTH,ATTHEIGHT);
		vessel->AddAttExhaustMode(atthand,ATTMODE_ROT,1,0);
		
		//Rot right
		
		m_exhaust_pos2= _V(-ATTCOOR2-0.33,ATTCOOR2-0.33-1.6,TRANZ+RCSOFFSETM2+2.9);
		m_exhaust_ref2 = _V(-1,0,-1);
		m_exhaust_pos3= _V(-ATTCOOR2,ATTCOOR2-0.33-1.6,TRANZ+RCSOFFSET-0.6);
		m_exhaust_ref3 = _V(1,0,-1);
		m_exhaust_pos4= _V(ATTCOOR2+0.33,ATTCOOR2-0.33-1.6,TRANZ+RCSOFFSETM2);
		m_exhaust_ref4 = _V(1,0,1);
		m_exhaust_pos5= _V(ATTCOOR2,ATTCOOR2-0.33-1.6,TRANZ+RCSOFFSET+2.9);
		m_exhaust_ref5 = _V(-1,0,1);
		
		atthand = vessel->AddAttExhaustRef(m_exhaust_pos2,m_exhaust_ref2,ATTWIDTH,ATTHEIGHT);
		vessel->AddAttExhaustMode(atthand,ATTMODE_ROT,1,1);
		atthand = vessel->AddAttExhaustRef(m_exhaust_pos3,m_exhaust_ref3,ATTWIDTH,ATTHEIGHT);
		vessel->AddAttExhaustMode(atthand,ATTMODE_ROT,1,1);
		atthand = vessel->AddAttExhaustRef(m_exhaust_pos4,m_exhaust_ref4,ATTWIDTH,ATTHEIGHT);
		vessel->AddAttExhaustMode(atthand,ATTMODE_ROT,1,1);
		atthand = vessel->AddAttExhaustRef(m_exhaust_pos5,m_exhaust_ref5,ATTWIDTH,ATTHEIGHT);
		vessel->AddAttExhaustMode(atthand,ATTMODE_ROT,1,1);
		
	
		//Roll left

		m_exhaust_pos2= _V(ATTCOOR2+.1,ATTCOOR2-0.1-1.6,TRANZ+RCSOFFSETM2-0.22);
		m_exhaust_pos4= _V(ATTCOOR2+.1,ATTCOOR2-0.1-1.6,TRANZ+RCSOFFSETM2-0.22+3.3);
		m_exhaust_ref2 = _V(0,1,0);
		m_exhaust_ref4 = _V(0,1,0);
		
		
		
		
		m_exhaust_pos3= _V(-ATTCOOR2-.1,ATTCOOR2-.6-1.6,TRANZ+RCSOFFSETM2-0.22);
		m_exhaust_pos5= _V(-ATTCOOR2-.1,ATTCOOR2-.6-1.6,TRANZ+RCSOFFSETM2-0.22+3.3);
		m_exhaust_ref3 = _V(-0.0,-1,-0.0);
		m_exhaust_ref5 = _V(-0.0,-1,0.0);
		
		atthand = vessel->AddAttExhaustRef(m_exhaust_pos2,m_exhaust_ref2,ATTWIDTH,ATTHEIGHT);
		vessel->AddAttExhaustMode(atthand,ATTMODE_ROT,2,0);
		atthand = vessel->AddAttExhaustRef(m_exhaust_pos3,m_exhaust_ref3,ATTWIDTH,ATTHEIGHT);
		vessel->AddAttExhaustMode(atthand,ATTMODE_ROT,2,0);
		atthand = vessel->AddAttExhaustRef(m_exhaust_pos4,m_exhaust_ref4,ATTWIDTH,ATTHEIGHT);
		vessel->AddAttExhaustMode(atthand,ATTMODE_ROT,2,0);
		atthand = vessel->AddAttExhaustRef(m_exhaust_pos5,m_exhaust_ref5,ATTWIDTH,ATTHEIGHT);
		vessel->AddAttExhaustMode(atthand,ATTMODE_ROT,2,0);
		//Roll right
		
		m_exhaust_pos3= _V(-ATTCOOR2-.1,ATTCOOR2-0.1-1.6,TRANZ+RCSOFFSETM2-0.22);
		m_exhaust_pos5= _V(-ATTCOOR2-.1,ATTCOOR2-0.1-1.6,TRANZ+RCSOFFSETM2-0.22+3.3);
		m_exhaust_ref3 = _V(0,1,0);
		m_exhaust_ref5 = _V(0,1,0);
		m_exhaust_pos2= _V(ATTCOOR2+.1,ATTCOOR2-.6-1.6,TRANZ+RCSOFFSETM2-0.22);
		m_exhaust_pos4= _V(ATTCOOR2+.1,ATTCOOR2-.6-1.6,TRANZ+RCSOFFSETM2-0.22+3.3);
		m_exhaust_ref2 = _V(0.0,-1,-0.0);
		m_exhaust_ref4 = _V(0.0,-1,0.0);
		
		
		atthand = vessel->AddAttExhaustRef(m_exhaust_pos2,m_exhaust_ref2,ATTWIDTH,ATTHEIGHT);
		vessel->AddAttExhaustMode(atthand,ATTMODE_ROT,2,1);
		atthand = vessel->AddAttExhaustRef(m_exhaust_pos3,m_exhaust_ref3,ATTWIDTH,ATTHEIGHT);
		vessel->AddAttExhaustMode(atthand,ATTMODE_ROT,2,1);
		atthand = vessel->AddAttExhaustRef(m_exhaust_pos4,m_exhaust_ref4,ATTWIDTH,ATTHEIGHT);
		vessel->AddAttExhaustMode(atthand,ATTMODE_ROT,2,1);
		atthand = vessel->AddAttExhaustRef(m_exhaust_pos5,m_exhaust_ref5,ATTWIDTH,ATTHEIGHT);
		vessel->AddAttExhaustMode(atthand,ATTMODE_ROT,2,1);



}
void ToggleEVA(VESSEL *vessel){
	
	ToggleEva=false;	
	
	if (EVA_IP){
		EVA_IP =false;
		vessel->ClearMeshes();
		vessel->ClearExhaustRefs();
		vessel->ClearAttExhaustRefs();
		VECTOR3 mesh_dir=_V(-0.08,0,0);
		vessel->AddMesh (hLMVessel, &mesh_dir);
		
		
	}else{
		EVA_IP =true;
		
		
		VESSELSTATUS vs1;
		vessel->GetStatus(vs1);
		VECTOR3 ofs1 = _V(0,0,0);
		VECTOR3 vel1 = _V(0,0,0);
		VECTOR3 rofs1, rvel1 = {vs1.rvel.x, vs1.rvel.y, vs1.rvel.z};
		vessel->Local2Rel (ofs1, vs1.rpos);
		vessel->GlobalRot (vel1, rofs1);
		vs1.rvel.x = rvel1.x+rofs1.x;
		vs1.rvel.y = rvel1.y+rofs1.y;
		vs1.rvel.z = rvel1.z+rofs1.z;
		//vs1.vdata[0].z = vs1.vdata[0].z +PI;
		char VName[256]="";
		strcpy (VName, vessel->GetName()); strcat (VName, "-LEVA");
		hLEVA = oapiCreateVessel(VName,"Saturn5_LEVA",vs1);
		vessel->ClearMeshes();
		vessel->ClearExhaustRefs();
		vessel->ClearAttExhaustRefs();
		VECTOR3 mesh_dir=_V(-0.08,-0.15,-4.3);
		vessel->AddMesh (hLMVessel, &mesh_dir);
		oapiSetFocusObject(hLEVA);

		PlayVesselWave(SLEVA,NOLOOP,255);
	}
}
void SetupEVA(VESSEL *vessel){
	
	
			
	
	if (EVA_IP){
		
		EVA_IP =true;
		vessel->ClearMeshes();
		VECTOR3 mesh_dir=_V(-0.08,-0.15,-4.3);
		vessel->AddMesh (hLMVessel, &mesh_dir);
	if(high){
			}else{
			high=true;
			vessel->SetTouchdownPoints (_V(0,-5,10), _V(-1,-5,-10), _V(1,-5,-10));
			}
		}
		
	
}


void SetView(VESSEL *vessel){


	if (cdrview)	{
		vessel->SetCameraOffset (_V(-1.02,1.05,-1.67));
		cdrview=false;		
	}
	if (lmpview){
		vessel->SetCameraOffset (_V(1.02,1.05,-1.67));
		lmpview=false;		
	}

}
void RedrawPanel_Horizon (VESSEL* vessel,SURFHANDLE surf)
{
	POINT pt[4];
	static double prange = RAD*30.0;
	static int size = 48, size2 = size*2;
	static int extent = (int)(size*prange);
	double bank = vessel->GetBank();
	double pitch = vessel->GetPitch();
	double pfrac = pitch/prange;
	double sinb = sin(bank), cosb = cos(bank);
	double a = tan(bank);
	double yl, yr, xb, xt, xlr, xll, ylr, yll;
	int i, iphi, n = 0;
	bool bl, br, bb, bt, bblue;
	if (cosb) { // horizon not vertical
		double b = pfrac/cosb;
		bl = (fabs(yl = -a+b) < 1.0); // left edge
		br = (fabs(yr =  a+b) < 1.0);  // right edge
		if (a) { // horizon not horizontal
			bb = (fabs(xb = ( 1.0-b)/a) < 1.0); // bottom edge
			bt = (fabs(xt = (-1.0-b)/a) < 1.0); // top edge
		} else { // horizon horizontal
			bb = bt = false;
		}
	} else { // horizon vertical
		bl = br = false;
		bb = bt = (fabs(xb = xt = pfrac) < 1.0);
	}
	if (bl) {
		pt[0].x = 0;
		pt[0].y = (int)(yl*size)+size;
		if (bt) {
			pt[1].x = (int)(xt*size)+size;
			pt[1].y = 0;
			pt[2].x = 0;
			pt[2].y = 0;
			n = 3;
			bblue = (cosb > 0.0);
		} else if (br) {
			pt[1].x = size2;
			pt[1].y = (int)(yr*size)+size;
			pt[2].x = size2;
			pt[2].y = 0;
			pt[3].x = 0;
			pt[3].y = 0;
			n = 4;
			bblue = (cosb > 0.0);
		} else if (bb) {
			pt[1].x = (int)(xb*size)+size;
			pt[1].y = size2;
			pt[2].x = 0;
			pt[2].y = size2;
			n = 3;
			bblue = (cosb < 0.0);
		}
	} else if (br) {
		pt[0].x = size2;
		pt[0].y = (int)(yr*size)+size;
		if (bt) {
			pt[1].x = (int)(xt*size)+size;
			pt[1].y = 0;
			pt[2].x = size2;
			pt[2].y = 0;
			n = 3;
			bblue = (cosb > 0.0);
		} else if (bb) {
			pt[1].x = (int)(xb*size)+size;
			pt[1].y = size2;
			pt[2].x = size2;
			pt[2].y = size2;
			n = 3;
			bblue = (cosb < 0.0);
		}
	} else if (bt && bb) {
		pt[0].x = (int)(xt*size)+size;
		pt[0].y = 0;
		pt[1].x = (int)(xb*size)+size;
		pt[1].y = size2;
		pt[2].x = 0;
		pt[2].y = size2;
		pt[3].x = 0;
		pt[3].y = 0;
		n = 4;
		bblue = ((xt-xb)*cosb > 0.0);
	}
	if (!n) bblue = (pitch < 0.0);
	oapiClearSurface (surf, bblue ? g_Param.col[3]:g_Param.col[2]);
	HDC hDC = oapiGetDC (surf);
	SelectObject (hDC, GetStockObject (BLACK_PEN));
	if (n >= 3) {
		SelectObject (hDC, g_Param.brush[bblue ? 2:3]);
		Polygon (hDC, pt, n);
		SelectObject (hDC, g_Param.pen[0]);
		MoveToEx (hDC, pt[0].x, pt[0].y, NULL); LineTo (hDC, pt[1].x, pt[1].y);
	}
	// bank indicator
	SelectObject (hDC, g_Param.pen[0]);
	SelectObject (hDC, GetStockObject (NULL_BRUSH));
	static double r1 = 40, r2 = 35;
	double sinb1 = sin(bank-0.1), cosb1 = cos(bank-0.1);
	double sinb2 = sin(bank+0.1), cosb2 = cos(bank+0.1);
	pt[0].x = (int)(r2*sinb1+0.5)+size; pt[0].y = -(int)(r2*cosb1+0.5)+size;
	pt[1].x = (int)(r1*sinb+0.5)+size;  pt[1].y = -(int)(r1*cosb+0.5)+size;
	pt[2].x = (int)(r2*sinb2+0.5)+size; pt[2].y = -(int)(r2*cosb2+0.5)+size;
	Polygon (hDC, pt, 3);

	// pitch ladder
	static double d = size*(10.0*RAD)/prange;
	static double ladderw = 14.0;
	double lwcosa = ladderw*cosb, lwsina = ladderw*sinb;
	double dsinb = d*sinb, dcosb = d*cosb;
	double phi0 = floor(pitch*DEG*0.1);
	double d0 = (pitch*DEG*0.1-phi0) * d, d1 = d0-4*d;
	// ladder
	xlr = lwcosa-d1*sinb, xll = -lwcosa-d1*sinb;
	ylr = lwsina+d1*cosb, yll = -lwsina+d1*cosb;
	for (iphi = (int)phi0+4, i = 0; i < 8; i++, iphi--) {
		if (iphi) {
			MoveToEx (hDC, size+(int)xll, size+(int)yll, NULL);
			LineTo   (hDC, size+(int)xlr, size+(int)ylr);
		}
		xlr -= dsinb, ylr += dcosb;
		xll -= dsinb, yll += dcosb;
	}
	oapiReleaseDC (surf, hDC);
	// labels
	lwcosa *= 1.6, lwsina *= 1.6;
	xlr = lwcosa-d1*sinb, xll = -lwcosa-d1*sinb;
	ylr = lwsina+d1*cosb, yll = -lwsina+d1*cosb;
	for (iphi = (int)phi0+4, i = 0; i < 8; i++, iphi--) {
		if (iphi) {
			int lb = abs(iphi)-1; if (lb >= 9) lb = 16-lb;
			oapiBlt (surf, srf[3], size-5+(int)xlr, size-3+(int)ylr, 9*lb, 96, 9, 7, SURF_PREDEF_CK);
			oapiBlt (surf, srf[3], size-5+(int)xll, size-3+(int)yll, 9*lb, 96, 9, 7, SURF_PREDEF_CK);
		}
		xlr -= dsinb, ylr += dcosb;
		xll -= dsinb, yll += dcosb;
	}

	// now overlay markings with transparent blt
	oapiBlt (surf, srf[3], 0, 0, 0, 0, 96, 96, SURF_PREDEF_CK);
	oapiBlt (surf, srf[5], 0, 0, 0, 0, 96, 96, SURF_PREDEF_CK);
}
void DrawNeedle (HDC hDC, int x, int y, double rad, double angle, HPEN pen0, HPEN pen1)
{
	double dx = rad * cos(angle), dy = rad * sin(angle);
	HGDIOBJ oldObj;
	oldObj = SelectObject (hDC, pen1);
	MoveToEx (hDC, x, y, 0); LineTo (hDC, x + (int)(0.85*dx+0.5), y - (int)(0.85*dy+0.5));
	SelectObject (hDC, oldObj);
	oldObj = SelectObject (hDC, pen0);
	MoveToEx (hDC, x, y, 0); LineTo (hDC, x + (int)(dx+0.5), y - (int)(dy+0.5));
	SelectObject (hDC, oldObj);
}

void RedrawPanel_Thrust (VESSEL *vessel, SURFHANDLE surf)
{
	double alpha;
	double range;
	
	alpha = vessel->GetEngineLevel(ENGINE_HOVER)*100;
	
	if (alpha > 100) alpha = 100;
	range = 270 * RAD;
	range = range / 100;
	alpha = 100 - alpha;
	HDC hDC = oapiGetDC (surf);
	DrawNeedle (hDC, 28, 28, 19.0, (alpha*range)-45*RAD, g_Param.pen[2], g_Param.pen[3] );//(alpha * range)
	oapiReleaseDC (surf, hDC);
	
	oapiBlt (surf, srf[16], 18, 18, 18, 18, 21, 21, SURF_PREDEF_CK);
	
	
}

void ReleaseSurfaces ()
{
	for (int i = 0; i < nsurf; i++)
		if (srf[i]) {
			oapiDestroySurface (srf[i]);
			srf[i] = 0;
		}
}
void InitPanel (int panel)
{
//	int i;

	switch (panel) {
	case 0: // main panel
		srf[0] = oapiCreateSurface (LOADBMP (IDB_ROT_KNOB));
		srf[1] = oapiCreateSurface (LOADBMP (IDB_INDICATORS1));
		srf[2] = oapiCreateSurface (LOADBMP (IDB_NEEDLE1));
		srf[3] = oapiCreateSurface (LOADBMP (IDB_HORIZON));   
		srf[4] = oapiCreateSurface (LOADBMP (IDB_DIGITAL));   
		srf[5] = oapiCreateSurface (LOADBMP (IDB_HORIZON2));   
		srf[6] = oapiCreateSurface (LOADBMP (IDB_SWITCHUP));   
		srf[7] = oapiCreateSurface (LOADBMP (IDB_SWLEVER)); 
		srf[8] = oapiCreateSurface (LOADBMP (IDB_SECSWITCH)); 
		srf[9] = oapiCreateSurface (LOADBMP (IDB_ABORT)); 
		srf[10] = oapiCreateSurface (LOADBMP (IDB_ANNUN)); 
		srf[11] = oapiCreateSurface (LOADBMP (IDB_LAUNCH)); 
		srf[12] = oapiCreateSurface (LOADBMP (IDB_LV_ENG));
		srf[13] = oapiCreateSurface (LOADBMP (IDB_LIGHTS2));
		srf[14] = oapiCreateSurface (LOADBMP (IDB_ANLG_ALT));
		srf[15] = oapiCreateSurface (LOADBMP (IDB_ANLG_GMETER));
		srf[16] = oapiCreateSurface (LOADBMP (IDB_THRUST));
		srf[17] = oapiCreateSurface (LOADBMP (IDB_HEADING));
		srf[18] = oapiCreateSurface (LOADBMP (IDB_CONTACT));
		oapiSetSurfaceColourKey (srf[3], 0);
		oapiSetSurfaceColourKey (srf[5], 16711935);
		oapiSetSurfaceColourKey (srf[14], 16711935);
		oapiSetSurfaceColourKey (srf[15], 16711935);
		oapiSetSurfaceColourKey (srf[16], 16711935);
		
		break;
	
	}
}

void SetLmVesselDockStage(VESSEL *vessel)
{	
	vessel->ClearThrusterDefinitions();
	vessel->SetSize (6);
	vessel->SetEmptyMass (6431.0);
	vessel->SetPMI (_V(2.8,2.29,2.37));
	vessel->SetCrossSections (_V(21,23,17));
	vessel->SetCW (0.1, 0.3, 1.4, 1.4);
	vessel->SetRotDrag (_V(0.7,0.7,0.7));
	vessel->SetPitchMomentScale (0);
	vessel->SetBankMomentScale (0);
	vessel->SetLiftCoeffFunc (0); 
	vessel->ClearMeshes();
	vessel->ClearExhaustRefs();
	vessel->ClearAttExhaustRefs();
	vessel->SetTouchdownPoints (_V(0,0,10), _V(-1,0,-10), _V(1,0,-10));
	VECTOR3 mesh_dir=_V(0.0,-0.2,0);//
	vessel->AddMesh (hLMPKD, &mesh_dir);
    if (!ph_Dsc)  ph_Dsc  = vessel->CreatePropellantResource(8165); //2nd stage Propellant
	vessel->SetDefaultPropellantResource (ph_Dsc); // display 2nd stage propellant level in generic HUD
	if (!ph_rcslm0){ph_rcslm0 = vessel->CreatePropellantResource(100);}
	// orbiter main thrusters
	th_hover[0] = vessel->CreateThruster (_V( 0,-2.5,0), _V( 0,1,0), 44910, ph_Dsc, 3107);
	vessel->DelThrusterGroup(THGROUP_HOVER,true);
	thg_hover = vessel->CreateThrusterGroup (th_hover, 1, THGROUP_HOVER);
	SURFHANDLE tex = oapiRegisterExhaustTexture ("Exhaust_atrcs");//"Exhaust2"
	vessel->AddExhaust (th_hover[0], 15.0, 0.65);//

	
	//vessel->SetMaxThrust (ENGINE_ATTITUDE, 480);
	vessel->SetCameraOffset (_V(-1,1.0,0.0));
	vessel->SetEngineLevel(ENGINE_HOVER,0);
	AddRCS_LMH(vessel,-1.90);
	status = 0;
	stage = 0;
	bModeDocked=true;
	VECTOR3 dockpos = {0.0 ,2.4, 0};
	VECTOR3 dockdir = {0,1,0};
	VECTOR3 dockrot = {-0.7045, 0, 0.7045};
	vessel->SetDockParams(dockpos, dockdir, dockrot);
	vessel->InitNavRadios (4);
	vessel->SetEnableFocus(true);
    EDSswitch=false;
	LPswitch1=true;LPswitch2=true;LPswitch3=true;LPswitch5=true;
	
}

void SetLmVesselHoverStage(VESSEL *vessel)
{
	vessel->ClearThrusterDefinitions();
	vessel->SetSize (7);
	vessel->SetEmptyMass (6431.0);
	vessel->SetPMI (_V(2.8,2.29,2.37));
	vessel->SetCrossSections (_V(21,23,17));
	vessel->SetCW (0.1, 0.3, 1.4, 1.4);
	vessel->SetRotDrag (_V(0.7,0.7,0.7));
	vessel->SetPitchMomentScale (0);
	vessel->SetBankMomentScale (0);
	vessel->SetLiftCoeffFunc (0); 
	vessel->ClearMeshes();
	vessel->ClearExhaustRefs();
	vessel->ClearAttExhaustRefs();
	vessel->SetTouchdownPoints (_V(0,0,10), _V(-1,0,-10), _V(1,0,-10));
	VECTOR3 mesh_dir=_V(0.0,0,0);
	vessel->AddMesh (hLMVessel, &mesh_dir);
    
	if (!ph_Dsc)  ph_Dsc  = vessel->CreatePropellantResource(8165); //2nd stage Propellant
	vessel->SetDefaultPropellantResource (ph_Dsc); // display 2nd stage propellant level in generic HUD
	if (!ph_rcslm0){ph_rcslm0 = vessel->CreatePropellantResource(100);}
	
	// orbiter main thrusters
	th_hover[0] = vessel->CreateThruster (_V( 0,-2.5,0), _V( 0,1,0), 44910, ph_Dsc, 3107);
	vessel->DelThrusterGroup(THGROUP_HOVER,true);
	thg_hover = vessel->CreateThrusterGroup (th_hover, 1, THGROUP_HOVER);
	SURFHANDLE tex = oapiRegisterExhaustTexture ("Exhaust_atrcs");//"Exhaust2"
	vessel->AddExhaust (th_hover[0], 15.0, 0.65);//

	
	//vessel->SetMaxThrust (ENGINE_ATTITUDE, 480);
	
	vessel->SetCameraOffset (_V(-1,1.0,0.0));
	status = 1;
	stage = 1;
	vessel->SetEngineLevel(ENGINE_HOVER,0);
	AddRCS_LMH(vessel,-1.90);
	bModeHover=true;
	VECTOR3 dockpos = {0.0 ,2.4, 0};
	VECTOR3 dockdir = {0,1,0};
	VECTOR3 dockrot = {-0.7045, 0, 0.7045};
	vessel->SetDockParams(dockpos, dockdir, dockrot);
	vessel->InitNavRadios (4);
	//vessel->SetEnableFocus(false);
	EDSswitch=true;
	LPswitch1=true;LPswitch2=true;LPswitch3=true;LPswitch5=true;
	
}


void SetLmAscentHoverStage(VESSEL *vessel){
	vessel->ClearThrusterDefinitions();
	if(ph_Dsc){vessel->DelPropellantResource(ph_Dsc);}
	if(ph_rcslm0){vessel->DelPropellantResource(ph_rcslm0);}
	vessel->ShiftCentreOfMass(_V(0.0,3.0,0.0));
	vessel->SetSize (5);
	vessel->SetCOG_elev (5);
	vessel->SetEmptyMass (2089.0);
	vessel->SetPMI (_V(2.8,2.29,2.37));
	vessel->SetCrossSections (_V(21,23,17));
	vessel->SetCW (0.1, 0.3, 1.4, 1.4);
	vessel->SetRotDrag (_V(0.7,0.7,0.7));
	vessel->SetPitchMomentScale (0);
	vessel->SetBankMomentScale (0);
	vessel->SetLiftCoeffFunc (0); 
	vessel->ClearMeshes();
	vessel->ClearExhaustRefs();
	vessel->ClearAttExhaustRefs();
	vessel->SetTouchdownPoints (_V(0,0,10), _V(-1,0,-10), _V(1,0,-10));
	VECTOR3 mesh_dir=_V(-0.1,0,0);
	vessel->AddMesh (hLMAscent, &mesh_dir);
    if (!ph_Asc)  ph_Asc  = vessel->CreatePropellantResource(2345); //2nd stage Propellant
	vessel->SetDefaultPropellantResource (ph_Asc); // display 2nd stage propellant level in generic HUD
	if (!ph_rcslm1){ph_rcslm1 = vessel->CreatePropellantResource(100);}
	// orbiter main thrusters
	th_hover[0] = vessel->CreateThruster (_V( 0,-0.9,0), _V( 0,1,0), 15880, ph_Asc, 2921);
	vessel->DelThrusterGroup(THGROUP_HOVER,true);
	thg_hover = vessel->CreateThrusterGroup (th_hover, 1, THGROUP_HOVER);
	SURFHANDLE tex = oapiRegisterExhaustTexture ("Exhaust_atrcs");//"Exhaust2"
	vessel->AddExhaust (th_hover[0], 15.0, 0.65);//

	
	//vessel->SetMaxThrust (ENGINE_ATTITUDE, 480);
	vessel->SetCameraOffset (_V(-1,1.0,0.0));
	status = 2;
	stage = 2;
	vessel->SetEngineLevel(ENGINE_HOVER,0);
	AddRCS_LMH2(vessel,-2.18);
	bModeHover=true;
	VECTOR3 dockpos = {0.0 ,0.6, -0.3};
	VECTOR3 dockdir = {0,1,0};
	VECTOR3 dockrot = {-0.7045, 0, 0.7045};
	vessel->SetDockParams(dockpos, dockdir, dockrot);
	vessel->InitNavRadios (4);
	vessel->SetEnableFocus(false);
	EDSswitch=false;
	LPswitch5=false;
}

void SeparateStage (VESSEL *vessel, UINT stage)

{
	ResetThrusters(vessel);
	VESSELSTATUS vs1;
	VECTOR3 ofs1 = _V(0,-5,0);
	VECTOR3 vel1 = _V(0,0,0);
	


	if (stage == 1)
	{
	    vessel->GetStatus (vs1);
		vs1.eng_main = vs1.eng_hovr = 0.0;
		VECTOR3 rofs1, rvel1 = {vs1.rvel.x, vs1.rvel.y, vs1.rvel.z};
		vessel->Local2Global (ofs1, vs1.rpos);
		vessel->GlobalRot (vel1, rofs1);
		vs1.rvel.x = rvel1.x+rofs1.x;
		vs1.rvel.y = rvel1.y+rofs1.y;
		vs1.rvel.z = rvel1.z+rofs1.z;
	    vs1.vrot.x = 0.0;	
		vs1.vrot.y = 0.0;
		vs1.vrot.z = 0.0;
		vessel->GetStatus (vs1);
		PlayVesselWave(StageS,NOLOOP,150);
		char VName[256];
		strcpy (VName, vessel->GetName()); strcat (VName, "-DESCENTSTG");
		hdsc = oapiCreateVessel(VName,"sat5LMDSC",vs1);
		SetLmAscentHoverStage(vessel);
		SPSswitch=true;
		//vessel->SetEngineLevel(ENGINE_HOVER,1);
	}
	
}


// ==============================================================
// API interface
// ==============================================================
// ==============================================================
// DLL entry point
// ==============================================================

BOOL WINAPI DllMain (HINSTANCE hModule,
					 DWORD ul_reason_for_call,
					 LPVOID lpReserved)
{
	int i;

	switch (ul_reason_for_call) {
	case DLL_PROCESS_ATTACH:
		g_Param.hDLL = hModule;
		// allocate GDI resources
		g_Param.font[0]  = CreateFont (-13, 0, 0, 0, 700, 0, 0, 0, 0, 0, 0, 0, 0, "Arial");
		g_Param.font[1]  = CreateFont (-10, 0, 0, 0, 400, 0, 0, 0, 0, 0, 0, 0, 0, "Arial");
		g_Param.brush[0] = CreateSolidBrush (RGB(0,255,0));    // green
		g_Param.brush[1] = CreateSolidBrush (RGB(255,0,0));    // red
		g_Param.brush[2] = CreateSolidBrush (RGB(154,154,154));  // Grey
		g_Param.brush[3] = CreateSolidBrush (RGB(3,3,3));  // Black
		g_Param.pen[0] = CreatePen (PS_SOLID, 1, RGB(224,224,224));
		g_Param.pen[1] = CreatePen (PS_SOLID, 3, RGB(164,164,164));
		g_Param.pen[2] = CreatePen (PS_SOLID, 1, RGB(255,0,0));
		g_Param.pen[3] = CreatePen (PS_SOLID, 3, RGB(255,0,0));
		
		break;
	case DLL_PROCESS_DETACH:
		// deallocate GDI resources
		for (i = 0; i < 2; i++) DeleteObject (g_Param.font[i]);
		for (i = 0; i < 4; i++) DeleteObject (g_Param.brush[i]);
		for (i = 0; i < 4; i++) DeleteObject (g_Param.pen[i]);
		break;
	}
	return TRUE;
}

// ==============================================================
// API interface
// ==============================================================

DLLCLBK bool ovcLoadPanel (VESSEL *vessel, int id)
{
	
	ReleaseSurfaces();

	HBITMAP hBmp = LoadBitmap (g_Param.hDLL, MAKEINTRESOURCE (IDB_LEMPANEL));
	MFDSPEC mfds_left  = {{900, 1, 1098, 200}, 6, 6, 41, 27};
	MFDSPEC mfds_right = {{860+222, 546, 1057+222, 744}, 6, 6, 41, 27};

	switch (id) {
	case 0: // main panel
		oapiRegisterPanelBackground (hBmp,PANEL_ATTACH_TOP|PANEL_ATTACH_BOTTOM|PANEL_ATTACH_LEFT|PANEL_MOVEOUT_RIGHT,  0xff00ff);//
		//oapiSetPanelNeighbours (-1,-1,1,2);
		oapiRegisterMFD (MFD_LEFT,  mfds_left);
		oapiRegisterMFD (MFD_RIGHT, mfds_right);

//		oapiRegisterPanelArea (AID_PROPELLANTSTATUS,  _R(  27,  81,  144, 156), PANEL_REDRAW_ALWAYS, PANEL_MOUSE_IGNORE, PANEL_MAP_BACKGROUND);
//		oapiRegisterPanelArea (AID_ENGINESTATUS,      _R(1000,  90, 1112, 256), PANEL_REDRAW_ALWAYS, PANEL_MOUSE_IGNORE, PANEL_MAP_BACKGROUND);
		
		// left MFD
		oapiRegisterPanelArea (AID_MFD1_BBUTTONS,     _R(680+222,204,864+222,218), PANEL_REDRAW_NEVER, PANEL_MOUSE_LBDOWN); // bottom button row
		oapiRegisterPanelArea (AID_MFD1_LBUTTONS,     _R(647+222,27,665+222,179), PANEL_REDRAW_USER, PANEL_MOUSE_LBDOWN|PANEL_MOUSE_LBPRESSED, PANEL_MAP_BACKGROUND); // left button column
		oapiRegisterPanelArea (AID_MFD1_RBUTTONS,     _R( 888+222, 28,1127,180), PANEL_REDRAW_USER, PANEL_MOUSE_LBDOWN|PANEL_MOUSE_LBPRESSED, PANEL_MAP_BACKGROUND); // right button column
		// right MFD
		oapiRegisterPanelArea (AID_MFD2_BBUTTONS,     _R(865+222,746,1049+222, 761), PANEL_REDRAW_NEVER, PANEL_MOUSE_LBDOWN); // bottom button row
		oapiRegisterPanelArea (AID_MFD2_LBUTTONS,     _R(829+222,572,847+222,724), PANEL_REDRAW_USER, PANEL_MOUSE_LBDOWN|PANEL_MOUSE_LBPRESSED, PANEL_MAP_BACKGROUND); // left button column
		oapiRegisterPanelArea (AID_MFD2_RBUTTONS,     _R(1070+222,573,1088+222,726), PANEL_REDRAW_USER, PANEL_MOUSE_LBDOWN|PANEL_MOUSE_LBPRESSED, PANEL_MAP_BACKGROUND); // right button column
		//Artificial Horizon
		oapiRegisterPanelArea (AID_HORIZON,           _R( 726+222, 266,  822+222, 362), PANEL_REDRAW_ALWAYS, PANEL_MOUSE_IGNORE);
		oapiRegisterPanelArea (AID_FUEL_DIGIT,           _R( 804, 686, 862, 702), PANEL_REDRAW_ALWAYS, PANEL_MOUSE_IGNORE,PANEL_MAP_BACKGROUND);
		oapiRegisterPanelArea (AID_ALTITUDE1,           _R( 866, 728,  962, 745), PANEL_REDRAW_ALWAYS, PANEL_MOUSE_IGNORE,PANEL_MAP_BACKGROUND);
		oapiRegisterPanelArea (AID_VELOCITY1,           _R( 905, 686,  970, 702), PANEL_REDRAW_ALWAYS, PANEL_MOUSE_IGNORE,PANEL_MAP_BACKGROUND);
		oapiRegisterPanelArea (AID_VSI,           _R( 785, 727, 847, 742), PANEL_REDRAW_ALWAYS, PANEL_MOUSE_IGNORE,PANEL_MAP_BACKGROUND);        
		oapiRegisterPanelArea (AID_SWITCH_HUD,           _R( 873, 630, 957,660 ), PANEL_REDRAW_ALWAYS, PANEL_MOUSE_DOWN,PANEL_MAP_BACKGROUND);
		oapiRegisterPanelArea (AID_SPS,           _R( 804, 602, 863, 670), PANEL_REDRAW_ALWAYS, PANEL_MOUSE_DOWN,PANEL_MAP_BACKGROUND);
		oapiRegisterPanelArea (AID_GAUGES1,           _R(831, 472,  946, 568), PANEL_REDRAW_ALWAYS, PANEL_MOUSE_IGNORE,PANEL_MAP_BACKGROUND);
		oapiRegisterPanelArea (AID_SWITCH_SEP,           _R(972, 692,1010,760), PANEL_REDRAW_ALWAYS, PANEL_MOUSE_DOWN,PANEL_MAP_BACKGROUND);
		oapiRegisterPanelArea (AID_INDICATOR1,        _R(1147, 4,1252,145), PANEL_REDRAW_ALWAYS, PANEL_MOUSE_IGNORE,PANEL_MAP_BACKGROUND);
		
		
		
		oapiRegisterPanelArea (AID_SWITCH_AUTO,           _R( 1143, 158, 1312, 194), PANEL_REDRAW_ALWAYS, PANEL_MOUSE_DOWN,PANEL_MAP_BACKGROUND);
		oapiRegisterPanelArea (AID_SWITCH_JET,           _R( 1255, 19, 1312, 90), PANEL_REDRAW_ALWAYS, PANEL_MOUSE_DOWN,PANEL_MAP_BACKGROUND);
		oapiRegisterPanelArea (AID_SWITCH_AUTO2,           _R( 1257, 107, 1313, 136), PANEL_REDRAW_ALWAYS, PANEL_MOUSE_DOWN,PANEL_MAP_BACKGROUND);
		
		
		oapiRegisterPanelArea (AID_SWITCH_PANEL_RIGHT,           _R( 991, 438, 1076, 512), PANEL_REDRAW_ALWAYS, PANEL_MOUSE_DOWN,PANEL_MAP_BACKGROUND);
		oapiRegisterPanelArea (AID_SWITCH_PANEL_LEFT,           _R(1099, 471, 1310, 505), PANEL_REDRAW_ALWAYS, PANEL_MOUSE_DOWN,PANEL_MAP_BACKGROUND);
		//oapiRegisterPanelArea (AID_GAUGES_CENTER,           _R( 787, 692, 898, 764), PANEL_REDRAW_ALWAYS, PANEL_MOUSE_DOWN,PANEL_MAP_BACKGROUND);
		//oapiRegisterPanelArea (AID_LIGHTS_LAUNCHER,           _R( 908, 480, 1040, 768), PANEL_REDRAW_ALWAYS, PANEL_MOUSE_DOWN,PANEL_MAP_BACKGROUND);
		//oapiRegisterPanelArea (AID_GMETER,           _R( 622, 451, 695, 529), PANEL_REDRAW_ALWAYS, PANEL_MOUSE_DOWN,PANEL_MAP_BACKGROUND);
		oapiRegisterPanelArea (AID_THRUSTMETER,           _R( 972, 548, 1030, 607), PANEL_REDRAW_ALWAYS, PANEL_MOUSE_DOWN,PANEL_MAP_BACKGROUND);
		
		oapiRegisterPanelArea (AID_EDS,           _R( 963, 634,988, 660), PANEL_REDRAW_ALWAYS, PANEL_MOUSE_DOWN,PANEL_MAP_BACKGROUND);
		oapiRegisterPanelArea (AID_DSKY,           _R( 1222, 215, 1295, 344), PANEL_REDRAW_ALWAYS, PANEL_MOUSE_DOWN,PANEL_MAP_BACKGROUND);
        
		//oapiRegisterPanelArea (AID_CLOCK,           _R( 829, 401, 927, 418), PANEL_REDRAW_ALWAYS, PANEL_MOUSE_IGNORE,PANEL_MAP_BACKGROUND);        
		//oapiRegisterPanelArea (AID_ALTIMETER  ,           _R( 933, 103, 1021, 191), PANEL_REDRAW_ALWAYS, PANEL_MOUSE_IGNORE,PANEL_MAP_BACKGROUND);        
		oapiRegisterPanelArea (AID_DSKY_KEY,           _R(1104,354,1310,441), PANEL_REDRAW_ALWAYS, PANEL_MOUSE_DOWN,PANEL_MAP_BACKGROUND);
		oapiRegisterPanelArea (AID_HDG1,           _R(958,233,1032,241), PANEL_REDRAW_ALWAYS, PANEL_MOUSE_DOWN,PANEL_MAP_BACKGROUND);
		oapiRegisterPanelArea (AID_CONTACT,           _R(858,234,888,268), PANEL_REDRAW_ALWAYS, PANEL_MOUSE_DOWN,PANEL_MAP_BACKGROUND);
		oapiRegisterPanelArea (AID_ABORT,           _R(834,353,888,380), PANEL_REDRAW_ALWAYS, PANEL_MOUSE_DOWN,PANEL_MAP_BACKGROUND);
		
		break;

	case 1: // overhead panel
		break;

	case 2: // bottom panel
		break;
	}
	InitPanel (id);
	return hBmp != NULL;
}
DLLCLBK bool ovcPanelMouseEvent (VESSEL *vessel, int id, int event, int mx, int my)
{
	int mfd;
	static int ctrl = 0;

	switch (id) {
	// panel 0 events:
	case AID_MFD1_BBUTTONS:
	case AID_MFD2_BBUTTONS:
		mfd = (id == AID_MFD1_BBUTTONS ? MFD_LEFT : MFD_RIGHT);
		if (mx < 17)                    oapiToggleMFD_on (mfd);
		else if (mx >= 145 && mx < 162) oapiSendMFDKey (mfd, OAPI_KEY_F1);
		else if (mx > 167)              oapiSendMFDKey (mfd, OAPI_KEY_GRAVE);
		return true;
	case AID_MFD1_LBUTTONS:
	case AID_MFD1_RBUTTONS:
	case AID_MFD2_LBUTTONS:
	case AID_MFD2_RBUTTONS:
		if (my%27 < 16) {
			mfd = (id <= AID_MFD1_RBUTTONS ? MFD_LEFT : MFD_RIGHT);
			int bt = my/27 + (id == AID_MFD1_LBUTTONS || id == AID_MFD2_LBUTTONS ? 0 : 6);
			oapiProcessMFDButton (mfd, bt, event);
			return true;
		}
		break;
	case AID_SWITCH_HUD:
		if (mx >=7 && mx <=17 ){//HUD_DOCKING
			if (my < 15 && oapiGetHUDMode() !=HUD_DOCKING){
				PlayVesselWave(Sclick,NOLOOP,255);
				oapiSetHUDMode(HUD_DOCKING) ;
			}else if(my >15 && oapiGetHUDMode() ==HUD_DOCKING){
				PlayVesselWave(Sclick,NOLOOP,255);
				oapiSetHUDMode(HUD_NONE) ;
			}
		}
	if (mx >=37 && mx <=47 ){//HUD_SURFACE
			if (my < 15 && oapiGetHUDMode() !=HUD_SURFACE){
				PlayVesselWave(Sclick,NOLOOP,255);
				oapiSetHUDMode(HUD_SURFACE) ;
			}else if(my >15 && oapiGetHUDMode() ==HUD_SURFACE){
				PlayVesselWave(Sclick,NOLOOP,255);
				oapiSetHUDMode(HUD_NONE) ;
			}
		}
	if (mx >=64 && mx <=74 ){//HUD_ORBIT
			if (my < 15 && oapiGetHUDMode() !=HUD_ORBIT){
				PlayVesselWave(Sclick,NOLOOP,255);
				oapiSetHUDMode(HUD_ORBIT) ;
			}else if(my >15 && oapiGetHUDMode() ==HUD_ORBIT){
				PlayVesselWave(Sclick,NOLOOP,255);
				oapiSetHUDMode(HUD_NONE) ;
			}
		}
	return true;
	case AID_SWITCH_JET:
	if(event & PANEL_MOUSE_RBDOWN){
			if(mx <24 ){
			Cswitch2 = !Cswitch2;
			PlayVesselWave(Sclick,NOLOOP,255);
			}
			if(mx <54 && mx>29 ){
			Cswitch3= !Cswitch3;
			PlayVesselWave(Sclick,NOLOOP,255);
			}
		
			
		}else if(event & PANEL_MOUSE_LBDOWN){
			
			if(mx <24 && Cswitch2){
				if(my >19 && my <28 && !Sswitch2){
				Sswitch2 = true;
				PlayVesselWave(Sclick,NOLOOP,255);
				}else if(my >28 && my <38 && Sswitch2 && Cswitch2){
				Sswitch2 = false;
				PlayVesselWave(Sclick,NOLOOP,255);
				
				}
			}
			if(mx <54 && mx>29 && Cswitch3){
				if(my >19 && my <28 && !Sswitch3){
				Sswitch3 = true;
				PlayVesselWave(Sclick,NOLOOP,255);
				}else if(my >28 && my <38 && Sswitch3 && Cswitch3){
				Sswitch3= false;
				PlayVesselWave(Sclick,NOLOOP,255);
				
				}
			}
			
			
		}return true;
		
	case AID_SPS:
			if (my >32 && SPSswitch){
				SPSswitch =false;
				PlayVesselWave(Sclick,NOLOOP,255);
							
			}else if(!SPSswitch && my < 32){
				SPSswitch =true;
				PlayVesselWave(Sclick,NOLOOP,255);
				
			}
		return true;
	case AID_DSKY_KEY:	

	DKey0=false;
	DKey1=false;
	DKey2=false;
	DKey3=false;
	DKey4=false;
	DKey5=false;
	DKey6=false;
	DKey7=false;
	DKey8=false;
	DKey9=false;
	DKeyP=false;
	DKeyM=false;
	DKeyENTR=false;
	DKeyRESET=false;
	DKeyCLR=false;
	DKeySTBY=false;
	DKeyKRLS=false;
	DKeyVERB =false;
	DKeyNOUN=false;

		if (mx > 0 && mx < 26){
				if (my > 13 && my < 39){
					DKeyVERB =true;			
				}
				if (my > 45 && my < 69){
					DKeyNOUN =true;			
				}
		}else if (mx > 172 && mx < 200){
				if (my > 13 && my < 39){
					DKeyENTR=true;			
				}
				if (my > 45 && my < 69){
					DKeyRESET =true;			
				}
		}else if (mx > 27 && mx < 54){
				if (my > 2 && my < 25){
					DKeyP=true;			
				}
				if (my > 30 && my < 55){
					DKeyM =true;			
				}
				if (my > 60 && my < 85){
					DKey0 =true;			
				}
		}else if (mx > 57 && mx < 83){
				if (my > 2 && my < 25){
					DKey7=true;			
				}
				if (my > 30 && my < 55){
					DKey4 =true;			
				}
				if (my > 60 && my < 85){
					DKey1 =true;			
				}
		}else if (mx > 87 && mx < 112){
				if (my > 2 && my < 25){
					DKey8=true;			
				}
				if (my > 30 && my < 55){
					DKey5 =true;			
				}
				if (my > 60 && my < 85){
					DKey2 =true;			
				}
		}else if (mx > 117 && mx < 141){
				if (my > 2 && my < 25){
					DKey9=true;			
				}
				if (my > 30 && my < 55){
					DKey6 =true;			
				}
				if (my > 60 && my < 85){
					DKey3 =true;			
				}
		}else if (mx > 146 && mx < 169){
				if (my > 2 && my < 25){
					DKeyCLR=true;			
				}
				if (my > 30 && my < 55){
					DKeySTBY =true;			
				}
				if (my > 60 && my < 85){
					DKeyKRLS =true;			
				}
		}
	
		if(DKey0||DKey1||DKey2||DKey3||DKey4||DKey5||DKey6||DKey7||DKey8||DKey9||DKeyP||DKeyM||DKeyENTR||DKeyRESET||DKeyCLR||DKeySTBY||DKeyKRLS||DKeyVERB||DKeyNOUN){	
		PlayVesselWave(Sclick,NOLOOP,255);
		}
		return true;
	case AID_ABORT:
		if (mx > 39 && mx < 86 && my > 175 && my < 201){
		bAbort =true;
		}
		return true;
	case AID_SWITCH_SEP:
		if(event & PANEL_MOUSE_RBDOWN){
			
			Cswitch1 = !Cswitch1;
			PlayVesselWave(Sclick,NOLOOP,255);
		
		}else if(event & PANEL_MOUSE_LBDOWN){
			
			
				if(my >19 && my <28 && !Sswitch1){
				Sswitch1 = true;
				PlayVesselWave(Sclick,NOLOOP,255);
				}else if(my >28 && my <38 && Sswitch1 && Cswitch1){
				Sswitch1 = false;
				PlayVesselWave(Sclick,NOLOOP,255);
				
				}
		}
		
		return true;
	case AID_SWITCH_AUTO:
		if (mx >=7 && mx <=17 ){
			if (my < 17 && !vessel->GetNavmodeState(NAVMODE_KILLROT)){
				PlayVesselWave(Sclick,NOLOOP,255);
				vessel->ActivateNavmode(NAVMODE_KILLROT);
			}else if(my >17 && vessel->GetNavmodeState(NAVMODE_KILLROT)){
				PlayVesselWave(Sclick,NOLOOP,255);
				vessel->DeactivateNavmode(NAVMODE_KILLROT);
			}
		}
		if (mx >=37 && mx <=47 ){
			if ( my < 17 && !vessel->GetNavmodeState(NAVMODE_PROGRADE)){
				PlayVesselWave(Sclick,NOLOOP,255);
				vessel->ActivateNavmode(NAVMODE_PROGRADE);
			}else if(my >17 && vessel->GetNavmodeState(NAVMODE_PROGRADE)){
				PlayVesselWave(Sclick,NOLOOP,255);
				vessel->DeactivateNavmode(NAVMODE_PROGRADE);
			}
		}
		if (mx >=65 && mx <=75 ){
			if ( my < 17 && !vessel->GetNavmodeState(NAVMODE_RETROGRADE)){
				PlayVesselWave(Sclick,NOLOOP,255);
				vessel->ActivateNavmode(NAVMODE_RETROGRADE);
			}else if(my >17 && vessel->GetNavmodeState(NAVMODE_RETROGRADE)){
				PlayVesselWave(Sclick,NOLOOP,255);
				vessel->DeactivateNavmode(NAVMODE_RETROGRADE);
			}
		}
		if (mx >=108 && mx <=118 ){
			if (my < 17 && !vessel->GetNavmodeState(NAVMODE_NORMAL)){
				PlayVesselWave(Sclick,NOLOOP,255);
				vessel->ActivateNavmode(NAVMODE_NORMAL);
			}else if(my >17 && vessel->GetNavmodeState(NAVMODE_NORMAL)){
				PlayVesselWave(Sclick,NOLOOP,255);
				vessel->DeactivateNavmode(NAVMODE_NORMAL);
			}
		}
		if (mx >=144 && mx <=154 ){
			if (my >8 && my < 17 && !vessel->GetNavmodeState(NAVMODE_ANTINORMAL)){
				PlayVesselWave(Sclick,NOLOOP,255);
				vessel->ActivateNavmode(NAVMODE_ANTINORMAL);
			}else if(my >17 && my < 24 && vessel->GetNavmodeState(NAVMODE_ANTINORMAL)){
				PlayVesselWave(Sclick,NOLOOP,255);
				vessel->DeactivateNavmode(NAVMODE_ANTINORMAL);
			}
		}
	return true;

	case AID_SWITCH_AUTO2:
		if (mx >=7 && mx <=17 ){
			if (my < 15 && !vessel->GetNavmodeState(NAVMODE_HLEVEL)){
				PlayVesselWave(Sclick,NOLOOP,255);
				vessel->ActivateNavmode(NAVMODE_HLEVEL);
			}else if(my >15 && vessel->GetNavmodeState(NAVMODE_HLEVEL)){
				PlayVesselWave(Sclick,NOLOOP,255);
				vessel->DeactivateNavmode(NAVMODE_HLEVEL);
			}
		}
	if (mx >=37 && mx <=47 ){
			if (my < 15 && !vessel->GetNavmodeState(NAVMODE_HOLDALT)){
				PlayVesselWave(Sclick,NOLOOP,255);
				vessel->ActivateNavmode(NAVMODE_HOLDALT);
			}else if(my >15 && vessel->GetNavmodeState(NAVMODE_HOLDALT)){
				PlayVesselWave(Sclick,NOLOOP,255);
				vessel->DeactivateNavmode(NAVMODE_HOLDALT);
			}
		}
	case AID_SWITCH_PANEL_RIGHT:
	
		if (my >=39 && my <=49 ){
			if (mx > 8 && mx < 18 && !RPswitch1){
				PlayVesselWave(Sclick,NOLOOP,255);
				RPswitch1=true;
			}else if (mx > 39 && mx < 49 && !RPswitch2 && RPswitch1){
				PlayVesselWave(Sclick,NOLOOP,255);
				RPswitch2=true;
			}else if (mx > 69 && mx < 79 && !RPswitch3 && RPswitch2 ){
				PlayVesselWave(Sclick,NOLOOP,255);
				RPswitch3=true;
			}			
		}else if (my >=50 && my <=60 ){
			if (mx >8 && mx < 18 && RPswitch1 && !RPswitch2){
				PlayVesselWave(Sclick,NOLOOP,255);
				RPswitch1=false;
			}else if (mx >39 && mx < 49 && RPswitch2 && !RPswitch3){
				PlayVesselWave(Sclick,NOLOOP,255);
				RPswitch2=false;
			}else if (mx >69 && mx < 79 && RPswitch3 ){
				PlayVesselWave(Sclick,NOLOOP,255);
				RPswitch3=false;
			}
	}
	
	
	return true;
	
	case AID_SWITCH_PANEL_LEFT:
	if (my >=5 && my <=15 ){
			if (mx >8 && mx < 18 && !LPswitch1){
				PlayVesselWave(Sclick,NOLOOP,255);
				LPswitch1=true;
			}else if (mx >39 && mx < 49 && !LPswitch2){
				PlayVesselWave(Sclick,NOLOOP,255);
				LPswitch2=true;
			}else if (mx >68 && mx < 78 && !LPswitch3){
				PlayVesselWave(Sclick,NOLOOP,255);
				LPswitch3=true;
			}else if (mx >99 && mx < 109 && !LPswitch4){
				PlayVesselWave(Sclick,NOLOOP,255);
				LPswitch4=true;
				toggleRCS =true;
			}else if (mx >129 && mx < 139 && !LPswitch5){
				PlayVesselWave(Sclick,NOLOOP,255);
				LPswitch5=true;
				toggleRCS =true;
			}else if (mx >157 && mx < 167 && !LPswitch6){
				PlayVesselWave(Sclick,NOLOOP,255);
				LPswitch6=true;
			}else if (mx >189 && mx < 199 && !LPswitch7){
				PlayVesselWave(Sclick,NOLOOP,255);
				LPswitch7=true;
			}
			
	}else if (my >=16 && my <=26 ){
			if (mx >8 && mx < 18 && LPswitch1){
				PlayVesselWave(Sclick,NOLOOP,255);
				LPswitch1=false;
			}else if (mx >39 && mx < 49 && LPswitch2){
				PlayVesselWave(Sclick,NOLOOP,255);
				LPswitch2=false;
			}else if (mx >68 && mx < 78 && LPswitch3){
				PlayVesselWave(Sclick,NOLOOP,255);
				LPswitch3=false;
			}else if (mx >99 && mx < 109 && LPswitch4){
				PlayVesselWave(Sclick,NOLOOP,255);
				LPswitch4=false;
				toggleRCS =true;
			}else if (mx >129 && mx < 139 && LPswitch5){
				PlayVesselWave(Sclick,NOLOOP,255);
				LPswitch5=false;
				toggleRCS =true;
			}else if (mx >157 && mx < 167 && LPswitch6){
				PlayVesselWave(Sclick,NOLOOP,255);
				LPswitch6=false;
			}else if (mx >189 && mx < 199 && LPswitch7){
				PlayVesselWave(Sclick,NOLOOP,255);
				LPswitch7=false;
			}
	}
	
		
	return true;
	//
	case AID_EDS:
			if (my > 10 && EDSswitch){
				EDSswitch =false;
				PlayVesselWave(Sclick,NOLOOP,255);
							
			}else if(!EDSswitch && my < 10){
				EDSswitch =true;
				PlayVesselWave(Sclick,NOLOOP,255);
				
			}
			VESSELSTATUS vs;
			vessel->GetStatus(vs);
				
			
				if (vessel->GetEngineLevel(ENGINE_MAIN)==0 &&vessel->GetEngineLevel(ENGINE_HOVER)==0&& vs.status ==0){
					if (!EDSswitch){
						if (status==1){
						SetLmVesselDockStage(vessel);
						bModeDocked = true;
						bModeHover=false;
						//PlayVesselWave(SDMode,NOLOOP,255);
						}
					}else {
						bModeDocked = false;
						bModeHover=true;
						//PlayVesselWave(SHMode,NOLOOP,255);
						if (status==0){
						SetLmVesselHoverStage(vessel);
						}
					}
				}
			
		return true;

	// panel 1 events:
	}
	return false;

}
DLLCLBK bool ovcPanelRedrawEvent (VESSEL *vessel, int id, int event, SURFHANDLE surf)
{
	

	switch (id) {
	// panel 0 events:
	case AID_ABORT:
		if (bAbort){
			oapiBlt(surf,srf[9],0,0,47,0,46,23);
		}return true;
	
	case AID_CONTACT:
		if (vessel->GroundContact()&& stage ==1){
			oapiBlt(surf,srf[18],0,0,0,0,30,30);
		}return true;
	case AID_SWITCH_SEP:
		if(Cswitch1){
			oapiBlt(surf,srf[8],2,0,29,0,27,49);
			if(Sswitch1){
			oapiBlt(surf,srf[6],3,20,0,0,23,20);
			}else{
			oapiBlt(surf,srf[6],3,20,24,0,23,20);
			}
		}else{
			oapiBlt(surf,srf[8],2,0,0,0,27,49);
			Sswitch1=false;
		}
		return true;
	case AID_SWITCH_PANEL_RIGHT:

		if(RPswitch1){
			oapiBlt(surf,srf[6],2,40,0,0,23,20);
			oapiBlt(surf,srf[13],6,1,35,0,17,17);
		}else{
			oapiBlt(surf,srf[6],2,41,24,0,23,20);
			oapiBlt(surf,srf[13],6,1,18,0,17,17);
		}
		if(RPswitch2){
			oapiBlt(surf,srf[6],32,40,0,0,23,20);
			oapiBlt(surf,srf[13],34,1,35,0,17,17);
		}else{
			oapiBlt(surf,srf[6],32,41,24,0,23,20);
			oapiBlt(surf,srf[13],34,1,18,0,17,17);
			
		}
		if(RPswitch3){
			oapiBlt(surf,srf[6],61,40,0,0,23,20);
		}else{
			oapiBlt(surf,srf[6],62,41,24,0,23,20);
		}return true;
	case AID_HORIZON:
		RedrawPanel_Horizon (vessel,surf);
		return true;
	case AID_INDICATOR1:
		if(status > 5){
			//if (autopilot){
			//oapiBlt(surf,srf[1],0,0,105,0,105,18);
			//}else{
			//oapiBlt(surf,srf[1],0,0,210,0,105,18);
			//}
		}else{
		oapiBlt(surf,srf[1],0,0,0,0,105,18);
		}
		if(vessel->GetNavmodeState(NAVMODE_KILLROT)){
			oapiBlt(surf,srf[1],0,91,105,95,105,18);
		}else{
			oapiBlt(surf,srf[1],0,91,0,95,105,18);
		}
		if(vessel->GetNavmodeState(NAVMODE_PROGRADE)){
			oapiBlt(surf,srf[1],0,19,105,21,105,18);
		}else{
			oapiBlt(surf,srf[1],0,19,0,21,105,18);
		}if(vessel->GetNavmodeState(NAVMODE_RETROGRADE)){
			oapiBlt(surf,srf[1],0,37,105,39,105,18);
		}else{
			oapiBlt(surf,srf[1],0,37,0,39,105,18);
		}if(vessel->GetNavmodeState(NAVMODE_NORMAL)){
			oapiBlt(surf,srf[1],0,54,105,56,105,18);
		}else{
			oapiBlt(surf,srf[1],0,54,0,56,105,18);
		}if(vessel->GetNavmodeState(NAVMODE_ANTINORMAL)){
			oapiBlt(surf,srf[1],0,72,105,74,105,18);
		}else{
			oapiBlt(surf,srf[1],0,72,0,74,105,18);
		}
		if(vessel->GetNavmodeState(NAVMODE_HLEVEL)){
			oapiBlt(surf,srf[1],0,108,105,112,105,18);
		}else{
			oapiBlt(surf,srf[1],0,108,0,112,105,18);
		}
		if(vessel->GetNavmodeState(NAVMODE_HOLDALT)){
			oapiBlt(surf,srf[1],0,126,105,129,105,14);
		}else{
			oapiBlt(surf,srf[1],0,126,0,129,105,14);
		}
		return true;
	case AID_VELOCITY1:
		int Curdigit;
		int Curdigit2;
		Curdigit=actualVEL/10000;
		oapiBlt(surf,srf[4],0,0,10*Curdigit,0,10,15);
		Curdigit=actualVEL/1000;
		Curdigit2=actualVEL/10000;
		oapiBlt(surf,srf[4],10,0,10*(Curdigit-(Curdigit2*10)),0,10,15);
		Curdigit=actualVEL/100;
		Curdigit2=actualVEL/1000;
		oapiBlt(surf,srf[4],20,0,10*(Curdigit-(Curdigit2*10)),0,10,15);
		Curdigit=actualVEL/10;
		Curdigit2=actualVEL/100;
		oapiBlt(surf,srf[4],30,0,10*(Curdigit-(Curdigit2*10)),0,10,15);
		Curdigit=actualVEL;
		Curdigit2=actualVEL/10;
		oapiBlt(surf,srf[4],40,0,10*(Curdigit-(Curdigit2*10)),0,10,15);
		return true;
	
	case AID_VSI:
			
		Curdigit=fabs(VSPEEDN1)/10000;
		oapiBlt(surf,srf[4],10,0,10*Curdigit,0,10,15);
		Curdigit=fabs(VSPEEDN1)/1000;
		Curdigit2=fabs(VSPEEDN1)/10000;
		oapiBlt(surf,srf[4],20,0,10*(Curdigit-(Curdigit2*10)),0,10,15);
		Curdigit=fabs(VSPEEDN1)/100;
		Curdigit2=fabs(VSPEEDN1)/1000;
		oapiBlt(surf,srf[4],30,0,10*(Curdigit-(Curdigit2*10)),0,10,15);
		Curdigit=fabs(VSPEEDN1)/10;
		Curdigit2=fabs(VSPEEDN1)/100;
		oapiBlt(surf,srf[4],40,0,10*(Curdigit-(Curdigit2*10)),0,10,15);
		Curdigit=fabs(VSPEEDN1);
		Curdigit2=fabs(VSPEEDN1)/10;
		oapiBlt(surf,srf[4],50,0,10*(Curdigit-(Curdigit2*10)),0,10,15);

		if (VSPEEDN1 < 0){
		oapiBlt(surf,srf[4],0,0,100,0,10,15);
		}else{
		oapiBlt(surf,srf[4],0,0,110,0,10,15);
		}
		return true;
		
	case AID_FUEL_DIGIT:
		int TmpFUEL;
		double tmpFUELdec;
		int tmpfuel2;
		
		TmpFUEL = actualFUEL;
		tmpFUELdec = actualFUEL-TmpFUEL;
		tmpfuel2 = tmpFUELdec *100;
		

		Curdigit=actualFUEL/100;
		oapiBlt(surf,srf[4],0,0,10*Curdigit,0,10,15);
		Curdigit=actualFUEL/10;
		Curdigit2=actualFUEL/100;
		oapiBlt(surf,srf[4],10,0,10*(Curdigit-(Curdigit2*10)),0,10,15);
		Curdigit=actualFUEL;
		Curdigit2=actualFUEL/10;
		oapiBlt(surf,srf[4],20,0,10*(Curdigit-(Curdigit2*10)),0,10,15);
		
		oapiBlt(surf,srf[4],30,0,140,0,10,15);//dot display
		
		Curdigit=tmpfuel2/10 ;
		Curdigit2=tmpfuel2 /100;
		oapiBlt(surf,srf[4],40,0,10*(Curdigit-(Curdigit2*10)),0,10,15);


		return true;
	
	
	case AID_ALTITUDE1:
		int TmpALT;
		double tmpALTdec;
		int tmpalt2;
		if (actualALT > 999999){
		actualALT = actualALT /1000000;
		oapiBlt(surf,srf[4],85,0,130,0,10,15);	
		}else if (actualALT > 9999){
		actualALT =actualALT /1000;
		oapiBlt(surf,srf[4],85,0,120,0,10,15);	
		}
		
		TmpALT = actualALT;
		tmpALTdec = actualALT-TmpALT;
		tmpalt2 = tmpALTdec *100;
		
		Curdigit=actualALT/10000;
		oapiBlt(surf,srf[4],0,0,10*Curdigit,0,10,15);
		Curdigit=actualALT/1000;
		Curdigit2=actualALT/10000;
		oapiBlt(surf,srf[4],10,0,10*(Curdigit-(Curdigit2*10)),0,10,15);
		Curdigit=actualALT/100;
		Curdigit2=actualALT/1000;
		oapiBlt(surf,srf[4],20,0,10*(Curdigit-(Curdigit2*10)),0,10,15);
		Curdigit=actualALT/10;
		Curdigit2=actualALT/100;
		oapiBlt(surf,srf[4],30,0,10*(Curdigit-(Curdigit2*10)),0,10,15);
		Curdigit=actualALT;
		Curdigit2=actualALT/10;
		oapiBlt(surf,srf[4],40,0,10*(Curdigit-(Curdigit2*10)),0,10,15);
		oapiBlt(surf,srf[4],50,0,140,0,10,15);//dot display
		
		Curdigit=tmpalt2/10 ;
		Curdigit2=tmpalt2 /100;
		oapiBlt(surf,srf[4],60,0,10*(Curdigit-(Curdigit2*10)),0,10,15);
		Curdigit=tmpalt2 ;
		Curdigit2=tmpalt2 /10;
		oapiBlt(surf,srf[4],70,0,10*(Curdigit-(Curdigit2*10)),0,10,15);
		return true;
			
	case AID_SWITCH_HUD:
		
		if(oapiGetHUDMode() == HUD_DOCKING){
			oapiBlt(surf,srf[6],1,6,0,0,23,20);
		}else{
			oapiBlt(surf,srf[6],1,6,24,0,23,20);
		}
		if(oapiGetHUDMode() == HUD_SURFACE){
			oapiBlt(surf,srf[6],30,6,0,0,23,20);
		}else{
			oapiBlt(surf,srf[6],30,6,24,0,23,20);
		}
		if(oapiGetHUDMode() == HUD_ORBIT){
			oapiBlt(surf,srf[6],59,6,0,0,23,20);
		}else{
			oapiBlt(surf,srf[6],59,6,24,0,23,20);
		}return true;
	case AID_SPS:
		if(SPSswitch){
		oapiBlt(surf,srf[7],1,0,0,0,48,63);
		}else{
		oapiBlt(surf,srf[7],0,0,49,0,48,63);
		}
		return true;
	case AID_HDG1:
	case AID_HDG2:
		double cap;
		oapiGetHeading(vessel->GetHandle(),&cap);
		cap = cap * DEG;
		//cap = 359;
		oapiBlt(surf,srf[17],0,0,4+(cap/10*12),0,72,7);
		return true;
		//sprintf(oapiDebugString() ,"Heading %f",cap);

	case AID_SWITCH_AUTO:
		if(vessel->GetNavmodeState(NAVMODE_KILLROT)){
			oapiBlt(surf,srf[6],2,8,0,0,23,20);
		}else{
			oapiBlt(surf,srf[6],2,8,24,0,23,20);
		}
		if(vessel->GetNavmodeState(NAVMODE_PROGRADE)){
			oapiBlt(surf,srf[6],33,8,0,0,23,20);
		}else{
			oapiBlt(surf,srf[6],31,8,24,0,23,20);
		}
		if(vessel->GetNavmodeState(NAVMODE_RETROGRADE)){
			oapiBlt(surf,srf[6],61,8,0,0,23,20);
		}else{
			oapiBlt(surf,srf[6],59,8,24,0,23,20);
		}
		if(vessel->GetNavmodeState(NAVMODE_NORMAL)){
			oapiBlt(surf,srf[6],102,8,0,0,23,20);
		}else{
			oapiBlt(surf,srf[6],100,8,24,0,23,20);
		}
		if(vessel->GetNavmodeState(NAVMODE_ANTINORMAL)){
			oapiBlt(surf,srf[6],140,8,0,0,23,20);
		}else{
			oapiBlt(surf,srf[6],138,8,24,0,23,20);
		}return true;
	
	case AID_SWITCH_AUTO2:
		if(vessel->GetNavmodeState(NAVMODE_HLEVEL)){
			oapiBlt(surf,srf[6],2,4,0,0,23,20);
		}else{
			oapiBlt(surf,srf[6],2,4,24,0,23,20);
		}
		if(vessel->GetNavmodeState(NAVMODE_HOLDALT)){
			oapiBlt(surf,srf[6],31,4,0,0,23,20);
		}else{
			oapiBlt(surf,srf[6],31,4,24,0,23,20);
		}return true;	
	case AID_THRUSTMETER  :
		RedrawPanel_Thrust(vessel,surf);
		return true;
	
	
	case AID_GAUGES1:
		double DispValue;
		
		if(ph_Dsc){
			DispValue = vessel->GetPropellantMass(ph_Dsc)/8165;
		}else{
				DispValue =0;
		}
		oapiBlt(surf,srf[2],0,(90-(DispValue)*90),0,0,6,4);//
		if(ph_Asc){
		DispValue = vessel->GetPropellantMass(ph_Asc)/vessel->GetPropellantMaxMass(ph_Asc);
		}else{
			DispValue =1;
		}
		
		oapiBlt(surf,srf[2],31,(90-(DispValue)*90),10,0,6,4);//
		if(ph_rcslm0){
		DispValue = vessel->GetPropellantMass(ph_rcslm0)/100;
		//sprintf(oapiDebugString(),"rcs0lm = true");
		}else{
			
			DispValue =0;
		}
		oapiBlt(surf,srf[2],65,(90-(DispValue)*90),0,0,6,4);//
		if(ph_rcslm1){
		DispValue = vessel->GetPropellantMass(ph_rcslm1)/100;
		}else{
			DispValue =1;
		}
		oapiBlt(surf,srf[2],96,(90-(DispValue)*90),10,0,6,4);//
		
		return true;
	
	case AID_DSKY:		
		
		Curdigit=DPROG/10;
		Curdigit2=DPROG/100;
		oapiBlt(surf,srf[4],46,10,10*(Curdigit-(Curdigit2*10)),0,10,15);
		Curdigit=DPROG;
		Curdigit2=DPROG/10;
		oapiBlt(surf,srf[4],56,10,10*(Curdigit-(Curdigit2*10)),0,10,15);
		
		
		Curdigit=VERB/10;
		Curdigit2=VERB/100;
		oapiBlt(surf,srf[4],4,34,10*(Curdigit-(Curdigit2*10)),0,10,15);
		Curdigit=VERB;
		Curdigit2=VERB/10;
		oapiBlt(surf,srf[4],14,34,10*(Curdigit-(Curdigit2*10)),0,10,15);
		
		Curdigit=NOUN/10;
		Curdigit2=NOUN/100;
		oapiBlt(surf,srf[4],46,34,10*(Curdigit-(Curdigit2*10)),0,10,15);
		Curdigit=NOUN;
		Curdigit2=NOUN/10;
		oapiBlt(surf,srf[4],56,34,10*(Curdigit-(Curdigit2*10)),0,10,15);
		

		Curdigit=fabs(R1)/10000;
		oapiBlt(surf,srf[4],4+6,54,10*Curdigit,0,10,15);
		Curdigit=fabs(R1)/1000;
		Curdigit2=fabs(R1)/10000;
		oapiBlt(surf,srf[4],4+16,54,10*(Curdigit-(Curdigit2*10)),0,10,15);
		Curdigit=fabs(R1)/100;
		Curdigit2=fabs(R1)/1000;
		oapiBlt(surf,srf[4],4+26,54,10*(Curdigit-(Curdigit2*10)),0,10,15);
		Curdigit=fabs(R1)/10;
		Curdigit2=fabs(R1)/100;
		oapiBlt(surf,srf[4],4+36,54,10*(Curdigit-(Curdigit2*10)),0,10,15);
		Curdigit=fabs(R1);
		Curdigit2=fabs(R1)/10;
		oapiBlt(surf,srf[4],4+46,54,10*(Curdigit-(Curdigit2*10)),0,10,15);
		if (R1<0){
		oapiBlt(surf,srf[4],0,54,100,0,10,15);
		}else{
		oapiBlt(surf,srf[4],0,54,110,0,10,15);
		}
		
		// Minute display on five digit (Dsky mode)
		Curdigit=fabs(R2)/10000;
		oapiBlt(surf,srf[4],4+6,78,10*Curdigit,0,10,15);
		Curdigit=fabs(R2)/1000;
		Curdigit2=fabs(R2)/10000;
		oapiBlt(surf,srf[4],4+16,78,10*(Curdigit-(Curdigit2*10)),0,10,15);
		Curdigit=fabs(R2)/100;
		Curdigit2=fabs(R2)/1000;
		oapiBlt(surf,srf[4],4+26,78,10*(Curdigit-(Curdigit2*10)),0,10,15);
		Curdigit=fabs(R2)/10;
		Curdigit2=fabs(R2)/100;
		oapiBlt(surf,srf[4],4+36,78,10*(Curdigit-(Curdigit2*10)),0,10,15);
		Curdigit=fabs(R2);
		Curdigit2=fabs(R2)/10;
		oapiBlt(surf,srf[4],4+46,78,10*(Curdigit-(Curdigit2*10)),0,10,15);
		if (R2<0){
		oapiBlt(surf,srf[4],0,78,100,0,10,15);
		}else{
		oapiBlt(surf,srf[4],0,78,110,0,10,15);
		}

		// second display on five digit (Dsky mode)
		Curdigit=fabs(R3)/10000;
		oapiBlt(surf,srf[4],4+6,100,10*Curdigit,0,10,15);
		Curdigit=fabs(R3)/1000;
		Curdigit2=fabs(R3)/10000;
		oapiBlt(surf,srf[4],4+16,100,10*(Curdigit-(Curdigit2*10)),0,10,15);
		Curdigit=fabs(R3)/100;
		Curdigit2=fabs(R3)/1000;
		oapiBlt(surf,srf[4],4+26,100,10*(Curdigit-(Curdigit2*10)),0,10,15);
		Curdigit=fabs(R3)/10;
		Curdigit2=fabs(R3)/100;
		oapiBlt(surf,srf[4],4+36,100,10*(Curdigit-(Curdigit2*10)),0,10,15);
		Curdigit=fabs(R3);
		Curdigit2=fabs(R3)/10;
		oapiBlt(surf,srf[4],4+46,100,10*(Curdigit-(Curdigit2*10)),0,10,15);
		if (R3<0){
		oapiBlt(surf,srf[4],0,100,100,0,10,15);
		}else{
		oapiBlt(surf,srf[4],0,100,110,0,10,15);
		}
		
		
		return true;
	case AID_EDS:
		if(EDSswitch){
			oapiBlt(surf,srf[6],0,1,0,0,23,20);
		}else{
			oapiBlt(surf,srf[6],0,0,24,0,23,20);
		}
		return true;
	case AID_SWITCH_PANEL_LEFT:
		
		
		if(LPswitch1){
			oapiBlt(surf,srf[6],3,6,0,0,23,20);
		}else{
			oapiBlt(surf,srf[6],2,6,24,0,23,20);
		}
		if(LPswitch2){
			oapiBlt(surf,srf[6],33,7,0,0,23,20);
		}else{
			oapiBlt(surf,srf[6],32,6,24,0,23,20);
		}
		if(LPswitch3){
			oapiBlt(surf,srf[6],63,6,0,0,23,20);
		}else{
			oapiBlt(surf,srf[6],62,6,24,0,23,20);
		}
		if(LPswitch4){
			oapiBlt(surf,srf[6],94,7,0,0,23,20);
		}else{
			oapiBlt(surf,srf[6],93,7,24,0,23,20);
		}
		if(LPswitch5){
			oapiBlt(surf,srf[6],124,7,0,0,23,20);
		}else{
			oapiBlt(surf,srf[6],123,7,24,0,23,20);
		}
		if(LPswitch6){
			oapiBlt(surf,srf[6],154,7,0,0,23,20);
		}else{
			oapiBlt(surf,srf[6],153,7,24,0,23,20);
		}
		if(LPswitch7){
			oapiBlt(surf,srf[6],184,7,0,0,23,20);
		}else{
			oapiBlt(surf,srf[6],183,7,24,0,23,20);
		}

	return true;
	
	
	
	case AID_SWITCH_JET:
		if(Cswitch3){
			oapiBlt(surf,srf[8],30,0,89,0,27,49);
			if(Sswitch3){
			oapiBlt(surf,srf[6],31,20,0,0,23,20);
			}else{
			oapiBlt(surf,srf[6],31,20,24,0,23,20);
			}
		}else{
			oapiBlt(surf,srf[8],30,0,60,0,27,49);
			
			Sswitch3=false;
		}
		if(Cswitch2){
			oapiBlt(surf,srf[8],2,0,89,0,27,49);
			if(Sswitch2){
			oapiBlt(surf,srf[6],3,20,0,0,23,20);
			}else{
			oapiBlt(surf,srf[6],3,20,24,0,23,20);
			}
		}else{
			oapiBlt(surf,srf[8],2,0,60,0,27,49);
			Sswitch2=false;
		}
		return true;		
	}	
	
	return false;
}
DLLCLBK VESSEL *ovcInit (OBJHANDLE hvessel, int flightmodel)
{
if (!refcount++) {
		hLMPKD =oapiLoadMeshGlobal ("LM_NoWheel");
		hLMVessel =oapiLoadMeshGlobal ("LM_vessel_on");
		hLMDescent =oapiLoadMeshGlobal ("LM_descent");
		hLMAscent =oapiLoadMeshGlobal ("LM_ascent");
		hLMAscent2=oapiLoadMeshGlobal ("LM_ascent2");
		hAstro1=oapiLoadMeshGlobal ("Sat5AstroS");
	}
	// VESSELSOUND **********************************************************************
	// initialisation
	ConnectToOrbiterSoundDLL();
	// load wave (Handle defined in begining of file)
	RequestLoadVesselWave(Sctdw,			"Sound\\vessel\\countdown1.WAV");
	RequestLoadVesselWave(StageS,			"Sound\\saturn1B\\Stagesep.wav");
	RequestLoadVesselWave(SLEVA,			"Sound\\saturn1B\\LEVA.wav");
	RequestLoadVesselWave(SDMode,			"Sound\\saturn1B\\Dmode.wav");
	RequestLoadVesselWave(SHMode,			"Sound\\saturn1B\\hmode.wav");
	RequestLoadVesselWave(Scontact,			"Sound\\saturn1B\\contact.wav");
	RequestLoadVesselWave(S5P100,			"Sound\\saturn1B\\5p100.wav");
	RequestLoadVesselWave(SAbort,			"Sound\\saturn1B\\abort.wav");
	RequestLoadVesselWave(Sclick,				"Sound\\Saturn1B\\click.wav");
	
	// VESSELSOUND 
	g_Param.col[2] = oapiGetColour(154,154,154);
	g_Param.col[3] = oapiGetColour(3,3,3);
	return new VESSEL (hvessel, flightmodel);
}


DLLCLBK int ovcConsumeKey (VESSEL *vessel, const char *keystate)
{
	if (KEYMOD_SHIFT (keystate)) 
	{
		return 0; 
	}
	else if (KEYMOD_CONTROL (keystate)) 
	{
	
	}
	else 
	{ 
		if (KEYDOWN (keystate, OAPI_KEY_J)) {
			if (oapiAcceptDelayedKey (OAPI_KEY_J, 1.0)){
			if (status !=0)
			//	bManualSeparate = true;
			return 1;
			}
		}
		if (KEYDOWN (keystate, OAPI_KEY_K)) {
			if (oapiAcceptDelayedKey (OAPI_KEY_K, 1.0)){
				
				bToggleHatch = true;
				
			return 1;
			}
		}
		
		if (KEYDOWN (keystate, OAPI_KEY_1)) {
			if (oapiAcceptDelayedKey (OAPI_KEY_1, 1.0)){
				
			return 1;
			}
		}
		if (KEYDOWN (keystate, OAPI_KEY_2)) {
			if (oapiAcceptDelayedKey (OAPI_KEY_2, 1.0)){
				
				
				
			return 1;
			}
		}
		if (KEYDOWN (keystate, OAPI_KEY_3)) {
			if (oapiAcceptDelayedKey (OAPI_KEY_3, 1.0)){
			}
			return 1;
			
		}
		
		if (KEYDOWN (keystate, OAPI_KEY_E)) {
			if (oapiAcceptDelayedKey (OAPI_KEY_E, 1.0)){
		if (status==1){
					//ToggleEva = true;
				}
			return 1;
			}
		}
		if (KEYDOWN (keystate, OAPI_KEY_V)) {
			if (oapiAcceptDelayedKey (OAPI_KEY_V, 1.0)){
				if (!velDISP){
					velDISP = true;
				}else{
					velDISP = false;
				}
			return 1;
			}
		}
		if (KEYDOWN (keystate, OAPI_KEY_7)) {
			if (oapiAcceptDelayedKey (OAPI_KEY_7, 1.0))
				lmpview = true;
			return 1;
		}
		if (KEYDOWN (keystate, OAPI_KEY_6)) {
			if (oapiAcceptDelayedKey (OAPI_KEY_6, 1.0))
				cdrview = true;
			return 1;
		}
		
	}
	return 0;
}

void SetRCS(VESSEL *vessel, PROPELLANT_HANDLE ph_prop)
{
		if(LPswitch1){
			for(int i=8;i<16;i++){
			
				vessel->SetThrusterResource(th_att_rot[i],ph_prop);
				vessel->SetThrusterResource(th_att_lin[i+8],ph_prop);
			}
		}else{
			for(int i=8;i<16;i++){
				vessel->SetThrusterResource(th_att_rot[i],NULL);
				vessel->SetThrusterResource(th_att_lin[i+8],NULL);
			}
		}
		if(LPswitch2){
			for(int i=0;i<8;i++){
				vessel->SetThrusterResource(th_att_rot[i],ph_prop);
				vessel->SetThrusterResource(th_att_lin[i+8],ph_prop);
			}
		}else{
			for(int i=0;i<8;i++){
				vessel->SetThrusterResource(th_att_rot[i],NULL);
				vessel->SetThrusterResource(th_att_lin[i+8],NULL);
			}
		}
		if(LPswitch3){
			for(int i=0;i<8;i++){
				vessel->SetThrusterResource(th_att_rot[i+16],ph_prop);
				vessel->SetThrusterResource(th_att_lin[i],ph_prop);
			}
		}else{
			for(int i=0;i<8;i++){
				vessel->SetThrusterResource(th_att_rot[i+16],NULL);
				vessel->SetThrusterResource(th_att_lin[i],NULL);
			}
		}

	return;		
}
DLLCLBK void ovcTimestep (VESSEL *vessel, double simt)
{

	
		
	char VName[256]="";
	char VName1[256]="";
	char VName2[256]="";
	char VName3[256]="";
	char VName4[256]="";
	char VName5[256]="";
	char VName6[256]="";
	char VName7[256]="";
	char VName8[256]="";
	char VName9[256]="";
	char VName10[256]="";
	char VName11[256]="";
	char VName12[256]="";
	
	strcpy (VName10, vessel->GetName()); strcat (VName10, "-LEVA");
	hLEVA=oapiGetVesselByName(VName10);
	
		SetView(vessel);
	
		VECTOR3 RVEL = _V(0.0,0.0,0.0);
	vessel->GetRelativeVel(vessel->GetGravityRef(),RVEL);
	
	
		//if(LPswitch6) LPswitch1 = false;
		//if(LPswitch7) LPswitch3 = false;
		
	
	actualVEL = (sqrt(RVEL.x *RVEL.x + RVEL.y * RVEL.y + RVEL.z * RVEL.z)/1000*3600);
	actualALT = vessel->GetAltitude() ;
	if (vessel->GetAltitude() < 1470){
	actualVEL = actualVEL-1470+vessel->GetAltitude();
	}
	if (vessel->GroundContact()){
	actualVEL =0;
	}
	if (status !=0 && Sswitch2 && Sswitch3){
				bManualSeparate = true;
	}
	actualFUEL = vessel->GetFuelMass()/vessel->GetMaxFuelMass()*100;	
	double dTime,aSpeed,DV,aALT,DVV,DVA;//aVAcc;aHAcc;ALTN1;SPEEDN1;aTime aVSpeed;
		aSpeed = actualVEL/3600*1000;
		aALT=actualALT;
		dTime=simt-aTime;
		if(dTime > 0.1){
			DV= aSpeed - SPEEDN1;
			aHAcc= (DV / dTime);
			DVV = aALT - ALTN1;
			aVSpeed = DVV / dTime;
			DVA = aVSpeed- VSPEEDN1;
			

			aVAcc=(DVA/ dTime);
			aTime = simt;
			VSPEEDN1 = aVSpeed;
			ALTN1 = aALT;
			SPEEDN1= aSpeed;
		}
	AttitudeLaunch1(vessel);
	if( toggleRCS){
			if(LPswitch4){
			vessel->SetAttitudeMode(1);
			toggleRCS =false;
			}else if (!LPswitch4){
			vessel->SetAttitudeMode(2);
			toggleRCS =false;
			}
		}
		if (vessel->GetAttitudeMode()==2){
		LPswitch4=false;
		}else if (vessel->GetAttitudeMode()==1 ){
		LPswitch4=true;
		}
	if(Sswitch1){
		Sswitch1=false;
		vessel->Undock(0);
	
		}
	if (vessel->GetNavmodeState(NAVMODE_KILLROT)&& !LPswitch1 && !LPswitch2){
			if (vessel->GetThrusterLevel(th_att_rot[10]) <0.00001 && vessel->GetThrusterLevel(th_att_rot[18]) <0.00001 ){
			vessel->DeactivateNavmode(NAVMODE_KILLROT);
			}
		}
	if (stage == 0)
	{
		if (SPSswitch){
		vessel->SetThrusterResource(th_hover[0],ph_Dsc);
		}else{
			vessel->SetThrusterResource(th_hover[0],NULL);
		}
		
		if(LPswitch5){
		SetRCS(vessel,ph_rcslm0);
		}else{
			SetRCS(vessel,ph_rcslm1);
		}
	}else if (stage == 1||stage == 5)
	{
		if(LPswitch5){
		SetRCS(vessel,ph_rcslm0);
		}else{
			SetRCS(vessel,ph_rcslm1);
		}if (SPSswitch){
		vessel->SetThrusterResource(th_hover[0],ph_Dsc);
		}else{
			vessel->SetThrusterResource(th_hover[0],NULL);
		}
		if (EVA_IP){
			if(!hLEVA){
			ToggleEVA(vessel);
			}else{
			if(high){
			}else{
			high=true;
			vessel->SetTouchdownPoints (_V(0,-5,10), _V(-1,-5,-10), _V(1,-5,-10));
			}
			}
		}
		if (ToggleEva && vessel->GroundContact()){
		ToggleEVA(vessel);
		}
		
		if (bToggleHatch){
				VESSELSTATUS vs;
				vessel->GetStatus(vs);
				if (vs.status == 1){
				//PlayVesselWave(Scontact,NOLOOP,255);
				//SetLmVesselHoverStage2(vessel);
					if(high){
					high=false;
					vessel->SetTouchdownPoints (_V(0,-0,10), _V(-1,-0,-10), _V(1,-0,-10));
					}else{
					high=true;
					vessel->SetTouchdownPoints (_V(0,-5,10), _V(-1,-5,-10), _V(1,-5,-10));
					}
				}
		bToggleHatch=false;
		}

		if (vessel->GetPropellantMass(ph_Dsc)==408){
			PlayVesselWave(S5P100,NOLOOP,255);
		}
		if (vessel->GetAltitude() < 5.3 && !ContactOK && vessel->GetAltitude() > 5.0){
			PlayVesselWave(Scontact,NOLOOP,255);
			vessel->SetEngineLevel(ENGINE_HOVER,0);
			ContactOK = true;

		}
		if (RPswitch1 && RPswitch2 &&RPswitch3 && vessel->GroundContact()){
		ToggleEva = true;
		RPswitch3=false;
		}
		
		if (vessel->GetPropellantMass(ph_Dsc)<=50 && vessel->GetAltitude() > 10){
			SeparateStage(vessel,stage);
			vessel->SetEngineLevel(ENGINE_HOVER,1);
			vessel->ActivateNavmode(NAVMODE_HLEVEL);
			stage = 2;
			PlayVesselWave(SAbort,NOLOOP,255);
		}
		if (bManualSeparate && !startimer){
			VESSELSTATUS vs;
			vessel->GetStatus(vs);

			if (vs.status == 1){
			countdown=simt;
			PlayVesselWave(Sctdw,NOLOOP,255);
			startimer=true;
			//vessel->SetTouchdownPoints (_V(0,-0,10), _V(-1,-0,-10), _V(1,-0,-10));
			}else{
			SeparateStage(vessel,stage);
			stage = 2;
			}
			
		}
			if ((simt-(10+countdown))>=0 && startimer ){
				SeparateStage(vessel,stage);
				vessel->SetEngineLevel(ENGINE_HOVER,1);
				stage = 2;
				startimer=false;
			}
			
	}else if (stage == 2){
		if (SPSswitch){
		vessel->SetThrusterResource(th_hover[0],ph_Asc);
		}else{
			vessel->SetThrusterResource(th_hover[0],NULL);
		}

	if(LPswitch5){
		SetRCS(vessel,NULL);
		}else{
			SetRCS(vessel,ph_rcslm1);
		}
	}else if (stage == 3){
		if (SPSswitch){
		vessel->SetThrusterResource(th_hover[0],ph_Asc);
		}else{
			vessel->SetThrusterResource(th_hover[0],NULL);
		}
	if(LPswitch5){
		SetRCS(vessel,NULL);
		}else{
			SetRCS(vessel,ph_rcslm1);
		}
	
	}else if (stage == 4)

	{
		
        
			
		
	}
	
		
}
DLLCLBK void ovcLoadStateEx (VESSEL *vessel, FILEHANDLE scn, VESSELSTATUS *vs)

{
    char *line;
	
	while (oapiReadScenario_nextline (scn, line)) {

        if (!strnicmp (line, "CONFIGURATION", 13)) {
            sscanf (line+13, "%d", &status);

		} else if (!strnicmp (line, "EVA", 3)) {

			EVA_IP = true;
			
			}else {
            vessel->ParseScenarioLineEx (line, vs);
        }
    }
	switch (status) {
	case 0:
		stage=0;
		SetLmVesselDockStage(vessel);
		break;
	case 1:
		stage=1;
		SetLmVesselHoverStage(vessel);
		if (EVA_IP){
		SetupEVA(vessel);
		}
		break;
	case 2:
		stage=2;
		SetLmAscentHoverStage(vessel);
		break;
	
	}
	

}

DLLCLBK void ovcSetClassCaps (VESSEL *vessel, FILEHANDLE cfg)
{
SetLmVesselDockStage(vessel);
}


DLLCLBK void ovcSaveState (VESSEL *vessel, FILEHANDLE scn)

{
	vessel->SaveDefaultState (scn);	
	oapiWriteScenario_int (scn, "CONFIGURATION", status);
	if (EVA_IP){
	oapiWriteScenario_int (scn, "EVA", int(TO_EVA));
	}


}