// ==============================================================
// ORBITER vessel module: Saturn5_LEVA
// ==============================================================

#include "orbitersdk.h"
#include "stdio.h"
#include "math.h"
#include "OrbiterSoundSDK.h"

static const HRover=29;
static const HAstro=30;

const VECTOR3 OFS_STAGE1 =  { 0, 0, -8.935};
const VECTOR3 OFS_STAGE2 =  { 0, 0, 9.25-12.25};
const VECTOR3 OFS_STAGE21 =  { 1.85,1.85,24.5-12.25};
const VECTOR3 OFS_STAGE22 =  { -1.85,1.85,24.5-12.25};
const VECTOR3 OFS_STAGE23 =  { 1.85,-1.85,24.5-12.25};
const VECTOR3 OFS_STAGE24 =  { -1.85,-1.85,24.5-12.25};

static OBJHANDLE hMaster;
static int refcount = 0;
static MESHHANDLE hCMPEVA;
static MESHHANDLE hLRV;
static bool GoDock1=false;
static bool GoHover=false;
static bool starthover=false;
static bool GoRover =false;
static bool Astro=true;						
static bool MotherShip=false;
static char EVAName[256]="";
static char CSMName[256]="";
static char MSName[256]="";
static bool KEY1 = false;
static bool	KEY2 = false;
static bool	KEY3 = false;
static bool	KEY4 = false;
static bool	KEY5 = false;
static bool	KEY6 = false;
static bool KEY7 = false;
static bool KEY8 = false;
static bool KEY9 = false;		
static bool GoFlag = false;		 
static bool Flagtrue = false;		 
void SetAstroStage (VESSEL *vessel)
{
	
	
	vessel->SetEmptyMass (115);
	vessel->SetISP (23e6);
	vessel->SetCOG_elev(3);
	vessel->SetSize (2);
	vessel->SetPMI (_V(5,5,5));
	vessel->SetRotDrag (_V(0.7,0.7,1.2));
	vessel->SetPitchMomentScale (0);
	vessel->SetBankMomentScale (0);
	vessel->SetLiftCoeffFunc (0); 
    vessel->ClearMeshes();
    vessel->ClearExhaustRefs();
    vessel->ClearAttExhaustRefs();
    vessel->ShiftCentreOfMass (_V(0,0,0));
	VECTOR3 mesh_dir=_V(0,0,0);
    vessel->AddMesh (hCMPEVA, &mesh_dir);
	vessel->SetCameraOffset(_V(0,-2.8,0));
	vessel->SetTouchdownPoints (_V(0,-2,1), _V(-1,-2,-1), _V(1,-2,-1));
	Astro=true;		
}


void SetRoverStage (VESSEL *vessel)
{
	
	
	vessel->SetEmptyMass (250);
	vessel->SetSize (2);
	vessel->SetCOG_elev(3);
	vessel->SetPMI (_V(15,15,15));
	vessel->SetRotDrag (_V(0.7,0.7,1.2));
	vessel->SetPitchMomentScale (0);
	vessel->SetBankMomentScale (0);
	vessel->SetLiftCoeffFunc (0); 
    vessel->ClearMeshes();
    vessel->ClearExhaustRefs();
    vessel->ClearAttExhaustRefs();
    vessel->ShiftCentreOfMass (_V(0,0.0,0));
	VECTOR3 mesh_dir=_V(0,0.0,0);
    vessel->AddMesh (hLRV, &mesh_dir);
	vessel->SetCameraOffset(_V(0,0,0));
	vessel->SetTouchdownPoints (_V(0,-2,1), _V(-1,-2,-1), _V(1,-2,-1));
	Astro=false;
	
}
void ScanMotherShip(VESSEL *vessel){
		
		
		double VessCount;
		int i=0;
		VessCount=oapiGetVesselCount();
		for ( i = 0 ; i< VessCount ; i++ ) 
	
		{
			hMaster=oapiGetVesselByIndex(i);
			strcpy(EVAName,vessel->GetName());
			oapiGetObjectName(hMaster,CSMName,256);
			strcpy(MSName,CSMName);
			strcat(CSMName,"-LEVA");
				if (strcmp(CSMName, EVAName)==0){
				MotherShip=true;
				i=int(VessCount);
				}else{
				strcpy(CSMName,"");
				}
		
			}
		

}
void MoveEVA(VESSEL *vessel){
	double cm ;
	double lat;
	double lon;
	double cap;
	double timeW=1;
	VESSELSTATUS eva;
	vessel->GetStatus(eva);
	oapiGetHeading(vessel->GetHandle(),&cap);
	timeW=oapiGetTimeAcceleration();
	if (timeW >100)
		oapiSetTimeAcceleration(100);
	lon=eva.vdata[0].x;
	lat=eva.vdata[0].y;
	if (Astro){
	cm = 0.86e-7*timeW;
	PlayVesselWave(HAstro,LOOP,135);
	}else{
	PlayVesselWave(HRover,LOOP,245);
	cm = 1.36e-7*timeW;
	}
	if (KEY1){
		eva.vdata[0].z = eva.vdata[0].z - PI*0.5/180;
		StopVesselWave(HAstro);
		if(eva.vdata[0].z <=-2*PI){
		eva.vdata[0].z = eva.vdata[0].z + 2*PI;
		}
		KEY1=false;
	}
	else if (KEY3){
		eva.vdata[0].z = eva.vdata[0].z +( PI*0.5/180);
		StopVesselWave(HAstro);
		if(eva.vdata[0].z >=2*PI){
		eva.vdata[0].z = eva.vdata[0].z - 2*PI;
		}
		KEY3=false;
	}
	else if (KEY2){
		lat = lat - cos(cap) * cm;
		lon = lon - sin(cap) * cm;
		KEY2=false;
	}
	else if (KEY4 && Astro){
		lat = lat + sin(cap) * cm;
		lon = lon - cos(cap) * cm;
		KEY4=false;
	}
	else if (KEY5){
		KEY5=false;
	}
	else if (KEY6 && Astro){
		lat = lat - sin(cap) * cm;
		lon = lon + cos(cap) * cm;
		KEY6=false;
	}
	else if (KEY7){
		KEY7=false;
	}
	else if (KEY8||GoHover && !Astro){// we go ahead whatever our headign
		lat = lat + cos(cap) * cm;
		lon = lon + sin(cap) * cm;
		KEY8=false;
	}
	else if (KEY9){
		KEY9=false;
	}else{
		StopVesselWave(HAstro);
		StopVesselWave(HRover);
	}

	eva.vdata[0].x=lon;
	eva.vdata[0].y=lat;
	vessel->DefSetState(&eva);
	
}

// ==============================================================
// API interface
// ==============================================================


DLLCLBK int ovcConsumeKey (VESSEL *vessel, const char *keystate)
{
	if (KEYMOD_SHIFT (keystate)) 
	{
		return 0; 
	}
	else if (KEYMOD_CONTROL (keystate)) 
	{
	
	}
	else 
	{ 
		if (KEYDOWN (keystate, OAPI_KEY_E)) {
			if (oapiAcceptDelayedKey (OAPI_KEY_E, 1)){
				
				if (Astro){
				GoDock1 = !GoDock1;
				}
				
			return 1;
			}
		}if (KEYDOWN (keystate, OAPI_KEY_V)) {
			if (oapiAcceptDelayedKey (OAPI_KEY_V, 1.0)){
				
				GoRover = !GoRover;
				
			return 1;
			}
		}if (KEYDOWN (keystate, OAPI_KEY_G)) {
			if (oapiAcceptDelayedKey (OAPI_KEY_G, 1.0)){
				if (!Astro)
				GoHover = !GoHover;
				
			return 1;
			}
		}if (KEYDOWN (keystate, OAPI_KEY_F)) {
			if (oapiAcceptDelayedKey (OAPI_KEY_F, 1.0)){
				if (Astro && !Flagtrue )
				GoFlag = true;
				
			return 1;
			}
		}if (KEYDOWN (keystate, OAPI_KEY_NUMPAD1)) {
			if (oapiAcceptDelayedKey (OAPI_KEY_NUMPAD1, .001)){
				
				KEY1 = true;
				
			return 1;
			}
		}if (KEYDOWN (keystate, OAPI_KEY_NUMPAD3)) {
			if (oapiAcceptDelayedKey (OAPI_KEY_NUMPAD3, 0.001)){
				
				KEY3 = true;
				
			return 1;
			}
		}if (KEYDOWN (keystate, OAPI_KEY_NUMPAD2)) {
			if (oapiAcceptDelayedKey (OAPI_KEY_NUMPAD2, .001)){
				
				KEY2 = true;
				
			return 1;
			}
		}if (KEYDOWN (keystate, OAPI_KEY_NUMPAD4)) {
			if (oapiAcceptDelayedKey (OAPI_KEY_NUMPAD4, 0.001)){
				
				KEY4 = true;
				
			return 1;
			}
		}if (KEYDOWN (keystate, OAPI_KEY_NUMPAD5)) {
			if (oapiAcceptDelayedKey (OAPI_KEY_NUMPAD5, .001)){
				
				KEY5 = true;
				
			return 1;
			}
		}if (KEYDOWN (keystate, OAPI_KEY_NUMPAD6)) {
			if (oapiAcceptDelayedKey (OAPI_KEY_NUMPAD6, .001)){
				
				KEY6 = true;
				
			return 1;
			}
		}if (KEYDOWN (keystate, OAPI_KEY_NUMPAD7)) {
			if (oapiAcceptDelayedKey (OAPI_KEY_NUMPAD7, .001)){
				
				KEY7 = true;
				
			return 1;
			}
		}if (KEYDOWN (keystate, OAPI_KEY_NUMPAD8)) {
			if (oapiAcceptDelayedKey (OAPI_KEY_NUMPAD8, .001)){
				
				KEY8 = true;
				
			return 1;
			}
		}if (KEYDOWN (keystate, OAPI_KEY_NUMPAD9)) {
			if (oapiAcceptDelayedKey (OAPI_KEY_NUMPAD9, .001)){
				
				KEY9 = true;
				
			return 1;
			}
		}
	}
	return 0;
}
void SetFlag(VESSEL *vessel){
		VESSELSTATUS vs1;
		vessel->GetStatus(vs1);
		VECTOR3 ofs1 = _V(3,0,0);
		VECTOR3 vel1 = _V(0,0,0);
		VECTOR3 rofs1, rvel1 = {vs1.rvel.x, vs1.rvel.y, vs1.rvel.z};
		vessel->Local2Rel (ofs1, vs1.rpos);
		vessel->GlobalRot (vel1, rofs1);
		vs1.rvel.x = rvel1.x+rofs1.x;
		vs1.rvel.y = rvel1.y+rofs1.y;
		vs1.rvel.z = rvel1.z+rofs1.z;
	double cm ;
	double lat;
	double lon;
	double cap;
	oapiGetHeading(vessel->GetHandle(),&cap);
	lon=vs1.vdata[0].x;
	lat=vs1.vdata[0].y;
	cm = 5.36e-7;
	lat = lat - sin(cap) * cm;
	lon = lon + cos(cap) * cm;
	vs1.vdata[0].x=lon;
	vs1.vdata[0].y=lat;
	
		char VName[256]="";
		strcpy (VName, vessel->GetName()); strcat (VName, "-FLAG");
		oapiCreateVessel(VName,"Sat5flag",vs1);
		Flagtrue = true;
		GoFlag = false;
}

DLLCLBK void ovcTimestep (VESSEL *vessel, double simt)
{
	
		sprintf(oapiDebugString(), "Lunar EVA From %s",MSName);// MSName
		MoveEVA(vessel);
		VESSELSTATUS csmV;
		VESSELSTATUS evaV;
		VESSEL *csmvessel;
		VECTOR3 rdist = {0,0,0};
		VECTOR3 posr  = {0,0,0};
		VECTOR3 rvel  = {0,0,0};
		VECTOR3 RelRot  = {0,0,0};
		double dist = 0.0;
		double Vel = 0.0;
		if (!MotherShip){
		ScanMotherShip(vessel);
		}else{
		}
		
	if (hMaster){
		csmvessel = oapiGetVesselInterface(hMaster);
		sprintf(oapiDebugString(), "docked to  M %s",csmvessel->GetName() );					
		oapiGetRelativePos (vessel->GetHandle() ,hMaster, &posr);
		oapiGetRelativeVel (vessel->GetHandle() ,hMaster , &rvel);
		vessel->GetStatus(evaV);
		csmvessel->GetStatus(csmV);
		vessel->GlobalRot (posr, RelRot);
		dist = sqrt(posr.x * posr.x + posr.y * posr.y + posr.z * posr.z);
		Vel = sqrt(rvel.x * rvel.x + rvel.y * rvel.y + rvel.z * rvel.z);
		if (GoDock1){
			sprintf(oapiDebugString(), "LEVA Back to LM Mode Relative Distance M %f", dist);				
			
				if (dist <= 6.00550){
					GoDock1 =false;
					oapiSetFocusObject(hMaster);
					oapiDeleteVessel(vessel->GetHandle());
				}
		}
		
	}
	
	if (GoRover && Astro){//GroundVehicleAutopilot
		SetRoverStage(vessel);
		
	}else if(!GoRover && !Astro){
		SetAstroStage(vessel);
	}
	if (GoFlag && !Flagtrue){
	 SetFlag(vessel);
	}
}
DLLCLBK void ovcLoadState (VESSEL *vessel, FILEHANDLE scn, VESSELSTATUS *vs)

{
    char *line;
	
	while (oapiReadScenario_nextline (scn, line)) {

        if (!strnicmp (line, "ROVERMODE", 9)) {
			
			SetRoverStage (vessel);
			Astro=false;
			GoRover=true;
			vessel->SetEngineLevel(ENGINE_HOVER,1);
			
			
		}else if (!strnicmp (line, "FLAG", 4)) {
			
			Flagtrue=true;
			
		}else {
            vessel->ParseScenarioLine (line, vs);
        }
    }
	

}


DLLCLBK void ovcSaveState (VESSEL *vessel, FILEHANDLE scn)
{
	vessel->SaveDefaultState (scn);
	if (Flagtrue){
	oapiWriteScenario_int (scn, "FLAG", 1);
	}
	if (!Astro){
	oapiWriteScenario_int (scn, "ROVERMODE", 1);
	}
	
}
DLLCLBK VESSEL *ovcInit (OBJHANDLE hvessel, int flightmodel)
{
	if (!refcount++) {
		hCMPEVA = oapiLoadMeshGlobal ("Sat5AstroS");//
		hLRV = oapiLoadMeshGlobal ("LRV");//
	}
	ConnectToOrbiterSoundDLL();
	RequestLoadVesselWave(HRover,				"Sound\\Saturn1B\\LRover.WAV");
	RequestLoadVesselWave(HAstro,				"Sound\\vessel\\NOISE.WAV");
	return new VESSEL (hvessel, flightmodel);
}


DLLCLBK void ovcSetClassCaps (VESSEL *vessel, FILEHANDLE cfg)
{
	SetAstroStage (vessel);
}

DLLCLBK void ovcExit (VESSEL *vessel)
{
StopVesselWave(HAstro);
StopVesselWave(HRover);
}