// ==============================================================
// ORBITER vessel module: Saturn 5
// ==============================================================

#include "Orbitersdk.h"
#include "stdio.h"
#include "math.h"
#include "OrbiterSoundSDK.h"
#include "resource.h"

#define LOADBMP(id) (LoadBitmap (g_Param.hDLL, MAKEINTRESOURCE (id)))

// ==============================================================
// Global parameters
// ==============================================================
typedef struct {
	HINSTANCE hDLL;
	HFONT font[2];
	DWORD col[4];
	HBRUSH brush[4];
	HPEN pen[4];
} GDIParams;

GDIParams g_Param;

const int nsurf = 18; // number of bitmap handles
const double N   = 1.0;
const double kN  = 1000.0;
const double KGF = N*G;
const double SEC = 1.0*G;
const double KG  = 1.0;
const double  CSM_THRUST_ATT   = 200.34*KGF;
const double  CSM_ISP          = 773*SEC;
SURFHANDLE srf[nsurf];  // handles for panel bitmaps
	
double CSM_FUEL_MASS_CM        = 420*KG;
double CSM_FUEL_MASS_RCS       = 22500*KG;
double CSM_fuel_mass_cm      = 420*KG;
double CSM_fuel_mass_rcs       = 22500*KG;
static double DockAngle =0;
static double AltDsc1=0;
double 	Offset1st ;
static double AltDsc2=0;
static double ignition_time;
static double ignition_2time;
static double ignition_3time;
static double ignition_S4time;
static double Release_time;
static double ignition_SMtime;
static double actualVEL;
static double actualALT;
static double actualFUEL;
static double aVAcc;
static double aVSpeed;
static double aHAcc;
static double ALTN1;
static double SPEEDN1;
static double VSPEEDN1;
static double aTime;
double AtempP ;
double AtempY ;
double AtempR ; 
static double T1;
static double T2;
static double TCPO;
static const DockS=1;
static const LaunchS=2;
static const SeparationS=3;
static const SMJetS=4;
static const S4CutS=5;
static const TowerJS=6;
static const StageS=7;
static const SplashS=8;
static const SpeedS=9;
static const SepS=10;
static const Sctdw = 11;
static const SShutS=12;
static const Swater=13;
static const CrashBumpS=14;
static const SCorrection=15;
static const SExploded=17;
static const S5P100=16;
static const SLEVA=20;
static const Sclick=19;
static const HRover=29;
static const ERADIUS=6371;
static  bool ToggleEva = false;
static  bool bRecovery = false;
static bool RCS_Full=true;
static bool Eds=true;
static bool KEY1=false;
static bool KEY2=false;
static bool KEY3=false;
static bool KEY4=false;
static bool KEY5=false;
static bool KEY6=false;
static bool KEY7=false;
static bool KEY8=false;
static bool KEY9=false;
static bool toggleRCS =false;
bool FIRSTCSM=false;
static bool StartGimbal=false;
static bool Cswitch1=false;
static bool Cswitch2=false;
static bool Cswitch3=false;
static bool Cswitch4=false;
static bool Cswitch5=false;
static bool Cswitch6=false;
static bool Cswitch7=false;
static bool Cswitch8=false;
static bool Cswitch9=false;
static bool Sswitch1=false;
static bool Sswitch2=false;
static bool Sswitch3=false;
static bool Sswitch4=false;
static bool Sswitch5=false;
static bool Sswitch6=false;
static bool Sswitch7=false;
static bool Sswitch8=false;
static bool Sswitch9=false;
static bool RPswitch1=false;
static bool RPswitch2=false;
static bool RPswitch3=false;
static bool RPswitch4=false;
static bool RPswitch5=false;
static bool RPswitch6=false;
static bool RPswitch7=false;
static bool RPswitch8=false;
static bool RPswitch9=false;
static bool RPswitch10=false;
static bool RPswitch11=false;
static bool RPswitch12=false;
static bool RPswitch13=false;
static bool RPswitch14=false;
static bool RPswitch15=false;
static bool RPswitch16=false;
static bool RPswitch17=false;
static bool LPswitch1=false;
static bool LPswitch2=false;
static bool LPswitch3=false;
static bool LPswitch4=false;
static bool LPswitch5=false;
static bool LPswitch6=false;
static bool LPswitch7=false;
static bool SPSswitch=false;
static bool EDSswitch=true;

static bool LAUNCHIND[8];
static bool ABORT_IND=false;
static bool ENGIND[7];
static bool stg1U = false;
static bool stg2U = false;
static bool stgSM = false;
static bool GoHover=false;
static bool stopsep=true;
static bool startsep=true;
static bool S4Shoot=false;
static bool LEM_DISPLAY=false;
static bool Scorrec=false;
static bool StopRot=false;
static bool Resetjet=false;
static bool S4BStarted=true;
static bool S4BStarted2=true;
static bool InterJet=false;
static bool sepsPyd=false;
static bool sepsPyd1=false;
static bool sepsPyd0=false;
static bool sepsPyd2=false;
static bool sepsPyd3=false;
static bool directcontrol=false;
static bool SMSep=false;
static bool S4Sep=false;
static bool velDISP=false;
static bool autoDISP=false;
static bool TargetDocked=false;
static bool probeOn=true;
static bool S4ShutDown=false;
static bool S4BASTP=false;
static bool Burned=false;
static bool setBurn=false;
static bool MasterVessel=true;
static bool S4Bset = false;
static bool bStartS4B =false;
static bool Uinsert =false;
static bool clockDISP=false;
static bool Apollo13 =false;
static bool ApolloExploded =false;
static double S4BStartTimer=0;
static double Utimer=0;
static int VERB;
static int NOUN;
static int DPROG;
static double R1;
static double R2;
static double R3;
static bool DKey0;
static bool DKey1;
static bool DKey2;
static bool DKey3;
static bool DKey4;
static bool DKey5;
static bool DKey6;
static bool DKey7;
static bool DKey8;
static bool DKey9;
static bool DKeyP;
static bool DKeyM;
static bool DKeyENTR;
static bool DKeyCLR;
static bool DKeyVERB;
static bool DKeyNOUN;
static bool DKeyRESET;
static bool DKeySTBY;
static bool DKeyKRLS;
static UINT probeidx;
const double SMVO = -0.14;
const double STG0O= 20.4;
const double STG1O= -5.25;
const double STG2O= 8;
const VECTOR3 OFS_STAGE1 =  { 0, 0, -54.935};
const VECTOR3 OFS_STAGE12 =  { 0, 0, -30.5};
const VECTOR3 OFS_STAGE2 =  { 0, 0, -20.25};
const VECTOR3 OFS_STAGE3 =  { 0, 0, 7.5+STG2O+21.5};
const VECTOR3 OFS_STAGE31 =  { -1.48,-1.48,4.8+STG2O+21.5};
const VECTOR3 OFS_STAGE32 =  { 1.48,-1.48,4.8+STG2O+21.5};
const VECTOR3 OFS_STAGE33 =  { 1.48,1.48,4.8+STG2O+21.5};
const VECTOR3 OFS_STAGE34 =  { -1.48,1.48,4.8+STG2O+21.5};
const VECTOR3 OFS_SM =  { 0, 0, 31.05-12.25-21.5-1.0};
const VECTOR3 OFS_ABORT =  { 0,0,-34.40};
const VECTOR3 OFS_ABORT2 =  { 0,0,-22.15};
const VECTOR3 OFS_ABORT_TOWER =  { 0,0,5};
const VECTOR3 OFS_CM_CONE =  { 0, 0, 36.05-12.25-21.5};
//const VECTOR3 OFS_MAINCHUTE =  { 0, 0, 30.15-12.25-21.5-4};
const VECTOR3 OFS_MAINCHUTE =  { 0, -2, 9};
const VECTOR3 OFS_TOWER =  { 0, 0, 40.05};
const VECTOR3 OFS_DOCKING =  { 0.0,0.0,14.5};
const VECTOR3 OFS_DOCKING2 =  { 0.0,-2.4,22.4};
static VECTOR3 RelPos = {0.0,0.0,0.0};
VECTOR3 MAIN1a_Vector;
VECTOR3 MAIN2a_Vector;
VECTOR3 MAIN3a_Vector;
VECTOR3 MAIN4a_Vector;
VECTOR3 MAIN5a_Vector;
static int buildstatus=8;
static OBJHANDLE hMaster;
static OBJHANDLE hEVA;
static OBJHANDLE hintstg;
static OBJHANDLE habort;
static OBJHANDLE hstage1;
static OBJHANDLE hstage2;
static OBJHANDLE astpvessel;
static OBJHANDLE targetvessel;
static OBJHANDLE targetvessel1;
static OBJHANDLE stg1vessel;
static OBJHANDLE stg2vessel;
static OBJHANDLE stgSMvessel;
static OBJHANDLE hstg1;
static OBJHANDLE hstg2;
static OBJHANDLE hesc1;
static OBJHANDLE hs4bM;
static OBJHANDLE hs4b1;
static OBJHANDLE hs4b2;
static OBJHANDLE hs4b3;
static OBJHANDLE hs4b4;
static OBJHANDLE hSMJet;
static OBJHANDLE hSMcone;
static OBJHANDLE TargetHandle;
static OBJHANDLE hPROBE;
static OBJHANDLE hLMV;
PROPELLANT_HANDLE ph_1st, ph_2nd, ph_3rd,ph_rcs0,ph_rcs1,ph_sps; // handles for propellant resources
THRUSTER_HANDLE th_main[5],th_ull[8],th_ver[3] ,th_att_cm[12];               // handles for orbiter main engines
THRUSTER_HANDLE th_sps[1],th_att_rot[24], th_att_lin[24];                 // handles for SPS engines
THGROUP_HANDLE thg_main,thg_ull,thg_ver;		          // handles for thruster groups
static HatchOpen=false;
bool ProbeJetison=false;
bool bManualSeparate = false;
bool bManualUnDock = false;
bool GoDock = false;
bool GoDock2 = false;
bool dockview = false;
bool cdrview = false;
bool cmpview = false;
bool dmpview = false;
static bool EVA_IP=false;
double stage_sep;
double gaz=0;
UINT stage = 0;
int status = 0;
int dockstate = 0;
int autoTimer = 0;
int TO_EVA = 1;
int TO_BURN = 1;
char targetname[256];
//int ReEntryID;
int VernierID1;
int VernierID2;
static int UllageID1;
static int UllageID2;
static int UllageID3;
static int UllageID4;
static int UllageID6;
static int UllageID7;
static int UllageID8;
static int UllageID9;
static int UllageSMID1;
static int UllageSMID2;
static int UllageSMID3;
static int UllageSMID4;
int CurState;
double slThrust = 0;
double vacThrust = 0;
static bool bToggleHatch = false;
static bool levelCSM;
static bool headingCSM;
static bool pitchCSM;
static bool bAbort;
static bool abortRocket;
static bool launchSound=false;
static bool clockMission;
static double autopTime;
static bool ActivateLEM = false;
static bool ActivateS4B = false;
static double abortTimer=0;
static int refcount = 0;
static UllageTimer =0;
static MESHHANDLE hCRAWL;
static MESHHANDLE hCMP;
static MESHHANDLE hCMPEVA;
static MESHHANDLE hCREW;
static MESHHANDLE hCRB; 
static MESHHANDLE hsat5stg1;
static MESHHANDLE hsat5intstg;
static MESHHANDLE hsat5stg2;
static MESHHANDLE hsat5stg3;
static MESHHANDLE hsat5stg31;
static MESHHANDLE hsat5stg32;
static MESHHANDLE hsat5stg33;
static MESHHANDLE hsat5stg34;
static MESHHANDLE hsat5tower;
static MESHHANDLE hCM;
static MESHHANDLE hCM2;
static MESHHANDLE hSM;
static MESHHANDLE hApollochute;
static MESHHANDLE hCONE;
static MESHHANDLE hChute30;
static MESHHANDLE hChute31;
static MESHHANDLE hChute32;
static MESHHANDLE hCMBALLOON;
static MESHHANDLE hApollocsm;
static MESHHANDLE hprobe;
static MESHHANDLE hSMhga;
static MESHHANDLE hFHO;
static MESHHANDLE hFHC;
static MESHHANDLE hFHO2;
static MESHHANDLE hFHC2;
static MESHHANDLE hCMB;
static MESHHANDLE hCM2B;
static MESHHANDLE hLMPKD;
static ELEMENTS elemSaturn1B;
static double refSaturn1B;
static ELEMENTS elemPREV;
static double refPREV;
static double AltitudePREV;
const double ISP_FIRST_SL    = 262*G;
const double ISP_FIRST_VAC   = 292*G;
const double ISP_SECOND_SL   = 300*G;//300*G;
const double ISP_SECOND_VAC  = 421*G;//421*G;
const double THRUST_FIRST_VAC	= 840426*G;
const double THRUST_SECOND_VAC  = 85200*G;//115200*G;
static double MIN_ALT = 220; //Min Altitude Km orbital insertion planned
static double TO_HDG=45;
static char VNameCM[256];
double LiftCoeff (double aoa)


{
const int nlift = 9;
static const double AOA[nlift] =
{-180*RAD,-155*RAD,-154*RAD,-34*RAD,0*RAD,34*RAD,154*RAD,155*RAD,180*RAD};
//static const double CL[nlift]  = {0.06375,  0.375,       0,      0,    0,
//0,      0,      0.1275, 0.06375};
static const double CL[nlift]  = {0.0275,  0.2575,       0.0575,      0.0075,   
0.0075,      0.0575, 0.2575, 0.0275};
static const double SCL[nlift] = {(CL[1]-CL[0])/(AOA[1]-AOA[0]),
(CL[2]-CL[1])/(AOA[2]-AOA[1]),
                              (CL[3]-CL[2])/(AOA[3]-AOA[2]),
(CL[4]-CL[3])/(AOA[4]-AOA[3]),
  (CL[5]-CL[4])/(AOA[5]-AOA[4]), (CL[6]-CL[5])/(AOA[6]-AOA[5]),
  (CL[7]-CL[6])/(AOA[7]-AOA[6]), (CL[8]-CL[7])/(AOA[8]-AOA[7])};
for (int i = 0; i < nlift-1 && AOA[i+1] < aoa; i++);
return -(CL[i] + (aoa-AOA[i])*SCL[i]);
}
double SetPitchApo(VESSEL *vessel){
			
			double cpitch;
			double SatApo1;
			double DiffApo;
			vessel->GetApDist(SatApo1);
			DiffApo = SatApo1 -((MIN_ALT+ERADIUS)*1000);
			cpitch=(vessel->GetPitch()*DEG)-aVAcc-(aVSpeed/50)+((MIN_ALT*1000-vessel->GetAltitude())/8000) ;
			if (cpitch>35){
				cpitch=35;
			}else if(cpitch<-35){
				cpitch=-35;
			}
			//sprintf(oapiDebugString(), "diff %f", cpitch );
return cpitch;		
			
}

void SetS4B(OBJHANDLE hS4B){
		
		VESSEL *targetvessel;
		VESSELSTATUS S4;
		targetvessel=oapiGetVesselInterface(hS4B);
		targetvessel->GetStatus(S4);
		S4.vrot = _V(0.0,0.0,0.0);
		targetvessel->DefSetState(&S4);
		
}
void AddRCSJets(VESSEL *vessel,double TRANZ,double MaxThrust)
{
	int i;
	const double ATTCOOR = 0;
	const double ATTCOOR2 = 2.10;
	const double ATTZ = 2.85;
	const double TRANCOOR = 0;
	const double TRANCOOR2 = 0.1;
	const double ATTWIDTH=.2;
	const double ATTHEIGHT=.5;
	const double TRANWIDTH=.2;
	const double TRANHEIGHT=1;
	const double RCSOFFSET=0.75;
	const double RCSOFFSETM=0.30;
	const double RCSOFFSETM2=0.47;

	
				
	th_att_lin[0]=th_att_rot[0]=vessel-> CreateThruster (_V(0,ATTCOOR2,TRANZ), _V(0,-0.1,1),MaxThrust, ph_rcs0,15000, 15000);
	th_att_lin[1]=th_att_rot[3]=vessel-> CreateThruster (_V(0,-ATTCOOR2,TRANZ), _V(0,0.1,1),MaxThrust, ph_rcs0,15000, 15000);
	th_att_lin[2]=th_att_rot[4]=vessel-> CreateThruster (_V(-ATTCOOR2,0,TRANZ), _V(0.1,0,1),MaxThrust, ph_rcs0,15000, 15000);
	th_att_lin[3]=th_att_rot[7]=vessel-> CreateThruster (_V(ATTCOOR2,0,TRANZ), _V(-0.1,0,1),MaxThrust, ph_rcs0,15000, 15000);
	th_att_lin[4]=th_att_rot[2]=vessel-> CreateThruster (_V(0,ATTCOOR2,TRANZ+RCSOFFSET), _V(0,-0.1,-1),MaxThrust, ph_rcs0,15000, 15000);
	th_att_lin[5]=th_att_rot[1]=vessel-> CreateThruster (_V(0,-ATTCOOR2,TRANZ+RCSOFFSET), _V(0,0.1,-1),MaxThrust, ph_rcs0,15000, 15000);
	th_att_lin[6]=th_att_rot[6]=vessel-> CreateThruster (_V(-ATTCOOR2,0,TRANZ+RCSOFFSET), _V(0.1,0,-1),MaxThrust, ph_rcs0,15000, 15000);
	th_att_lin[7]=th_att_rot[5]=vessel-> CreateThruster (_V(ATTCOOR2,0,TRANZ+RCSOFFSET), _V(-0.1,0,-1),MaxThrust, ph_rcs0,15000, 15000);
	vessel->CreateThrusterGroup (th_att_lin,   4, THGROUP_ATT_FORWARD);
	vessel->CreateThrusterGroup (th_att_lin+4, 4, THGROUP_ATT_BACK);
	vessel->CreateThrusterGroup (th_att_rot,   2, THGROUP_ATT_PITCHDOWN);
	vessel->CreateThrusterGroup (th_att_rot+2,   2, THGROUP_ATT_PITCHUP);
	vessel->CreateThrusterGroup (th_att_rot+4,   2, THGROUP_ATT_YAWRIGHT);
	vessel->CreateThrusterGroup (th_att_rot+6,   2, THGROUP_ATT_YAWLEFT);
	SURFHANDLE tex = oapiRegisterExhaustTexture ("Exhaust_atrcs");//"Exhaust2"
	for (i = 0; i < 8; i++) vessel->AddExhaust (th_att_lin[i], 1.2, 0.18,tex);
	
	th_att_lin[8]=th_att_rot[16]=th_att_rot[17]=vessel-> CreateThruster (_V(-0.3,ATTCOOR2,TRANZ+RCSOFFSETM), _V(1,-0.1,0),MaxThrust, ph_rcs0,15000, 15000);
	th_att_lin[9]=th_att_rot[8]=th_att_rot[9]=vessel-> CreateThruster (_V(-0.3,-ATTCOOR2,TRANZ+RCSOFFSETM2), _V(1,0.1,0),MaxThrust, ph_rcs0,15000, 15000);
	th_att_lin[10]=vessel-> CreateThruster (_V(-0.3,ATTCOOR2,-TRANZ-RCSOFFSETM), _V(1,-0.1,0),MaxThrust, ph_rcs0,15000, 15000);
	th_att_lin[11]=vessel-> CreateThruster (_V(-0.3,-ATTCOOR2,-TRANZ-RCSOFFSETM2), _V(1,0.1,0),MaxThrust, ph_rcs0,15000, 15000);
		
	th_att_lin[12]=th_att_rot[10]=th_att_rot[11]=vessel-> CreateThruster (_V(0.3,ATTCOOR2,TRANZ+RCSOFFSETM2), _V(-1,-0.1,0),MaxThrust, ph_rcs0,15000, 15000);
	th_att_lin[13]=th_att_rot[18]=th_att_rot[19]=vessel-> CreateThruster (_V(0.3,-ATTCOOR2,TRANZ+RCSOFFSETM), _V(-1,0.1,0),MaxThrust, ph_rcs0,15000, 15000);
	th_att_lin[14]=vessel-> CreateThruster (_V(0.3,ATTCOOR2,-TRANZ-RCSOFFSETM2), _V(-1,-0.1,0),MaxThrust, ph_rcs0,15000, 15000);
	th_att_lin[15]=vessel-> CreateThruster (_V(0.3,-ATTCOOR2,-TRANZ-RCSOFFSETM), _V(-1,0.1,0),MaxThrust, ph_rcs0,15000, 15000);
	
	th_att_lin[16]=th_att_rot[14]=th_att_rot[15]=vessel-> CreateThruster (_V(ATTCOOR2,-0.3,TRANZ+RCSOFFSETM2), _V(-0.1,1,0),MaxThrust, ph_rcs0,15000, 15000);
	th_att_lin[17]=th_att_rot[22]=th_att_rot[23]=vessel-> CreateThruster (_V(-ATTCOOR2,-0.3,TRANZ+RCSOFFSETM), _V(-0.1,1,0),MaxThrust, ph_rcs0,15000, 15000);
	th_att_lin[18]=vessel-> CreateThruster (_V(ATTCOOR2,-0.3,-TRANZ-RCSOFFSETM2), _V(-0.1,1,0),MaxThrust, ph_rcs0,15000, 15000);
	th_att_lin[19]=vessel-> CreateThruster (_V(-ATTCOOR2,-0.3,-TRANZ-RCSOFFSETM), _V(-0.1,1,0),MaxThrust, ph_rcs0,15000, 15000);
	
	th_att_lin[20]=th_att_rot[20]=th_att_rot[21]=vessel-> CreateThruster (_V(ATTCOOR2,0.3,TRANZ+RCSOFFSETM), _V(-0.1,-1,0),MaxThrust, ph_rcs0,15000, 15000);
	th_att_lin[21]=th_att_rot[12]=th_att_rot[13]=vessel-> CreateThruster (_V(-ATTCOOR2,0.3,TRANZ+RCSOFFSETM2), _V(0.1,-1,0),MaxThrust, ph_rcs0,15000, 15000);
	th_att_lin[22]=vessel-> CreateThruster (_V(ATTCOOR2,0.3,-TRANZ-RCSOFFSETM), _V(-0.1,-1,0),MaxThrust, ph_rcs0,15000, 15000);
	th_att_lin[23]=vessel-> CreateThruster (_V(-ATTCOOR2,0.3,-TRANZ-RCSOFFSETM2), _V(0.1,-1,0),MaxThrust, ph_rcs0,15000, 15000);

	
	vessel->CreateThrusterGroup (th_att_lin+8,   4, THGROUP_ATT_RIGHT);
	vessel->CreateThrusterGroup (th_att_lin+12, 4, THGROUP_ATT_LEFT);
	vessel->CreateThrusterGroup (th_att_lin+16,   4, THGROUP_ATT_UP);
	vessel->CreateThrusterGroup (th_att_lin+20,   4, THGROUP_ATT_DOWN);
	vessel->CreateThrusterGroup (th_att_rot+8,   8, THGROUP_ATT_BANKLEFT);
	vessel->CreateThrusterGroup (th_att_rot+16,   8, THGROUP_ATT_BANKRIGHT);
	
	for (i = 8; i < 24; i++) vessel->AddExhaust (th_att_rot[i], 1.2, 0.18,tex);
	

	
	

}
void AddRCS_S4B(VESSEL *vessel)
{
	
	const double ATTCOOR = -10;
	const double ATTCOOR2 = 3.61;
	const double TRANCOOR = 0;
	const double TRANCOOR2 = 0.1;
	const double TRANZ=-2.1-STG2O;
	const double ATTWIDTH=.2;
	const double ATTHEIGHT=.5;
	const double TRANWIDTH=.2;
	const double TRANHEIGHT=1;
	const double RCSOFFSET=0.75;
	const double RCSOFFSETM=0.30;
	const double RCSOFFSETM2=0.47;
	const double RCSX=0.35;
		VECTOR3 m_exhaust_pos2= {0,ATTCOOR2,TRANZ};
		VECTOR3 m_exhaust_pos3= {0,-ATTCOOR2,TRANZ};
		VECTOR3 m_exhaust_pos4= {-ATTCOOR2,0,TRANZ};
		VECTOR3 m_exhaust_pos5= {ATTCOOR2,0,TRANZ};
		VECTOR3 m_exhaust_ref2 = {0,0.1,-1};
		VECTOR3 m_exhaust_ref3 = {0,-0.1,-1};
		VECTOR3 m_exhaust_ref4 = {-0.1,0,-1};
		VECTOR3 m_exhaust_ref5 = {0.1,0,-1};
	
	
		
	th_att_rot[0] =vessel-> CreateThruster (_V(0,ATTCOOR2+0.15,TRANZ-0.15), _V(0, -1,0), 20740.0, ph_3rd,5000000, 4000000);
	th_att_rot[1] =vessel-> CreateThruster (_V(0,-ATTCOOR2-0.15,TRANZ-0.15), _V(0,1,0),20740.0, ph_3rd,5000000, 4000000);
	vessel->AddExhaust (th_att_rot[0], 0.6, 0.078);
	vessel->AddExhaust (th_att_rot[1], 0.6, 0.078);
	vessel->CreateThrusterGroup (th_att_rot,   1, THGROUP_ATT_PITCHUP);
	vessel->CreateThrusterGroup (th_att_rot+1, 1, THGROUP_ATT_PITCHDOWN);
	
		
	th_att_rot[2] =vessel-> CreateThruster (_V(RCSX,ATTCOOR2-0.2,TRANZ-0.25), _V(-1,0,0),17400.0, ph_3rd,250000, 240000);
	th_att_rot[3] =vessel-> CreateThruster (_V(-RCSX,-ATTCOOR2+0.2,TRANZ-0.25), _V( 1,0,0), 17400.0, ph_3rd,250000, 240000);
	th_att_rot[4] =vessel-> CreateThruster (_V(-RCSX,ATTCOOR2-.2,TRANZ-0.25), _V( 1,0,0), 17400.0, ph_3rd,250000, 240000);
	th_att_rot[5] =vessel-> CreateThruster (_V(RCSX,-ATTCOOR2+.2,TRANZ-0.25), _V(-1,0,0),17400.0, ph_3rd,250000, 240000);
	vessel->AddExhaust (th_att_rot[2], 0.6, 0.078);
	vessel->AddExhaust (th_att_rot[3], 0.6, 0.078);
	vessel->AddExhaust (th_att_rot[4], 0.6, 0.078);
	vessel->AddExhaust (th_att_rot[5], 0.6, 0.078);
	vessel->CreateThrusterGroup (th_att_rot+2,   2, THGROUP_ATT_BANKLEFT);
	vessel->CreateThrusterGroup (th_att_rot+4, 2, THGROUP_ATT_BANKRIGHT);
		
	
	th_att_rot[6] =vessel-> CreateThruster (_V(-RCSX,ATTCOOR2-.2,TRANZ-0.25), _V(1,0,0), 17400.0, ph_3rd,250000, 240000);
	th_att_rot[7] =vessel-> CreateThruster (_V(-RCSX,-ATTCOOR2+.2,TRANZ-0.25), _V(1,0,0), 17400.0, ph_3rd,250000, 240000);
	th_att_rot[8] =vessel-> CreateThruster (_V(RCSX,-ATTCOOR2+.2,TRANZ-0.25), _V(-1,0,0), 17400.0, ph_3rd,250000, 240000);
	th_att_rot[9] =vessel-> CreateThruster (_V(RCSX,ATTCOOR2-.2,TRANZ-0.25), _V(-1,0,0), 17400.0, ph_3rd,250000, 240000);
	
	vessel->AddExhaust (th_att_rot[6], 0.6, 0.078);
	vessel->AddExhaust (th_att_rot[7], 0.6, 0.078);
	vessel->AddExhaust (th_att_rot[8], 0.6, 0.078);
	vessel->AddExhaust (th_att_rot[9], 0.6, 0.078);
	
	vessel->CreateThrusterGroup (th_att_rot+6,   2, THGROUP_ATT_YAWLEFT);
	vessel->CreateThrusterGroup (th_att_rot+8, 2, THGROUP_ATT_YAWRIGHT);
	
	
	th_att_lin[0] =vessel-> CreateThruster (_V(0,ATTCOOR2-0.15,TRANZ-.25), _V(0,0,1), 17400.0, ph_3rd,250000, 240000);
	th_att_lin[1] =vessel-> CreateThruster (_V(0,-ATTCOOR2+.15,TRANZ-.25), _V(0,0,1), 17400.0, ph_3rd,250000, 240000);
	vessel->AddExhaust (th_att_lin[0], 0.6, 0.078);
	vessel->AddExhaust (th_att_lin[1], 0.6, 0.078);
	vessel->CreateThrusterGroup (th_att_lin,   2, THGROUP_ATT_FORWARD);
	

}
void AddRCS_CM(VESSEL *vessel,double MaxThrust)
{
	
	UINT atthand;
	const double ATTCOOR = 0.95;
	const double ATTCOOR2 = 1.92;
	const double TRANCOOR = 0;
	const double TRANCOOR2 = 0.1;
	const double TRANZ=-0.65;
	const double ATTWIDTH=.15;
	const double ATTHEIGHT=.2;
	const double TRANWIDTH=.2;
	const double TRANHEIGHT=.6;
	const double RCSOFFSET=0.75;
	const double RCSOFFSETM=0.30;
	const double RCSOFFSETM2=0.47;
		VECTOR3 m_exhaust_pos2= {0,ATTCOOR2,TRANZ};
		VECTOR3 m_exhaust_pos3= {0,-ATTCOOR2,TRANZ};
		VECTOR3 m_exhaust_pos4= {-ATTCOOR2,0,TRANZ};
		VECTOR3 m_exhaust_pos5= {ATTCOOR2,0,TRANZ};
		VECTOR3 m_exhaust_ref2 = {0,0.1,-1};
		VECTOR3 m_exhaust_ref3 = {0,-0.1,-1};
		VECTOR3 m_exhaust_ref4 = {-0.1,0,-1};
		VECTOR3 m_exhaust_ref5 = {0.1,0,-1};

			int i;
	
	MaxThrust=120;
				
	th_att_cm[2]=vessel-> CreateThruster (_V(2,2,-2), _V(0,0,1),120, ph_rcs1,15000, 15000);
	th_att_cm[4]=vessel-> CreateThruster (_V(-2,2,-2), _V(0,0,1),MaxThrust, ph_rcs1,15000, 15000);
	th_att_cm[3]=vessel-> CreateThruster (_V(2,-2,-2), _V(0,0,1),MaxThrust, ph_rcs1,15000, 15000);
	th_att_cm[5]=vessel-> CreateThruster (_V(-2,-2,-2), _V(0,0,1),MaxThrust, ph_rcs1,15000, 15000);
	th_att_cm[7]=vessel-> CreateThruster (_V(2,2,2), _V(0,0,-1),120, ph_rcs1,15000, 15000);
	th_att_cm[0]=vessel-> CreateThruster (_V(-2,2,2), _V(0,0,-1),MaxThrust, ph_rcs1,15000, 15000);
	th_att_cm[6]=vessel-> CreateThruster (_V(2,-2,2), _V(0,0,-1),MaxThrust, ph_rcs1,15000, 15000);
	th_att_cm[1]=vessel-> CreateThruster (_V(-2,-2,2), _V(0,0,-1),MaxThrust, ph_rcs1,15000, 15000);
	vessel->CreateThrusterGroup (th_att_cm,   4, THGROUP_ATT_YAWLEFT);
	vessel->CreateThrusterGroup (th_att_cm+4,   4, THGROUP_ATT_YAWRIGHT);
	th_att_cm[8]=vessel-> CreateThruster (_V(2,2,-2), _V(0,-1,0),120, ph_rcs1,15000, 15000);
	th_att_cm[9]=vessel-> CreateThruster (_V(-2,2,-2), _V(0,-1,0),MaxThrust, ph_rcs1,15000, 15000);
	th_att_cm[12]=vessel-> CreateThruster (_V(2,2,2), _V(0,-1,0),120, ph_rcs1,15000, 15000);
	th_att_cm[13]=vessel-> CreateThruster (_V(-2,2,2), _V(0,-1,0),MaxThrust, ph_rcs1,15000, 15000);
	
	th_att_cm[15]=vessel-> CreateThruster (_V(2,-2,-2), _V(0,1,0),MaxThrust, ph_rcs1,15000, 15000);
	th_att_cm[14]=vessel-> CreateThruster (_V(-2,-2,-2), _V(0,1,0),MaxThrust, ph_rcs1,15000, 15000);
	th_att_cm[10]=vessel-> CreateThruster (_V(2,-2,2), _V(0,1,0),MaxThrust, ph_rcs1,15000, 15000);
	th_att_cm[11]=vessel-> CreateThruster (_V(-2,-2,2), _V(0,1,0),MaxThrust, ph_rcs1,15000, 15000);
	
	vessel->CreateThrusterGroup (th_att_cm+12,   4, THGROUP_ATT_PITCHDOWN);
	vessel->CreateThrusterGroup (th_att_cm+8,   4, THGROUP_ATT_PITCHUP);
	
	th_att_cm[16]=vessel-> CreateThruster (_V(2,2,-2), _V(0,-1,0),120, ph_rcs1,15000, 15000);
	th_att_cm[17]=vessel-> CreateThruster (_V(2,2,2), _V(0,-1,0),120, ph_rcs1,15000, 15000);
	th_att_cm[18]=vessel-> CreateThruster (_V(-2,-2,2), _V(0,1,0),MaxThrust, ph_rcs1,15000, 15000);
	th_att_cm[19]=vessel-> CreateThruster (_V(-2,-2,-2), _V(0,1,0),MaxThrust, ph_rcs1,15000, 15000);
	th_att_cm[23]=vessel-> CreateThruster (_V(-2,2,2), _V(0,-1,0),MaxThrust, ph_rcs1,15000, 15000);
	th_att_cm[22]=vessel-> CreateThruster (_V(2,-2,-2), _V(0,1,0),MaxThrust, ph_rcs1,15000, 15000);
	th_att_cm[20]=vessel-> CreateThruster (_V(-2,2,-2), _V(0,-1,0),MaxThrust, ph_rcs1,15000, 15000);
	th_att_cm[21]=vessel-> CreateThruster (_V(2,-2,2), _V(0,1,0),MaxThrust, ph_rcs1,15000, 15000);
	
	vessel->CreateThrusterGroup (th_att_cm+20,   4, THGROUP_ATT_BANKLEFT);
	vessel->CreateThrusterGroup (th_att_cm+16,   4, THGROUP_ATT_BANKRIGHT);
	

		
		//Rot up
		
		m_exhaust_pos2= _V(0.1,ATTCOOR2,TRANZ +0.05);
		m_exhaust_ref2 = _V(0,1,1);
		
		atthand = vessel->AddAttExhaustRef(m_exhaust_pos2,m_exhaust_ref2,ATTWIDTH,ATTHEIGHT);
		vessel->AddAttExhaustMode(atthand,ATTMODE_ROT,0,0);
		
		
		//Rot down
		m_exhaust_pos3= _V(0.1,ATTCOOR-0.2,TRANZ+1.4);
		m_exhaust_ref3 = _V(0,1,1);
		atthand = vessel->AddAttExhaustRef(m_exhaust_pos3,m_exhaust_ref3,ATTWIDTH,ATTHEIGHT);
		vessel->AddAttExhaustMode(atthand,ATTMODE_ROT,0,1);
		
		//Rot left

		m_exhaust_pos2= _V(ATTCOOR2,0.1,TRANZ);
		m_exhaust_ref2 = _V(0.5,0.1,0);
		
		atthand = vessel->AddAttExhaustRef(m_exhaust_pos2,m_exhaust_ref2,ATTWIDTH,ATTHEIGHT);
		vessel->AddAttExhaustMode(atthand,ATTMODE_ROT,1,1);
		
		//Rot right
		m_exhaust_pos2= _V(-ATTCOOR2,0.1,TRANZ);
		m_exhaust_ref2 = _V(-0.5,0.1,0);
		
		atthand = vessel->AddAttExhaustRef(m_exhaust_pos2,m_exhaust_ref2,ATTWIDTH,ATTHEIGHT);
		vessel->AddAttExhaustMode(atthand,ATTMODE_ROT,1,0);
		

		//Roll left

		m_exhaust_pos2= _V(ATTCOOR2/1.4,ATTCOOR2/1.4,TRANZ);
		m_exhaust_ref2 = _V(1,-0.5,0);
		
		atthand = vessel->AddAttExhaustRef(m_exhaust_pos2,m_exhaust_ref2,ATTWIDTH,ATTHEIGHT);
		vessel->AddAttExhaustMode(atthand,ATTMODE_ROT,2,1);
		
		//Roll right
		m_exhaust_pos2= _V(-ATTCOOR2/1.4,ATTCOOR2/1.4,TRANZ);
		m_exhaust_ref2 = _V(-1,-0.5,0);
		
		atthand = vessel->AddAttExhaustRef(m_exhaust_pos2,m_exhaust_ref2,ATTWIDTH,ATTHEIGHT);
		vessel->AddAttExhaustMode(atthand,ATTMODE_ROT,2,0);
	
}
void SetRCS_CM(VESSEL *vessel){

		if(RPswitch7){
			vessel->SetThrusterResource(th_att_cm[0],ph_rcs1);
			vessel->SetThrusterResource(th_att_cm[1],ph_rcs1);
			vessel->SetThrusterResource(th_att_cm[2],ph_rcs1);
			vessel->SetThrusterResource(th_att_cm[3],ph_rcs1);
			
		}else{
			vessel->SetThrusterResource(th_att_cm[0],NULL);
			vessel->SetThrusterResource(th_att_cm[1],NULL);
			vessel->SetThrusterResource(th_att_cm[2],NULL);
			vessel->SetThrusterResource(th_att_cm[3],NULL);
			
		}	
		if(RPswitch9){
			vessel->SetThrusterResource(th_att_cm[4],ph_rcs1);
			vessel->SetThrusterResource(th_att_cm[5],ph_rcs1);
			vessel->SetThrusterResource(th_att_cm[7],ph_rcs1);
			vessel->SetThrusterResource(th_att_cm[6],ph_rcs1);
			
		}else{
			vessel->SetThrusterResource(th_att_cm[4],NULL);
			vessel->SetThrusterResource(th_att_cm[5],NULL);
			vessel->SetThrusterResource(th_att_cm[6],NULL);
			vessel->SetThrusterResource(th_att_cm[7],NULL);
			
		}
		if(RPswitch8){
			vessel->SetThrusterResource(th_att_cm[8],ph_rcs1);
			vessel->SetThrusterResource(th_att_cm[9],ph_rcs1);
			vessel->SetThrusterResource(th_att_cm[10],ph_rcs1);
			vessel->SetThrusterResource(th_att_cm[11],ph_rcs1);
			
		}else{
			vessel->SetThrusterResource(th_att_cm[8],NULL);
			vessel->SetThrusterResource(th_att_cm[9],NULL);
			vessel->SetThrusterResource(th_att_cm[10],NULL);
			vessel->SetThrusterResource(th_att_cm[11],NULL);
			
		}	
}
//Needle function by Rob Conley from Mercury code
void DrawNeedle (HDC hDC, int x, int y, double rad, double angle, HPEN pen0, HPEN pen1)
{
	double dx = rad * cos(angle), dy = rad * sin(angle);
	HGDIOBJ oldObj;
	oldObj = SelectObject (hDC, pen1);
	MoveToEx (hDC, x, y, 0); LineTo (hDC, x + (int)(0.85*dx+0.5), y - (int)(0.85*dy+0.5));
	SelectObject (hDC, oldObj);
	oldObj = SelectObject (hDC, pen0);
	MoveToEx (hDC, x, y, 0); LineTo (hDC, x + (int)(dx+0.5), y - (int)(dy+0.5));
	SelectObject (hDC, oldObj);
}

void RedrawPanel_G (VESSEL *vessel, SURFHANDLE surf)
{
	double alpha;
	double range;
	
	alpha = fabs(aHAcc/G);
	
	//sprintf(oapiDebugString(), "Accel %f", alpha);
	if (alpha > 15) alpha = 15;
	range = 235 * RAD;
	range = range / 15;
	alpha = 15 - alpha;
	HDC hDC = oapiGetDC (surf);
	DrawNeedle (hDC, 37, 37, 28.0, (alpha*range)-50*RAD, g_Param.pen[2], g_Param.pen[3] );//(alpha * range)
	oapiReleaseDC (surf, hDC);
	
	oapiBlt (surf, srf[15], 25, 25, 25, 25, 25, 25, SURF_PREDEF_CK);
	
	
}
void RedrawPanel_Thrust (VESSEL *vessel, SURFHANDLE surf)
{
	double alpha;
	double range;
	
	alpha = vessel->GetEngineLevel(ENGINE_MAIN)*100;
	
	if (alpha > 100) alpha = 100;
	range = 270 * RAD;
	range = range / 100;
	alpha = 100 - alpha;
	HDC hDC = oapiGetDC (surf);
	DrawNeedle (hDC, 28, 28, 19.0, (alpha*range)-45*RAD, g_Param.pen[2], g_Param.pen[3] );//(alpha * range)
	oapiReleaseDC (surf, hDC);
	
	oapiBlt (surf, srf[16], 18, 18, 18, 18, 21, 21, SURF_PREDEF_CK);
	
	
}


//Altimeter Needle function by Rob Conley from Mercury code, Heavily modified to have non linear gauge range... :):)

void RedrawPanel_Alt (VESSEL *vessel, SURFHANDLE surf)
{
	double alpha;
	double range;
	
	alpha = vessel->GetAltitude();
	alpha = alpha / 0.305;
	
	//sprintf(oapiDebugString(), "altitude %f", alpha);
	if (alpha > 50000) alpha = 50000;
	if (alpha < 4001){
	range = 120 * RAD;
	range = range / 4000;
	alpha = 4000 - alpha;
	HDC hDC = oapiGetDC (surf);
	DrawNeedle (hDC, 44, 44, 40.0, (alpha*range)+150*RAD, g_Param.pen[2], g_Param.pen[3] );//(alpha * range)
	oapiReleaseDC (surf, hDC);
	}else if (alpha > 4001 && alpha < 6001){
	range = 35 * RAD;
	range = range / 2000;
	alpha = 2000 - alpha;
	HDC hDC = oapiGetDC (surf);
	DrawNeedle (hDC, 44, 44, 40.0, (alpha*range)+185*RAD, g_Param.pen[2], g_Param.pen[3] );//(alpha * range)
	oapiReleaseDC (surf, hDC);
	}else	if (alpha > 6001 && alpha < 8001){
	range = 25 * RAD;
	range = range / 2000;
	alpha = 2000 - alpha;
	HDC hDC = oapiGetDC (surf);
	DrawNeedle (hDC, 44, 44, 40.0, (alpha*range)+165*RAD, g_Param.pen[2], g_Param.pen[3] );//(alpha * range)
	oapiReleaseDC (surf, hDC);
	}else if (alpha > 8001 && alpha < 10001){
	range = 20 * RAD;
	range = range / 2000;
	alpha = 2000 - alpha;
	HDC hDC = oapiGetDC (surf);
	DrawNeedle (hDC, 44, 44, 40.0, (alpha*range)+150*RAD, g_Param.pen[2], g_Param.pen[3] );//(alpha * range)
	oapiReleaseDC (surf, hDC);
	}else if (alpha > 10001 && alpha < 20001){
	range = 55 * RAD;
	range = range / 10000;
	alpha = 10000 - alpha;
	HDC hDC = oapiGetDC (surf);
	DrawNeedle (hDC, 44, 44, 40.0, (alpha*range)+70*RAD, g_Param.pen[2], g_Param.pen[3] );//(alpha * range)
	oapiReleaseDC (surf, hDC);
	}else if (alpha > 20001 && alpha < 40001){
	range = 65 * RAD;
	range = range / 20000;
	alpha = 20000 - alpha;
	HDC hDC = oapiGetDC (surf);
	DrawNeedle (hDC, 44, 44, 40.0, (alpha*range)+15*RAD, g_Param.pen[2], g_Param.pen[3] );//(alpha * range)
	oapiReleaseDC (surf, hDC);
	}else {
	range = 20 * RAD;
	range = range / 10000;
	alpha = 10000 - alpha;
	HDC hDC = oapiGetDC (surf);
	DrawNeedle (hDC, 44, 44, 40.0, (alpha*range)+10*RAD, g_Param.pen[2], g_Param.pen[3] );//(alpha * range)
	oapiReleaseDC (surf, hDC);
	}
	oapiBlt (surf, srf[14], 21, 16, 22, 21, 48, 52, SURF_PREDEF_CK);
	
	
}


void StageTransform(VESSEL *vessel, VESSELSTATUS *vs, VECTOR3 ofs, VECTOR3 vel)
{
	
	VECTOR3 rofs, rvel = {vs->rvel.x, vs->rvel.y, vs->rvel.z};
	rofs.x=0;
	rofs.y=0;
	rofs.z=0;
// Staging Velocity represents 
// Need to do some transforms to get the correct vector to eject the stage
	vessel->Local2Rel (ofs, vs->rpos);
	vessel->GlobalRot (vel, rofs);
	vs->rvel.x = rvel.x+rofs.x;
	vs->rvel.y = rvel.y+rofs.y;
	vs->rvel.z = rvel.z+rofs.z;
}

void ToggelHatch(VESSEL *vessel){

	vessel->ClearMeshes();
	VECTOR3 mesh_dir=_V(0,SMVO,30.25-12.25-21.5);
	vessel->AddMesh (hSM, &mesh_dir);
	mesh_dir=_V(-2.2,-1.7,28.82-12.25-21.5);
	vessel->AddMesh (hSMhga, &mesh_dir);
	mesh_dir=_V(0,0,34.4-12.25-21.5);
	vessel->AddMesh (hCM, &mesh_dir);
	mesh_dir=_V(0,0.15,34.25-12.25-21.5);
	vessel->AddMesh (hCMP, &mesh_dir);
	mesh_dir=_V(0,0.15,34.25-12.25-21.5);
	vessel->AddMesh (hCREW, &mesh_dir);

	//Don't Forget the Hatch
	if (HatchOpen){
		
		mesh_dir=_V(0.02,1.35,34.54-12.25-21.5);
		vessel->AddMesh (hFHC, &mesh_dir);
			HatchOpen= false;
	
	}else{
		
		mesh_dir=_V(-0.7,1.75,34.85-12.25-21.5);
		vessel->AddMesh (hFHO, &mesh_dir);
		HatchOpen= true;
	}
	if (dockstate <=4 ){
	mesh_dir=_V(0,0,35.90-12.25-21.5);
	probeidx=vessel->AddMesh (hprobe, &mesh_dir);
	}
}
void ToggelHatch2(VESSEL *vessel){
	vessel->ClearMeshes();
	UINT meshidx ;
	VECTOR3 mesh_dir=_V(0,0,-1.2);
	if (Burned){
	vessel->AddMesh (hCM2B, &mesh_dir);
	}else{
	vessel->AddMesh (hCM2, &mesh_dir);
	}
	mesh_dir=_V(0,-0.1,-0.2);
	meshidx=vessel->AddMesh (hCMBALLOON, &mesh_dir);
	vessel ->SetMeshVisibleInternal (meshidx, true);
	mesh_dir=_V(0,0.15,-1.35);
	vessel->AddMesh (hCMP, &mesh_dir);
	mesh_dir=_V(0,0.15,-1.35);
	vessel->AddMesh (hCREW, &mesh_dir);
	

	//Don't Forget the Hatch
	if (HatchOpen){
	
			
			mesh_dir=_V(0.02,1.35,-1.06);
			vessel->AddMesh (hFHC, &mesh_dir);
			HatchOpen= false;
	}else{
	
			
			mesh_dir=_V(-0.7,1.75,0.45-1.2);
			vessel->AddMesh (hFHO, &mesh_dir);
			HatchOpen= true;
	}
	
}

void ToggleEVA(VESSEL *vessel){
	
	ToggleEva=false;	
	
	if (EVA_IP){
		EVA_IP =false;

	vessel->ClearMeshes();
	VECTOR3 mesh_dir=_V(0,SMVO,30.25-12.25-21.5);
	vessel->AddMesh (hSM, &mesh_dir);
	mesh_dir=_V(-2.2,-1.7,28.82-12.25-21.5);
	vessel->AddMesh (hSMhga, &mesh_dir);
	mesh_dir=_V(0,0,34.4-12.25-21.5);
	vessel->AddMesh (hCM, &mesh_dir);
	mesh_dir=_V(0,0.15,34.25-12.25-21.5);
	vessel->AddMesh (hCMP, &mesh_dir);
	mesh_dir=_V(0,0.15,34.25-12.25-21.5);
	vessel->AddMesh (hCREW, &mesh_dir);
	//Don't Forget the Hatch
	mesh_dir=_V(-0.7,1.75,34.85-12.25-21.5);
	vessel->AddMesh (hFHO, &mesh_dir);
	HatchOpen= true;
	if (dockstate <=4 ){
	mesh_dir=_V(0,0,35.90-12.25-21.5);
	probeidx=vessel->AddMesh (hprobe, &mesh_dir);
	}

	
	}else{
		EVA_IP =true;

	vessel->ClearMeshes();
	VECTOR3 mesh_dir=_V(0,SMVO,30.25-12.25-21.5);
	vessel->AddMesh (hSM, &mesh_dir);
	mesh_dir=_V(-2.2,-1.7,28.82-12.25-21.5);
	vessel->AddMesh (hSMhga, &mesh_dir);
	mesh_dir=_V(0,0,34.4-12.25-21.5);
	vessel->AddMesh (hCM, &mesh_dir);
	mesh_dir=_V(0,0.15,34.25-12.25-21.5);
	vessel->AddMesh (hCREW, &mesh_dir);

	//Don't Forget the Hatch
	mesh_dir=_V(-0.7,1.75,34.85-12.25-21.5);
	vessel->AddMesh (hFHO, &mesh_dir);
	HatchOpen= true;
	
	if (dockstate <=4 ){
	mesh_dir=_V(0,0,35.90-12.25-21.5);
	probeidx=vessel->AddMesh (hprobe, &mesh_dir);
	}
		
		VESSELSTATUS vs1;
		vessel->GetStatus(vs1);
		VECTOR3 ofs1 = _V(0,0.15,34.25-12.25-21.5);
		VECTOR3 vel1 = _V(0,0,0);
		VECTOR3 rofs1, rvel1 = {vs1.rvel.x, vs1.rvel.y, vs1.rvel.z};
		vessel->Local2Rel (ofs1, vs1.rpos);
		vessel->GlobalRot (vel1, rofs1);
		vs1.rvel.x = rvel1.x+rofs1.x;
		vs1.rvel.y = rvel1.y+rofs1.y;
		vs1.rvel.z = rvel1.z+rofs1.z;
		char VName[256]="";
		strcpy (VName, vessel->GetName()); strcat (VName, "-EVA");
		hEVA = oapiCreateVessel(VName,"Saturn5_EVA",vs1);
		oapiSetFocusObject(hEVA);
	}
}
void SetupEVA(VESSEL *vessel){
	
	
	
	if (EVA_IP){
		
		EVA_IP =true;

	vessel->ClearMeshes();
	VECTOR3 mesh_dir=_V(0,SMVO,30.25-12.25-21.5);
	vessel->AddMesh (hSM, &mesh_dir);
	mesh_dir=_V(-2.2,-1.7,28.82-12.25-21.5);
	vessel->AddMesh (hSMhga, &mesh_dir);
	mesh_dir=_V(0,0,34.4-12.25-21.5);
	vessel->AddMesh (hCM, &mesh_dir);
	mesh_dir=_V(0,0.15,34.25-12.25-21.5);
	vessel->AddMesh (hCREW, &mesh_dir);

	//Don't Forget the Hatch
	mesh_dir=_V(-0.7,1.75,34.85-12.25-21.5);
	vessel->AddMesh (hFHO, &mesh_dir);
	HatchOpen= true;
	
	if (dockstate <=4 ){
	mesh_dir=_V(0,0,35.90-12.25-21.5);
	probeidx=vessel->AddMesh (hprobe, &mesh_dir);
	}
		
	}
}

void SetRecovery(VESSEL *vessel){
	
	vessel->ClearMeshes();
	UINT meshidx ;
	VECTOR3 mesh_dir=_V(0,0,-1.2);
	if (Burned){
	vessel->AddMesh (hCM2B, &mesh_dir);
	}else{
	vessel->AddMesh (hCM2, &mesh_dir);
	}
	mesh_dir=_V(-0.7,1.75,0.45-1.2);
	vessel->AddMesh (hFHO, &mesh_dir);
	HatchOpen= true;
	mesh_dir=_V(0,-0.1,-0.2);
	meshidx=vessel->AddMesh (hCMBALLOON, &mesh_dir);
	vessel ->SetMeshVisibleInternal (meshidx, true);
	mesh_dir=_V(2.7,1.8,-1.5);
	vessel->AddMesh (hCRB, &mesh_dir);
	
	
}
void SetView(VESSEL *vessel){


	if (cdrview)	{
		vessel->SetCameraOffset (_V(-1.02,1.05,-1.67));
		cdrview=false;		
		if (probeidx !=0){
		vessel->SetMeshVisibleInternal(probeidx,false);
		}
	}
	if (cmpview){
		vessel->SetCameraOffset (_V(0,1.05,-1.67));
		cmpview=false;		
		if (probeidx !=0){
		vessel->SetMeshVisibleInternal(probeidx,false);
		}
	}
	if (dmpview){
		vessel->SetCameraOffset (_V(1.02,1.05,-1.67));
		dmpview=false;		
		if (probeidx !=0){
		vessel->SetMeshVisibleInternal(probeidx,false);
		}
	}
	if (dockview){
		if (dockstate==13){
		vessel->SetCameraOffset (_V(0,0,2.9));
		}else{
		vessel->SetCameraOffset (_V(0,0,-1.67));
		}
		dockview=false;	
		if (probeidx !=0){
		vessel->SetMeshVisibleInternal(probeidx,true);
		}
	}


}

double GetCurrentValue(VESSEL *vessel, double sl, double vac)

{
	double c_atm=0;
	double c_value=0;
	c_atm = vessel->GetAtmPressure() / 101.4e3; 
	c_value = c_atm * (sl-vac);				
	c_value += vac;							
	return c_value;
}

void DoThrustAdjust(VESSEL *vessel, double sealevel, double vacuum)
{
	double *booster_thrust;
	booster_thrust = vessel->GetMainThrustModPtr();
	*booster_thrust = 0;
	*booster_thrust = (GetCurrentValue(vessel,sealevel,vacuum)-GetCurrentValue(vessel,vacuum,vacuum));
}

double CalcSeaLevelThrust(double vacThrust, double vacISP, double slISP, double FuelMass)
{
	double vacBurnTime = 0.0;
	vacBurnTime = (FuelMass / vacThrust) * vacISP * G;
	return (FuelMass / vacBurnTime) * slISP *G;
}


#define N	16	// flight plan table size
const double met[N]    = { 0,  58, 75, 80,  90, 110, 130,   160, 170, 205, 450, 480, 490, 500, 535, 700};   // MET in sec
const double cpitch[N] = {90,  82, 65, 55,  48,  45,  35,    35,   35, 35,    25,   20, 10 , 5, -2,0};	// Commanded pitch in 

//#define N	13	// flight plan table size
//const double met[N]    = { 0, 25, 60, 95, 130, 145, 152, 165, 200, 235, 270, 305, 330};   // MET in sec
//const double cpitch[N] = {90, 90, 80, 70,  60,  55,  55,  50,  40,  30,  20,  10,   0};	// Commanded pitch in 



bool autopilot = false;

static double GetCPitch(double t)
{
	int i;
	if (t>met[N-1]) return cpitch[N-1];
	i=1;
	while (met[i]<t) i++;
	return cpitch[i-1]+(cpitch[i]-cpitch[i-1])/(met[i]-met[i-1])*(t-met[i-1]);
}


void KillDist(VESSEL *vessel,OBJHANDLE hvessel){
	
			
		VECTOR3 posr  = {0,0,0};
		double dist = 0.0;
		oapiGetRelativePos (vessel->GetHandle() ,hvessel, &posr);
		dist = sqrt(posr.x * posr.x + posr.y * posr.y + posr.z * posr.z);
	
		if (dist  > 2000){
				oapiDeleteVessel(hvessel,vessel->GetHandle());
				
		}
		

}
void KillAlt(VESSEL *vessel,OBJHANDLE hvessel,double altVS){

		
		int getit;
		getit = oapiGetAltitude(hvessel,&altVS);
	
		if ((altVS < 90) && altVS >= 0 ){
			oapiDeleteVessel(hvessel,vessel->GetHandle());
		}
}
void RedrawPanel_Horizon (VESSEL* vessel,SURFHANDLE surf)
{
	POINT pt[4];
	static double prange = RAD*30.0;
	static int size = 48, size2 = size*2;
	static int extent = (int)(size*prange);
	double bank = vessel->GetBank();
	double pitch = vessel->GetPitch();
	double pfrac = pitch/prange;
	double sinb = sin(bank), cosb = cos(bank);
	double a = tan(bank);
	double yl, yr, xb, xt, xlr, xll, ylr, yll;
	int i, iphi, n = 0;
	bool bl, br, bb, bt, bblue;
	if (cosb) { // horizon not vertical
		double b = pfrac/cosb;
		bl = (fabs(yl = -a+b) < 1.0); // left edge
		br = (fabs(yr =  a+b) < 1.0);  // right edge
		if (a) { // horizon not horizontal
			bb = (fabs(xb = ( 1.0-b)/a) < 1.0); // bottom edge
			bt = (fabs(xt = (-1.0-b)/a) < 1.0); // top edge
		} else { // horizon horizontal
			bb = bt = false;
		}
	} else { // horizon vertical
		bl = br = false;
		bb = bt = (fabs(xb = xt = pfrac) < 1.0);
	}
	if (bl) {
		pt[0].x = 0;
		pt[0].y = (int)(yl*size)+size;
		if (bt) {
			pt[1].x = (int)(xt*size)+size;
			pt[1].y = 0;
			pt[2].x = 0;
			pt[2].y = 0;
			n = 3;
			bblue = (cosb > 0.0);
		} else if (br) {
			pt[1].x = size2;
			pt[1].y = (int)(yr*size)+size;
			pt[2].x = size2;
			pt[2].y = 0;
			pt[3].x = 0;
			pt[3].y = 0;
			n = 4;
			bblue = (cosb > 0.0);
		} else if (bb) {
			pt[1].x = (int)(xb*size)+size;
			pt[1].y = size2;
			pt[2].x = 0;
			pt[2].y = size2;
			n = 3;
			bblue = (cosb < 0.0);
		}
	} else if (br) {
		pt[0].x = size2;
		pt[0].y = (int)(yr*size)+size;
		if (bt) {
			pt[1].x = (int)(xt*size)+size;
			pt[1].y = 0;
			pt[2].x = size2;
			pt[2].y = 0;
			n = 3;
			bblue = (cosb > 0.0);
		} else if (bb) {
			pt[1].x = (int)(xb*size)+size;
			pt[1].y = size2;
			pt[2].x = size2;
			pt[2].y = size2;
			n = 3;
			bblue = (cosb < 0.0);
		}
	} else if (bt && bb) {
		pt[0].x = (int)(xt*size)+size;
		pt[0].y = 0;
		pt[1].x = (int)(xb*size)+size;
		pt[1].y = size2;
		pt[2].x = 0;
		pt[2].y = size2;
		pt[3].x = 0;
		pt[3].y = 0;
		n = 4;
		bblue = ((xt-xb)*cosb > 0.0);
	}
	if (!n) bblue = (pitch < 0.0);
	oapiClearSurface (surf, bblue ? g_Param.col[3]:g_Param.col[2]);
	HDC hDC = oapiGetDC (surf);
	SelectObject (hDC, GetStockObject (BLACK_PEN));
	if (n >= 3) {
		SelectObject (hDC, g_Param.brush[bblue ? 2:3]);
		Polygon (hDC, pt, n);
		SelectObject (hDC, g_Param.pen[0]);
		MoveToEx (hDC, pt[0].x, pt[0].y, NULL); LineTo (hDC, pt[1].x, pt[1].y);
	}
	// bank indicator
	SelectObject (hDC, g_Param.pen[0]);
	SelectObject (hDC, GetStockObject (NULL_BRUSH));
	static double r1 = 40, r2 = 35;
	double sinb1 = sin(bank-0.1), cosb1 = cos(bank-0.1);
	double sinb2 = sin(bank+0.1), cosb2 = cos(bank+0.1);
	pt[0].x = (int)(r2*sinb1+0.5)+size; pt[0].y = -(int)(r2*cosb1+0.5)+size;
	pt[1].x = (int)(r1*sinb+0.5)+size;  pt[1].y = -(int)(r1*cosb+0.5)+size;
	pt[2].x = (int)(r2*sinb2+0.5)+size; pt[2].y = -(int)(r2*cosb2+0.5)+size;
	Polygon (hDC, pt, 3);

	// pitch ladder
	static double d = size*(10.0*RAD)/prange;
	static double ladderw = 14.0;
	double lwcosa = ladderw*cosb, lwsina = ladderw*sinb;
	double dsinb = d*sinb, dcosb = d*cosb;
	double phi0 = floor(pitch*DEG*0.1);
	double d0 = (pitch*DEG*0.1-phi0) * d, d1 = d0-4*d;
	// ladder
	xlr = lwcosa-d1*sinb, xll = -lwcosa-d1*sinb;
	ylr = lwsina+d1*cosb, yll = -lwsina+d1*cosb;
	for (iphi = (int)phi0+4, i = 0; i < 8; i++, iphi--) {
		if (iphi) {
			MoveToEx (hDC, size+(int)xll, size+(int)yll, NULL);
			LineTo   (hDC, size+(int)xlr, size+(int)ylr);
		}
		xlr -= dsinb, ylr += dcosb;
		xll -= dsinb, yll += dcosb;
	}
	oapiReleaseDC (surf, hDC);
	// labels
	lwcosa *= 1.6, lwsina *= 1.6;
	xlr = lwcosa-d1*sinb, xll = -lwcosa-d1*sinb;
	ylr = lwsina+d1*cosb, yll = -lwsina+d1*cosb;
	for (iphi = (int)phi0+4, i = 0; i < 8; i++, iphi--) {
		if (iphi) {
			int lb = abs(iphi)-1; if (lb >= 9) lb = 16-lb;
			oapiBlt (surf, srf[3], size-5+(int)xlr, size-3+(int)ylr, 9*lb, 96, 9, 7, SURF_PREDEF_CK);
			oapiBlt (surf, srf[3], size-5+(int)xll, size-3+(int)yll, 9*lb, 96, 9, 7, SURF_PREDEF_CK);
		}
		xlr -= dsinb, ylr += dcosb;
		xll -= dsinb, yll += dcosb;
	}

	// now overlay markings with transparent blt
	oapiBlt (surf, srf[3], 0, 0, 0, 0, 96, 96, SURF_PREDEF_CK);
	oapiBlt (surf, srf[5], 0, 0, 0, 0, 96, 96, SURF_PREDEF_CK);
}

void ReleaseSurfaces ()
{
	for (int i = 0; i < nsurf; i++)
		if (srf[i]) {
			oapiDestroySurface (srf[i]);
			srf[i] = 0;
		}
}
void InitPanel (int panel)
{
//	int i;

	switch (panel) {
	case 0: // main panel
		srf[0] = oapiCreateSurface (LOADBMP (IDB_ROT_KNOB));
		srf[1] = oapiCreateSurface (LOADBMP (IDB_INDICATORS1));
		srf[2] = oapiCreateSurface (LOADBMP (IDB_NEEDLE1));
		srf[3] = oapiCreateSurface (LOADBMP (IDB_HORIZON));   
		srf[4] = oapiCreateSurface (LOADBMP (IDB_DIGITAL));   
		srf[5] = oapiCreateSurface (LOADBMP (IDB_HORIZON2));   
		srf[6] = oapiCreateSurface (LOADBMP (IDB_SWITCHUP));   
		srf[7] = oapiCreateSurface (LOADBMP (IDB_SWLEVER)); 
		srf[8] = oapiCreateSurface (LOADBMP (IDB_SECSWITCH)); 
		srf[9] = oapiCreateSurface (LOADBMP (IDB_ABORT)); 
		srf[10] = oapiCreateSurface (LOADBMP (IDB_ANNUN)); 
		srf[11] = oapiCreateSurface (LOADBMP (IDB_LAUNCH)); 
		srf[12] = oapiCreateSurface (LOADBMP (IDB_LV_ENG));
		srf[13] = oapiCreateSurface (LOADBMP (IDB_LIGHTS2));
		srf[14] = oapiCreateSurface (LOADBMP (IDB_ANLG_ALT));
		srf[15] = oapiCreateSurface (LOADBMP (IDB_ANLG_GMETER));
		srf[16] = oapiCreateSurface (LOADBMP (IDB_THRUST));
		srf[17] = oapiCreateSurface (LOADBMP (IDB_HEADING));
		oapiSetSurfaceColourKey (srf[3], 0);
		oapiSetSurfaceColourKey (srf[5], 16711935);
		oapiSetSurfaceColourKey (srf[14], 16711935);
		oapiSetSurfaceColourKey (srf[15], 16711935);
		oapiSetSurfaceColourKey (srf[16], 16711935);
		
		break;
	
	}
}

void BuildFirstStage (VESSEL *vessel,int bstate)
{

	
	vessel->SetSize (59.5);
	vessel->SetEmptyMass (848100);
	vessel->SetMaxFuelMass (2246000);
	vessel->SetFuelMass(0);
	vessel->SetPMI (_V(1147,1147,216.68));
	vessel->SetCrossSections (_V(1129,1133,52.4));
	vessel->SetCW (0.1, 0.3, 1.4, 1.4);
	vessel->SetRotDrag (_V(0.7,0.7,1.2));
	vessel->SetPitchMomentScale (0);
	vessel->SetBankMomentScale (0);
	vessel->SetLiftCoeffFunc (0); 
	vessel->SetSurfaceFrictionCoeff(10e80,10e80);
	vessel->ClearMeshes();
	VECTOR3 m_exhaust_pos1= {3,3,Offset1st};
    vessel->ClearMeshes();
	VECTOR3 mesh_dir=_V(0,0,-80.0+STG0O);
	vessel->AddMesh (hCRAWL, &mesh_dir);
	mesh_dir=_V(0,0,-54.0+STG0O);
	vessel->AddMesh (hsat5stg1, &mesh_dir);
	if (bstate >=1){
	mesh_dir=_V(0,0,-30.5+STG0O);
	vessel->AddMesh (hsat5intstg, &mesh_dir);
	}
	if (bstate >=1){
	mesh_dir=_V(0,0,-17.2+STG0O);
	vessel->AddMesh (hsat5stg2, &mesh_dir);
	}
	if (bstate >=2){
	mesh_dir=_V(0,0,2.+STG0O);
	vessel->AddMesh (hsat5stg3, &mesh_dir);
	}if (bstate >=3){
	mesh_dir=_V(0,0,12+STG0O);
	vessel->AddMesh (hLMPKD, &mesh_dir);
	}if (bstate >=4){
	mesh_dir=_V(-1.48,-1.48,14.55+STG0O);
	vessel->AddMesh (hsat5stg31, &mesh_dir);
	}if (bstate >=4){
	mesh_dir=_V(1.48,-1.48,14.55+STG0O);
	vessel->AddMesh (hsat5stg32, &mesh_dir);
	}if (bstate >=4){
	mesh_dir=_V(1.48,1.48,14.55+STG0O);
    vessel->AddMesh (hsat5stg33, &mesh_dir);
	}if (bstate >=4){
	mesh_dir=_V(-1.48,1.48,14.55+STG0O);
    vessel->AddMesh (hsat5stg34, &mesh_dir);
	}if (bstate >=5){
	mesh_dir=_V(0,SMVO,19.1+STG0O);
	vessel->AddMesh (hSM, &mesh_dir);
	}if (bstate >=6){
	mesh_dir=_V(0,0,23.25+STG0O);
	vessel->AddMesh (hCM, &mesh_dir);
	}if (bstate >=7){
	mesh_dir=_V(0,0,28.2+STG0O);
	 vessel->AddMesh (hsat5tower, &mesh_dir);
	}
	Offset1st = -60.1+STG0O;
	vessel->SetCameraOffset (_V(-1,1.0,23.1+STG0O));
	status = 0;
	//vessel->DefSetState(&vs);
}

void SetFirstStage (VESSEL *vessel)
{
	int i;

	// *********************** physical parameters *********************************
	vessel->DelThrusterGroup(THGROUP_MAIN,true);
    vessel->SetSize (59.5);
	vessel->SetEmptyMass (848100);
	vessel->SetPMI (_V(1147,1147,116.60));
	vessel->SetCrossSections (_V(1129,1133,52.4));
	vessel->SetCW (0.1, 0.3, 1.4, 1.4);
	vessel->SetRotDrag (_V(0.7,0.7,1.2));
	vessel->SetPitchMomentScale (0);
	vessel->SetBankMomentScale (0);
	vessel->SetLiftCoeffFunc (0); 
	vessel->SetSurfaceFrictionCoeff(10e90,10e90);
	// ************************* propellant specs **********************************
	if (!ph_1st)  ph_1st  = vessel->CreatePropellantResource(2246000); //1st stage Propellant
	vessel->SetDefaultPropellantResource (ph_1st); // display 1st stage propellant level in generic HUD

	// *********************** thruster definitions ********************************

	vessel->ClearThrusterDefinitions();
	Offset1st = -75.1+STG0O;
	VECTOR3 m_exhaust_ref = {0,0,-1};
    VECTOR3 MAIN4a_Vector= {3,3,Offset1st+0.5};
	VECTOR3 MAIN2a_Vector={-3,-3,Offset1st+0.5};
	VECTOR3 MAIN1a_Vector= {-3,3,Offset1st+0.5};
	VECTOR3 MAIN3a_Vector={3,-3,Offset1st+0.5};
	VECTOR3 MAIN5a_Vector={0,0,Offset1st+0.5};
	// orbiter main thrusters
	th_main[0] = vessel->CreateThruster (MAIN4a_Vector, _V( 0,0,1),7357500 , ph_1st, 2489.6);
	th_main[1] = vessel->CreateThruster (MAIN2a_Vector, _V( 0,0,1),7357500 , ph_1st, 2489.6);
	th_main[2] = vessel->CreateThruster (MAIN1a_Vector, _V( 0,0,1),7357500 , ph_1st, 2489.6);
	th_main[3] = vessel->CreateThruster (MAIN3a_Vector, _V( 0,0,1),7357500 , ph_1st, 2489.6);
	th_main[4] = vessel->CreateThruster (MAIN5a_Vector, _V( 0,0,1),7357500 , ph_1st, 2489.6);
	SURFHANDLE tex = oapiRegisterExhaustTexture ("Exhaust_atsrb");//"Exhaust2"
	thg_main = vessel->CreateThrusterGroup (th_main, 5, THGROUP_MAIN);
	for (i = 0; i < 5; i++) vessel->AddExhaust (th_main[i], 120.0, 10.80, tex);

	
	// attitude - this is temporary
	// attitude adjustment during launch phase should really be done via ENGINE gimbaling
	//CreateAttControls_Launch();
	//vessel->SetMaxThrust (ENGINE_ATTITUDE, 8e5);
	// ************************ visual parameters **********************************

	
	vessel->ClearMeshes();
	UINT meshidx;
	double TCP=-101.5+STG0O-TCPO;
	vessel->SetTouchdownPoints (_V(0,-100.0,TCP), _V(-7,7,TCP), _V(7,7,TCP));
	VECTOR3 mesh_dir=_V(0,0,-54.0+STG0O);
	vessel->AddMesh (hsat5stg1, &mesh_dir);
	mesh_dir=_V(0,0,-30.5+STG0O);
	vessel->AddMesh (hsat5intstg, &mesh_dir);
	mesh_dir=_V(0,0,-17.2+STG0O);
	vessel->AddMesh (hsat5stg2, &mesh_dir);
	mesh_dir=_V(0,0,2.+STG0O);
	vessel->AddMesh (hsat5stg3, &mesh_dir);
	if (LEM_DISPLAY){
	mesh_dir=_V(0,0,12+STG0O);
	vessel->AddMesh (hLMPKD, &mesh_dir);
	}
	mesh_dir=_V(-1.48,-1.48,14.55+STG0O);
	vessel->AddMesh (hsat5stg31, &mesh_dir);
	mesh_dir=_V(1.48,-1.48,14.55+STG0O);
	vessel->AddMesh (hsat5stg32, &mesh_dir);
	mesh_dir=_V(1.48,1.48,14.55+STG0O);
    vessel->AddMesh (hsat5stg33, &mesh_dir);
	mesh_dir=_V(-1.48,1.48,14.55+STG0O);
    vessel->AddMesh (hsat5stg34, &mesh_dir);
	mesh_dir=_V(0,SMVO,19.1+STG0O);
	vessel->AddMesh (hSM, &mesh_dir);
	mesh_dir=_V(0,0,23.25+STG0O);
	vessel->AddMesh (hCM, &mesh_dir);
	mesh_dir=_V(0,0,28.2+STG0O);
	meshidx = vessel->AddMesh (hsat5tower, &mesh_dir);
	vessel ->SetMeshVisibleInternal (meshidx, true);
	vessel->SetCameraOffset (_V(-1,1.0,22.90+STG0O));
	status = 0;
	buildstatus=8;
	char VNameApollo[256]="";
	char VNameRef13[256]="";
	strcpy (VNameApollo, vessel->GetName());
	strcpy (VNameRef13, "AS-508");
		if (strcmp(VNameApollo,VNameRef13)==0){
		Apollo13 =true;
		}
	vessel->EnableTransponder (true);

	// **************************** NAV radios *************************************

	vessel->InitNavRadios (4);
	RPswitch10=true;
	RPswitch11=true;
	autopilot = true;
	DPROG = 01;
	R1 = MIN_ALT;
	R2 = TO_HDG;
}


void SetSecondStage (VESSEL *vessel)
{
	

	const double ATTWIDTH=.2;
	const double ATTHEIGHT=.5;
	UINT meshidx;
	vessel->ClearMeshes();
	vessel->DelThrusterGroup(THGROUP_MAIN,true);
    vessel->ClearThrusterDefinitions();
	if(ph_1st)	vessel->DelPropellantResource(ph_1st);
	vessel->SetSize (35.5);
	vessel->SetCOG_elev (15.225);
	vessel->SetEmptyMass (227100);
	vessel->SetPMI (_V(374,374,60));
	vessel->SetCrossSections (_V(524,524,97));
	vessel->SetCW (0.1, 0.3, 1.4, 1.4);
	vessel->SetRotDrag (_V(0.7,0.7,1.2));
	vessel->SetPitchMomentScale (0);
	vessel->SetBankMomentScale (0);
	vessel->SetLiftCoeffFunc (0); 
    vessel->ShiftCentreOfMass (_V(0,0,STG1O));
	VECTOR3 mesh_dir=_V(0,0,-30.5-STG1O);
	vessel->AddMesh (hsat5intstg, &mesh_dir);
	mesh_dir=_V(0,0,-17.2-STG1O);
	vessel->AddMesh (hsat5stg2, &mesh_dir);
	mesh_dir=_V(0,0,2.-STG1O);
	vessel->AddMesh (hsat5stg3, &mesh_dir);
	if (LEM_DISPLAY){
	mesh_dir=_V(0,0,12-STG1O);
	vessel->AddMesh (hLMPKD, &mesh_dir);
	}
	mesh_dir=_V(-1.48,-1.48,14.55-STG1O);
	vessel->AddMesh (hsat5stg31, &mesh_dir);
	mesh_dir=_V(1.48,-1.48,14.55-STG1O);
	vessel->AddMesh (hsat5stg32, &mesh_dir);
	mesh_dir=_V(1.48,1.48,14.55-STG1O);
    vessel->AddMesh (hsat5stg33, &mesh_dir);
	mesh_dir=_V(-1.48,1.48,14.55-STG1O);
    vessel->AddMesh (hsat5stg34, &mesh_dir);
	mesh_dir=_V(0,SMVO,19.1-STG1O);
	vessel->AddMesh (hSM, &mesh_dir);
	mesh_dir=_V(0,0,23.25-STG1O);
	vessel->AddMesh (hCM, &mesh_dir);
	mesh_dir=_V(0,0,28.2-STG1O);
	meshidx = vessel->AddMesh (hsat5tower, &mesh_dir);
	vessel ->SetMeshVisibleInternal (meshidx, true);
	
	
	// ************************* propellant specs **********************************
	if (!ph_2nd)  ph_2nd  = vessel->CreatePropellantResource(471000); //2nd stage Propellant
	vessel->SetDefaultPropellantResource (ph_2nd); // display 2nd stage propellant level in generic HUD
	// attitude - this is temporary
	// attitude adjustment during launch phase should really be done via ENGINE gimbaling
	//vessel->SetMaxThrust (ENGINE_ATTITUDE, 2e5);
	
	// *********************** thruster definitions ********************************
	int i;	

	VECTOR3 m_exhaust_pos1= {-1.8,-1.8,-33.5-STG1O};
	VECTOR3 m_exhaust_pos2= {1.8,1.8,-33.5-STG1O};
	VECTOR3 m_exhaust_pos3= {-1.8,1.8,-33.5-STG1O};
	VECTOR3 m_exhaust_pos4 = {1.8,-1.8,-33.5-STG1O};
	VECTOR3 m_exhaust_pos5 = {0,0,-33.5-STG1O};
	// orbiter main thrusters 
	th_main[0] = vessel->CreateThruster (m_exhaust_pos1, _V( 0,0,1),1201725 , ph_2nd, 4579.85);
	th_main[1] = vessel->CreateThruster (m_exhaust_pos2,_V( 0,0,1),1201725 , ph_2nd, 4579.85);
	th_main[2] = vessel->CreateThruster (m_exhaust_pos3, _V( 0,0,1),1201725 , ph_2nd, 4579.85);
	th_main[3] = vessel->CreateThruster (m_exhaust_pos4, _V( 0,0,1),1201725 , ph_2nd, 4579.85);
	th_main[4] = vessel->CreateThruster (m_exhaust_pos5, _V( 0,0,1),1201725 , ph_2nd, 4579.85);
	thg_main = vessel->CreateThrusterGroup (th_main, 5, THGROUP_MAIN);
	SURFHANDLE tex = oapiRegisterExhaustTexture ("Exhaust_atsme");//"Exhaust2"
	for (i = 0; i < 5; i++) vessel->AddExhaust (th_main[i], 25.0, 1.5,tex);
	vessel->SetThrusterGroupLevel(thg_main, 0.0);
	
	

	status = 1;
	vessel->SetCameraOffset (_V(-1,1.0,22.9-STG1O));

		
	VECTOR3	m_exhaust_pos6= _V(0,5.07,-33.15-STG1O);
	VECTOR3 m_exhaust_pos7= _V(0,-5.07,-33.15-STG1O);
	VECTOR3	m_exhaust_pos8= _V(5.07,0,-33.15-STG1O);
	VECTOR3 m_exhaust_pos9= _V(-5.07,0,-33.15-STG1O);
	VECTOR3	m_exhaust_pos10= _V(3.55,3.7,-33.15-STG1O);
	VECTOR3 m_exhaust_pos11= _V(3.55,-3.7,-33.15-STG1O);
	VECTOR3	m_exhaust_pos12= _V(-3.55,3.7,-33.15-STG1O);
	VECTOR3 m_exhaust_pos13= _V(-3.55,-3.7,-33.15-STG1O);
	
	th_ull[0] = vessel->CreateThruster (m_exhaust_pos6, _V( 0,0,1),725 , ph_2nd, 45790.85);
	th_ull[1] = vessel->CreateThruster (m_exhaust_pos7, _V( 0,0,1),725 , ph_2nd, 45790.85);
	th_ull[2] = vessel->CreateThruster (m_exhaust_pos8, _V( 0,0,1),725 , ph_2nd, 45790.85);
	th_ull[3] = vessel->CreateThruster (m_exhaust_pos9, _V( 0,0,1),725 , ph_2nd, 45790.85);
	th_ull[4] = vessel->CreateThruster (m_exhaust_pos10, _V( 0,0,1),725 , ph_2nd, 45790.85);
	th_ull[5] = vessel->CreateThruster (m_exhaust_pos11, _V( 0,0,1),725 , ph_2nd, 45790.85);
	th_ull[6] = vessel->CreateThruster (m_exhaust_pos12, _V( 0,0,1),725 , ph_2nd, 45790.85);
	th_ull[7] = vessel->CreateThruster (m_exhaust_pos13, _V( 0,0,1),725 , ph_2nd, 45790.85);
	for (i = 0; i < 8; i++) vessel->AddExhaust (th_ull[i], 5.0, 0.15);
	//PlayVesselWave(SepS,LOOP,255);
	thg_ull = vessel->CreateThrusterGroup (th_ull, 8,THGROUP_USER);
	vessel->SetThrusterGroupLevel(thg_ull,1.0);
	LAUNCHIND[6]=true;
	char VNameApollo[256]="";
	char VNameRef13[256]="";
	strcpy (VNameApollo, vessel->GetName());
	strcpy (VNameRef13, "AS-508");
		if (strcmp(VNameApollo,VNameRef13)==0){
		Apollo13 =true;
		}
	
}
void SetSecondStage1 (VESSEL *vessel)
{
	
	
	UINT meshidx;
	vessel->ClearMeshes();
	vessel->DelThrusterGroup(THGROUP_MAIN,true);
	vessel->ClearThrusterDefinitions();
	if(ph_1st)	vessel->DelPropellantResource(ph_1st);
	vessel->SetSize (35.5);
	vessel->SetCOG_elev (15.225);
	vessel->SetEmptyMass (227100);
	vessel->SetPMI (_V(374,374,60));
	vessel->SetCrossSections (_V(524,524,97));
	vessel->SetCW (0.1, 0.3, 1.4, 1.4);
	vessel->SetRotDrag (_V(0.7,0.7,1.2));
	vessel->SetPitchMomentScale (0);
	vessel->SetBankMomentScale (0);
	vessel->SetLiftCoeffFunc (0); 
    VECTOR3 mesh_dir=_V(0,0,-17.2-STG1O);
	vessel->AddMesh (hsat5stg2, &mesh_dir);
	mesh_dir=_V(0,0,2.-STG1O);
	vessel->AddMesh (hsat5stg3, &mesh_dir);
	if (LEM_DISPLAY){
	mesh_dir=_V(0,0,12-STG1O);
	vessel->AddMesh (hLMPKD, &mesh_dir);
	}
	mesh_dir=_V(-1.48,-1.48,14.55-STG1O);
	vessel->AddMesh (hsat5stg31, &mesh_dir);
	mesh_dir=_V(1.48,-1.48,14.55-STG1O);
	vessel->AddMesh (hsat5stg32, &mesh_dir);
	mesh_dir=_V(1.48,1.48,14.55-STG1O);
    vessel->AddMesh (hsat5stg33, &mesh_dir);
	mesh_dir=_V(-1.48,1.48,14.55-STG1O);
    vessel->AddMesh (hsat5stg34, &mesh_dir);
	mesh_dir=_V(0,SMVO,19.1-STG1O);
	vessel->AddMesh (hSM, &mesh_dir);
	mesh_dir=_V(0,0,23.25-STG1O);
	vessel->AddMesh (hCM, &mesh_dir);
	mesh_dir=_V(0,0,28.2-STG1O);
	meshidx = vessel->AddMesh (hsat5tower, &mesh_dir);
	vessel ->SetMeshVisibleInternal (meshidx, true);
		// ************************* propellant specs **********************************
	if (!ph_2nd)  ph_2nd  = vessel->CreatePropellantResource(471000); //2nd stage Propellant
	vessel->SetDefaultPropellantResource (ph_2nd); // display 2nd stage propellant level in generic HUD
	// attitude - this is temporary
	// attitude adjustment during launch phase should really be done via ENGINE gimbaling
//	vessel->SetMaxThrust (ENGINE_ATTITUDE, 2e5);
	
	// *********************** thruster definitions ********************************
	int i;	

	VECTOR3 m_exhaust_pos1= {-1.8,-1.8,-33.5-STG1O};
	VECTOR3 m_exhaust_pos2= {1.8,1.8,-33.5-STG1O};
	VECTOR3 m_exhaust_pos3= {-1.8,1.8,-33.5-STG1O};
	VECTOR3 m_exhaust_pos4 = {1.8,-1.8,-33.5-STG1O};
	VECTOR3 m_exhaust_pos5 = {0,0,-33.5-STG1O};
	// orbiter main thrusters
	th_main[0] = vessel->CreateThruster (m_exhaust_pos1, _V( 0,0,1),1201725 , ph_2nd, 4579.85);
	th_main[1] = vessel->CreateThruster (m_exhaust_pos2,_V( 0,0,1),1201725 , ph_2nd, 4579.85);
	th_main[2] = vessel->CreateThruster (m_exhaust_pos3, _V( 0,0,1),1201725 , ph_2nd, 4579.85);
	th_main[3] = vessel->CreateThruster (m_exhaust_pos4, _V( 0,0,1),1201725 , ph_2nd, 4579.85);
	th_main[4] = vessel->CreateThruster (m_exhaust_pos5, _V( 0,0,1),1201725 , ph_2nd, 4579.85);
	thg_main = vessel->CreateThrusterGroup (th_main, 5, THGROUP_MAIN);
	SURFHANDLE tex = oapiRegisterExhaustTexture ("Exhaust_atsme");//"Exhaust2"
	for (i = 0; i < 5; i++) vessel->AddExhaust (th_main[i], 25.0, 1.5,tex);
	vessel->SetThrusterGroupLevel(thg_main, 1.0);
	
		status = 2;
	vessel->SetCameraOffset (_V(-1,1.0,22.9-STG1O));
	char VNameApollo[256]="";
	char VNameRef13[256]="";
	strcpy (VNameApollo, vessel->GetName());
	strcpy (VNameRef13, "AS-508");
		if (strcmp(VNameApollo,VNameRef13)==0){
		Apollo13 =true;
		}
}

void SetSecondStage2 (VESSEL *vessel)
{

	vessel->ClearMeshes();
	vessel->DelThrusterGroup(THGROUP_MAIN,true);
    vessel->ClearThrusterDefinitions();
	if(ph_1st)	vessel->DelPropellantResource(ph_1st);
	vessel->SetSize (35.5);
	vessel->SetCOG_elev (15.225);
	vessel->SetEmptyMass (227100);
	vessel->SetPMI (_V(374,374,60));
	vessel->SetCrossSections (_V(524,524,97));
	vessel->SetCW (0.1, 0.3, 1.4, 1.4);
	vessel->SetRotDrag (_V(0.7,0.7,1.2));
	vessel->SetPitchMomentScale (0);
	vessel->SetBankMomentScale (0);
	vessel->SetLiftCoeffFunc (0); 
    VECTOR3 mesh_dir=_V(0,0,-17.2-STG1O);
	vessel->AddMesh (hsat5stg2, &mesh_dir);
	mesh_dir=_V(0,0,2.-STG1O);
	vessel->AddMesh (hsat5stg3, &mesh_dir);
	if (LEM_DISPLAY){
	mesh_dir=_V(0,0,12-STG1O);
	vessel->AddMesh (hLMPKD, &mesh_dir);
	}
	mesh_dir=_V(-1.48,-1.48,14.55-STG1O);
	vessel->AddMesh (hsat5stg31, &mesh_dir);
	mesh_dir=_V(1.48,-1.48,14.55-STG1O);
	vessel->AddMesh (hsat5stg32, &mesh_dir);
	mesh_dir=_V(1.48,1.48,14.55-STG1O);
    vessel->AddMesh (hsat5stg33, &mesh_dir);
	mesh_dir=_V(-1.48,1.48,14.55-STG1O);
    vessel->AddMesh (hsat5stg34, &mesh_dir);
	mesh_dir=_V(0,SMVO,19.1-STG1O);
	vessel->AddMesh (hSM, &mesh_dir);
	mesh_dir=_V(0,0,23.25-STG1O);
	vessel->AddMesh (hCM, &mesh_dir);
	mesh_dir=_V(0.02,1.35,23.39-STG1O);
	vessel->AddMesh (hFHC, &mesh_dir);
	mesh_dir=_V(0,0.15,23.1-STG1O);
	vessel->AddMesh (hCMP, &mesh_dir);
	mesh_dir=_V(0,0.15,23.1-STG1O);
	vessel->AddMesh (hCREW, &mesh_dir);
	mesh_dir=_V(0,0,24.8-STG1O);
	probeidx=vessel->AddMesh (hprobe, &mesh_dir);
	// ************************* propellant specs **********************************
	if (!ph_2nd)  ph_2nd  = vessel->CreatePropellantResource(471000); //2nd stage Propellant
	vessel->SetDefaultPropellantResource (ph_2nd); // display 2nd stage propellant level in generic HUD
	//vessel->SetMaxThrust (ENGINE_ATTITUDE, 2e5);
	// *********************** thruster definitions ********************************
	int i;	

	VECTOR3 m_exhaust_pos1= {-1.8,-1.8,-33.5-STG1O};
	VECTOR3 m_exhaust_pos2= {1.8,1.8,-33.5-STG1O};
	VECTOR3 m_exhaust_pos3= {-1.8,1.8,-33.5-STG1O};
	VECTOR3 m_exhaust_pos4 = {1.8,-1.8,-33.5-STG1O};
	VECTOR3 m_exhaust_pos5 = {0,0,-33.5-STG1O};
		// orbiter main thrusters
	th_main[0] = vessel->CreateThruster (m_exhaust_pos1, _V( 0,0,1),1201725 , ph_2nd, 4579.85);
	th_main[1] = vessel->CreateThruster (m_exhaust_pos2,_V( 0,0,1),1201725 , ph_2nd, 4579.85);
	th_main[2] = vessel->CreateThruster (m_exhaust_pos3, _V( 0,0,1),1201725 , ph_2nd, 4579.85);
	th_main[3] = vessel->CreateThruster (m_exhaust_pos4, _V( 0,0,1),1201725 , ph_2nd, 4579.85);
	th_main[4] = vessel->CreateThruster (m_exhaust_pos5, _V( 0,0,1),1201725 , ph_2nd, 4579.85);
	thg_main = vessel->CreateThrusterGroup (th_main, 5, THGROUP_MAIN);
	SURFHANDLE tex = oapiRegisterExhaustTexture ("Exhaust_atsme");//"Exhaust2"
	for (i = 0; i < 5; i++) vessel->AddExhaust (th_main[i], 25.0, 1.5,tex);
	vessel->SetThrusterGroupLevel(thg_main, 1.0);
	status = 3;
	vessel->SetCameraOffset (_V(-1,1.0,22.9-STG1O));
	char VNameApollo[256]="";
	char VNameRef13[256]="";
	strcpy (VNameApollo, vessel->GetName());
	strcpy (VNameRef13, "AS-508");
		if (strcmp(VNameApollo,VNameRef13)==0){
		Apollo13 =true;
		}
	
}


void SetThirdStage (VESSEL *vessel)
{
	vessel->ClearMeshes();
	vessel->DelThrusterGroup(THGROUP_MAIN,true);
     vessel->ClearThrusterDefinitions();
	if(ph_2nd)	vessel->DelPropellantResource(ph_2nd);
	vessel->SetSize (15.5);
	vessel->SetCOG_elev (15.225);
	vessel->SetEmptyMass (65600);
	vessel->SetPMI (_V(53.5,53.5,5));
	vessel->SetCrossSections (_V(167,167,47));
	vessel->SetCW (0.1, 0.3, 1.4, 1.4);
	vessel->SetRotDrag (_V(0.7,0.7,1.2));
	vessel->SetPitchMomentScale (0);
	vessel->SetBankMomentScale (0);
	vessel->SetLiftCoeffFunc (0); 
    vessel->ShiftCentreOfMass (_V(0,0,STG2O));
	VECTOR3 mesh_dir=_V(0,0,2.-STG2O);
	vessel->AddMesh (hsat5stg3, &mesh_dir);
	if (LEM_DISPLAY){
	mesh_dir=_V(0,0,12-STG2O);
	vessel->AddMesh (hLMPKD, &mesh_dir);
	}
	mesh_dir=_V(-1.48,-1.48,14.55-STG2O);
	vessel->AddMesh (hsat5stg31, &mesh_dir);
	mesh_dir=_V(1.48,-1.48,14.55-STG2O);
	vessel->AddMesh (hsat5stg32, &mesh_dir);
	mesh_dir=_V(1.48,1.48,14.55-STG2O);
    vessel->AddMesh (hsat5stg33, &mesh_dir);
	mesh_dir=_V(-1.48,1.48,14.55-STG2O);
    vessel->AddMesh (hsat5stg34, &mesh_dir);
	mesh_dir=_V(0,SMVO,19.1-STG2O);
	vessel->AddMesh (hSM, &mesh_dir);
	mesh_dir=_V(0,0,23.25-STG2O);
	vessel->AddMesh (hCM, &mesh_dir);
	mesh_dir=_V(0.02,1.35,23.39-STG2O);
	vessel->AddMesh (hFHC, &mesh_dir);
	mesh_dir=_V(0,0.15,23.1-STG2O);
	vessel->AddMesh (hCMP, &mesh_dir);
	mesh_dir=_V(0,0.15,23.1-STG2O);
	vessel->AddMesh (hCREW, &mesh_dir);
	mesh_dir=_V(0,0,24.8-STG2O);
	probeidx=vessel->AddMesh (hprobe, &mesh_dir);
	
	// ************************* propellant specs **********************************
	if (!ph_3rd)  ph_3rd  = vessel->CreatePropellantResource(114000); //3rd stage Propellant
	vessel->SetDefaultPropellantResource (ph_3rd); // display 3rd stage propellant level in generic HUD
	//vessel->SetMaxThrust (ENGINE_ATTITUDE, 4700);
	
	// *********************** thruster definitions ********************************


	VECTOR3 m_exhaust_pos1= {0,0,-8.-STG2O};
	// orbiter main thrusters
	th_main[0] = vessel->CreateThruster (m_exhaust_pos1, _V( 0,0,1),1201725 , ph_3rd, 5159.5);
	thg_main = vessel->CreateThrusterGroup (th_main, 1, THGROUP_MAIN);
	SURFHANDLE tex = oapiRegisterExhaustTexture ("Exhaust_atsme");//"Exhaust2"
	vessel->AddExhaust (th_main[0], 25.0, 1.5,tex);
	
	
	// attitude - this is temporary
	// attitude adjustment during launch phase should really be done via ENGINE gimbaling
	vessel->SetEngineLevel(ENGINE_MAIN, 0.0);
	status = 4;
	vessel->SetCameraOffset (_V(-1,1.0,32.4-STG2O));
	VECTOR3	m_exhaust_pos6= _V(0,3.3,-2-STG2O);
	VECTOR3 m_exhaust_pos7= _V(2.0,-2.2,-2-STG2O);
	VECTOR3	m_exhaust_pos8= _V(-2.0,-2.0,-2-STG2O);
	int i;		
		th_ver[0] = vessel->CreateThruster (m_exhaust_pos6, _V( 0.0,-0.45,1),725 , ph_3rd, 45790.85);
		th_ver[1] = vessel->CreateThruster (m_exhaust_pos7, _V( -0.45,0.45,1),725 , ph_3rd, 45790.85);
		th_ver[2] = vessel->CreateThruster (m_exhaust_pos8, _V( 0.45,0.45,1),725 , ph_3rd, 45790.85);
		for (i = 0; i < 3; i++) vessel->AddExhaust (th_ver[i], 5.0, 0.25);
		thg_ver = vessel->CreateThrusterGroup (th_ver, 3,THGROUP_USER);
		vessel->SetThrusterGroupLevel(thg_ver,1.0);
	RPswitch3=true;RPswitch4=true;RPswitch5=true;
	AddRCS_S4B(vessel);
	char VNameApollo[256]="";
	char VNameRef13[256]="";
	strcpy (VNameApollo, vessel->GetName());
	strcpy (VNameRef13, "AS-508");
		if (strcmp(VNameApollo,VNameRef13)==0){
		Apollo13 =true;
		}
}




void SetCSMStage (VESSEL *vessel)
{
	vessel->ClearMeshes();
    vessel->ClearThrusterDefinitions();
	if(ph_3rd)	vessel->DelPropellantResource(ph_3rd);
	char CSMName1[256];
	strcpy(CSMName1,vessel->GetName());
	vessel->SetSize (7);
	vessel->SetCOG_elev (3.5);
	vessel->SetEmptyMass (13000);
	// ************************* propellant specs **********************************
	if (!ph_rcs0)  ph_rcs0  = vessel->CreatePropellantResource(500); //RCS stage Propellant
	if (!ph_sps)  ph_sps  = vessel->CreatePropellantResource(20500); //SPS stage Propellant
	vessel->SetDefaultPropellantResource (ph_sps); // display SPS stage propellant level in generic HUD
		
	// *********************** thruster definitions ********************************


	VECTOR3 m_exhaust_pos1= {0,0,-8.-STG2O};
	// orbiter main thrusters
	th_main[0] = vessel->CreateThruster (_V( 0,0,-6.5), _V( 0,0,1),100552.5 , ph_sps, 3778.5);
	vessel->DelThrusterGroup(THGROUP_MAIN,true);
	thg_main = vessel->CreateThrusterGroup (th_main, 1, THGROUP_MAIN);
	SURFHANDLE tex = oapiRegisterExhaustTexture ("Exhaust_atrcs");//"Exhaust2"
	vessel->AddExhaust (th_main[0], 20.0, 2.25, tex);
	vessel->SetPMI (_V(12,12,7));
	vessel->SetCrossSections (_V(40,40,14));
	vessel->SetCW (0.1, 0.3, 1.4, 1.4);
	vessel->SetRotDrag (_V(0.7,0.7,0.3));
	vessel->SetPitchMomentScale (0);
	vessel->SetBankMomentScale (0);
	vessel->SetLiftCoeffFunc (0); 
	vessel->ShiftCentreOfMass (_V(0,0,21.5));
	if (FIRSTCSM){
	//sprintf(oapiDebugString(), "shift %f", gaz);		
	vessel->ShiftCentreOfMass (_V(0,0,21.5));
	FIRSTCSM=false;
	}else if (bManualUnDock){
		dockstate = 4;
	}
	VECTOR3 mesh_dir=_V(0,SMVO,30.25-12.25-21.5);
	vessel->AddMesh (hSM, &mesh_dir);
	strcpy (VNameCM ,vessel->GetName());
	mesh_dir=_V(-2.2,-1.7,28.82-12.25-21.5);
	vessel->AddMesh (hSMhga, &mesh_dir);
	mesh_dir=_V(0,0,34.4-12.25-21.5);
	vessel->AddMesh (hCM, &mesh_dir);
	//Don't Forget the Hatch
	mesh_dir=_V(0.02,1.35,34.54-12.25-21.5);
	vessel->AddMesh (hFHC, &mesh_dir);
	// And the Crew
	mesh_dir=_V(0,0.15,34.25-12.25-21.5);
	vessel->AddMesh (hCMP, &mesh_dir);
	mesh_dir=_V(0,0.15,34.25-12.25-21.5);
	vessel->AddMesh (hCREW, &mesh_dir);
	mesh_dir=_V(0,0,35.90-12.25-21.5);
	probeidx=vessel->AddMesh (hprobe, &mesh_dir);
	
	
	VECTOR3 dockpos = {0,0,35.90-12.25-21.5};
	VECTOR3 dockdir = {0,0,1};
	VECTOR3 dockrot = {0,1,0};
	vessel->SetDockParams(dockpos, dockdir, dockrot);
	status = 5;
	AddRCSJets(vessel,-2.30,1990);
	cdrview=true;
	SetView(vessel);
	// **************************** NAV radios *************************************
	LPswitch1=true;LPswitch2=true;LPswitch3=true;LPswitch4=true;
	vessel->InitNavRadios (4);
	vessel->SetEnableFocus(true);
	vessel->	EnableTransponder (true);
	char VNameApollo[256]="";
	char VNameRef13[256]="";
	strcpy (VNameApollo, vessel->GetName());
	strcpy (VNameRef13, "AS-508");
	if (strcmp(VNameApollo,VNameRef13)==0){
	Apollo13 =true;
	}
	
}
void SetCSM2Stage (VESSEL *vessel)
{
	vessel->ClearMeshes();
	vessel->DelThrusterGroup(THGROUP_MAIN,true);
    vessel->ClearThrusterDefinitions();
	if(ph_3rd)	vessel->DelPropellantResource(ph_3rd);
	char CSMName1[256];
	strcpy(CSMName1,vessel->GetName());
	vessel->SetSize (7);
	vessel->SetCOG_elev (3.5);
	vessel->SetEmptyMass (13000);
	// ************************* propellant specs **********************************
	if (!ph_rcs0)  ph_rcs0  = vessel->CreatePropellantResource(500); //RCS stage Propellant
	if (!ph_sps)  ph_sps  = vessel->CreatePropellantResource(20500); //SPS stage Propellant
	vessel->SetDefaultPropellantResource (ph_sps); // display SPS stage propellant level in generic HUD
		
	// *********************** thruster definitions ********************************


	VECTOR3 m_exhaust_pos1= {0,0,-8.-STG2O};
	// orbiter main thrusters
	th_main[0] = vessel->CreateThruster (_V( 0,0,-6.5), _V( 0,0,1),100552.5 , ph_sps, 3778.5);
	thg_main = vessel->CreateThrusterGroup (th_main, 1, THGROUP_MAIN);
	SURFHANDLE tex = oapiRegisterExhaustTexture ("Exhaust_atrcs");//"Exhaust2"
	vessel->AddExhaust (th_main[0], 20.0, 2.25, tex);
	vessel->SetEngineLevel(ENGINE_MAIN, 0.0);
	vessel->SetPMI (_V(12,12,7));
	vessel->SetCrossSections (_V(40,40,14));
	vessel->SetCW (0.1, 0.3, 1.4, 1.4);
	vessel->SetRotDrag (_V(0.7,0.7,0.3));
	vessel->SetPitchMomentScale (0);
	vessel->SetBankMomentScale (0);
	vessel->SetLiftCoeffFunc (0); 
	VECTOR3 mesh_dir=_V(0,SMVO,30.25-12.25-21.5);
	vessel->AddMesh (hSM, &mesh_dir);
	strcpy (VNameCM ,vessel->GetName());
	mesh_dir=_V(-2.2,-1.7,28.82-12.25-21.5);
	vessel->AddMesh (hSMhga, &mesh_dir);
	mesh_dir=_V(0,0,34.4-12.25-21.5);
	vessel->AddMesh (hCM, &mesh_dir);
	//Don't Forget the Hatch
	mesh_dir=_V(0.02,1.35,34.54-12.25-21.5);
	vessel->AddMesh (hFHC, &mesh_dir);
	// And the Crew
	mesh_dir=_V(0,0.15,34.25-12.25-21.5);
	vessel->AddMesh (hCMP, &mesh_dir);
	mesh_dir=_V(0,0.15,34.25-12.25-21.5);
	vessel->AddMesh (hCREW, &mesh_dir);
	vessel->SetEngineLevel(ENGINE_MAIN, 0.0);
	status = 5;
	AddRCSJets(vessel,-2.30,1990);
	cdrview=true;
	//SetView(vessel);
	
	vessel->	EnableTransponder (true);

	// **************************** NAV radios *************************************

	vessel->InitNavRadios (4);
	probeOn=false;
	probeidx=0;
	LPswitch1=true;LPswitch2=true;LPswitch3=true;
	vessel->SetEnableFocus(true);
	char VNameApollo[256]="";
	char VNameRef13[256]="";
	strcpy (VNameApollo, vessel->GetName());
	strcpy (VNameRef13, "AS-508");
		if (strcmp(VNameApollo,VNameRef13)==0){
		Apollo13 =true;
		}
}

void SetDockedStage6 (){
	dockstate=6;
}
void SetReentryStage (VESSEL *vessel)
{
	vessel->ClearMeshes();
    vessel->ClearThrusterDefinitions();
	
	vessel->SetSize (6.0);
	vessel->SetCOG_elev (2.0);
	vessel->SetEmptyMass (5500);
	vessel->SetPMI (_V(12,12,7));
	//vessel->SetPMI (_V(1.5,1.35,1.35));
	vessel->SetCrossSections (_V(7.17,7.13,7.0));
	vessel->SetCW (2.5, 0.1, 3.4, 3.4);
	vessel->SetRotDrag (_V(0.7,0.7,0.3));
	if (vessel->GetFlightModel() >= 1) 
	{
	vessel->SetPitchMomentScale (-1e-5);
	vessel->SetBankMomentScale (-1e-5);
	vessel->SetLiftCoeffFunc (LiftCoeff); 
    }
  	vessel->ShiftCentreOfMass (_V(0,0,0.5));
	VECTOR3 mesh_dir=_V(0,0,0);
	vessel->AddMesh (hCM, &mesh_dir);
	mesh_dir=_V(0.02,1.35,0.14);
	vessel->AddMesh (hFHC, &mesh_dir);
	// And the Crew
	mesh_dir=_V(0,0.15,-.15);
	vessel->AddMesh (hCMP, &mesh_dir);
	mesh_dir=_V(0,0.15,-.15);
	vessel->AddMesh (hCREW, &mesh_dir);
	status = 6;
	if (ph_sps) vessel->DelPropellantResource(ph_sps);
	if (ph_rcs0) vessel->DelPropellantResource(ph_rcs0);
	if (!ph_rcs1) ph_rcs1  = vessel->CreatePropellantResource(500); //rcs stage Propellant
	vessel->SetDefaultPropellantResource (ph_rcs1); // display rcs stage propellant level in generic HUD
	vessel->SetCameraOffset (_V(-1.02,1.05,-2.05+0.85));
	RPswitch8=true;RPswitch9=true;RPswitch7=true;
	LPswitch1=false;LPswitch2=false;LPswitch3=false;LPswitch4=false;LPswitch5=false;LPswitch6=false;
	vessel->DelThrusterGroup(THGROUP_MAIN,true);
	//vessel->DelThruster(th_main[0]);
	
	AddRCS_CM(vessel,240);
	SURFHANDLE tex =oapiRegisterReentryTexture("reentry");
	vessel->SetReentryTexture(tex,5e5,10.5,0.8);
	VECTOR3 dockpos = {0,0,1.5};
	VECTOR3 dockdir = {0,0,1};
	VECTOR3 dockrot = {0,1,0};
	vessel->SetDockParams(dockpos, dockdir, dockrot);
	vessel->SetCameraOffset (_V(-1,1.0,-2.25));
}

void SetAbortStage (VESSEL *vessel)
{
	vessel->ClearMeshes();
    vessel->ClearThrusterDefinitions();
	UINT meshidx;
	vessel->SetSize (8);
	vessel->SetCOG_elev (2.0);
	vessel->SetEmptyMass (6718);
	vessel->SetPMI (_V(20,20,12));
	vessel->SetCrossSections (_V(2.8,2.8,7));
	vessel->SetCW (0.1, 0.3, 1.4, 1.4);
	vessel->SetRotDrag (_V(0.7,0.7,0.3));
	if (vessel->GetFlightModel() >= 1) 
	{
	vessel->SetPitchMomentScale (-1e-5);
	vessel->SetBankMomentScale (-1e-5);
	vessel->SetLiftCoeffFunc (LiftCoeff); 
    }
	vessel->ShiftCentreOfMass (_V(0,0,1.5));
	VECTOR3 mesh_dir=_V(0,0,33.0-12.25-21.5-1.5);
	vessel->AddMesh (hCM, &mesh_dir);
	mesh_dir=_V(0,0,38.0-12.25-21.5-1.5);
	meshidx = vessel->AddMesh (hsat5tower, &mesh_dir);
	vessel ->SetMeshVisibleInternal (meshidx, true);
	//VECTOR3 bdir = _V(0,0,1);
	//ReEntryID = vessel->AddExhaustRef(EXHAUST_CUSTOM,_V(0,0,-0.5), 0, 0, &bdir);
	if (!ph_rcs1)  ph_rcs1  = vessel->CreatePropellantResource(500); //RCS stage Propellant
	if (!ph_sps)  ph_sps  = vessel->CreatePropellantResource(2500); //SPS stage Propellant
	vessel->SetDefaultPropellantResource (ph_sps); // display SPS stage propellant level in generic HUD
		
	// *********************** thruster definitions ********************************


	
	// orbiter main thrusters
	th_main[0] = vessel->CreateThruster (_V( 0,0,-6.5), _V( 0,0,1),721035 , ph_sps, 900);
	thg_main = vessel->CreateThrusterGroup (th_main, 1, THGROUP_MAIN);
	
	AddRCS_CM(vessel,540);
	vessel->SetThrusterLevel(th_main[0], 1.0);
	
	VECTOR3 m_exhaust_pos1= {0.4,0.0,1.6};
    VECTOR3 m_exhaust_pos2= {-0.4,0.0,1.6};
	VECTOR3 m_exhaust_pos3= {0.0,0.1,6.8};
	VECTOR3 m_exhaust_pos4= {0.0,0.4,1.6};
	VECTOR3 m_exhaust_pos5= {0.0,-0.4,1.6};
	VECTOR3 m_exhaust_ref1 = {0.65,0,-1};
	VECTOR3 m_exhaust_ref2 = {-0.65,0,-1};
	VECTOR3 m_exhaust_ref3 = {0,0.5,-1};
	VECTOR3 m_exhaust_ref4 = {0.0,0.65,-1};
	VECTOR3 m_exhaust_ref5 = {0.0,-0.65,-1};
	vessel->AddExhaustRef (EXHAUST_MAIN, m_exhaust_pos1, 5.0, 0.15, &m_exhaust_ref1);
	vessel->AddExhaustRef (EXHAUST_MAIN, m_exhaust_pos2, 5.0, 0.15, &m_exhaust_ref2);
	vessel->AddExhaustRef (EXHAUST_MAIN, m_exhaust_pos3, 3.0, 0.10, &m_exhaust_ref3);
	vessel->AddExhaustRef (EXHAUST_MAIN, m_exhaust_pos4, 5.0, 0.15, &m_exhaust_ref4);
	vessel->AddExhaustRef (EXHAUST_MAIN, m_exhaust_pos5, 5.0, 0.15, &m_exhaust_ref5);
	
	//vessel->AddExhaustRef (EXHAUST_MAIN, m_exhaust_pos4, 5.0, 0.25, &m_exhaust_ref4);
	status = 14;
	vessel->SetCameraOffset (_V(-1,1.0,-1.25));
	ABORT_IND = true;
	RPswitch8=true;RPswitch9=true;RPswitch7=true;
	LPswitch1=false;LPswitch2=false;LPswitch3=false;LPswitch4=false;LPswitch5=false;LPswitch6=false;
	AddRCS_CM(vessel,540);

}
void Ullage(OBJHANDLE hvessel,double gaz){
		
		
		VESSEL *stg1vessel;
		stg1vessel = oapiGetVesselInterface(hvessel);
		VECTOR3 m_exhaust_ref = {0,0,1};
		VECTOR3 m_exhaust_pos2= {0,-5.03,20.95};
		VECTOR3 m_exhaust_pos3= {0,5.03,20.95};
		VECTOR3 m_exhaust_ref2 = {0,-0.35,1};
		VECTOR3 m_exhaust_ref3 = {0,0.35,1};
		VECTOR3 m_exhaust_pos4= {-5.03,0,20.95};
		VECTOR3 m_exhaust_pos5= {5.03,0,20.95};
		VECTOR3 m_exhaust_ref4 = {-0.35,0,1};
		VECTOR3 m_exhaust_ref5 = {0.35,0,1};
		if (!UllageID2){
		UllageID1=stg1vessel ->AddExhaustRef (EXHAUST_CUSTOM, m_exhaust_pos2, 5.0, 0.15, &m_exhaust_ref2);
		UllageID2=stg1vessel ->AddExhaustRef (EXHAUST_CUSTOM, m_exhaust_pos3, 5.0, 0.15, &m_exhaust_ref3);
		UllageID3=stg1vessel ->AddExhaustRef (EXHAUST_CUSTOM, m_exhaust_pos4, 5.0, 0.15, &m_exhaust_ref4);
		UllageID4=stg1vessel ->AddExhaustRef (EXHAUST_CUSTOM, m_exhaust_pos5, 5.0, 0.15, &m_exhaust_ref5);
		}
		stg1vessel ->SetExhaustScales (EXHAUST_CUSTOM, UllageID1, gaz, 0.15);
		stg1vessel ->SetExhaustScales (EXHAUST_CUSTOM, UllageID2, gaz, 0.15);
		stg1vessel ->SetExhaustScales (EXHAUST_CUSTOM, UllageID3, gaz, 0.15);
		stg1vessel ->SetExhaustScales (EXHAUST_CUSTOM, UllageID4, gaz, 0.15);
		//sprintf(oapiDebugString(), "Reentry %f", gaz);		
			
}
void Ullage2(OBJHANDLE hvessel,double gaz){
		
		
		VESSEL *stg2vessel;
		stg2vessel = oapiGetVesselInterface(hvessel);
		VECTOR3 m_exhaust_ref = {0,0,1};
		VECTOR3 m_exhaust_pos2= {0,-4,12.2};
		VECTOR3 m_exhaust_pos3= {0,4,12.2};
		VECTOR3 m_exhaust_ref2 = {0,-0.35,1};
		VECTOR3 m_exhaust_ref3 = {0,0.35,1};
		VECTOR3 m_exhaust_pos4= {-4,0,12.2};
		VECTOR3 m_exhaust_pos5= {4,0,12.2};
		VECTOR3 m_exhaust_ref4 = {-0.35,0,1};
		VECTOR3 m_exhaust_ref5 = {0.35,0,1};
		if (!UllageID7){
		UllageID6=stg2vessel ->AddExhaustRef (EXHAUST_CUSTOM, m_exhaust_pos2, 5.0, 0.15, &m_exhaust_ref2);
		UllageID7=stg2vessel ->AddExhaustRef (EXHAUST_CUSTOM, m_exhaust_pos3, 5.0, 0.15, &m_exhaust_ref3);
		UllageID8=stg2vessel ->AddExhaustRef (EXHAUST_CUSTOM, m_exhaust_pos4, 5.0, 0.15, &m_exhaust_ref4);
		UllageID9=stg2vessel ->AddExhaustRef (EXHAUST_CUSTOM, m_exhaust_pos5, 5.0, 0.15, &m_exhaust_ref5);
		}
		stg2vessel ->SetExhaustScales (EXHAUST_CUSTOM, UllageID6, gaz, 0.15);
		stg2vessel ->SetExhaustScales (EXHAUST_CUSTOM, UllageID7, gaz, 0.15);
		stg2vessel ->SetExhaustScales (EXHAUST_CUSTOM, UllageID8, gaz, 0.15);
		stg2vessel ->SetExhaustScales (EXHAUST_CUSTOM, UllageID9, gaz, 0.15);
		//sprintf(oapiDebugString(), "Reentry %f", gaz);		
		if (gaz  > 0){
		stg2vessel->SetAttitudeLinLevel(2,-1);
		}else{
		stg2vessel->SetAttitudeLinLevel(2,0);
		}
}


void setupSM(OBJHANDLE hvessel){
		
	VESSEL *stg1vessel;
		stg1vessel = oapiGetVesselInterface(hvessel);
		stg1vessel->SetSize (4.0);
		stg1vessel->SetCOG_elev (3.5);
		stg1vessel->SetEmptyMass (10318);
		stg1vessel->SetMaxFuelMass (2222);
		stg1vessel->SetFuelMass(2222);
		stg1vessel->SetISP (3083);
		stg1vessel->SetMaxThrust (ENGINE_ATTITUDE, 10980);
		stg1vessel->SetPMI (_V(30,30,15.5));
		stg1vessel->SetRotDrag (_V(0.7,0.7,0.3));
		stg1vessel->ClearMeshes();
		VECTOR3 mesh_dir=_V(0,SMVO,0);
		stg1vessel->AddMesh (hSM, &mesh_dir);

		mesh_dir=_V(-2.2,-1.7,-1.6);
		stg1vessel->AddMesh (hSMhga, &mesh_dir);
		//Roll left
	

		

	

}

void setupS4B(OBJHANDLE hvessel){
		
		VESSEL *stgSMvessel;
		stgSMvessel = oapiGetVesselInterface(hvessel);
		stgSMvessel->SetSize (15.5);
		stgSMvessel->SetEmptyMass (65600);
		stgSMvessel->SetMaxFuelMass (114000);
		stgSMvessel->SetFuelMass(100);
		stgSMvessel->SetISP (5159.5);
		stgSMvessel->SetEnableFocus(false);
		stgSMvessel->SetMaxThrust (ENGINE_MAIN, 1201725);
		stgSMvessel->SetMaxThrust (ENGINE_ATTITUDE, 4700);
		stgSMvessel->SetEngineLevel(ENGINE_MAIN, 0.0);
		stgSMvessel->ClearMeshes();
		VECTOR3 mesh_dir=_V(0,0,-14.5);
		stgSMvessel->AddMesh (hsat5stg3, &mesh_dir);
		if( dockstate <=2){
		mesh_dir=_V(-0.0,0,-4.7);
		stgSMvessel->AddMesh (hLMPKD, &mesh_dir);
		}
		//stgSMvessel->CreateDock(_V(0.0,0.0,-2.2),_V(0.0,0.0,1.0),_V(-0.705, -0.705, 0));
}


void UllageSM(OBJHANDLE hvessel,double gaz1, double time){
	
	T1=T2;
	T2 = time;

	if (ignition_SMtime == 0 && !SMSep){
		setupSM(hvessel);
		ignition_SMtime=time;
		SMSep=true;
	}

		VESSEL *stg1vessel;
		stg1vessel = oapiGetVesselInterface(hvessel);
			
		if (gaz1 >0){
			stg1vessel->SetAttitudeLinLevel(2,-1);
			if (time > ignition_SMtime+5){
				stg1vessel->SetAttitudeRotLevel(2,-1);
			}
			if (time > ignition_SMtime+7){
				stg1vessel->SetAttitudeRotLevel(2,0);
		}
		}else{
		stg1vessel->SetAttitudeLinLevel(2,0);
		stg1vessel->SetAttitudeRotLevel(2,0);
		stg1vessel->SetAttitudeRotLevel(1,0);
		}
}
void AttitudeLaunch1(VESSEL *vessel)
{
	//Original code function by Richard Craig From MErcury Sample by Rob CONLEY
	// Modification for NASSP specific needs by JL Rocca-Serra
	VECTOR3 ang_vel;
	vessel->GetAngularVel(ang_vel);// gets current angular velocity for stabilizer and rate control
// variables to store each component deflection vector	
	VECTOR3 rollvectorl={0.0,0.0,0.0};
	VECTOR3 rollvectorr={0.0,0.0,0.0};
	VECTOR3 pitchvector={0.0,0.0,0.0};
	VECTOR3 yawvector={0.0,0.0,0.0};
	VECTOR3 yawvectorm={0.0,0.0,0.0};
	VECTOR3 pitchvectorm={0.0,0.0,0.0};
//************************************************************
// variables to store Manual control levels for each axis
	double tempP = 0.0;
	double tempY = 0.0;
	double tempR = 0.0; 
//************************************************************
// Variables to store correction factors for rate control
	double rollcorrect = 0.0;
	double yawcorrect= 0.0;
	double pitchcorrect = 0.0;
//************************************************************
// gets manual control levels in each axis, this code copied directly from Rob Conley's Mercury Atlas	
	if(RPswitch10 && autopilot){
	tempR = AtempR ;
	tempP =AtempP ;
	tempY =AtempY ;
	}else{
	tempP = vessel->GetManualControlLevel(THGROUP_ATT_PITCHDOWN, MANCTRL_ANYDEVICE, MANCTRL_ANYMODE) - vessel->GetManualControlLevel(THGROUP_ATT_PITCHUP, MANCTRL_ANYDEVICE, MANCTRL_ANYMODE);
	tempY = vessel->GetManualControlLevel(THGROUP_ATT_YAWLEFT, MANCTRL_ANYDEVICE, MANCTRL_ANYMODE) - vessel->GetManualControlLevel(THGROUP_ATT_YAWRIGHT, MANCTRL_ANYDEVICE, MANCTRL_ANYMODE);
	tempR = vessel->GetManualControlLevel(THGROUP_ATT_BANKLEFT, MANCTRL_ANYDEVICE, MANCTRL_ANYMODE) - vessel->GetManualControlLevel(THGROUP_ATT_BANKRIGHT, MANCTRL_ANYDEVICE, MANCTRL_ANYMODE);
	}
	//sprintf (oapiDebugString(), "roll input: %f, roll vel: %f,pitch input: %f, pitch vel: %f", tempR, ang_vel.z,tempP, ang_vel.x);
	
//*************************************************************
//Creates correction factors for rate control in each axis as a function of input level
// and current angular velocity. Varies from 1 to 0 as angular velocity approaches command level
// multiplied by maximum rate desired
	if(tempR != 0.0)	{
		rollcorrect = (1/(fabs(tempR)*0.175))*((fabs(tempR)*0.175)-fabs(ang_vel.z));
			if((tempR > 0 && ang_vel.z > 0) || (tempR < 0 && ang_vel.z < 0))	{
						rollcorrect = 1;
					}
	}
	if(tempP != 0.0)	{
		pitchcorrect = (1/(fabs(tempP)*0.175))*((fabs(tempP)*0.175)-fabs(ang_vel.x));
		if((tempP > 0 && ang_vel.x > 0) || (tempP < 0 && ang_vel.x < 0))	{
						pitchcorrect = 1;
					}
	}
	if(tempY != 0.0)	{
	yawcorrect = (1/(fabs(tempY)*0.175))*((fabs(tempY)*0.175)-fabs(ang_vel.y));
	if((tempY > 0 && ang_vel.y < 0) || (tempY < 0 && ang_vel.y > 0))	{
						yawcorrect = 1;
					}
	}
//*************************************************************	
// Create deflection vectors in each axis
	pitchvector = _V(0.0,0.05*tempP*pitchcorrect,0.0);
	pitchvectorm = _V(0.0,0.09*tempP*pitchcorrect,0.0);
	yawvector = _V(0.05*tempY*yawcorrect,0.0,0.0);
	yawvectorm = _V(0.09*tempY*yawcorrect,0.0,0.0);
	rollvectorl = _V(0.0,0.60*tempR*rollcorrect,0.0);
	rollvectorr = _V(0.0,-0.60*tempR*rollcorrect,0.0);

//*************************************************************
// create opposite vectors for "gyro stabilization" if command levels are 0
	if(tempP==0.0) {
		
		pitchvectorm=_V(0.0,0.8*ang_vel.x*3,0.0);
	}
	if(tempY==0.0) {
		
		yawvectorm=_V(-0.8*ang_vel.y*3,0.0,0.0);
	}
	if(tempR==0.0) {
		rollvectorl = _V(0.0,0.95*ang_vel.z*3,0.0);
		
	}
//**************************************************************	
// Sets thrust vectors by simply adding up all the axis deflection vectors and the 
// "neutral" default vector
	vessel->SetThrusterDir(th_main[0],pitchvectorm+yawvectorm+rollvectorl+_V( 0,0,1));//4
	vessel->SetThrusterDir(th_main[1],pitchvectorm+yawvectorm-rollvectorl+_V( 0,0,1));//2
	vessel->SetThrusterDir(th_main[2],pitchvectorm+yawvectorm-rollvectorl+_V( 0,0,1));//1
	vessel->SetThrusterDir(th_main[3],pitchvectorm+yawvectorm+rollvectorl+_V( 0,0,1));//3
	vessel->SetThrusterDir(th_main[4],pitchvectorm+yawvectorm+_V( 0,0,1));//5
	// sprintf (oapiDebugString(), "pitch vector: %f, roll vel: %f", tempR, ang_vel.z);

}
void AttitudeLaunch2(VESSEL *vessel)
{
	VECTOR3 ang_vel;
	vessel->GetAngularVel(ang_vel);// gets current angular velocity for stabilizer and rate control
// variables to store each component deflection vector	
	VECTOR3 rollvectorl={0.0,0.0,0.0};
	VECTOR3 rollvectorr={0.0,0.0,0.0};
	VECTOR3 pitchvector={0.0,0.0,0.0};
	VECTOR3 yawvector={0.0,0.0,0.0};
	VECTOR3 yawvectorm={0.0,0.0,0.0};
	VECTOR3 pitchvectorm={0.0,0.0,0.0};
//************************************************************
// variables to store Manual control levels for each axis
	double tempP = 0.0;
	double tempY = 0.0;
	double tempR = 0.0; 
//************************************************************
// Variables to store correction factors for rate control
	double rollcorrect = 0.0;
	double yawcorrect= 0.0;
	double pitchcorrect = 0.0;
//************************************************************
// gets manual control levels in each axis, this code copied directly from Rob Conley's Mercury Atlas	
	if(RPswitch10 && autopilot){
	tempP =AtempP ;tempR =AtempR ;tempY =AtempY ;
	}else{
	tempP = vessel->GetManualControlLevel(THGROUP_ATT_PITCHDOWN, MANCTRL_ANYDEVICE, MANCTRL_ANYMODE) - vessel->GetManualControlLevel(THGROUP_ATT_PITCHUP, MANCTRL_ANYDEVICE, MANCTRL_ANYMODE);
	tempY = vessel->GetManualControlLevel(THGROUP_ATT_YAWLEFT, MANCTRL_ANYDEVICE, MANCTRL_ANYMODE) - vessel->GetManualControlLevel(THGROUP_ATT_YAWRIGHT, MANCTRL_ANYDEVICE, MANCTRL_ANYMODE);
	tempR = vessel->GetManualControlLevel(THGROUP_ATT_BANKLEFT, MANCTRL_ANYDEVICE, MANCTRL_ANYMODE) - vessel->GetManualControlLevel(THGROUP_ATT_BANKRIGHT, MANCTRL_ANYDEVICE, MANCTRL_ANYMODE);
	}
//*************************************************************
//Creates correction factors for rate control in each axis as a function of input level
// and current angular velocity. Varies from 1 to 0 as angular velocity approaches command level
// multiplied by maximum rate desired
	if(tempR != 0.0)	{
		rollcorrect = (1/(fabs(tempR)*0.35))*((fabs(tempR)*0.35)-fabs(ang_vel.z));
			}
	if(tempP != 0.0)	{
		pitchcorrect = (1/(fabs(tempP)*0.175))*((fabs(tempP)*0.175)-fabs(ang_vel.x));
		if((tempP > 0 && ang_vel.x > 0) || (tempP < 0 && ang_vel.x < 0))	{
						pitchcorrect = 1;
					}
	}
	if(tempY != 0.0)	{
	yawcorrect = (1/(fabs(tempY)*0.175))*((fabs(tempY)*0.175)-fabs(ang_vel.y));
	if((tempY > 0 && ang_vel.y < 0) || (tempY < 0 && ang_vel.y > 0))	{
						yawcorrect = 1;
					}
	}
//*************************************************************	
// Create deflection vectors in each axis
	pitchvector = _V(0.0,0.05*tempP*pitchcorrect,0.0);
	pitchvectorm = _V(0.0,0.09*tempP*pitchcorrect,0.0);
	yawvector = _V(0.05*tempY*yawcorrect,0.0,0.0);
	yawvectorm = _V(0.09*tempY*yawcorrect,0.0,0.0);
	rollvectorl = _V(0.0,0.090*tempR*rollcorrect,0.0);
	rollvectorr = _V(0.0,-0.09*tempR*rollcorrect,0.0);

//*************************************************************
// create opposite vectors for "gyro stabilization" if command levels are 0
	if(tempP==0.0) {
		
		pitchvectorm=_V(0.0,0.95*ang_vel.x*2,0.0);
	}
	if(tempY==0.0) {
		
		yawvectorm=_V(-0.95*ang_vel.y*2,0.0,0.0);
	}
	if(tempR==0.0) {
		rollvectorl = _V(0.0,0.99*ang_vel.z*2,0.0);
		
	}
//**************************************************************	
// Sets thrust vectors by simply adding up all the axis deflection vectors and the 
// "neutral" default vector
	vessel->SetThrusterDir(th_main[0],pitchvectorm+yawvectorm-rollvectorl+_V( 0,0,1));//4
	vessel->SetThrusterDir(th_main[1],pitchvectorm+yawvectorm+rollvectorl+_V( 0,0,1));//2
	vessel->SetThrusterDir(th_main[2],pitchvectorm+yawvectorm-rollvectorl+_V( 0,0,1));//1
	vessel->SetThrusterDir(th_main[3],pitchvectorm+yawvectorm+rollvectorl+_V( 0,0,1));//3
	vessel->SetThrusterDir(th_main[4],pitchvectorm+yawvectorm+_V( 0,0,1));//5
	// sprintf (oapiDebugString(), "roll input: %f, roll vel: %f", tempR, ang_vel.z);

}void AttitudeLaunch3(VESSEL *vessel)
{
	VECTOR3 ang_vel;
	vessel->GetAngularVel(ang_vel);// gets current angular velocity for stabilizer and rate control
// variables to store each component deflection vector	
	VECTOR3 rollvectorl={0.0,0.0,0.0};
	VECTOR3 rollvectorr={0.0,0.0,0.0};
	VECTOR3 pitchvector={0.0,0.0,0.0};
	VECTOR3 yawvector={0.0,0.0,0.0};
	VECTOR3 yawvectorm={0.0,0.0,0.0};
	VECTOR3 pitchvectorm={0.0,0.0,0.0};
//************************************************************
// variables to store Manual control levels for each axis
	double tempP = 0.0;
	double tempY = 0.0;
	double tempR = 0.0; 
//************************************************************
// Variables to store correction factors for rate control
	double rollcorrect = 0.0;
	double yawcorrect= 0.0;
	double pitchcorrect = 0.0;
//************************************************************
// gets manual control levels in each axis, this code copied directly from Rob Conley's Mercury Atlas	
	if(RPswitch10 && autopilot){
	tempP =AtempP ;tempR =AtempR ;tempY =AtempY ;
	}else{
	if(RPswitch4){tempP = vessel->GetManualControlLevel(THGROUP_ATT_PITCHDOWN, MANCTRL_ANYDEVICE, MANCTRL_ANYMODE) - vessel->GetManualControlLevel(THGROUP_ATT_PITCHUP, MANCTRL_ANYDEVICE, MANCTRL_ANYMODE);}
	if(RPswitch5){tempY = vessel->GetManualControlLevel(THGROUP_ATT_YAWLEFT, MANCTRL_ANYDEVICE, MANCTRL_ANYMODE) - vessel->GetManualControlLevel(THGROUP_ATT_YAWRIGHT, MANCTRL_ANYDEVICE, MANCTRL_ANYMODE);}
	tempR = vessel->GetManualControlLevel(THGROUP_ATT_BANKLEFT, MANCTRL_ANYDEVICE, MANCTRL_ANYMODE) - vessel->GetManualControlLevel(THGROUP_ATT_BANKRIGHT, MANCTRL_ANYDEVICE, MANCTRL_ANYMODE);
	}
	
//*************************************************************
//Creates correction factors for rate control in each axis as a function of input level
// and current angular velocity. Varies from 1 to 0 as angular velocity approaches command level
// multiplied by maximum rate desired
	if(tempR != 0.0)	{
		rollcorrect = (1/(fabs(tempR)*0.35))*((fabs(tempR)*0.35)-fabs(ang_vel.z));
			}
	if(tempP != 0.0)	{
		pitchcorrect = (1/(fabs(tempP)*0.175))*((fabs(tempP)*0.175)-fabs(ang_vel.x));
		if((tempP > 0 && ang_vel.x > 0) || (tempP < 0 && ang_vel.x < 0))	{
						pitchcorrect = 1;
					}
	}
	if(tempY != 0.0)	{
	yawcorrect = (1/(fabs(tempY)*0.175))*((fabs(tempY)*0.175)-fabs(ang_vel.y));
	if((tempY > 0 && ang_vel.y < 0) || (tempY < 0 && ang_vel.y > 0))	{
						yawcorrect = 1;
					}
	}
//*************************************************************	
// Create deflection vectors in each axis
	pitchvector = _V(0.0,0.05*tempP*pitchcorrect,0.0);
	pitchvectorm = _V(0.0,0.09*tempP*pitchcorrect,0.0);
	yawvector = _V(0.05*tempY*yawcorrect,0.0,0.0);
	yawvectorm = _V(0.09*tempY*yawcorrect,0.0,0.0);
	rollvectorl = _V(0.0,0.090*tempR*rollcorrect,0.0);
	rollvectorr = _V(0.0,-0.09*tempR*rollcorrect,0.0);

//*************************************************************
// create opposite vectors for "gyro stabilization" if command levels are 0
	if(tempP==0.0) {
		
		pitchvectorm=_V(0.0,0.95*ang_vel.x*2,0.0);
	}
	if(tempY==0.0) {
		
		yawvectorm=_V(-0.95*ang_vel.y*2,0.0,0.0);
	}
	if(tempR==0.0) {
		rollvectorl = _V(0.0,0.99*ang_vel.z*2,0.0);
		
	}
//**************************************************************	
// Sets thrust vectors by simply adding up all the axis deflection vectors and the 
// "neutral" default vector
	vessel->SetThrusterDir(th_main[0],pitchvectorm+yawvectorm+_V( 0,0,1));//4
	// sprintf (oapiDebugString(), "roll input: %f, roll vel: %f", tempR, ang_vel.z);

}

void AttitudeLaunch4(VESSEL *vessel)
{
	VECTOR3 ang_vel;
	vessel->GetAngularVel(ang_vel);// gets current angular velocity for stabilizer and rate control
// variables to store each component deflection vector	
	VECTOR3 rollvectorl={0.0,0.0,0.0};
	VECTOR3 rollvectorr={0.0,0.0,0.0};
	VECTOR3 pitchvector={0.0,0.0,0.0};
	VECTOR3 yawvector={0.0,0.0,0.0};
	VECTOR3 yawvectorm={0.0,0.0,0.0};
	VECTOR3 pitchvectorm={0.0,0.0,0.0};
//************************************************************
// variables to store Manual control levels for each axis
	double tempP = 0.0;
	double tempY = 0.0;
	double tempR = 0.0; 
//************************************************************
// Variables to store correction factors for rate control
	double rollcorrect = 0.0;
	double yawcorrect= 0.0;
	double pitchcorrect = 0.0;
//************************************************************
// gets manual control levels in each axis, this code copied directly from Rob Conley's Mercury Atlas	
	if(LPswitch6){tempP = vessel->GetManualControlLevel(THGROUP_ATT_PITCHDOWN, MANCTRL_ANYDEVICE, MANCTRL_ANYMODE) - vessel->GetManualControlLevel(THGROUP_ATT_PITCHUP, MANCTRL_ANYDEVICE, MANCTRL_ANYMODE);}
	if(LPswitch7){tempY = vessel->GetManualControlLevel(THGROUP_ATT_YAWLEFT, MANCTRL_ANYDEVICE, MANCTRL_ANYMODE) - vessel->GetManualControlLevel(THGROUP_ATT_YAWRIGHT, MANCTRL_ANYDEVICE, MANCTRL_ANYMODE);}
	tempR = vessel->GetManualControlLevel(THGROUP_ATT_BANKLEFT, MANCTRL_ANYDEVICE, MANCTRL_ANYMODE) - vessel->GetManualControlLevel(THGROUP_ATT_BANKRIGHT, MANCTRL_ANYDEVICE, MANCTRL_ANYMODE);
//*************************************************************
//Creates correction factors for rate control in each axis as a function of input level
// and current angular velocity. Varies from 1 to 0 as angular velocity approaches command level
// multiplied by maximum rate desired
	if(tempR != 0.0)	{
		rollcorrect = (1/(fabs(tempR)*0.35))*((fabs(tempR)*0.35)-fabs(ang_vel.z));
			}
	if(tempP != 0.0)	{
		pitchcorrect = (1/(fabs(tempP)*0.175))*((fabs(tempP)*0.175)-fabs(ang_vel.x));
		if((tempP > 0 && ang_vel.x > 0) || (tempP < 0 && ang_vel.x < 0))	{
						pitchcorrect = 1;
					}
	}
	if(tempY != 0.0)	{
	yawcorrect = (1/(fabs(tempY)*0.175))*((fabs(tempY)*0.175)-fabs(ang_vel.y));
	if((tempY > 0 && ang_vel.y < 0) || (tempY < 0 && ang_vel.y > 0))	{
						yawcorrect = 1;
					}
	}
//*************************************************************	
// Create deflection vectors in each axis
	pitchvector = _V(0.0,0.05*tempP*pitchcorrect,0.0);
	pitchvectorm = _V(0.0,0.09*tempP*pitchcorrect,0.0);
	yawvector = _V(0.05*tempY*yawcorrect,0.0,0.0);
	yawvectorm = _V(0.09*tempY*yawcorrect,0.0,0.0);
	rollvectorl = _V(0.0,0.090*tempR*rollcorrect,0.0);
	rollvectorr = _V(0.0,-0.09*tempR*rollcorrect,0.0);

//*************************************************************
// create opposite vectors for "gyro stabilization" if command levels are 0
	if(tempP==0.0) {
		
		pitchvectorm=_V(0.0,0.95*ang_vel.x*2,0.0);
	}
	if(tempY==0.0) {
		
		yawvectorm=_V(-0.95*ang_vel.y*2,0.0,0.0);
	}
	if(tempR==0.0) {
		rollvectorl = _V(0.0,0.99*ang_vel.z*2,0.0);
		
	}
//**************************************************************	
// Sets thrust vectors by simply adding up all the axis deflection vectors and the 
// "neutral" default vector
	vessel->SetThrusterDir(th_main[0],pitchvectorm+yawvectorm+_V( 0,0,1));//4
	// sprintf (oapiDebugString(), "roll input: %f, roll vel: %f", tempR, ang_vel.z);

}
void AutoPilot(VESSEL *vessel, double autoT)
{
	static int first_time=1;
	static int t = 0;
	static int out_level=0;
	double level=0.;
	double altitude;
	double pitch;
	double pitch_c;
	double heading;
	double bank;
	directcontrol=false;
	char current_key=0;
	vessel->GetElements(elemSaturn1B,refSaturn1B);
	AltitudePREV=vessel->GetAltitude();
	VESSELSTATUS vsp;
	vessel->GetStatus(vsp);
	double totalRot=0;
	totalRot=vsp.vrot.x+vsp.vrot.y+vsp.vrot.z;
	
	if (fabs(totalRot) >= 0.0025){
			StopRot=true;
	}
		

	if( (vessel->GetAltitude()>=120000) && ((refSaturn1B - refPREV)>=0) && (stage == 4) && (elemSaturn1B.e > elemPREV.e ) && (elemSaturn1B.e < 0.03) && (RPswitch11||RPswitch10))
	{
	
		if (vessel->GetEngineLevel(ENGINE_MAIN)>0){
			vessel->SetEngineLevel(ENGINE_MAIN,0);
			PlayVesselWave(S4CutS,NOLOOP,255);
			RPswitch1=true;RPswitch2=true;RPswitch3=true;RPswitch4=false;RPswitch5=false;
			vessel->ActivateNavmode(NAVMODE_KILLROT);
			autoTimer = 0;
			autopilot=false;
		}
		return;
	}else{
		elemPREV = elemSaturn1B;
		refPREV=refSaturn1B;
	}

 // navigation
	oapiGetFocusPitch(&pitch);
	pitch=pitch*180./PI;
	oapiGetFocusAltitude(&altitude);
	//sprintf(oapiDebugString(), "Autopilot %f", altitude);
 // guidance
	pitch_c=GetCPitch(altitude);
 // control
	
	if (vessel->GetAltitude() < 250  && vessel->GetAltitude() > 150 ){
		//sprintf(oapiDebugString(), "Autopilot initial Pitch DEG %d", (int)fabs(pitch));
		if (pitch >88){
			AtempP = 0.8;
			AtempR = 0.0;
			AtempY = 0.0;
		}else{
			AtempP = 0.0;
			AtempR = 0.0;
			AtempY = 0.0;
		}

		DPROG = 10;
		R1 = pitch;
		
	}else if (vessel->GetAltitude() < 1200  && vessel->GetAltitude() > 250)	{
		
		//directcontrol = true;
		oapiGetFocusBank(&bank);
		bank = bank*180./PI;
		if (fabs(bank+(90-TO_HDG)) <15  && StopRot){
				AtempP = 0.0;
				AtempR = 0.0;
				AtempY = 0.0;
		}
		if (fabs(bank+(90-TO_HDG))<0.5){
			AtempP = 0.0;
			AtempR = 0.0;
			AtempY = 0.0;
				
		}


		//sprintf(oapiDebugString(), "Autopilot Bank Mode TotalROT %f", totalRot);
		
		if (bank > -(90-TO_HDG)+0.5){
			AtempR = -fabs((90-TO_HDG)-bank);
			if (AtempR < -1)AtempR = -1;
			AtempP = 0.0;
			AtempY = 0.0;
		}else if (bank < -(90-TO_HDG)-0.5){
			AtempR = fabs((90-TO_HDG)-bank);
			if (AtempR > 1)AtempR = 1;
			AtempP = 0.0;
			AtempY = 0.0;
		}else {
			AtempR = 0.0;
		}
		
		
		DPROG = 11;
		R1 = pitch;
		R2 = bank;
		
		
	}else if (vessel->GetAltitude() < 2800  && vessel->GetAltitude() > 1200){
		
		oapiGetHeading(vessel->GetHandle(),&heading);
		heading = heading*180./PI;
		//sprintf(oapiDebugString(), "Autopilot Heading Mode DEG %f", heading);
		oapiGetFocusBank(&bank);
		bank = bank*180./PI;
				
		
		if (fabs(heading-TO_HDG) <10 && StopRot) {
			AtempP = 0.0;
			AtempR = 0.0;
			AtempY = 0.0;
		}
		if (fabs(heading-TO_HDG) <0.5) {
			AtempP = 0.0;
			AtempR = 0.0;
			AtempY = 0.0;

		}else if (heading > (TO_HDG +0.5) && TO_HDG <90) {
			AtempP = heading - TO_HDG ;
			if (AtempP > 1.0) AtempP = 1.0;
			AtempR = -0.5;
			AtempY = 0.0;
			//vessel->SetAttitudeRotLevel(0, -1);

		}else if (heading < (TO_HDG -0.5) && TO_HDG <90) {
			AtempP = heading  - TO_HDG;
			if (AtempP<-1.0) AtempP = -1.0;
			AtempR = 0.2;
			AtempY = 0.0;
			//vessel->SetAttitudeRotLevel(0, 1);
		}else if (heading > (TO_HDG +0.5) && TO_HDG >90) {
			AtempP = -(heading - TO_HDG) ;
			if (AtempP<-1.0) AtempP = -1.0;
			AtempR = -0.2;
			AtempY = 0.0;
			//vessel->SetAttitudeRotLevel(0, -1);

		}else if (heading < (TO_HDG -0.5) && TO_HDG >90) {
			AtempP = -(heading  - TO_HDG);
			if (AtempP > 1.0) AtempP = 1.0;
			AtempR = 0.8;
			AtempY = 0.0;
			//vessel->SetAttitudeRotLevel(0, 1);

		}else {
			AtempP = 0.0;
			AtempR = 0.0;
			AtempY = 0.0;
		}
		DPROG = 12;
		R1 = pitch;
		R2 = heading;
		R3 = TO_HDG;
				
	}else if (vessel->GetAltitude() < 4500  && vessel->GetAltitude() > 2800){		
		
		oapiGetFocusBank(&bank);
		bank = bank*180./PI;
		oapiGetHeading(vessel->GetHandle(),&heading);
		heading = heading*180./PI;
				
		if (fabs(bank) < 0.5) {
			AtempP = 0.0;
			AtempR = 0.0;
			AtempY = 0.0;

		}else if (bank < 0 && fabs(vsp.vrot.z) < 0.11) {
			AtempR = 1.0;
			//vessel->SetAttitudeRotLevel(2,-1 );//bank/30

		}else if (bank > 0 && fabs(vsp.vrot.z) < 0.11) {
			AtempR = -1.0;
			//vessel->SetAttitudeRotLevel(2, 1);		

		}else {
			AtempP = 0.0;
			AtempR = 0.0;
			AtempY = 0.0;
		}	
		if (fabs(bank) < 10 && fabs(vsp.vrot.z) > 0.1) {
			AtempP = 0.0;
			AtempR = 0.0;
			AtempY = 0.0;
			StopRot=false;
		}
		DPROG = 13;
		R1 = pitch;
		R2 = heading;
		R3 = bank;

	}else if (vessel->GetAltitude() > 4500)	{		
	
	// navigation
	oapiGetFocusPitch(&pitch);
	pitch=pitch*180./PI;
	oapiGetFocusAltitude(&altitude);

 // guidance
	pitch_c=GetCPitch(autoT);

 // control
	double SatApo;
	vessel->GetApDist(SatApo);
	
	if (SatApo >= ((MIN_ALT *.80) +ERADIUS)*1000){	
		double TimeW=0;
		TimeW = oapiGetTimeAcceleration ();
		if (TimeW>1){
		//TimeW = 1;
		//oapiSetTimeAcceleration (1);
		}
		pitch_c=SetPitchApo(vessel);
		level = pitch_c - pitch;
		DPROG = 16;

	}else if(autopTime < 150){
		DPROG = 14;
		level = pitch_c - pitch;
	}else{
		if (status>=2){
			DPROG = 15;
			pitch_c = 35;
		}else{
		DPROG = 14;
		pitch_c=GetCPitch(autoT);
		}
	level = pitch_c - pitch;
	
	}
	//sprintf(oapiDebugString(), "Autopilot Pitch Mode%f", elemSaturn1B.a );
			
			R1 =pitch_c ;
			R2 =pitch;
			R3 = autopTime;
	

			if (fabs(level)<10 && StopRot){	// above atmosphere, soft correction
	
				AtempP = 0.0;
				AtempR = 0.0;
				AtempY = 0.0;
				StopRot = false;
			}
			if (fabs(level)<0.05){	// above atmosphere, soft correction
	
				AtempP = 0.0;
				AtempR = 0.0;
				AtempY = 0.0;
				
				
			}else if (level>0 && fabs(vsp.vrot.z) < 0.09){
				
				AtempP = -(fabs(level)/10);
				if (AtempP < -1.0) AtempP = -1.0;
			}
				else if (level<0 && fabs(vsp.vrot.z) < 0.09)
				{
				AtempP = (fabs(level)/10);
				if (AtempP > 1.0) AtempP = 1.0;
				}
				else{
				AtempP = 0.0;
				AtempR = 0.0;
				AtempY = 0.0;
				}
		}
	if (RPswitch10){
		switch (stage){

			case 0:
			AttitudeLaunch1(vessel);
		break;
			case 1:
			AttitudeLaunch2(vessel);
		break;
			case 2:
			AttitudeLaunch2(vessel);
		break;
			case 3:
			AttitudeLaunch2(vessel);
		break;
			case 4:
			AttitudeLaunch3(vessel);
		break;
		}
	}
	
}
void AccelS4B(OBJHANDLE hvessel, double time){
	
	T1=T2;
	T2 = time;
	VESSEL *stg1vessel;
		stg1vessel = oapiGetVesselInterface(hvessel);
	if (ignition_S4time == 0 && !S4Sep){
		ignition_S4time=time;
		S4Sep=true;
		VECTOR3 m_exhaust_pos1= {0,0,-STG2O-4};
		VECTOR3 m_exhaust_ref = {0,0,-1};
		stg1vessel->AddExhaustRef (EXHAUST_MAIN, m_exhaust_pos1, 15.0, 1.5, &m_exhaust_ref);	
		stg1vessel->SetAttitudeLinLevel(2,-1);
	}
	if (time > ignition_S4time+5){
			stg1vessel->SetAttitudeLinLevel(2,0);
			stg1vessel->SetAttitudeLinLevel(0,-1);
	}
	if (time > ignition_S4time+10){
			stg1vessel->SetAttitudeLinLevel(0,0);
	}	
			if (time > ignition_S4time+180){
			stg1vessel->ActivateNavmode(NAVMODE_KILLROT);
			stg1vessel->DeactivateNavmode(NAVMODE_RETROGRADE);
			stg1vessel->SetEngineLevel(ENGINE_MAIN,1);
			S4Shoot=true;
			}
			if (time > ignition_S4time+120){
				stg1vessel->ActivateNavmode(NAVMODE_RETROGRADE);
			}
			
}
void MoveEVA(VESSEL *vessel){
	double cm ;
	double lat;
	double lon;
	double cap;
	double timeW=1;
	VESSELSTATUS eva;
	vessel->GetStatus(eva);
	oapiGetHeading(vessel->GetHandle(),&cap);
	timeW=oapiGetTimeAcceleration();
	lon=eva.vdata[0].x;
	lat=eva.vdata[0].y;
	PlayVesselWave(HRover,LOOP,245);
	cm = 5.36e-8*timeW;

	if (KEY1){
		eva.vdata[0].z = eva.vdata[0].z - ((PI*0.1/180)*timeW/2);
		if(eva.vdata[0].z <=-2*PI){
		eva.vdata[0].z = eva.vdata[0].z + 2*PI;
		}
		KEY1=false;
	}
	else if (KEY3){
		eva.vdata[0].z = eva.vdata[0].z +(( PI*0.1/180)*timeW/2);
		if(eva.vdata[0].z >=2*PI){
		eva.vdata[0].z = eva.vdata[0].z - 2*PI;
		}
		KEY3=false;
	}
	else if (KEY2){
		lat = lat - cos(cap) * cm;
		lon = lon - sin(cap) * cm;
		KEY2=false;
	}
	else if (KEY4){
		lat = lat + sin(cap) * cm;
		lon = lon - cos(cap) * cm;
		KEY4=false;
	}
	else if (KEY5){
		KEY5=false;
	}
	else if (KEY6){
		lat = lat - sin(cap) * cm;
		lon = lon + cos(cap) * cm;
		KEY6=false;
	}
	else if (KEY7){
		KEY7=false;
	}
	else if (KEY8||GoHover){// we go ahead whatever our headign
		lat = lat + cos(cap) * cm;
		lon = lon + sin(cap) * cm;
		KEY8=false;
	}
	else if (KEY9){
		KEY9=false;
	}else{
		StopVesselWave(HRover);
	}

	eva.vdata[0].x=lon;
	eva.vdata[0].y=lat;
	vessel->DefSetState(&eva);
}

void SetChuteStage1(VESSEL *vessel)
{
	UINT meshidx;
	vessel->SetSize (15);
	vessel->SetCOG_elev (1);
	vessel->SetEmptyMass (5500);
	vessel->SetMaxFuelMass (100);
	vessel->SetFuelMass (0);
	vessel->SetMaxThrust (ENGINE_MAIN,  0);
	vessel->SetMaxThrust (ENGINE_RETRO, 0);
	vessel->SetMaxThrust (ENGINE_HOVER, 0);
	vessel->SetMaxThrust (ENGINE_ATTITUDE, 0);
	vessel->SetEngineLevel(ENGINE_ATTITUDE,0);
	vessel->SetEngineLevel(ENGINE_MAIN, 0.0);
	vessel->SetPMI (_V(20,20,12));
	vessel->SetCrossSections (_V(2.8,2.8,50.0));
	vessel->SetCW (0.5, 1.5, 1.4, 1.4);
	vessel->SetRotDrag (_V(0.7,0.7,1.2));
	if (vessel->GetFlightModel() >= 1) 
	{
		vessel->SetPitchMomentScale (-5e-3);
		vessel->SetBankMomentScale (-5e-3);
	}
	vessel->SetLiftCoeffFunc (0);
    vessel->ClearMeshes();
    vessel->ClearExhaustRefs();
    vessel->ClearAttExhaustRefs();
	//vessel->ShiftCentreOfMass (_V(0,0,6.25));
	VECTOR3 mesh_dir=_V(0,0,34.40-12.25-16.5-6.5-6.25);
			if (Burned){
			vessel->ClearMeshes();
			mesh_dir=_V(0,0,34.40-12.25-21.5-7.75);
			vessel->AddMesh (hCM2B, &mesh_dir);
			mesh_dir=_V(0.02,1.35,34.54-12.25-21.5-7.75);
			vessel->AddMesh (hFHC, &mesh_dir);
			// And the Crew
			mesh_dir=_V(0,0.15,34.25-12.25-21.5-7.75);
			vessel->AddMesh (hCMP, &mesh_dir);
			mesh_dir=_V(0,0.15,34.25-12.25-21.5-7.75);
			vessel->AddMesh (hCREW, &mesh_dir);
			}else{
			vessel->ClearMeshes();
			mesh_dir=_V(0,0,34.40-12.25-21.5-7.75);
			vessel->AddMesh (hCM2, &mesh_dir);
			mesh_dir=_V(0.02,1.35,34.54-12.25-21.5-7.75);
			vessel->AddMesh (hFHC, &mesh_dir);
			// And the Crew
			mesh_dir=_V(0,0.15,34.25-12.25-21.5-7.75);
			vessel->AddMesh (hCMP, &mesh_dir);
			mesh_dir=_V(0,0.15,34.25-12.25-21.5-7.75);
			vessel->AddMesh (hCREW, &mesh_dir);
			}
	mesh_dir=_V(0,0,44.00-12.25-21.5-7.75);
	meshidx=vessel->AddMesh (hChute30, &mesh_dir);
	vessel ->SetMeshVisibleInternal (meshidx, true);
	status = 8;
	cdrview=true;
	SetView(vessel);
	vessel->DeactivateNavmode(NAVMODE_KILLROT);
	vessel->SetTouchdownPoints (_V(0,-1.0,0), _V(-.7,.7,0), _V(.7,.7,0));
	LAUNCHIND[3]=true;
	LAUNCHIND[1]=true;
}
void SetChuteStage2(VESSEL *vessel)
{
	UINT meshidx;   
	vessel->SetCOG_elev (1);
	vessel->SetEmptyMass (5500);
	vessel->SetMaxFuelMass (100);
	vessel->SetFuelMass (0);
	vessel->SetMaxThrust (ENGINE_MAIN,  0);
	vessel->SetMaxThrust (ENGINE_RETRO, 0);
	vessel->SetMaxThrust (ENGINE_HOVER, 0);
	vessel->SetMaxThrust (ENGINE_ATTITUDE, 0);
	vessel->SetEngineLevel(ENGINE_ATTITUDE,0);
	vessel->SetEngineLevel(ENGINE_MAIN, 0.0);
	vessel->SetPMI (_V(20,20,12));
	vessel->SetCrossSections (_V(2.8,2.8,120.0));
	vessel->SetCW (0.5, 1.5, 1.4, 1.4);
	vessel->SetRotDrag (_V(0.7,0.7,1.2));
	if (vessel->GetFlightModel() >= 1) 
	{
		vessel->SetPitchMomentScale (-5e-3);
		vessel->SetBankMomentScale (-5e-3);
	}
	vessel->SetLiftCoeffFunc (0);
    vessel->ClearMeshes();
    vessel->ClearExhaustRefs();
    vessel->ClearAttExhaustRefs();
	//vessel->ShiftCentreOfMass (_V(0,0,6.25));
	VECTOR3 mesh_dir=_V(0,0,34.40-12.25-16.5-6.5-6.25);
	if (Burned){
			vessel->ClearMeshes();
			mesh_dir=_V(0,0,34.40-12.25-21.5-7.75);
			vessel->AddMesh (hCM2B, &mesh_dir);
			mesh_dir=_V(0.02,1.35,34.54-12.25-21.5-7.75);
			vessel->AddMesh (hFHC, &mesh_dir);
			// And the Crew
			mesh_dir=_V(0,0.15,34.25-12.25-21.5-7.75);
			vessel->AddMesh (hCMP, &mesh_dir);
			mesh_dir=_V(0,0.15,34.25-12.25-21.5-7.75);
			vessel->AddMesh (hCREW, &mesh_dir);
			}else{
			vessel->ClearMeshes();
			mesh_dir=_V(0,0,34.40-12.25-21.5-7.75);
			vessel->AddMesh (hCM2, &mesh_dir);
			mesh_dir=_V(0.02,1.35,34.54-12.25-21.5-7.75);
			vessel->AddMesh (hFHC, &mesh_dir);
			// And the Crew
			mesh_dir=_V(0,0.15,34.25-12.25-21.5-7.75);
			vessel->AddMesh (hCMP, &mesh_dir);
			mesh_dir=_V(0,0.15,34.25-12.25-21.5-7.75);
			vessel->AddMesh (hCREW, &mesh_dir);
			}
	mesh_dir=_V(0,-0.25,39.7-12.25-21.5-7.75);
	meshidx=vessel->AddMesh (hChute31, &mesh_dir);
	vessel ->SetMeshVisibleInternal (meshidx, true);
	status = 9;
	cdrview=true;
	SetView(vessel);
	vessel->SetTouchdownPoints (_V(0,-1.0,0), _V(-.7,.7,0), _V(.7,.7,0));
	LAUNCHIND[3]=true;
	LAUNCHIND[1]=true;
}
void SetChuteStage3(VESSEL *vessel)
{
	UINT meshidx;   
	vessel->SetSize (12);
	vessel->SetCOG_elev (1);
	vessel->SetEmptyMass (5500);
	vessel->SetMaxFuelMass (100);
	vessel->SetFuelMass (0);
	vessel->SetMaxThrust (ENGINE_MAIN,  0);
	vessel->SetMaxThrust (ENGINE_RETRO, 0);
	vessel->SetMaxThrust (ENGINE_HOVER, 0);
	vessel->SetMaxThrust (ENGINE_ATTITUDE, 0);
	vessel->SetEngineLevel(ENGINE_ATTITUDE,0);
	vessel->SetEngineLevel(ENGINE_MAIN, 0.0);
	vessel->SetPMI (_V(20,20,12));
	vessel->SetCrossSections (_V(2.8,2.8,480.0));
	vessel->SetCW (0.5, 1.5, 1.4, 1.4);
	vessel->SetRotDrag (_V(0.7,0.7,1.2));
	if (vessel->GetFlightModel() >= 1) 
	{
		vessel->SetPitchMomentScale (-5e-3);
		vessel->SetBankMomentScale (-5e-3);
	}
	vessel->SetLiftCoeffFunc (0);
    vessel->ClearMeshes();
    vessel->ClearExhaustRefs();
    vessel->ClearAttExhaustRefs();
	//vessel->ShiftCentreOfMass (_V(0,0,6.25));
	VECTOR3 mesh_dir=_V(0,0,34.40-12.25-16.5-6.5-6.25);
	if (Burned){
			vessel->ClearMeshes();
			mesh_dir=_V(0,0,34.40-12.25-21.5-7.75);
			vessel->AddMesh (hCM2B, &mesh_dir);
			mesh_dir=_V(0.02,1.35,34.54-12.25-21.5-7.75);
			vessel->AddMesh (hFHC, &mesh_dir);
			// And the Crew
			mesh_dir=_V(0,0.15,34.25-12.25-21.5-7.75);
			vessel->AddMesh (hCMP, &mesh_dir);
			mesh_dir=_V(0,0.15,34.25-12.25-21.5-7.75);
			vessel->AddMesh (hCREW, &mesh_dir);
			}else{
			vessel->ClearMeshes();
			mesh_dir=_V(0,0,34.40-12.25-21.5-7.75);
			vessel->AddMesh (hCM2, &mesh_dir);
			mesh_dir=_V(0.02,1.35,34.54-12.25-21.5-7.75);
			vessel->AddMesh (hFHC, &mesh_dir);
			// And the Crew
			mesh_dir=_V(0,0.15,34.25-12.25-21.5-7.75);
			vessel->AddMesh (hCMP, &mesh_dir);
			mesh_dir=_V(0,0.15,34.25-12.25-21.5-7.75);
			vessel->AddMesh (hCREW, &mesh_dir);
			}	mesh_dir=_V(0,-1.3,17);
	meshidx=vessel->AddMesh (hChute32, &mesh_dir);
	vessel ->SetMeshVisibleInternal (meshidx, true);
	status = 10;
	cdrview=true;
	SetView(vessel);
	vessel->SetTouchdownPoints (_V(0,-1.0,0), _V(-.7,.7,0), _V(.7,.7,0));
	LAUNCHIND[3]=true;
	LAUNCHIND[1]=true;
}
void SetChuteStage4(VESSEL *vessel)
{
	UINT meshidx;   
	vessel->SetSize (12);
	vessel->SetCOG_elev (1);
	vessel->SetEmptyMass (5500);
	vessel->SetMaxFuelMass (500);
	vessel->SetFuelMass (0);
	vessel->SetTouchdownPoints (_V(0,0.0,0), _V(-1,0,0), _V(1,0,0));
	vessel->SetPMI (_V(20,20,12));
	vessel->SetCrossSections (_V(2.8,2.8,3280.0));
	vessel->SetCW (0.5, 1.5, 1.4, 1.4);
	vessel->SetRotDrag (_V(0.7,0.7,1.2));
	if (vessel->GetFlightModel() >= 1) 
	{
		vessel->SetPitchMomentScale (-5e-3);
		vessel->SetBankMomentScale (-5e-3);
	}
	vessel->SetLiftCoeffFunc (0);
    vessel->ClearMeshes();
    vessel->ClearExhaustRefs();
    vessel->ClearAttExhaustRefs();
	//vessel->ShiftCentreOfMass (_V(0,0,6.25));
	VECTOR3 mesh_dir=_V(0,0,34.40-12.25-16.5-6.5-6.25);
	if (Burned){
			vessel->ClearMeshes();
			mesh_dir=_V(0,0,34.40-12.25-21.5-7.75);
			vessel->AddMesh (hCM2B, &mesh_dir);
			mesh_dir=_V(0.02,1.35,34.54-12.25-21.5-7.75);
			vessel->AddMesh (hFHC, &mesh_dir);
			// And the Crew
			mesh_dir=_V(0,0.15,34.25-12.25-21.5-7.75);
			vessel->AddMesh (hCMP, &mesh_dir);
			mesh_dir=_V(0,0.15,34.25-12.25-21.5-7.75);
			vessel->AddMesh (hCREW, &mesh_dir);
			}else{
			vessel->ClearMeshes();
			mesh_dir=_V(0,0,34.40-12.25-21.5-7.75);
			vessel->AddMesh (hCM2, &mesh_dir);
			mesh_dir=_V(0.02,1.35,34.54-12.25-21.5-7.75);
			vessel->AddMesh (hFHC, &mesh_dir);
			// And the Crew
			mesh_dir=_V(0,0.15,34.25-12.25-21.5-7.75);
			vessel->AddMesh (hCMP, &mesh_dir);
			mesh_dir=_V(0,0.15,34.25-12.25-21.5-7.75);
			vessel->AddMesh (hCREW, &mesh_dir);
			}
	mesh_dir=OFS_MAINCHUTE;
	meshidx=vessel->AddMesh (hApollochute, &mesh_dir);
	vessel ->SetMeshVisibleInternal (meshidx, true);
	status = 11;
	cdrview=true;
	SetView(vessel);
	vessel->SetTouchdownPoints (_V(0,-1.0,0), _V(-.7,.7,0), _V(.7,.7,0));
	LAUNCHIND[5]=true;
	LAUNCHIND[3]=true;
	LAUNCHIND[1]=true;
}

void SetSplashStage(VESSEL *vessel)
{
	UINT meshidx;   
	vessel->SetSize (4);
	vessel->SetCOG_elev (2);
	vessel->SetEmptyMass (5500);
	vessel->SetMaxFuelMass (0);
	vessel->SetFuelMass (0);
	vessel->SetMaxThrust (ENGINE_MAIN,  0);
	vessel->SetMaxThrust (ENGINE_ATTITUDE, 0);
	vessel->SetEngineLevel(ENGINE_ATTITUDE,0);
	vessel->SetEngineLevel(ENGINE_MAIN, 0.0);
	vessel->SetPMI (_V(20,20,12));
	vessel->SetCrossSections (_V(2.8,2.8,7.0));
	vessel->SetCW (0.5, 1.5, 1.4, 1.4);
	vessel->SetRotDrag (_V(0.7,0.7,1.2));
	vessel->SetTouchdownPoints (_V(0,-1.0,0), _V(-.7,.7,0), _V(.7,.7,0));
	if (vessel->GetFlightModel() >= 1) 
	{
		vessel->SetPitchMomentScale (-5e-3);
		vessel->SetBankMomentScale (-5e-3);
	}
	vessel->SetLiftCoeffFunc (0);
    vessel->ClearMeshes();
    vessel->ClearExhaustRefs();
    vessel->ClearAttExhaustRefs();
	//vessel->ShiftCentreOfMass (_V(0,0,6.25));
	VECTOR3 mesh_dir=_V(0,0,-1.2);
	if (Burned){
	vessel->AddMesh (hCM2B, &mesh_dir);
	mesh_dir=_V(0.02,1.35,-1.06);
	vessel->AddMesh (hFHC2, &mesh_dir);
	}else{
	vessel->AddMesh (hCM2, &mesh_dir);
	mesh_dir=_V(0.02,1.35,-1.06);
	vessel->AddMesh (hFHC, &mesh_dir);
	}
	mesh_dir=_V(0,-0.1,-0.2);
	meshidx=vessel->AddMesh (hCMBALLOON, &mesh_dir);
	vessel ->SetMeshVisibleInternal (meshidx, true);
	mesh_dir=_V(0,0.15,-1.35);
	vessel->AddMesh (hCMP, &mesh_dir);
	mesh_dir=_V(0,0.15,-1.35);
	vessel->AddMesh (hCREW, &mesh_dir);
	status = 12;
	cdrview=true;
	SetView(vessel);

}
double GetFuelUsage(double simt, double thrust, double ISP)
{
	return (simt * thrust) / ISP;
}
void DoFuelUsage (VESSEL *vessel)
{
	
	if (CSM_fuel_mass_rcs <= vessel->GetFuelMass()){
	vessel->SetFuelMass(CSM_fuel_mass_rcs);
	}
	double simStep = oapiGetSimStep();
	double rotLevel = 0;
	VECTOR3 rotThrust;
	vessel->GetAttitudeRotLevel(rotThrust);
	rotLevel = fabs(rotThrust.x) + fabs(rotThrust.y) + fabs(rotThrust.z);
	rotLevel *= simStep;
	vessel->SetFuelMass(vessel->GetFuelMass() - (GetFuelUsage(simStep, CSM_THRUST_ATT * rotLevel * 4, CSM_ISP)));
	CSM_fuel_mass_rcs = vessel->GetFuelMass();
	if (CSM_fuel_mass_rcs == 0)
		vessel->SetMaxThrust(ENGINE_ATTITUDE, 0);
}



void SeparateStage (VESSEL *vessel, UINT stage)

{
	//ResetThrusters(vessel);
	VESSELSTATUS vs1;
	VESSELSTATUS vs2;
	VESSELSTATUS vs3;
	VESSELSTATUS vs4;
	VESSELSTATUS vs5;
	VECTOR3 ofs1 = _V(0,0,0);
	VECTOR3 ofs2 = _V(0,0,0);
	VECTOR3 ofs3 = _V(0,0,0);
	VECTOR3 ofs4 = _V(0,0,0);
	VECTOR3 ofs5 = _V(0,0,0);
	VECTOR3 vel1 = _V(0,0,0);
	VECTOR3 vel2 = _V(0,0,0);
	VECTOR3 vel3 = _V(0,0,0);
	VECTOR3 vel4 = _V(0,0,0);
	VECTOR3 vel5 = _V(0,0,0);
	
	vessel->GetStatus (vs1);
	vessel->GetStatus (vs2);
	vessel->GetStatus (vs3);
	vessel->GetStatus (vs4);
	vessel->GetStatus (vs5);
	vs1.eng_main = vs1.eng_hovr = 0.0;
	vs2.eng_main = vs2.eng_hovr = 0.0;
	vs3.eng_main = vs3.eng_hovr = 0.0;
	vs4.eng_main = vs4.eng_hovr = 0.0;
	vs5.eng_main = vs5.eng_hovr = 0.0;

	if (stage == 0 && !bAbort)
	{
	    
		ofs1 = OFS_STAGE1;		
		vel1 = _V(0,0,-4.0);	
	
	}
	if (stage ==0 && bAbort)
	{
	 	
		ofs1= OFS_ABORT;
		vel1 = _V(0,0,-4.0);	
	
	}
	if (stage == 1 && !bAbort)
	{
	    
		ofs1 = OFS_STAGE12;		
		vel1 = _V(0,0,-4.0);	
	
	}
	if (stage == 2 && !bAbort|| stage == 14 && !bAbort)
	{
		ofs1 = OFS_TOWER;		
		vel1 = _V(15.0,15.0,106.0);
	}

	if (stage ==1&& bAbort||stage ==2 && bAbort)
	{
	 			 	
		ofs1= OFS_ABORT2;
		vel1 = _V(0,0,-4.0);	
	}
	
	if (stage == 3)
	{
	 	ofs1 = OFS_STAGE2;		
		vel1 = _V(0,0,-6.0);	
		
	}if (stage == 4)
	{
	 	ofs1 = OFS_STAGE3;		
		vel1 = _V(0,0,-0.135);	
		ofs2 = OFS_STAGE31;		
		vel2 = _V(-0.5,-0.5,-0.55);
		ofs3 = OFS_STAGE32;		
		vel3 = _V(0.5,-0.5,-0.55);	
		ofs4 = OFS_STAGE33;	
		vel4 = _V(0.5,0.5,-0.55);	
		ofs5 = OFS_STAGE34;		
		vel5 = _V(-0.5,0.5,-0.55);	
	}
	
	if (stage == 5)
	{
	 	ofs1 = OFS_SM;		
		vel1 = _V(0,0,-0.5);
		ofs2 = OFS_DOCKING;	
		vel2 = _V(0.0,0.0,0.6);
	
	}
	if (stage == 6)
	{
		ofs1 = OFS_CM_CONE;	
		vel1 = _V(1.0,1.0,1.0);
	}
	if (stage == 14)
	{
		ofs1 = OFS_ABORT_TOWER;	
		vel1 = _V(15.0,15.0,50.0);
	}
	VECTOR3 rofs1, rvel1 = {vs1.rvel.x, vs1.rvel.y, vs1.rvel.z};
	VECTOR3 rofs2, rvel2 = {vs2.rvel.x, vs2.rvel.y, vs2.rvel.z};
	VECTOR3 rofs3, rvel3 = {vs3.rvel.x, vs3.rvel.y, vs3.rvel.z};
	VECTOR3 rofs4, rvel4 = {vs4.rvel.x, vs4.rvel.y, vs4.rvel.z};
	VECTOR3 rofs5, rvel5 = {vs5.rvel.x, vs5.rvel.y, vs5.rvel.z};
	vessel->Local2Rel (ofs1, vs1.rpos);
	vessel->Local2Rel (ofs2, vs2.rpos);
	vessel->Local2Rel (ofs3, vs3.rpos);
	vessel->Local2Rel (ofs4, vs4.rpos);
	vessel->Local2Rel (ofs5, vs5.rpos);
	vessel->GlobalRot (vel1, rofs1);
	vessel->GlobalRot (vel2, rofs2);
	vessel->GlobalRot (vel3, rofs3);
	vessel->GlobalRot (vel4, rofs4);
	vessel->GlobalRot (vel5, rofs5);
	vs1.rvel.x = rvel1.x+rofs1.x;
	vs1.rvel.y = rvel1.y+rofs1.y;
	vs1.rvel.z = rvel1.z+rofs1.z;
	vs2.rvel.x = rvel2.x+rofs2.x;
	vs2.rvel.y = rvel2.y+rofs2.y;
	vs2.rvel.z = rvel2.z+rofs2.z;
	vs3.rvel.x = rvel3.x+rofs3.x;
	vs3.rvel.y = rvel3.y+rofs3.y;
	vs3.rvel.z = rvel3.z+rofs3.z;
	vs4.rvel.x = rvel4.x+rofs4.x;
	vs4.rvel.y = rvel4.y+rofs4.y;
	vs4.rvel.z = rvel4.z+rofs4.z;
	vs5.rvel.x = rvel5.x+rofs5.x;
	vs5.rvel.y = rvel5.y+rofs5.y;
	vs5.rvel.z = rvel5.z+rofs5.z;
//
	
	if (stage == 7)
	{
		if (vessel->GetAtmPressure()>350000){
		
		}
		SetChuteStage1 (vessel);
	}
    if (stage == 0 && !bAbort )
	{
	    vs1.vrot.x = 0.025;	
		vs1.vrot.y = 0.025;
		vs1.vrot.z = 0.0;
		vs2.vrot.x = 0.0;	
		vs2.vrot.y = 0.0;
		vs2.vrot.z = 0.0;
		PlayVesselWave(StageS,NOLOOP);
		char VName[256];
		strcpy (VName, vessel->GetName()); strcat (VName, "-STG1");
		hstg1 = oapiCreateVessel(VName,"sat5stg1",vs1);
		stg1U = true;
		Ullage(hstg1,5);
		SetSecondStage (vessel);	
	}
	if (stage == 1 && !bAbort )
	{
	    vs1.vrot.x = 0.025;	
		vs1.vrot.y = 0.025;
		vs1.vrot.z = 0.0;
		vs2.vrot.x = 0.0;	
		vs2.vrot.y = 0.0;
		vs2.vrot.z = 0.0;
		PlayVesselWave(CrashBumpS,NOLOOP,150);
		char VName[256];
		strcpy (VName, vessel->GetName()); strcat (VName, "-INTSTG");
		hintstg = oapiCreateVessel(VName,"sat5intstg",vs1);
		SetSecondStage1 (vessel);	
	}
	if (stage == 2 && !bAbort )
	{
	   
		vs1.vrot.x = 0.0;	
		vs1.vrot.y = 0.0;
		vs1.vrot.z = 0.0;
		PlayVesselWave(TowerJS,NOLOOP,255);
		char VName[256];
		strcpy (VName, vessel->GetName()); strcat (VName, "-TWR");
		
		hesc1 = oapiCreateVessel(VName,"sat5btower",vs1);
		SetSecondStage2 (vessel);	
	}
	if (stage == 3)
	{
	    vs1.vrot.x = 0.025;	
		vs1.vrot.y = 0.025;
		vs1.vrot.z = 0.0;
		vs2.vrot.x = 0.0;	
		vs2.vrot.y = 0.0;
		vs2.vrot.z = 0.0;
		PlayVesselWave(StageS,NOLOOP);
		char VName[256];
		strcpy (VName, vessel->GetName()); strcat (VName, "-STG2");
		hstg2 = oapiCreateVessel(VName,"sat5stg2",vs1);
		Ullage2(hstg2,5);
		SetThirdStage (vessel);
		stg2U = true;
		S4BStarted=false;
		S4BStarted2=false;
	}
	if (stage == 4)
	{
		
		char VName[256]="";
		char VName1[256]="";
		char VName2[256]="";
		char VName3[256]="";
		char VName4[256]="";
		
		vs1.vrot.x = 0.0;	
		vs1.vrot.y = 0.0;	
		vs1.vrot.z = 0.0;
		vs2.vrot.x = -0.1;	
		vs2.vrot.y = 0.1;	
		vs2.vrot.z = 0.0;
		vs3.vrot.x = -0.1;	
		vs3.vrot.y = -0.1;	
		vs3.vrot.z = 0.0;
		vs4.vrot.x = 0.1;	
		vs4.vrot.y = -0.1;	
		vs4.vrot.z = 0.0;
		vs5.vrot.x = 0.1;	
		vs5.vrot.y = 0.1;	
		vs5.vrot.z = 0.0;
		strcpy (VName, vessel->GetName()); strcat (VName, "-S4BSTG");
		hs4bM = oapiCreateVessel(VName, "sat5stg3", vs1);
		setupS4B(hs4bM);
		strcpy (VName1, vessel->GetName()); strcat (VName1, "-S4B1");
		hs4b1 = oapiCreateVessel(VName1, "sat5stg31", vs2);
		strcpy (VName2, vessel->GetName()); strcat (VName2, "-S4B2");
		hs4b2 = oapiCreateVessel(VName2, "sat5stg32", vs3);
		strcpy (VName3, vessel->GetName()); strcat (VName3, "-S4B3");
		hs4b3 = oapiCreateVessel(VName3, "sat5stg33", vs4);
		strcpy (VName4, vessel->GetName()); strcat (VName4, "-S4B4");
		hs4b4 = oapiCreateVessel(VName4, "sat5stg34", vs5);
		PlayVesselWave(SeparationS,NOLOOP,255);
		dockstate = 1;
		FIRSTCSM=true;
		SetCSMStage (vessel);
		

	}
	if (stage == 5)
	{
		char VName[256];
		vs1.vrot.x = 0.0;	
		vs1.vrot.y = 0.0;	
		vs1.vrot.z = 0.0;
		PlayVesselWave(SMJetS,NOLOOP);
		
		if(dockstate !=5){
		VECTOR3 ofs = OFS_DOCKING2;
		VECTOR3 vel = {0.0,0.0,2.5};
		VESSELSTATUS vs4b;
		vessel->GetStatus (vs4b);
		StageTransform(vessel,&vs4b,ofs,vel);
		vs4b.vrot.x = 0.0;
		vs4b.vrot.y = 0.0;
		vs4b.vrot.z = 0.0;
		strcpy (VName, vessel->GetName()); strcat (VName, "-DCKPRB");
		hPROBE = oapiCreateVessel(VName, "sat1probe", vs4b);
		}	
		
		strcpy (VName, vessel->GetName()); strcat (VName, "-SM");
		hSMJet = oapiCreateVessel(VName, "sat1_SM", vs1);
		stgSM= true;
		SetReentryStage (vessel);

		
	}

		if (stage == 6)
	{
		
		SetChuteStage2 (vessel);
	}
		if (stage == 7)
	{
		
		SetChuteStage3 (vessel);
	}
		if (stage == 9)
	{
		
		SetChuteStage4 (vessel);
	}
		if (stage == 10)
	{
		
		SetSplashStage (vessel);
	}
	
	if (stage ==0 && bAbort )
	{
		vs1.vrot.x = 0.0;	
		vs1.vrot.y = 0.0;	
		vs1.vrot.z = 0.0;
		PlayVesselWave(StageS,NOLOOP);
		VESSEL::Create ("Saturn5_Abort", "Saturn5Abort1", vs1);
		abortRocket =true;
		SetAbortStage (vessel);
	}
	if (stage ==1 && bAbort ||stage ==2 && bAbort )
	{
		vs1.vrot.x = 0.0;	
		vs1.vrot.y = 0.0;	
		vs1.vrot.z = 0.0;
		PlayVesselWave(StageS,NOLOOP);
		VESSEL::Create ("Saturn5_Abort", "Saturn5Abort2", vs1);
		abortRocket =true;
		SetAbortStage (vessel);
	}
	if (stage ==14 )
	{
		char VName[256];
		vs1.vrot.x = 0.0;	
		vs1.vrot.y = 0.0;	
		vs1.vrot.z = 0.0;
		PlayVesselWave(TowerJS,NOLOOP,160);
		strcpy (VName, vessel->GetName()); strcat (VName, "-TWR");
		VESSEL::Create (VName, "sat5btower", vs1);
		hesc1=oapiGetVesselByName(VName);
		SetReentryStage (vessel);
		vessel->ActivateNavmode(NAVMODE_KILLROT);
	}


}


void DockStage (VESSEL *vessel, UINT dockstatus)
{
	VESSELSTATUS vs1;
	VESSELSTATUS vs2;
	VESSELSTATUS vs3;
	VESSELSTATUS vs4;
	VESSELSTATUS vs5;
	VECTOR3 ofs1 = _V(0,0,0);
	VECTOR3 ofs2 = _V(0,0,0);
	VECTOR3 ofs3 = _V(0,0,0);
	VECTOR3 ofs4 = _V(0,0,0);
	VECTOR3 ofs5 = _V(0,0,0);
	VECTOR3 vel1 = _V(0,0,0);
	VECTOR3 vel2 = _V(0,0,0);
	VECTOR3 vel3 = _V(0,0,0);
	VECTOR3 vel4 = _V(0,0,0);
	VECTOR3 vel5 = _V(0,0,0);
	vessel->SetEngineLevel(ENGINE_MAIN, 0);
	vessel->GetStatus (vs1);
	vessel->GetStatus (vs2);
	vessel->GetStatus (vs3);
	vessel->GetStatus (vs4);
	vessel->GetStatus (vs5);
	vs1.eng_main = vs1.eng_hovr = 0.0;
	vs2.eng_main = vs2.eng_hovr = 0.0;
	vs3.eng_main = vs3.eng_hovr = 0.0;
	vs4.eng_main = vs4.eng_hovr = 0.0;
	vs5.eng_main = vs5.eng_hovr = 0.0;

		
	if (dockstatus == 2||dockstatus == 6)
	{
	 	ofs1 = RelPos;		
		vel1 = _V(0,0,0.5);
	}

	VECTOR3 rofs1, rvel1 = {vs1.rvel.x, vs1.rvel.y, vs1.rvel.z};
	VECTOR3 rofs2, rvel2 = {vs2.rvel.x, vs2.rvel.y, vs2.rvel.z};
	VECTOR3 rofs3, rvel3 = {vs3.rvel.x, vs3.rvel.y, vs3.rvel.z};
	VECTOR3 rofs4, rvel4 = {vs4.rvel.x, vs4.rvel.y, vs4.rvel.z};
	VECTOR3 rofs5, rvel5 = {vs5.rvel.x, vs5.rvel.y, vs5.rvel.z};
	vessel->Local2Rel (ofs1, vs1.rpos);
	vessel->Local2Rel (ofs2, vs2.rpos);
	vessel->Local2Rel (ofs3, vs3.rpos);
	vessel->Local2Rel (ofs4, vs4.rpos);
	vessel->Local2Rel (ofs5, vs5.rpos);
	vessel->GlobalRot (vel1, rofs1);
	vessel->GlobalRot (vel2, rofs2);
	vessel->GlobalRot (vel3, rofs3);
	vessel->GlobalRot (vel4, rofs4);
	vessel->GlobalRot (vel5, rofs5);
	vs1.rvel.x = rvel1.x+rofs1.x;
	vs1.rvel.y = rvel1.y+rofs1.y;
	vs1.rvel.z = rvel1.z+rofs1.z;
	vs2.rvel.x = rvel2.x+rofs2.x;
	vs2.rvel.y = rvel2.y+rofs2.y;
	vs2.rvel.z = rvel2.z+rofs2.z;
	vs3.rvel.x = rvel3.x+rofs3.x;
	vs3.rvel.y = rvel3.y+rofs3.y;
	vs3.rvel.z = rvel3.z+rofs3.z;
	vs4.rvel.x = rvel4.x+rofs4.x;
	vs4.rvel.y = rvel4.y+rofs4.y;
	vs4.rvel.z = rvel4.z+rofs4.z;
	vs5.rvel.x = rvel5.x+rofs5.x;
	vs5.rvel.y = rvel5.y+rofs5.y;
	vs5.rvel.z = rvel5.z+rofs5.z;


	
   switch (dockstatus)	{

   case 1:	
	   
		break;
	
   case 2:
		
		//Interface initialization for mesh modification to SIVB
		VESSEL *targetvessel;
		VESSELSTATUS2 vslm2;
		VESSELSTATUS vslm;
		char VNameLM[256];		
		vessel->Undock(0);
		targetvessel=oapiGetVesselInterface(hs4bM);
		//time to free LM from SIVB		
		targetvessel->ClearMeshes();
		VECTOR3 mesh_dir=_V(0,0,0);
		targetvessel->ShiftCentreOfMass(_V(0,0,-14.1));
		targetvessel->AddMesh (hsat5stg3, &mesh_dir);
		//targetvessel->SetDockParams(_V(0,0,-15.0), _V(0,0,1), _V(-0.705, -0.705, 0));
		//Release of Slaved Stage
		//Time to hear the Stage separation
		PlayVesselWave(SMJetS,NOLOOP,230);
		//Now Lets create a real LEM and dock it
		//oapiDeleteVessel(hs4bM,vessel->GetHandle());
		strcpy (VNameLM, vessel->GetName()); strcat (VNameLM, "-LM");
		vslm2.version = 2;
		vessel->GetStatusEx(&vslm2);
		vslm2.dockinfo = new VESSELSTATUS2::DOCKINFOSPEC[1];
		vslm2.dockinfo[0].idx = 0;
		vslm2.dockinfo[0].ridx = 0;
		vslm2.dockinfo[0].rvessel = vessel->GetHandle();
  		vslm2.ndockinfo = 1;
		vslm2.flag = VS_DOCKINFOLIST;
		vslm2.version = 2;
		hLMV=oapiCreateVesselEx(VNameLM, "sat5_LMPKD", &vslm2);
		delete []vslm2.dockinfo;
		vessel->GetStatusEx(&vslm2);
		vslm2.dockinfo = new VESSELSTATUS2::DOCKINFOSPEC[1];
		vslm2.dockinfo[0].idx = 0;
		vslm2.dockinfo[0].ridx = 0;
		vslm2.dockinfo[0].rvessel = hLMV;
  		vslm2.ndockinfo = 1;
		vslm2.flag = VS_DOCKINFOLIST;
		vslm2.version = 2;
		vessel->DefSetStateEx(&vslm2);
		vessel->GetStatus(vslm);
		bManualUnDock= false;
		dockstate=3;
		vessel->SetAttitudeLinLevel(2,-1);
		
		break;
	
   case 3:
	if(bManualUnDock) {
	
		//DM Jetison preparation
		vessel->SetAttitudeLinLevel(2,-1);
		TargetHandle =0;
		TargetDocked=false;
		//Time to hear the Stage separation
		PlayVesselWave(SMJetS,NOLOOP);
		bManualUnDock= false;
		if (ProbeJetison){
			if (stage ==5){
			SetCSM2Stage (vessel);
			}
			PlayVesselWave(StageS,NOLOOP);
			bManualUnDock= false;
			dockstate=5;
	
		}else{
			if (stage ==5){
			SetCSMStage (vessel);
			}
			PlayVesselWave(SMJetS,NOLOOP);
			bManualUnDock= false;
			ProbeJetison=true;
			dockstate=4;
	
		}
	
	
	}	  
	break;
   case 4:

	   break;
   case 5:

	   break;
		
	
	
   
	}

}
// ==============================================================
// DLL entry point
// ==============================================================

BOOL WINAPI DllMain (HINSTANCE hModule,
					 DWORD ul_reason_for_call,
					 LPVOID lpReserved)
{
	int i;

	switch (ul_reason_for_call) {
	case DLL_PROCESS_ATTACH:
		g_Param.hDLL = hModule;
		// allocate GDI resources
		g_Param.font[0]  = CreateFont (-13, 0, 0, 0, 700, 0, 0, 0, 0, 0, 0, 0, 0, "Arial");
		g_Param.font[1]  = CreateFont (-10, 0, 0, 0, 400, 0, 0, 0, 0, 0, 0, 0, 0, "Arial");
		g_Param.brush[0] = CreateSolidBrush (RGB(0,255,0));    // green
		g_Param.brush[1] = CreateSolidBrush (RGB(255,0,0));    // red
		g_Param.brush[2] = CreateSolidBrush (RGB(154,154,154));  // Grey
		g_Param.brush[3] = CreateSolidBrush (RGB(3,3,3));  // Black
		g_Param.pen[0] = CreatePen (PS_SOLID, 1, RGB(224,224,224));
		g_Param.pen[1] = CreatePen (PS_SOLID, 3, RGB(164,164,164));
		g_Param.pen[2] = CreatePen (PS_SOLID, 1, RGB(255,0,0));
		g_Param.pen[3] = CreatePen (PS_SOLID, 3, RGB(255,0,0));
		
		break;
	case DLL_PROCESS_DETACH:
		// deallocate GDI resources
		for (i = 0; i < 2; i++) DeleteObject (g_Param.font[i]);
		for (i = 0; i < 4; i++) DeleteObject (g_Param.brush[i]);
		for (i = 0; i < 4; i++) DeleteObject (g_Param.pen[i]);
		break;
	}
	return TRUE;
}

// ==============================================================
// API interface
// ==============================================================
DLLCLBK void ovcDockEvent (VESSEL *vessel, int dock,OBJHANDLE connected)
{
	if(vessel->GetDockStatus(vessel->GetDockHandle(0))==NULL){
		
	}	
	
}

DLLCLBK bool ovcLoadPanel (VESSEL *vessel, int id)
{
	
	ReleaseSurfaces();

	HBITMAP hBmp = LoadBitmap (g_Param.hDLL, MAKEINTRESOURCE (IDB_MAINPANEL));
	MFDSPEC mfds_left  = {{782, 218, 978, 414}, 6, 6, 41, 27};
	MFDSPEC mfds_right = {{1090, 2, 1290, 198}, 6, 6, 41, 27};

	switch (id) {
	case 0: // main panel
		oapiRegisterPanelBackground (hBmp,PANEL_ATTACH_TOP|PANEL_ATTACH_BOTTOM|PANEL_ATTACH_LEFT|PANEL_MOVEOUT_RIGHT,  0xff00ff);//
		//oapiSetPanelNeighbours (-1,-1,1,2);
		oapiRegisterMFD (MFD_LEFT,  mfds_left);
		oapiRegisterMFD (MFD_RIGHT, mfds_right);

		//oapiRegisterPanelArea (AID_PROPELLANTSTATUS,  _R(  27,  81,  144, 156), PANEL_REDRAW_ALWAYS, PANEL_MOUSE_IGNORE, PANEL_MAP_BACKGROUND);
		//oapiRegisterPanelArea (AID_ENGINESTATUS,      _R(1000,  90, 1112, 256), PANEL_REDRAW_ALWAYS, PANEL_MOUSE_IGNORE, PANEL_MAP_BACKGROUND);
		
		// left MFD
		oapiRegisterPanelArea (AID_MFD1_BBUTTONS,     _R(788,419,971,432), PANEL_REDRAW_NEVER, PANEL_MOUSE_LBDOWN); // bottom button row
		oapiRegisterPanelArea (AID_MFD1_LBUTTONS,     _R(751,244, 768, 395), PANEL_REDRAW_USER, PANEL_MOUSE_LBDOWN|PANEL_MOUSE_LBPRESSED, PANEL_MAP_BACKGROUND); // left button column
		oapiRegisterPanelArea (AID_MFD1_RBUTTONS,     _R(992,244,1010,395), PANEL_REDRAW_USER, PANEL_MOUSE_LBDOWN|PANEL_MOUSE_LBPRESSED, PANEL_MAP_BACKGROUND); // right button column
		// right MFD
		oapiRegisterPanelArea (AID_MFD2_BBUTTONS,     _R( 1096,205,1279, 217), PANEL_REDRAW_NEVER, PANEL_MOUSE_LBDOWN); // bottom button row
		oapiRegisterPanelArea (AID_MFD2_LBUTTONS,     _R(1059,30,1078,180), PANEL_REDRAW_USER, PANEL_MOUSE_LBDOWN|PANEL_MOUSE_LBPRESSED, PANEL_MAP_BACKGROUND); // left button column
		oapiRegisterPanelArea (AID_MFD2_RBUTTONS,     _R(1300,30,1317,180), PANEL_REDRAW_USER, PANEL_MOUSE_LBDOWN|PANEL_MOUSE_LBPRESSED, PANEL_MAP_BACKGROUND); // right button column
		//Artificial Horizon
		oapiRegisterPanelArea (AID_HORIZON,           _R( 1140, 266,  1236, 362), PANEL_REDRAW_ALWAYS, PANEL_MOUSE_IGNORE);
		oapiRegisterPanelArea (AID_HORIZON2,           _R( 759,502 ,  855, 598), PANEL_REDRAW_ALWAYS, PANEL_MOUSE_IGNORE);
		oapiRegisterPanelArea (AID_PILOT1,           _R(1337, 108,1386,172), PANEL_REDRAW_ALWAYS, PANEL_MOUSE_DOWN,PANEL_MAP_NONE);
		oapiRegisterPanelArea (AID_INDICATOR1,        _R(1405, 25,1515,185), PANEL_REDRAW_ALWAYS, PANEL_MOUSE_IGNORE,PANEL_MAP_BACKGROUND);
		oapiRegisterPanelArea (AID_GAUGES1,           _R(1310, 300,  1415, 395), PANEL_REDRAW_ALWAYS, PANEL_MOUSE_IGNORE,PANEL_MAP_BACKGROUND);
		oapiRegisterPanelArea (AID_VELOCITY1,           _R( 624, 665,  678, 685), PANEL_REDRAW_ALWAYS, PANEL_MOUSE_IGNORE,PANEL_MAP_BACKGROUND);
		oapiRegisterPanelArea (AID_ALTITUDE1,           _R( 584, 706,  685, 721), PANEL_REDRAW_ALWAYS, PANEL_MOUSE_IGNORE,PANEL_MAP_BACKGROUND);
		oapiRegisterPanelArea (AID_SWITCH_AUTO,           _R( 1331, 217, 1498, 250), PANEL_REDRAW_ALWAYS, PANEL_MOUSE_DOWN,PANEL_MAP_BACKGROUND);
		oapiRegisterPanelArea (AID_SWITCH_JET,           _R( 1127, 695, 1280, 748), PANEL_REDRAW_ALWAYS, PANEL_MOUSE_DOWN,PANEL_MAP_BACKGROUND);
		oapiRegisterPanelArea (AID_SWITCH_AUTO2,           _R( 1438, 331, 1502, 368), PANEL_REDRAW_ALWAYS, PANEL_MOUSE_DOWN,PANEL_MAP_BACKGROUND);
		oapiRegisterPanelArea (AID_SWITCH_HUD,           _R( 550, 550, 632,579 ), PANEL_REDRAW_ALWAYS, PANEL_MOUSE_DOWN,PANEL_MAP_BACKGROUND);
		oapiRegisterPanelArea (AID_FUEL_DIGIT,           _R( 520, 665, 586, 683), PANEL_REDRAW_ALWAYS, PANEL_MOUSE_IGNORE,PANEL_MAP_BACKGROUND);
		oapiRegisterPanelArea (AID_SWITCH_PANEL_RIGHT,           _R( 1318, 485, 1518, 705), PANEL_REDRAW_ALWAYS, PANEL_MOUSE_DOWN,PANEL_MAP_BACKGROUND);
		oapiRegisterPanelArea (AID_SWITCH_PANEL_LEFT,           _R( 482, 618, 691, 650), PANEL_REDRAW_ALWAYS, PANEL_MOUSE_DOWN,PANEL_MAP_BACKGROUND);
		oapiRegisterPanelArea (AID_GAUGES_CENTER,           _R( 787, 692, 898, 764), PANEL_REDRAW_ALWAYS, PANEL_MOUSE_DOWN,PANEL_MAP_BACKGROUND);
		oapiRegisterPanelArea (AID_LIGHTS_LAUNCHER,           _R( 908, 480, 1040, 768), PANEL_REDRAW_ALWAYS, PANEL_MOUSE_DOWN,PANEL_MAP_BACKGROUND);
		oapiRegisterPanelArea (AID_GMETER,           _R( 622, 451, 695, 529), PANEL_REDRAW_ALWAYS, PANEL_MOUSE_DOWN,PANEL_MAP_BACKGROUND);
		oapiRegisterPanelArea (AID_THRUSTMETER,           _R( 704, 685, 762, 743), PANEL_REDRAW_ALWAYS, PANEL_MOUSE_DOWN,PANEL_MAP_BACKGROUND);
		oapiRegisterPanelArea (AID_SPS,           _R( 436, 660, 488, 730), PANEL_REDRAW_ALWAYS, PANEL_MOUSE_DOWN,PANEL_MAP_BACKGROUND);
		oapiRegisterPanelArea (AID_EDS,           _R( 1099, 714, 1122, 737), PANEL_REDRAW_ALWAYS, PANEL_MOUSE_DOWN,PANEL_MAP_BACKGROUND);
		oapiRegisterPanelArea (AID_DSKY,           _R( 1203, 445, 1275, 575), PANEL_REDRAW_ALWAYS, PANEL_MOUSE_DOWN,PANEL_MAP_BACKGROUND);
        oapiRegisterPanelArea (AID_VSI,           _R( 502, 706, 570, 730), PANEL_REDRAW_ALWAYS, PANEL_MOUSE_IGNORE,PANEL_MAP_BACKGROUND);        
		oapiRegisterPanelArea (AID_CLOCK,           _R( 1348, 414, 1480, 435), PANEL_REDRAW_ALWAYS, PANEL_MOUSE_IGNORE,PANEL_MAP_BACKGROUND);        
		oapiRegisterPanelArea (AID_ALTIMETER  ,           _R( 933, 103, 1021, 191), PANEL_REDRAW_ALWAYS, PANEL_MOUSE_IGNORE,PANEL_MAP_BACKGROUND);        
		oapiRegisterPanelArea (AID_DSKY_KEY,           _R(1089,585,1289,671), PANEL_REDRAW_ALWAYS, PANEL_MOUSE_DOWN,PANEL_MAP_BACKGROUND);
		oapiRegisterPanelArea (AID_HDG1,           _R(770,470,842,477), PANEL_REDRAW_ALWAYS, PANEL_MOUSE_DOWN,PANEL_MAP_BACKGROUND);
		oapiRegisterPanelArea (AID_HDG2,           _R(1151,232,1223,239), PANEL_REDRAW_ALWAYS, PANEL_MOUSE_DOWN,PANEL_MAP_BACKGROUND);

		break;

	case 1: // overhead panel
		break;

	case 2: // bottom panel
		break;
	}
	InitPanel (id);
	return hBmp != NULL;
}

DLLCLBK bool ovcPanelMouseEvent (VESSEL *vessel, int id, int event, int mx, int my)
{
	int mfd;
	static int ctrl = 0;

	switch (id) {
	// panel 0 events:
	case AID_MFD1_BBUTTONS:
	case AID_MFD2_BBUTTONS:
		mfd = (id == AID_MFD1_BBUTTONS ? MFD_LEFT : MFD_RIGHT);
		if (mx < 17)                    oapiToggleMFD_on (mfd);
		else if (mx >= 145 && mx < 162) oapiSendMFDKey (mfd, OAPI_KEY_F1);
		else if (mx > 167)              oapiSendMFDKey (mfd, OAPI_KEY_GRAVE);
		return true;
	
	case AID_DSKY_KEY:	
	DKey0=false;
	DKey1=false;
	DKey2=false;
	DKey3=false;
	DKey4=false;
	DKey5=false;
	DKey6=false;
	DKey7=false;
	DKey8=false;
	DKey9=false;
	DKeyP=false;
	DKeyM=false;
	DKeyENTR=false;
	DKeyRESET=false;
	DKeyCLR=false;
	DKeySTBY=false;
	DKeyKRLS=false;
	DKeyVERB =false;
	DKeyNOUN=false;

		if (mx > 0 && mx < 26){
				if (my > 13 && my < 39){
					DKeyVERB =true;			
				}
				if (my > 45 && my < 69){
					DKeyNOUN =true;			
				}
		}else if (mx > 172 && mx < 200){
				if (my > 13 && my < 39){
					DKeyENTR=true;			
				}
				if (my > 45 && my < 69){
					DKeyRESET =true;			
				}
		}else if (mx > 27 && mx < 54){
				if (my > 2 && my < 25){
					DKeyP=true;			
				}
				if (my > 30 && my < 55){
					DKeyM =true;			
				}
				if (my > 60 && my < 85){
					DKey0 =true;			
				}
		}else if (mx > 57 && mx < 83){
				if (my > 2 && my < 25){
					DKey7=true;			
				}
				if (my > 30 && my < 55){
					DKey4 =true;			
				}
				if (my > 60 && my < 85){
					DKey1 =true;			
				}
		}else if (mx > 87 && mx < 112){
				if (my > 2 && my < 25){
					DKey8=true;			
				}
				if (my > 30 && my < 55){
					DKey5 =true;			
				}
				if (my > 60 && my < 85){
					DKey2 =true;			
				}
		}else if (mx > 117 && mx < 141){
				if (my > 2 && my < 25){
					DKey9=true;			
				}
				if (my > 30 && my < 55){
					DKey6 =true;			
				}
				if (my > 60 && my < 85){
					DKey3 =true;			
				}
		}else if (mx > 146 && mx < 169){
				if (my > 2 && my < 25){
					DKeyCLR=true;			
				}
				if (my > 30 && my < 55){
					DKeySTBY =true;			
				}
				if (my > 60 && my < 85){
					DKeyKRLS =true;			
				}
		}
	
		if(DKey0||DKey1||DKey2||DKey3||DKey4||DKey5||DKey6||DKey7||DKey8||DKey9||DKeyP||DKeyM||DKeyENTR||DKeyRESET||DKeyCLR||DKeySTBY||DKeyKRLS||DKeyVERB||DKeyNOUN){	
		PlayVesselWave(Sclick,NOLOOP,255);
		}
		return true;
	case AID_LIGHTS_LAUNCHER:
		if (mx > 39 && mx < 86 && my > 175 && my < 201){
		bAbort =true;
		}
		return true;
	case AID_PILOT1:
		
			if (my >32 && autopilot){
				autopilot =false;
				PlayVesselWave(Sclick,NOLOOP,255);
							
			}else if(!autopilot && my < 32){
				autopilot =true;
				PlayVesselWave(Sclick,NOLOOP,255);
				
			}
	return true;
	case AID_SWITCH_JET:
		if(event & PANEL_MOUSE_RBDOWN){
			if(mx <24 ){
			Cswitch1 = !Cswitch1;
			PlayVesselWave(Sclick,NOLOOP,255);
			}
			if(mx <54 && mx>29 ){
			Cswitch2 = !Cswitch2;
			PlayVesselWave(Sclick,NOLOOP,255);
			}
			if(mx <85 && mx>62 ){
			Cswitch3 = !Cswitch3;
			PlayVesselWave(Sclick,NOLOOP,255);
			}
			if(mx <115 && mx>92 ){
			Cswitch4 = !Cswitch4;
			PlayVesselWave(Sclick,NOLOOP,255);
			}
			if(mx <143 && mx>121 ){
			Cswitch5 = !Cswitch5;
			PlayVesselWave(Sclick,NOLOOP,255);
			}
			
		}else if(event & PANEL_MOUSE_LBDOWN){
			
			if(mx <24 && Cswitch1){
				if(my >19 && my <28 && !Sswitch1){
				Sswitch1 = true;
				PlayVesselWave(Sclick,NOLOOP,255);
				}else if(my >28 && my <38 && Sswitch1 && Cswitch1){
				Sswitch1 = false;
				PlayVesselWave(Sclick,NOLOOP,255);
				
				}
			}
			if(mx <54 && mx>29 && Cswitch2){
				if(my >19 && my <28 && !Sswitch2){
				Sswitch2 = true;
				PlayVesselWave(Sclick,NOLOOP,255);
				}else if(my >28 && my <38 && Sswitch2 && Cswitch2){
				Sswitch2 = false;
				PlayVesselWave(Sclick,NOLOOP,255);
				
				}
			}
			if(mx <85 && mx>62 && Cswitch3){
				if(my >19 && my <28 && !Sswitch3){
				Sswitch3 = true;
				PlayVesselWave(Sclick,NOLOOP,255);
				}else if(my >28 && my <38 && Sswitch3 && Cswitch3){
				Sswitch3 = false;
				PlayVesselWave(Sclick,NOLOOP,255);
				
				}
			}
			if(mx <115 && mx>92 && Cswitch4){
				if(my >19 && my <28 && !Sswitch4){
				Sswitch4 = true;
				PlayVesselWave(Sclick,NOLOOP,255);
				}else if(my >28 && my <38 && Sswitch4 && Cswitch4){
				Sswitch4 = false;
				PlayVesselWave(Sclick,NOLOOP,255);
				
				}
			}
			
			if(mx <143 && mx>121 && Cswitch5){
				if(my >19 && my <28 && !Sswitch5){
				Sswitch5 = true;
				PlayVesselWave(Sclick,NOLOOP,255);
				}else if(my >28 && my <38 && Sswitch5 && Cswitch5){
				Sswitch5 = false;
				PlayVesselWave(Sclick,NOLOOP,255);
				
				}
			}
			
			
		}
		
		return true;
	case AID_SWITCH_AUTO:
		if (mx >=7 && mx <=17 ){
			if (my < 17 && !vessel->GetNavmodeState(NAVMODE_KILLROT)){
				PlayVesselWave(Sclick,NOLOOP,255);
				vessel->ActivateNavmode(NAVMODE_KILLROT);
			}else if(my >17 && vessel->GetNavmodeState(NAVMODE_KILLROT)){
				PlayVesselWave(Sclick,NOLOOP,255);
				vessel->DeactivateNavmode(NAVMODE_KILLROT);
			}
		}
		if (mx >=37 && mx <=47 ){
			if ( my < 17 && !vessel->GetNavmodeState(NAVMODE_PROGRADE)){
				PlayVesselWave(Sclick,NOLOOP,255);
				vessel->ActivateNavmode(NAVMODE_PROGRADE);
			}else if(my >17 && vessel->GetNavmodeState(NAVMODE_PROGRADE)){
				PlayVesselWave(Sclick,NOLOOP,255);
				vessel->DeactivateNavmode(NAVMODE_PROGRADE);
			}
		}
		if (mx >=65 && mx <=75 ){
			if ( my < 17 && !vessel->GetNavmodeState(NAVMODE_RETROGRADE)){
				PlayVesselWave(Sclick,NOLOOP,255);
				vessel->ActivateNavmode(NAVMODE_RETROGRADE);
			}else if(my >17 && vessel->GetNavmodeState(NAVMODE_RETROGRADE)){
				PlayVesselWave(Sclick,NOLOOP,255);
				vessel->DeactivateNavmode(NAVMODE_RETROGRADE);
			}
		}
		if (mx >=108 && mx <=118 ){
			if (my < 17 && !vessel->GetNavmodeState(NAVMODE_NORMAL)){
				PlayVesselWave(Sclick,NOLOOP,255);
				vessel->ActivateNavmode(NAVMODE_NORMAL);
			}else if(my >17 && vessel->GetNavmodeState(NAVMODE_NORMAL)){
				PlayVesselWave(Sclick,NOLOOP,255);
				vessel->DeactivateNavmode(NAVMODE_NORMAL);
			}
		}
		if (mx >=144 && mx <=154 ){
			if (my >8 && my < 17 && !vessel->GetNavmodeState(NAVMODE_ANTINORMAL)){
				PlayVesselWave(Sclick,NOLOOP,255);
				vessel->ActivateNavmode(NAVMODE_ANTINORMAL);
			}else if(my >17 && my < 24 && vessel->GetNavmodeState(NAVMODE_ANTINORMAL)){
				PlayVesselWave(Sclick,NOLOOP,255);
				vessel->DeactivateNavmode(NAVMODE_ANTINORMAL);
			}
		}
	return true;

	case AID_SWITCH_AUTO2:
		if (mx >=7 && mx <=17 ){
			if (my < 15 && !vessel->GetNavmodeState(NAVMODE_HLEVEL)){
				PlayVesselWave(Sclick,NOLOOP,255);
				vessel->ActivateNavmode(NAVMODE_HLEVEL);
			}else if(my >15 && vessel->GetNavmodeState(NAVMODE_HLEVEL)){
				PlayVesselWave(Sclick,NOLOOP,255);
				vessel->DeactivateNavmode(NAVMODE_HLEVEL);
			}
		}
	if (mx >=37 && mx <=47 ){
			if (my < 15 && !vessel->GetNavmodeState(NAVMODE_HOLDALT)){
				PlayVesselWave(Sclick,NOLOOP,255);
				vessel->ActivateNavmode(NAVMODE_HOLDALT);
			}else if(my >15 && vessel->GetNavmodeState(NAVMODE_HOLDALT)){
				PlayVesselWave(Sclick,NOLOOP,255);
				vessel->DeactivateNavmode(NAVMODE_HOLDALT);
			}
		}
	return true;
	
	case AID_SWITCH_HUD:
		if (mx >=7 && mx <=17 ){//HUD_DOCKING
			if (my < 15 && oapiGetHUDMode() !=HUD_DOCKING){
				PlayVesselWave(Sclick,NOLOOP,255);
				oapiSetHUDMode(HUD_DOCKING) ;
			}else if(my >15 && oapiGetHUDMode() ==HUD_DOCKING){
				PlayVesselWave(Sclick,NOLOOP,255);
				oapiSetHUDMode(HUD_NONE) ;
			}
		}
	if (mx >=37 && mx <=47 ){//HUD_SURFACE
			if (my < 15 && oapiGetHUDMode() !=HUD_SURFACE){
				PlayVesselWave(Sclick,NOLOOP,255);
				oapiSetHUDMode(HUD_SURFACE) ;
			}else if(my >15 && oapiGetHUDMode() ==HUD_SURFACE){
				PlayVesselWave(Sclick,NOLOOP,255);
				oapiSetHUDMode(HUD_NONE) ;
			}
		}
	if (mx >=64 && mx <=74 ){//HUD_ORBIT
			if (my < 15 && oapiGetHUDMode() !=HUD_ORBIT){
				PlayVesselWave(Sclick,NOLOOP,255);
				oapiSetHUDMode(HUD_ORBIT) ;
			}else if(my >15 && oapiGetHUDMode() ==HUD_ORBIT){
				PlayVesselWave(Sclick,NOLOOP,255);
				oapiSetHUDMode(HUD_NONE) ;
			}
		}
	return true;
	case AID_SWITCH_PANEL_RIGHT:
	if (my >=6 && my <=15 ){
			if (mx > 8 && mx < 18 && !RPswitch1){
				PlayVesselWave(Sclick,NOLOOP,255);
				RPswitch1=true;
			}else if (mx > 39 && mx < 49 && !RPswitch2){
				PlayVesselWave(Sclick,NOLOOP,255);
				RPswitch2=true;
			}else if (mx > 69 && mx < 79 && !RPswitch3){
				PlayVesselWave(Sclick,NOLOOP,255);
				RPswitch3=true;
			}else if (mx > 124 && mx < 134 && !RPswitch4){
				PlayVesselWave(Sclick,NOLOOP,255);
				RPswitch4=true;
			}else if (mx > 154  && mx < 164 && !RPswitch5){
				PlayVesselWave(Sclick,NOLOOP,255);
				RPswitch5=true;
			}else if (mx > 183 && mx < 193 && !RPswitch6){
				PlayVesselWave(Sclick,NOLOOP,255);
				RPswitch6=true;
			}
			
	}else if (my >=15 && my <=25 ){
			if (mx >8 && mx < 18 && RPswitch1){
				PlayVesselWave(Sclick,NOLOOP,255);
				RPswitch1=false;
			}else if (mx >39 && mx < 49 && RPswitch2){
				PlayVesselWave(Sclick,NOLOOP,255);
				RPswitch2=false;
			}else if (mx >69 && mx < 79 && RPswitch3){
				PlayVesselWave(Sclick,NOLOOP,255);
				RPswitch3=false;
			}else if (mx >124 && mx < 134 && RPswitch4){
				PlayVesselWave(Sclick,NOLOOP,255);
				RPswitch4=false;
			}else if (mx >154 && mx < 164 && RPswitch5){
				PlayVesselWave(Sclick,NOLOOP,255);
				RPswitch5=false;
			}else if (mx >183 && mx < 193 && RPswitch6){
				PlayVesselWave(Sclick,NOLOOP,255);
				RPswitch6=false;
			}
	}else if (my >=100 && my <=110 ){
			if (mx >8 && mx < 18 && !RPswitch7){
				PlayVesselWave(Sclick,NOLOOP,255);
				RPswitch7=true;
			}else if (mx >39 && mx < 49 && !RPswitch8){
				PlayVesselWave(Sclick,NOLOOP,255);
				RPswitch8=true;
			}else if (mx >69 && mx < 79 && !RPswitch9){
				PlayVesselWave(Sclick,NOLOOP,255);
				RPswitch9=true;
			}else if (mx >117 && mx < 127 && !RPswitch10){
				PlayVesselWave(Sclick,NOLOOP,255);
				RPswitch10=true;
			}else if (mx >148 && mx < 158 && !RPswitch11){
				PlayVesselWave(Sclick,NOLOOP,255);
				RPswitch11=true;
			
			}
	}else if (my >=110 && my <=120 ){
			if (mx >8 && mx < 18 && RPswitch7){
				PlayVesselWave(Sclick,NOLOOP,255);
				RPswitch7=false;
			}else if (mx >39 && mx < 49 && RPswitch8){
				PlayVesselWave(Sclick,NOLOOP,255);
				RPswitch8=false;
			}else if (mx >69 && mx < 79 && RPswitch9){
				PlayVesselWave(Sclick,NOLOOP,255);
				RPswitch9=false;
			}else if (mx >117 && mx < 127 && RPswitch10){
				PlayVesselWave(Sclick,NOLOOP,255);
				RPswitch10=false;
			}else if (mx >148 && mx < 158 && RPswitch11){
				PlayVesselWave(Sclick,NOLOOP,255);
				RPswitch11=false;
			}
	}else if (my >=192 && my <=202 ){
			if (mx >8 && mx < 18 && !RPswitch12){
				PlayVesselWave(Sclick,NOLOOP,255);
				RPswitch12=true;
			}else if (mx >39 && mx < 49 && !RPswitch13 && RPswitch12){
				PlayVesselWave(Sclick,NOLOOP,255);
				RPswitch13=true;
			}else if (mx >69 && mx < 79 && !RPswitch14){
				PlayVesselWave(Sclick,NOLOOP,255);
				RPswitch14=true;
			}else if (mx >124 && mx < 134 && !RPswitch15){
				PlayVesselWave(Sclick,NOLOOP,255);
				RPswitch15=true;
			}else if (mx >154 && mx < 164 && !RPswitch16){
				PlayVesselWave(Sclick,NOLOOP,255);
				RPswitch16=true;
			}else if (mx >183 && mx < 193 && !RPswitch17){
				PlayVesselWave(Sclick,NOLOOP,255);
				RPswitch17=true;
			}
			
	}else if (my >=202 && my <=212 ){
			if (mx >8 && mx < 18 && RPswitch12 && !RPswitch13){
				PlayVesselWave(Sclick,NOLOOP,255);
				RPswitch12=false;
			}else if (mx >39 && mx < 49 && RPswitch13 ){
				PlayVesselWave(Sclick,NOLOOP,255);
				RPswitch13=false;
			}else if (mx >69 && mx < 79 && RPswitch14){
				PlayVesselWave(Sclick,NOLOOP,255);
				RPswitch14=false;
			}else if (mx >124 && mx < 134 && RPswitch15){
				PlayVesselWave(Sclick,NOLOOP,255);
				RPswitch15=false;
			}else if (mx >154 && mx < 164 && RPswitch16){
				PlayVesselWave(Sclick,NOLOOP,255);
				RPswitch16=false;
			}else if (mx >183 && mx < 193 && RPswitch17){
				PlayVesselWave(Sclick,NOLOOP,255);
				RPswitch17=false;
			}
	}
	
	return true;
	
	case AID_SWITCH_PANEL_LEFT:
	if (my >=5 && my <=15 ){
			if (mx >8 && mx < 18 && !LPswitch1){
				PlayVesselWave(Sclick,NOLOOP,255);
				LPswitch1=true;
			}else if (mx >39 && mx < 49 && !LPswitch2){
				PlayVesselWave(Sclick,NOLOOP,255);
				LPswitch2=true;
			}else if (mx >68 && mx < 78 && !LPswitch3){
				PlayVesselWave(Sclick,NOLOOP,255);
				LPswitch3=true;
			}else if (mx >99 && mx < 109 && !LPswitch4){
				PlayVesselWave(Sclick,NOLOOP,255);
				LPswitch4=true;
			}else if (mx >129 && mx < 139 && !LPswitch5){
				PlayVesselWave(Sclick,NOLOOP,255);
				LPswitch5=true;
				toggleRCS =true;
			}else if (mx >157 && mx < 167 && !LPswitch6){
				PlayVesselWave(Sclick,NOLOOP,255);
				LPswitch6=true;
			}else if (mx >189 && mx < 199 && !LPswitch7){
				PlayVesselWave(Sclick,NOLOOP,255);
				LPswitch7=true;
			}
			
	}else if (my >=16 && my <=26 ){
			if (mx >8 && mx < 18 && LPswitch1){
				PlayVesselWave(Sclick,NOLOOP,255);
				LPswitch1=false;
			}else if (mx >39 && mx < 49 && LPswitch2){
				PlayVesselWave(Sclick,NOLOOP,255);
				LPswitch2=false;
			}else if (mx >68 && mx < 78 && LPswitch3){
				PlayVesselWave(Sclick,NOLOOP,255);
				LPswitch3=false;
			}else if (mx >99 && mx < 109 && LPswitch4){
				PlayVesselWave(Sclick,NOLOOP,255);
				LPswitch4=false;
			}else if (mx >129 && mx < 139 && LPswitch5){
				PlayVesselWave(Sclick,NOLOOP,255);
				LPswitch5=false;
				toggleRCS =true;
			}else if (mx >157 && mx < 167 && LPswitch6){
				PlayVesselWave(Sclick,NOLOOP,255);
				LPswitch6=false;
			}else if (mx >189 && mx < 199 && LPswitch7){
				PlayVesselWave(Sclick,NOLOOP,255);
				LPswitch7=false;
			}
	}
	
		
	return true;
	//
	case AID_SPS:
			if (my >32 && SPSswitch){
				SPSswitch =false;
				PlayVesselWave(Sclick,NOLOOP,255);
							
			}else if(!SPSswitch && my < 32){
				SPSswitch =true;
				PlayVesselWave(Sclick,NOLOOP,255);
				
			}
		return true;
	case AID_EDS:
			if (my > 10 && EDSswitch){
				EDSswitch =false;
				PlayVesselWave(Sclick,NOLOOP,255);
							
			}else if(!EDSswitch && my < 10){
				EDSswitch =true;
				PlayVesselWave(Sclick,NOLOOP,255);
				
			}
		return true;

	case AID_MFD1_LBUTTONS:
	case AID_MFD1_RBUTTONS:
	case AID_MFD2_LBUTTONS:
	case AID_MFD2_RBUTTONS:
		if (my%27 < 16) {
			mfd = (id <= AID_MFD1_RBUTTONS ? MFD_LEFT : MFD_RIGHT);
			int bt = my/27 + (id == AID_MFD1_LBUTTONS || id == AID_MFD2_LBUTTONS ? 0 : 6);
			oapiProcessMFDButton (mfd, bt, event);
			return true;
		}
		break;

	// panel 1 events:
	}
	return false;

}

DLLCLBK bool ovcPanelRedrawEvent (VESSEL *vessel, int id, int event, SURFHANDLE surf)
{
	

	switch (id) {
	// panel 0 events:
	case AID_HDG1:
	case AID_HDG2:
		double cap;
		oapiGetHeading(vessel->GetHandle(),&cap);
		cap = cap * DEG;
		//cap = 359;
		oapiBlt(surf,srf[17],0,0,4+(cap/10*12),0,72,7);
		return true;
		//sprintf(oapiDebugString() ,"Heading %f",cap);
	case AID_HORIZON:
		RedrawPanel_Horizon (vessel,surf);
		return true;
	case AID_HORIZON2:
		RedrawPanel_Horizon (vessel,surf);
		return true;
	case AID_PILOT1:
		if(autopilot){
		oapiBlt(surf,srf[7],1,0,0,0,48,63);
		//sprintf(oapiDebugString() ,"Autopilot On" );
		}else{
		oapiBlt(surf,srf[7],0,0,49,0,48,63);
		//sprintf(oapiDebugString() ,"Autopilot Off" );
		}return true;
	case AID_SWITCH_AUTO:
		if(vessel->GetNavmodeState(NAVMODE_KILLROT)){
			oapiBlt(surf,srf[6],2,8,0,0,23,20);
		}else{
			oapiBlt(surf,srf[6],2,8,24,0,23,20);
		}
		if(vessel->GetNavmodeState(NAVMODE_PROGRADE)){
			oapiBlt(surf,srf[6],33,8,0,0,23,20);
		}else{
			oapiBlt(surf,srf[6],31,8,24,0,23,20);
		}
		if(vessel->GetNavmodeState(NAVMODE_RETROGRADE)){
			oapiBlt(surf,srf[6],61,8,0,0,23,20);
		}else{
			oapiBlt(surf,srf[6],59,8,24,0,23,20);
		}
		if(vessel->GetNavmodeState(NAVMODE_NORMAL)){
			oapiBlt(surf,srf[6],102,8,0,0,23,20);
		}else{
			oapiBlt(surf,srf[6],100,8,24,0,23,20);
		}
		if(vessel->GetNavmodeState(NAVMODE_ANTINORMAL)){
			oapiBlt(surf,srf[6],140,8,0,0,23,20);
		}else{
			oapiBlt(surf,srf[6],138,8,24,0,23,20);
		}return true;
	
	case AID_SWITCH_HUD:
		if(oapiGetHUDMode() == HUD_DOCKING){
			oapiBlt(surf,srf[6],1,6,0,0,23,20);
		}else{
			oapiBlt(surf,srf[6],1,6,24,0,23,20);
		}
		if(oapiGetHUDMode() == HUD_SURFACE){
			oapiBlt(surf,srf[6],30,6,0,0,23,20);
		}else{
			oapiBlt(surf,srf[6],30,6,24,0,23,20);
		}
		if(oapiGetHUDMode() == HUD_ORBIT){
			oapiBlt(surf,srf[6],59,6,0,0,23,20);
		}else{
			oapiBlt(surf,srf[6],59,6,24,0,23,20);
		}return true;

	case AID_SWITCH_AUTO2:
		if(vessel->GetNavmodeState(NAVMODE_HLEVEL)){
			oapiBlt(surf,srf[6],2,4,0,0,23,20);
		}else{
			oapiBlt(surf,srf[6],2,4,24,0,23,20);
		}
		if(vessel->GetNavmodeState(NAVMODE_HOLDALT)){
			oapiBlt(surf,srf[6],31,4,0,0,23,20);
		}else{
			oapiBlt(surf,srf[6],31,4,24,0,23,20);
		}return true;	
	case AID_ALTIMETER  :
		RedrawPanel_Alt(vessel,surf);
		return true;
	case AID_GMETER  :
		RedrawPanel_G(vessel,surf);
		return true;
	case AID_THRUSTMETER  :
		RedrawPanel_Thrust(vessel,surf);
		return true;
	
	
	case AID_SWITCH_JET:
		
		if(Cswitch1){
			oapiBlt(surf,srf[8],2,0,29,0,27,49);
			if(Sswitch1){
			oapiBlt(surf,srf[6],3,20,0,0,23,20);
			}else{
			oapiBlt(surf,srf[6],3,20,24,0,23,20);
			}
		}else{
			oapiBlt(surf,srf[8],2,0,0,0,27,49);
			Sswitch1=false;
		}
		if(Cswitch2){
			oapiBlt(surf,srf[8],30,0,29,0,27,49);
			if(Sswitch2){
			oapiBlt(surf,srf[6],31,20,0,0,23,20);
			}else{
			oapiBlt(surf,srf[6],31,20,24,0,23,20);
			}
		}else{
			oapiBlt(surf,srf[8],30,0,0,0,27,49);
			Sswitch2=false;
		}
		if(Cswitch3){
			oapiBlt(surf,srf[8],62,0,89,0,27,49);
			if(Sswitch3){
			oapiBlt(surf,srf[6],63,20,0,0,23,20);
			}else{
			oapiBlt(surf,srf[6],63,20,24,0,23,20);
			}
		}else{
			oapiBlt(surf,srf[8],62,0,60,0,27,49);
			Sswitch3=false;
		}
		if(Cswitch4){
			oapiBlt(surf,srf[8],92,0,89,0,27,49);
			if(Sswitch4){
			oapiBlt(surf,srf[6],93,20,0,0,23,20);
			}else{
			oapiBlt(surf,srf[6],93,20,24,0,23,20);
			}
		}else{
			oapiBlt(surf,srf[8],92,0,60,0,27,49);
			Sswitch4=false;
		}
		if(Cswitch5){
			oapiBlt(surf,srf[8],120,0,29,0,27,49);
			if(Sswitch5){
			oapiBlt(surf,srf[6],121,20,0,0,23,20);
			}else{
			oapiBlt(surf,srf[6],121,20,24,0,23,20);
			}
		}else{
			oapiBlt(surf,srf[8],120,0,0,0,27,49);
			Sswitch5=false;
		}
		return true;		
		
	case AID_INDICATOR1:
		if(status < 5){
			if (autopilot){
			oapiBlt(surf,srf[1],0,0,105,0,105,18);
			}else{
			oapiBlt(surf,srf[1],0,0,210,0,105,18);
			}
		}else{
		oapiBlt(surf,srf[1],0,0,0,0,105,18);
		}
		if(vessel->GetNavmodeState(NAVMODE_KILLROT)){
			oapiBlt(surf,srf[1],0,91,105,95,105,18);
		}else{
			oapiBlt(surf,srf[1],0,91,0,95,105,18);
		}
		if(vessel->GetNavmodeState(NAVMODE_PROGRADE)){
			oapiBlt(surf,srf[1],0,19,105,21,105,18);
		}else{
			oapiBlt(surf,srf[1],0,19,0,21,105,18);
		}if(vessel->GetNavmodeState(NAVMODE_RETROGRADE)){
			oapiBlt(surf,srf[1],0,37,105,39,105,18);
		}else{
			oapiBlt(surf,srf[1],0,37,0,39,105,18);
		}if(vessel->GetNavmodeState(NAVMODE_NORMAL)){
			oapiBlt(surf,srf[1],0,54,105,56,105,18);
		}else{
			oapiBlt(surf,srf[1],0,54,0,56,105,18);
		}if(vessel->GetNavmodeState(NAVMODE_ANTINORMAL)){
			oapiBlt(surf,srf[1],0,72,105,74,105,18);
		}else{
			oapiBlt(surf,srf[1],0,72,0,74,105,18);
		}
		if(vessel->GetNavmodeState(NAVMODE_HLEVEL)){
			oapiBlt(surf,srf[1],0,108,105,112,105,18);
		}else{
			oapiBlt(surf,srf[1],0,108,0,112,105,18);
		}
		if(vessel->GetNavmodeState(NAVMODE_HOLDALT)){
			oapiBlt(surf,srf[1],0,126,105,129,105,14);
		}else{
			oapiBlt(surf,srf[1],0,126,0,129,105,14);
		}
		return true;
	case AID_GAUGES1:
		double DispValue;
		if (!ph_sps){
			if(status<5){
				DispValue = 1;
			}else{
				DispValue = 0;
			}
		}else{
		DispValue = vessel->GetPropellantMass(ph_sps)/20500;
		}
		oapiBlt(surf,srf[2],0,(90-(DispValue)*90),0,0,6,4);//
		oapiBlt(surf,srf[2],31,(90-(DispValue)*90),10,0,6,4);//
		if (!ph_rcs0){
			if(status<5){
				DispValue = 1;
			}else{
				DispValue = 0;
			}
		}else{
		DispValue = vessel->GetPropellantMass(ph_rcs0)/500;
		}
		oapiBlt(surf,srf[2],65,(90-(DispValue)*90),0,0,6,4);//
		if (!ph_rcs1){
			if(status<6){
				DispValue = 1;
			}else{
				DispValue = 0;
			}
		}else{
		DispValue = vessel->GetPropellantMass(ph_rcs1)/500;
		}
		
		oapiBlt(surf,srf[2],96,(90-(DispValue)*90),10,0,6,4);//
		
		return true;
	case AID_GAUGES_CENTER:

		
		if (!ph_1st){
			if(status<1){
				DispValue = 1;
			}else{
				DispValue = 0;
			}
		}else{
		DispValue = vessel->GetPropellantMass(ph_1st)/2246000;
		}
		oapiBlt(surf,srf[2],8,(60-(DispValue)*60)+5,0,0,6,4);//
		oapiBlt(surf,srf[2],18,(60-(DispValue)*60)+5,10,0,6,4);//
		oapiBlt(surf,srf[2],35,(60-(DispValue)*60)+5,0,0,6,4);//
		oapiBlt(surf,srf[2],46,(60-(DispValue)*60)+5,10,0,6,4);//
		
		if (!ph_2nd){
			if(status<4){
				DispValue = 1;
			}else{
				DispValue = 0;
			}
		}else{
		DispValue = vessel->GetPropellantMass(ph_2nd)/471000;
		}
		oapiBlt(surf,srf[2],62,(60-(DispValue)*60)+5,0,0,6,4);//
		oapiBlt(surf,srf[2],71,(60-(DispValue)*60)+5,10,0,6,4);//
		if (!ph_3rd){
			if(status<4){
				DispValue = 1;
			}else{
				DispValue = 0;
			}
		}else{
		DispValue = vessel->GetPropellantMass(ph_3rd)/114000;
		}
		oapiBlt(surf,srf[2],90,(60-(DispValue)*60)+5,0,0,6,4);//
		oapiBlt(surf,srf[2],99,(60-(DispValue)*60)+5,10,0,6,4);//
		
		return true;

	case AID_VELOCITY1:
		int Curdigit;
		int Curdigit2;
		Curdigit=actualVEL/10000;
		oapiBlt(surf,srf[4],0,0,10*Curdigit,0,10,15);
		Curdigit=actualVEL/1000;
		Curdigit2=actualVEL/10000;
		oapiBlt(surf,srf[4],10,0,10*(Curdigit-(Curdigit2*10)),0,10,15);
		Curdigit=actualVEL/100;
		Curdigit2=actualVEL/1000;
		oapiBlt(surf,srf[4],20,0,10*(Curdigit-(Curdigit2*10)),0,10,15);
		Curdigit=actualVEL/10;
		Curdigit2=actualVEL/100;
		oapiBlt(surf,srf[4],30,0,10*(Curdigit-(Curdigit2*10)),0,10,15);
		Curdigit=actualVEL;
		Curdigit2=actualVEL/10;
		oapiBlt(surf,srf[4],40,0,10*(Curdigit-(Curdigit2*10)),0,10,15);
		return true;
	
	case AID_VSI:
			
		Curdigit=fabs(VSPEEDN1)/10000;
		oapiBlt(surf,srf[4],10,0,10*Curdigit,0,10,15);
		Curdigit=fabs(VSPEEDN1)/1000;
		Curdigit2=fabs(VSPEEDN1)/10000;
		oapiBlt(surf,srf[4],20,0,10*(Curdigit-(Curdigit2*10)),0,10,15);
		Curdigit=fabs(VSPEEDN1)/100;
		Curdigit2=fabs(VSPEEDN1)/1000;
		oapiBlt(surf,srf[4],30,0,10*(Curdigit-(Curdigit2*10)),0,10,15);
		Curdigit=fabs(VSPEEDN1)/10;
		Curdigit2=fabs(VSPEEDN1)/100;
		oapiBlt(surf,srf[4],40,0,10*(Curdigit-(Curdigit2*10)),0,10,15);
		Curdigit=fabs(VSPEEDN1);
		Curdigit2=fabs(VSPEEDN1)/10;
		oapiBlt(surf,srf[4],50,0,10*(Curdigit-(Curdigit2*10)),0,10,15);

		if (VSPEEDN1 < 0){
		oapiBlt(surf,srf[4],0,0,100,0,10,15);
		}else{
		oapiBlt(surf,srf[4],0,0,110,0,10,15);
		}
		return true;
		
	case AID_FUEL_DIGIT:
		int TmpFUEL;
		double tmpFUELdec;
		int tmpfuel2;
		
		TmpFUEL = actualFUEL;
		tmpFUELdec = actualFUEL-TmpFUEL;
		tmpfuel2 = tmpFUELdec *100;
		

		Curdigit=actualFUEL/100;
		oapiBlt(surf,srf[4],0,0,10*Curdigit,0,10,15);
		Curdigit=actualFUEL/10;
		Curdigit2=actualFUEL/100;
		oapiBlt(surf,srf[4],10,0,10*(Curdigit-(Curdigit2*10)),0,10,15);
		Curdigit=actualFUEL;
		Curdigit2=actualFUEL/10;
		oapiBlt(surf,srf[4],20,0,10*(Curdigit-(Curdigit2*10)),0,10,15);
		
		oapiBlt(surf,srf[4],30,0,140,0,10,15);//dot display
		
		Curdigit=tmpfuel2/10 ;
		Curdigit2=tmpfuel2 /100;
		oapiBlt(surf,srf[4],40,0,10*(Curdigit-(Curdigit2*10)),0,10,15);
//		Curdigit=tmpfuel2 ;
//		Curdigit2=tmpfuel2 /10;
//		oapiBlt(surf,srf[4],50,0,10*(Curdigit-(Curdigit2*10)),0,10,15);


		return true;
	
	
	case AID_ALTITUDE1:
		int TmpALT;
		double tmpALTdec;
		int tmpalt2;
		if (actualALT > 999999){
		actualALT = actualALT /1000000;
		oapiBlt(surf,srf[4],85,0,130,0,10,15);	
		}else if (actualALT > 9999){
		actualALT =actualALT /1000;
		oapiBlt(surf,srf[4],85,0,120,0,10,15);	
		}
		
		TmpALT = actualALT;
		tmpALTdec = actualALT-TmpALT;
		tmpalt2 = tmpALTdec *100;
		
		Curdigit=actualALT/10000;
		oapiBlt(surf,srf[4],0,0,10*Curdigit,0,10,15);
		Curdigit=actualALT/1000;
		Curdigit2=actualALT/10000;
		oapiBlt(surf,srf[4],10,0,10*(Curdigit-(Curdigit2*10)),0,10,15);
		Curdigit=actualALT/100;
		Curdigit2=actualALT/1000;
		oapiBlt(surf,srf[4],20,0,10*(Curdigit-(Curdigit2*10)),0,10,15);
		Curdigit=actualALT/10;
		Curdigit2=actualALT/100;
		oapiBlt(surf,srf[4],30,0,10*(Curdigit-(Curdigit2*10)),0,10,15);
		Curdigit=actualALT;
		Curdigit2=actualALT/10;
		oapiBlt(surf,srf[4],40,0,10*(Curdigit-(Curdigit2*10)),0,10,15);
		oapiBlt(surf,srf[4],50,0,140,0,10,15);//dot display
		
		Curdigit=tmpalt2/10 ;
		Curdigit2=tmpalt2 /100;
		oapiBlt(surf,srf[4],60,0,10*(Curdigit-(Curdigit2*10)),0,10,15);
		Curdigit=tmpalt2 ;
		Curdigit2=tmpalt2 /10;
		oapiBlt(surf,srf[4],70,0,10*(Curdigit-(Curdigit2*10)),0,10,15);
		return true;
	case AID_CLOCK:
		int TmpCLKHR;
		int TmpCLKMNT;
		int TmpCLKsec;
		
		
		TmpCLKHR = autopTime/3600;
		TmpCLKMNT = ((autopTime-(TmpCLKHR*3600))/60);
		TmpCLKsec = ((autopTime-((TmpCLKHR*3600)+TmpCLKMNT*60)));
		
		// Hour display on three digit 
		Curdigit=TmpCLKHR/100;
		Curdigit2=TmpCLKHR/1000;
		oapiBlt(surf,srf[4],4,0, 10*(Curdigit-(Curdigit2*10)),0,10,15);
		Curdigit=TmpCLKHR/10;
		Curdigit2=TmpCLKHR/100;
		oapiBlt(surf,srf[4],4+10,0, 10*(Curdigit-(Curdigit2*10)),0,10,15);
		Curdigit=TmpCLKHR;
		Curdigit2=TmpCLKHR/10;
		oapiBlt(surf,srf[4],4+20,0, 10*(Curdigit-(Curdigit2*10)),0,10,15);
		oapiBlt(surf,srf[4],4+30,0, 140,0,10,15);
		// Minute display on five digit 
		Curdigit=TmpCLKMNT/10;
		Curdigit2=TmpCLKMNT/100;
		oapiBlt(surf,srf[4],4+40,0, 10*(Curdigit-(Curdigit2*10)),0,10,15);
		Curdigit=TmpCLKMNT;
		Curdigit2=TmpCLKMNT/10;
		oapiBlt(surf,srf[4],4+50,0, 10*(Curdigit-(Curdigit2*10)),0,10,15);
		oapiBlt(surf,srf[4],4+60,0, 140,0,10,15);
		// second display on five digit 
		Curdigit=TmpCLKsec/10;
		Curdigit2=TmpCLKsec/100;
		oapiBlt(surf,srf[4],4+70,0, 10*(Curdigit-(Curdigit2*10)),0,10,15);
		Curdigit=TmpCLKsec;
		Curdigit2=TmpCLKsec/10;
		oapiBlt(surf,srf[4],4+80,0, 10*(Curdigit-(Curdigit2*10)),0,10,15);
		
		
		
		return true;

	case AID_DSKY:		
		
		Curdigit=DPROG/10;
		Curdigit2=DPROG/100;
		oapiBlt(surf,srf[4],46,10,10*(Curdigit-(Curdigit2*10)),0,10,15);
		Curdigit=DPROG;
		Curdigit2=DPROG/10;
		oapiBlt(surf,srf[4],56,10,10*(Curdigit-(Curdigit2*10)),0,10,15);
		
		
		Curdigit=VERB/10;
		Curdigit2=VERB/100;
		oapiBlt(surf,srf[4],4,34,10*(Curdigit-(Curdigit2*10)),0,10,15);
		Curdigit=VERB;
		Curdigit2=VERB/10;
		oapiBlt(surf,srf[4],14,34,10*(Curdigit-(Curdigit2*10)),0,10,15);
		
		Curdigit=NOUN/10;
		Curdigit2=NOUN/100;
		oapiBlt(surf,srf[4],46,34,10*(Curdigit-(Curdigit2*10)),0,10,15);
		Curdigit=NOUN;
		Curdigit2=NOUN/10;
		oapiBlt(surf,srf[4],56,34,10*(Curdigit-(Curdigit2*10)),0,10,15);
		

		Curdigit=fabs(R1)/10000;
		oapiBlt(surf,srf[4],4+6,54,10*Curdigit,0,10,15);
		Curdigit=fabs(R1)/1000;
		Curdigit2=fabs(R1)/10000;
		oapiBlt(surf,srf[4],4+16,54,10*(Curdigit-(Curdigit2*10)),0,10,15);
		Curdigit=fabs(R1)/100;
		Curdigit2=fabs(R1)/1000;
		oapiBlt(surf,srf[4],4+26,54,10*(Curdigit-(Curdigit2*10)),0,10,15);
		Curdigit=fabs(R1)/10;
		Curdigit2=fabs(R1)/100;
		oapiBlt(surf,srf[4],4+36,54,10*(Curdigit-(Curdigit2*10)),0,10,15);
		Curdigit=fabs(R1);
		Curdigit2=fabs(R1)/10;
		oapiBlt(surf,srf[4],4+46,54,10*(Curdigit-(Curdigit2*10)),0,10,15);
		if (R1<0){
		oapiBlt(surf,srf[4],0,54,100,0,10,15);
		}else{
		oapiBlt(surf,srf[4],0,54,110,0,10,15);
		}
		
		// Minute display on five digit (Dsky mode)
		Curdigit=fabs(R2)/10000;
		oapiBlt(surf,srf[4],4+6,78,10*Curdigit,0,10,15);
		Curdigit=fabs(R2)/1000;
		Curdigit2=fabs(R2)/10000;
		oapiBlt(surf,srf[4],4+16,78,10*(Curdigit-(Curdigit2*10)),0,10,15);
		Curdigit=fabs(R2)/100;
		Curdigit2=fabs(R2)/1000;
		oapiBlt(surf,srf[4],4+26,78,10*(Curdigit-(Curdigit2*10)),0,10,15);
		Curdigit=fabs(R2)/10;
		Curdigit2=fabs(R2)/100;
		oapiBlt(surf,srf[4],4+36,78,10*(Curdigit-(Curdigit2*10)),0,10,15);
		Curdigit=fabs(R2);
		Curdigit2=fabs(R2)/10;
		oapiBlt(surf,srf[4],4+46,78,10*(Curdigit-(Curdigit2*10)),0,10,15);
		if (R2<0){
		oapiBlt(surf,srf[4],0,78,100,0,10,15);
		}else{
		oapiBlt(surf,srf[4],0,78,110,0,10,15);
		}

		// second display on five digit (Dsky mode)
		Curdigit=fabs(R3)/10000;
		oapiBlt(surf,srf[4],4+6,100,10*Curdigit,0,10,15);
		Curdigit=fabs(R3)/1000;
		Curdigit2=fabs(R3)/10000;
		oapiBlt(surf,srf[4],4+16,100,10*(Curdigit-(Curdigit2*10)),0,10,15);
		Curdigit=fabs(R3)/100;
		Curdigit2=fabs(R3)/1000;
		oapiBlt(surf,srf[4],4+26,100,10*(Curdigit-(Curdigit2*10)),0,10,15);
		Curdigit=fabs(R3)/10;
		Curdigit2=fabs(R3)/100;
		oapiBlt(surf,srf[4],4+36,100,10*(Curdigit-(Curdigit2*10)),0,10,15);
		Curdigit=fabs(R3);
		Curdigit2=fabs(R3)/10;
		oapiBlt(surf,srf[4],4+46,100,10*(Curdigit-(Curdigit2*10)),0,10,15);
		if (R3<0){
		oapiBlt(surf,srf[4],0,100,100,0,10,15);
		}else{
		oapiBlt(surf,srf[4],0,100,110,0,10,15);
		}
		
		
		return true;
	case AID_SPS:
		if(SPSswitch){
		oapiBlt(surf,srf[7],1,0,0,0,48,63);
		}else{
		oapiBlt(surf,srf[7],0,0,49,0,48,63);
		}
		return true;
	case AID_SWITCH_PANEL_RIGHT:
		if(RPswitch1){
			oapiBlt(surf,srf[6],3,6,0,0,23,20);
		}else{
			oapiBlt(surf,srf[6],2,6,24,0,23,20);
		}
		if(RPswitch2){
			oapiBlt(surf,srf[6],33,6,0,0,23,20);
		}else{
			oapiBlt(surf,srf[6],32,6,24,0,23,20);
		}
		if(RPswitch3){
			oapiBlt(surf,srf[6],63,6,0,0,23,20);
		}else{
			oapiBlt(surf,srf[6],62,6,24,0,23,20);
		}
		if(RPswitch4){
			oapiBlt(surf,srf[6],119,6,0,0,23,20);
		}else{
			oapiBlt(surf,srf[6],119,6,24,0,23,20);
		}
		if(RPswitch5){
			oapiBlt(surf,srf[6],149,6,0,0,23,20);
		}else{
			oapiBlt(surf,srf[6],148,6,24,0,23,20);
		}
		if(RPswitch6){
			oapiBlt(surf,srf[6],178,6,0,0,22,20);
		}else{
			oapiBlt(surf,srf[6],178,6,24,0,22,20);
		}
		if(RPswitch7){
			oapiBlt(surf,srf[6],4,100,0,0,23,20);
		}else{
			oapiBlt(surf,srf[6],3,100,24,0,23,20);
		}
		if(RPswitch8){
			oapiBlt(surf,srf[6],35,100,0,0,23,20);
		}else{
			oapiBlt(surf,srf[6],35,100,24,0,23,20);
		}
		if(RPswitch9){
			oapiBlt(surf,srf[6],64,100,0,0,23,20);
		}else{
			oapiBlt(surf,srf[6],64,100,24,0,23,20);
		}
		if(RPswitch10){
			oapiBlt(surf,srf[6],111,100,0,0,23,20);
		}else{
			oapiBlt(surf,srf[6],111,100,24,0,23,20);
		}
		if(RPswitch11){
			oapiBlt(surf,srf[6],142,100,0,0,23,20);
		}else{
			oapiBlt(surf,srf[6],142,100,24,0,23,20);
		}
		if(RPswitch12){
			oapiBlt(surf,srf[6],3,192,0,0,23,20);
			oapiBlt(surf,srf[13],9,154,35,0,17,17);
		}else{
			oapiBlt(surf,srf[6],3,192,24,0,23,20);
			oapiBlt(surf,srf[13],9,154,18,0,17,17);
		}
		if(RPswitch13){
			oapiBlt(surf,srf[13],37,154,35,0,17,17);
			oapiBlt(surf,srf[6],34,192,0,0,23,20);
		}else{
			oapiBlt(surf,srf[13],37,154,18,0,17,17);
			oapiBlt(surf,srf[6],33,192,24,0,23,20);
		}
		if(RPswitch14){
			oapiBlt(surf,srf[6],64,192,0,0,23,20);
		}else{
			oapiBlt(surf,srf[6],63,192,24,0,23,20);
		}
		if(RPswitch15){
			oapiBlt(surf,srf[6],116,192,0,0,23,20);
			if ( ActivateS4B ||ActivateLEM){//
			oapiBlt(surf,srf[13],121,154,18,0,17,17);
			}else{
			oapiBlt(surf,srf[13],121,154,35,0,17,17);
			}
		}else{
			oapiBlt(surf,srf[13],121,154,35,0,17,17);
			oapiBlt(surf,srf[6],115,192,24,0,23,20);
		}
		if(RPswitch16){
			oapiBlt(surf,srf[6],145,192,0,0,23,20);
			if ( ActivateS4B ){//
			oapiBlt(surf,srf[13],149,154,18,0,17,17);
			}else{
			oapiBlt(surf,srf[13],149,154,35,0,17,17);
			}
		}else{
			oapiBlt(surf,srf[13],149,154,35,0,17,17);
			oapiBlt(surf,srf[6],145,192,24,0,23,20);
		}
		if(RPswitch17){
			oapiBlt(surf,srf[6],176,192,0,0,21,20);
		}else{
			oapiBlt(surf,srf[6],176,192,24,0,21,20);
		}

	return true;
	
	case AID_EDS:
		if(EDSswitch){
			oapiBlt(surf,srf[6],0,0,0,0,23,20);
		}else{
			oapiBlt(surf,srf[6],0,0,24,0,23,20);
		}
		return true;
	case AID_SWITCH_PANEL_LEFT:
		
		
		if(LPswitch1){
			oapiBlt(surf,srf[6],3,6,0,0,23,20);
		}else{
			oapiBlt(surf,srf[6],2,6,24,0,23,20);
		}
		if(LPswitch2){
			oapiBlt(surf,srf[6],33,7,0,0,23,20);
		}else{
			oapiBlt(surf,srf[6],32,6,24,0,23,20);
		}
		if(LPswitch3){
			oapiBlt(surf,srf[6],63,6,0,0,23,20);
		}else{
			oapiBlt(surf,srf[6],62,6,24,0,23,20);
		}
		if(LPswitch4){
			oapiBlt(surf,srf[6],94,7,0,0,23,20);
		}else{
			oapiBlt(surf,srf[6],93,7,24,0,23,20);
		}
		if(LPswitch5){
			oapiBlt(surf,srf[6],124,7,0,0,23,20);
		}else{
			oapiBlt(surf,srf[6],123,7,24,0,23,20);
		}
		if(LPswitch6){
			oapiBlt(surf,srf[6],154,7,0,0,23,20);
		}else{
			oapiBlt(surf,srf[6],153,7,24,0,23,20);
		}
		if(LPswitch7){
			oapiBlt(surf,srf[6],184,7,0,0,23,20);
		}else{
			oapiBlt(surf,srf[6],183,7,24,0,23,20);
		}

	return true;
	case AID_LIGHTS_LAUNCHER:
		if (LAUNCHIND[0]){
		oapiBlt(surf,srf[11],13,208,115,6,25,22);
		}else{
		oapiBlt(surf,srf[11],13,208,5,6,25,22);
		}
		if (LAUNCHIND[1]){
		oapiBlt(surf,srf[11],88,208,190,6,25,22);
		}else{
		oapiBlt(surf,srf[11],88,208,80,6,25,22);
		}
		if (LAUNCHIND[2]){
		oapiBlt(surf,srf[11],13,242,115,40,25,22);
		}else{
		oapiBlt(surf,srf[11],13,242,5,40,25,22);
		}
		if (LAUNCHIND[3]){
		oapiBlt(surf,srf[11],88,242,190,40,25,22);
		}else{
		oapiBlt(surf,srf[11],88,242,80,40,25,22);
		}
		if (LAUNCHIND[4]){
		oapiBlt(surf,srf[11],13,274,115,72,25,13);
		}else{
		oapiBlt(surf,srf[11],13,274,5,72,25,13);
		}
		if (LAUNCHIND[5]){
		oapiBlt(surf,srf[11],88,274,190,72,25,13);
		}else{
		oapiBlt(surf,srf[11],88,274,80,72,25,13);
		}
		if (LAUNCHIND[6]){
		oapiBlt(surf,srf[10],30,12,39,0,38,37);
		}else{
		oapiBlt(surf,srf[10],30,12,0,0,38,37);
		}
		if (LAUNCHIND[7]){
		oapiBlt(surf,srf[10],75,12,78,0,38,37);
		}else{
		oapiBlt(surf,srf[10],75,12,0,0,38,37);
		}
		if (ABORT_IND){
		oapiBlt(surf,srf[9],39,176,47,0,46,24);
		}else{
		oapiBlt(surf,srf[9],39,176,0,0,46,24);
		}
		if (ENGIND[0]){
		oapiBlt(surf,srf[12],70,99,37,33,16,16);
		}else{
		oapiBlt(surf,srf[12],70,99,105,33,16,16);
		}
		if (ENGIND[1]){
		oapiBlt(surf,srf[12],70,136,37,71,16,16);
		}else{
		oapiBlt(surf,srf[12],70,136,105,71,16,16);
		}
		if (ENGIND[2]){
		oapiBlt(surf,srf[12],48,136,15,71,16,16);
		}else{
		oapiBlt(surf,srf[12],48,136,83,71,16,16);
		}
		if (ENGIND[3]){
		oapiBlt(surf,srf[12],48,99,17,33,16,16);
		}else{
		oapiBlt(surf,srf[12],48,99,84,33,16,16);
		}
		if (ENGIND[4]){
		oapiBlt(surf,srf[12],58,118,25,52,16,16);
		}else{
		oapiBlt(surf,srf[12],58,118,93,52,16,16);
		}
		if (ENGIND[5]){
		oapiBlt(surf,srf[12],40,72,6,5,16,16);
		}else{
		oapiBlt(surf,srf[12],40,72,74,5,16,16);
		}
		if (ENGIND[6]){
		oapiBlt(surf,srf[12],60,72,27,5,16,16);
		}else{
		oapiBlt(surf,srf[12],60,72,95,5,16,16);
		}
		if (ENGIND[7]){
		oapiBlt(surf,srf[12],81,72,47,5,16,16);
		}else{
		oapiBlt(surf,srf[12],81,72,115,5,16,16);
		}
		return true;		
	}
	return false;
}

DLLCLBK void ovcMFDmode (VESSEL *vessel, int mfd, int mode)
{
	switch (mfd) {
	case MFD_LEFT:
		oapiTriggerPanelRedrawArea (0, AID_MFD1_LBUTTONS);
		oapiTriggerPanelRedrawArea (0, AID_MFD1_RBUTTONS);
		break;
	case MFD_RIGHT:
		oapiTriggerPanelRedrawArea (0, AID_MFD2_LBUTTONS);
		oapiTriggerPanelRedrawArea (0, AID_MFD2_RBUTTONS);
		break;
	}
}
DLLCLBK VESSEL *ovcInit (OBJHANDLE hvessel, int flightmodel)
{
	if (!refcount++) {
		hsat5stg1 = oapiLoadMeshGlobal ("sat5stg1");
		hsat5intstg = oapiLoadMeshGlobal ("sat5intstg");
		hsat5stg2 = oapiLoadMeshGlobal ("sat5stg2");
		hsat5stg3 = oapiLoadMeshGlobal ("sat5stg3");
		hsat5stg31 = oapiLoadMeshGlobal ("sat5stg31");
		hsat5stg32 = oapiLoadMeshGlobal ("sat5stg32");
		hsat5stg33 = oapiLoadMeshGlobal ("sat5stg33");
		hsat5stg34 = oapiLoadMeshGlobal ("sat5stg34");
		hsat5tower = oapiLoadMeshGlobal ("sat5BPC");
		hCM = oapiLoadMeshGlobal ("Sat5CM");//("Apollo_CM")
		hCM2 = oapiLoadMeshGlobal ("Sat5CM2");
	//	hCM = oapiLoadMeshGlobal ("Saturn1_CM");//("Apollo_CM")
	//	hCM2 = oapiLoadMeshGlobal ("Saturn1_CM2");
		hSM = oapiLoadMeshGlobal ("nSaturn1_SM");
		hCMBALLOON = oapiLoadMeshGlobal ("nsat1CMBN");
		hChute30 = oapiLoadMeshGlobal ("Apollo_2chute");
		hChute31 = oapiLoadMeshGlobal ("Apollo_3chuteEX");
		hChute32 = oapiLoadMeshGlobal ("Apollo_3chuteHD");
		hApollochute = oapiLoadMeshGlobal ("Apollo_3chute");
		hprobe = oapiLoadMeshGlobal ("sat5probe");
		hFHC = oapiLoadMeshGlobal ("SAT5HC");
		hFHO = oapiLoadMeshGlobal ("SAT5HO");
		hFHC2 = oapiLoadMeshGlobal ("SAT5HC2");
		hFHO2 = oapiLoadMeshGlobal ("SAT5HO2");
		hSMhga =oapiLoadMeshGlobal ("nsat1SMHGA");
		hCMP =oapiLoadMeshGlobal ("SAT5CMP");
		hCMPEVA =oapiLoadMeshGlobal ("nSATURN1_CMP_EVA");
		hCREW =oapiLoadMeshGlobal ("SAT5CREW");
		hCRB =oapiLoadMeshGlobal ("nSATURN1_CRB");
		hCMB =oapiLoadMeshGlobal ("SAT5CMB");
		hCM2B =oapiLoadMeshGlobal ("SAT5CM2B");
		hLMPKD =oapiLoadMeshGlobal ("LM_Parked");
		hCRAWL =oapiLoadMeshGlobal ("CRAWLER");
		
	}
	// VESSELSOUND **********************************************************************
	// initialisation
	ConnectToOrbiterSoundDLL();
	// load wave (Handle defined in begining of file)
	RequestLoadVesselWave(Sctdw,			"Sound\\vessel\\countdown1.WAV");
	RequestLoadVesselWave(SepS,				"Sound\\vessel\\hover_int.WAV");
	RequestLoadVesselWave(LaunchS,			"Sound\\saturn1B\\Launch2.wav");
	RequestLoadVesselWave(SeparationS,		"Sound\\saturn1B\\Separation.wav");
	RequestLoadVesselWave(SMJetS,			"Sound\\saturn1B\\SMJetison.wav");
	RequestLoadVesselWave(S4CutS,			"Sound\\saturn1B\\SIVBShutdown.wav");
	RequestLoadVesselWave(TowerJS,			"Sound\\saturn1B\\TowerJet.wav");
	RequestLoadVesselWave(StageS,			"Sound\\saturn1B\\Stagesep.wav");
	RequestLoadVesselWave(SplashS,			"Sound\\saturn1B\\Splash.wav");
	RequestLoadVesselWave(SpeedS,			"Sound\\saturn1B\\reentry.wav");
	RequestLoadVesselWave(SShutS,			"Sound\\saturn1B\\boostShut.wav");
	RequestLoadVesselWave(Swater,			"Sound\\saturn1B\\waterloop.wav");
	RequestLoadVesselWave(DockS,            "Sound\\vessel\\docking.wav");
	RequestLoadVesselWave(CrashBumpS,        "Sound\\vessel\\Crash.wav");
	RequestLoadVesselWave(SCorrection,        "Sound\\saturn1B\\Correction.wav");
	// VESSELSOUND 
	RequestLoadVesselWave(SLEVA,			"Sound\\saturn1B\\LEVA.wav");
	RequestLoadVesselWave(HRover,				"Sound\\Saturn1B\\LRover.WAV");	
	RequestLoadVesselWave(SExploded,				"Sound\\Saturn1B\\13explode.wav");
	RequestLoadVesselWave(Sclick,				"Sound\\Saturn1B\\click.wav");
	
	// need to init device-dependent resources here in case the screen mode has changed
		
	g_Param.col[2] = oapiGetColour(154,154,154);
	g_Param.col[3] = oapiGetColour(3,3,3);
	//for (int i = 0;i<8;i++){
	//LAUNCHIND[i]=false;
	//}
	for (int i = 0;i<5;i++){
	ENGIND[i]=false;
	}
	
	return new VESSEL (hvessel, flightmodel);
	hMaster = hvessel;

	
	
	
}

DLLCLBK void ovcExit (VESSEL *vessel)
{
	--refcount;
	if (vessel) delete vessel;
}

DLLCLBK int ovcConsumeKey (VESSEL *vessel, const char *keystate)
{
	if (KEYMOD_SHIFT (keystate)) 
	{
		return 0; 
	}
	else if (KEYMOD_CONTROL (keystate)) 
	{
	
	}
	else 
	{ 
		if (status ==0){
				if (KEYDOWN (keystate, OAPI_KEY_B)) {
					if (oapiAcceptDelayedKey (OAPI_KEY_B, 1.0)){
						if (buildstatus < 7){
							buildstatus = buildstatus + 1;
							BuildFirstStage(vessel,buildstatus);
							PlayVesselWave(CrashBumpS,NOLOOP,205);
						}
					
				return 1;
					}
				
				}if (KEYDOWN (keystate, OAPI_KEY_U)) {
					if (oapiAcceptDelayedKey (OAPI_KEY_U, 1.0)){
						if (buildstatus > 0 && buildstatus < 8){
							buildstatus = buildstatus - 1;
							BuildFirstStage(vessel,buildstatus);
							PlayVesselWave(CrashBumpS,NOLOOP,205);
						}
					
				return 1;
					}
				
				}if (KEYDOWN (keystate, OAPI_KEY_0)) {
					if (oapiAcceptDelayedKey (OAPI_KEY_0, 1.0)){
					if (buildstatus ==7){
						SetFirstStage(vessel);
					}
					return 1;
					}
				}if (KEYDOWN (keystate, OAPI_KEY_G)) {
					if (oapiAcceptDelayedKey (OAPI_KEY_G, 1.0)){
					GoHover = !GoHover;
				
			return 1;
			}
			}VESSELSTATUS vs;
			vessel->GetStatus(vs);
			if (vs.status ==1 ){
				if (KEYDOWN (keystate, OAPI_KEY_NUMPAD1)) {
				if (oapiAcceptDelayedKey (OAPI_KEY_NUMPAD1, .001)){
				
				KEY1 = true;
				
				return 1;
				}
			}if (KEYDOWN (keystate, OAPI_KEY_NUMPAD3)) {
				if (oapiAcceptDelayedKey (OAPI_KEY_NUMPAD3, 0.001)){
				
					KEY3 = true;
				
				return 1;
				}
			}if (KEYDOWN (keystate, OAPI_KEY_NUMPAD2)) {
				if (oapiAcceptDelayedKey (OAPI_KEY_NUMPAD2, .001)){
				
				KEY2 = true;
				
			return 1;
			}
			}if (KEYDOWN (keystate, OAPI_KEY_NUMPAD4)) {
				if (oapiAcceptDelayedKey (OAPI_KEY_NUMPAD4, 0.001)){
				
				KEY4 = true;
				
			return 1;
			}
			}if (KEYDOWN (keystate, OAPI_KEY_NUMPAD5)) {
				if (oapiAcceptDelayedKey (OAPI_KEY_NUMPAD5, .001)){
				
				KEY5 = true;
				
			return 1;
			}
			}if (KEYDOWN (keystate, OAPI_KEY_NUMPAD6)) {
				if (oapiAcceptDelayedKey (OAPI_KEY_NUMPAD6, .001)){
				
				KEY6 = true;
				
			return 1;
			}
			}if (KEYDOWN (keystate, OAPI_KEY_NUMPAD7)) {
				if (oapiAcceptDelayedKey (OAPI_KEY_NUMPAD7, .001)){
				
				KEY7 = true;
				
			return 1;
			}
			}if (KEYDOWN (keystate, OAPI_KEY_NUMPAD8)) {
				if (oapiAcceptDelayedKey (OAPI_KEY_NUMPAD8, .001)){
				
				KEY8 = true;
				
			return 1;
			}
			}if (KEYDOWN (keystate, OAPI_KEY_NUMPAD9)) {
				if (oapiAcceptDelayedKey (OAPI_KEY_NUMPAD9, .001)){
				
				KEY9 = true;
				
			return 1;
			}
			}
			}
			}
			
		if (KEYDOWN (keystate, OAPI_KEY_J)) {
			if (oapiAcceptDelayedKey (OAPI_KEY_J, 1.0)){
				if (status >=3)
				//bManualSeparate = true;
			return 1;
			}
		}
		if (KEYDOWN (keystate, OAPI_KEY_P)) {
			if (oapiAcceptDelayedKey (OAPI_KEY_P, 1.0)){
			if (autopilot){
				//autopilot = false;
				//ResetThrusters(vessel);
			} else
				//autopilot = true;
			return 1;
			}
		}
		if (KEYDOWN (keystate, OAPI_KEY_K)) {
			if (oapiAcceptDelayedKey (OAPI_KEY_K, 1.0)){
				if (status==5||status ==12){
				//bToggleHatch = true;
				}
			return 1;
			}
		}
		if (KEYDOWN (keystate, OAPI_KEY_R)) {
			if (oapiAcceptDelayedKey (OAPI_KEY_R, 1.0)){
				{
					if (status ==12 && HatchOpen){
						bRecovery = true;
					}
				}
			return 1;
			}
		}
		if (KEYDOWN (keystate, OAPI_KEY_G)) {
			if (oapiAcceptDelayedKey (OAPI_KEY_G, 1.0)){
				{
					if (status ==4 ){
						//bStartS4B = true;
					}
				}
			return 1;
			}
		}
		if (KEYDOWN (keystate, OAPI_KEY_1)) {
			if (oapiAcceptDelayedKey (OAPI_KEY_1, 1.0)){

			//	bManualUnDock = true;
			return 1;
			}
		}
		if (KEYDOWN (keystate, OAPI_KEY_2)) {
			if (oapiAcceptDelayedKey (OAPI_KEY_2, 1.0)){
			//Eds=!Eds;
			
			return 1;
			}
		}
		if (KEYDOWN (keystate, OAPI_KEY_3)) {
			if (oapiAcceptDelayedKey (OAPI_KEY_3, 1.0)){
			//	ProbeJetison=false;
			}
			return 1;
			
		}
		if (KEYDOWN (keystate, OAPI_KEY_4)) {
			if (oapiAcceptDelayedKey (OAPI_KEY_4, 1.0)){
				if (dockstate==3){
			//	ProbeJetison=true;
			//	bManualUnDock = true;
				}
			return 1;
			}
		}
		if (KEYDOWN (keystate, OAPI_KEY_5)) {
			if (oapiAcceptDelayedKey (OAPI_KEY_5, 1.0)){
				if (ActivateLEM){
					ActivateLEM=false;
				}
				return 1;
			}
		}
		if (KEYDOWN (keystate, OAPI_KEY_E)) {
			if (oapiAcceptDelayedKey (OAPI_KEY_E, 1.0)){
				if (clockMission && status <=4){
					//bAbort = true;
				}else if (status==5 && HatchOpen){
				//	ToggleEva = true;
				}
			return 1;
			}
		}
		if (KEYDOWN (keystate, OAPI_KEY_V)) {
			if (oapiAcceptDelayedKey (OAPI_KEY_V, 1.0)){
				if (!velDISP){
				//	velDISP = true;
				}else{
				//	velDISP = false;
				}
			return 1;
			}
		}
		if (KEYDOWN (keystate, OAPI_KEY_S)) {
			if (oapiAcceptDelayedKey (OAPI_KEY_S, 1.0)){
				if (!autoDISP){
					autoDISP = true;
				}else{
					autoDISP = false;
				}
			return 1;
			}
		}
		if (KEYDOWN (keystate, OAPI_KEY_C)) {
			if (oapiAcceptDelayedKey (OAPI_KEY_C, 1.0)){
				
				//	clockDISP = !clockDISP;
				
			return 1;
			}
		}
		if (KEYDOWN (keystate, OAPI_KEY_9)) {
			if (oapiAcceptDelayedKey (OAPI_KEY_9, 1.0))
				dockview = true;
			return 1;
		}
		if (KEYDOWN (keystate, OAPI_KEY_8)) {
			if (oapiAcceptDelayedKey (OAPI_KEY_8, 1.0))
				dmpview = true;
			return 1;
		}
		if (KEYDOWN (keystate, OAPI_KEY_7)) {
			if (oapiAcceptDelayedKey (OAPI_KEY_7, 1.0))
				cmpview = true;
			return 1;
		}
		if (KEYDOWN (keystate, OAPI_KEY_6)) {
			if (oapiAcceptDelayedKey (OAPI_KEY_6, 1.0))
				cdrview = true;
			return 1;
		}
		
	}
	return 0;
}

DLLCLBK void ovcSetClassCaps (VESSEL *vessel, FILEHANDLE cfg)
{
		
}


DLLCLBK void ovcTimestep (VESSEL *vessel, double simt)
{

	
	
	char VName[256]="";
	char VName1[256]="";
	char VName2[256]="";
	char VName3[256]="";
	char VName4[256]="";
	char VName5[256]="";
	char VName6[256]="";
	char VName7[256]="";
	char VName8[256]="";
	char VName9[256]="";
	char VName10[256]="";
	char VName11[256]="";
	char VName12[256]="";

	strcpy (VName, vessel->GetName()); strcat (VName, "-TWR");
	hesc1=oapiGetVesselByName(VName);
	strcpy (VName1, vessel->GetName()); strcat (VName1, "-STG1");
	hstg1=oapiGetVesselByName(VName1);
	strcpy (VName2, vessel->GetName()); strcat (VName2, "-S4BSTG");
	hs4bM=oapiGetVesselByName(VName2);
	strcpy (VName3, vessel->GetName()); strcat (VName3, "-S4B1");
	hs4b1 = oapiGetVesselByName(VName3);
	strcpy (VName4, vessel->GetName()); strcat (VName4, "-S4B2");
	hs4b2 =oapiGetVesselByName(VName4);
	strcpy (VName5, vessel->GetName()); strcat (VName5, "-S4B3");
	hs4b3 = oapiGetVesselByName(VName5);
	strcpy (VName6, vessel->GetName()); strcat (VName6, "-S4B4");
	hs4b4=oapiGetVesselByName(VName6);
	strcpy (VName7, vessel->GetName()); strcat (VName7, "-SM");
	hSMJet=oapiGetVesselByName(VName7);
	strcpy (VName8, vessel->GetName()); strcat (VName8, "-LM");
	hLMV=oapiGetVesselByName(VName8);
	strcpy (VName9, vessel->GetName()); strcat (VName9, "-DCKPRB");
	hPROBE=oapiGetVesselByName(VName9);
	strcpy (VName10, vessel->GetName()); strcat (VName10, "-EVA");
	hEVA=oapiGetVesselByName(VName10);
	strcpy (VName11, vessel->GetName()); strcat (VName11, "-INTSTG");
	hintstg =oapiGetVesselByName(VName11);
	strcpy (VName12, vessel->GetName()); strcat (VName12, "-STG2");
	hstg2 =oapiGetVesselByName(VName12);
	


		
	
	VECTOR3 RVEL = _V(0.0,0.0,0.0);
	vessel->GetRelativeVel(vessel->GetGravityRef(),RVEL);
	
	actualVEL = (sqrt(RVEL.x *RVEL.x + RVEL.y * RVEL.y + RVEL.z * RVEL.z)/1000*3600);
	actualALT = vessel->GetAltitude() ;
	
	
	actualFUEL = vessel->GetFuelMass()/vessel->GetMaxFuelMass()*100;	
	double dTime,aSpeed,DV,aALT,DVV,DVA;//aVAcc;aHAcc;ALTN1;SPEEDN1;aTime aVSpeed;
		aSpeed = actualVEL/3600*1000;
		aALT=actualALT;
		dTime=simt-aTime;
		if(dTime > 0.1){
			DV= aSpeed - SPEEDN1;
			aHAcc= (DV / dTime);
			DVV = aALT - ALTN1;
			aVSpeed = DVV / dTime;
			DVA = aVSpeed- VSPEEDN1;
			

			aVAcc=(DVA/ dTime);
			aTime = simt;
			VSPEEDN1 = aVSpeed;
			ALTN1 = aALT;
			SPEEDN1= aSpeed;
		}
		
		
	if (vessel->GetAltitude() < 1470){
	actualVEL = actualVEL-1470+vessel->GetAltitude();
	}
	if (vessel->GroundContact()){
	actualVEL =0;
	}
	
		
	 if (stage !=5){
		if (vessel->GetAttitudeMode() == ATTMODE_LIN){
			vessel->SetAttitudeMode(ATTMODE_ROT);
		}	
	 }else{
		//SetView(vessel);
	 }

	
	if (hstg1){
		
		if ((simt-(4+ignition_2time))>=0 && stg1U){
			Ullage(hstg1,0);
			stg1U = false;
		}else if (stg1U){
			Ullage(hstg1,5);
		}
		KillAlt(vessel,hstg1,60);
		
	}
	if (hstg2){
		
		if ((simt-(4+ignition_3time))>=0 && stg2U){
			Ullage2(hstg2,0);
			stg2U = false;
		}else if (stg2U){
			Ullage2(hstg2,5);
		
		}
		KillAlt(vessel,hstg2,60);
		
		
	}
	if (hintstg){
		
		InterJet=true;
		KillAlt(vessel,hintstg,60);
		
	}
	if (hesc1){
		KillAlt(vessel,hesc1,90);
	}
	if (hPROBE){
		KillDist(vessel,hPROBE);
	}
	if (hs4bM){
		if (!S4Bset){
			setupS4B(hs4bM);
			S4Bset = true;
		}
		if (dockstate > 2){
			double TimeW1;
			TimeW1 = oapiGetTimeAcceleration ();
			if (TimeW1>10){
			SetS4B(hs4bM);
			}
			
		}
	}
	if (hSMJet && !ApolloExploded){
		if ((simt-(20+ignition_SMtime))>=0 && stgSM){
			UllageSM(hSMJet,0,simt);
			stgSM=false;
		}else if (!SMSep){
			UllageSM(hSMJet,5,simt);
		}
		KillAlt(vessel,hSMJet,350000);
	}
	if (hs4b1)
		KillDist(vessel,hs4b1);				
	if (hs4b2)
		KillDist(vessel,hs4b2);				
	if (hs4b3)
		KillDist(vessel,hs4b3);				
	if (hs4b4)
		KillDist(vessel,hs4b4);	
	if (clockMission)
		autopTime = autopTime + oapiGetSimStep();
	if (abortRocket){
		//
		double altabort;
		int getIT;
		habort = oapiGetVesselByName("Saturn5_Abort");
		getIT = oapiGetAltitude(habort,&altabort);
	
		if (altabort < 100 && getIT >0){
		oapiDeleteVessel(habort,vessel->GetHandle());
		abortRocket = false;
		}

	}
	if(stage <5 && autopilot){
	
		ENGIND[7]=RPswitch10 ;
		}else{
		ENGIND[7]=false;
	}
	if(stage < 4){

		if (vessel->GetNavmodeState(NAVMODE_KILLROT)){
	
				vessel->DeactivateNavmode(NAVMODE_KILLROT);
	
			}
	}
	if (bAbort && stage <3 ){
		
		vessel->SetEngineLevel(ENGINE_MAIN,0);
		SeparateStage (vessel, stage);
		stage =14;
		bAbort=false;
		return;
	}
		
	if (stage == 0)
	{
	
		
		VESSELSTATUS vs;
		vessel->GetStatus(vs);
		int i;
		for (i = 0;i<5;i++){
		
			if (vessel->GetThrusterLevel(th_main[i]) > 0){
			ENGIND[i] =true;			
			}else{
			ENGIND[i] =false;			
			}
		}
		
		if (vs.status ==1 ){
			MoveEVA(vessel);
		}
		if (clockMission){
			if (vessel->GetEngineLevel(ENGINE_MAIN) <0.3 && autopTime <100 && autopTime > 10 && EDSswitch){
				bAbort = true;
			}
		}
		if (vessel->GetEngineLevel(ENGINE_MAIN)>0 && autopTime>= 0 && !clockMission){
		ignition_time = simt;
		autopTime =0;
		clockMission = true;
		LAUNCHIND[0]=true;
	
			if (!launchSound){
				PlayVesselWave(LaunchS,NOLOOP,255);
				launchSound = true;
			}
		}
		if (autopTime >=139 && !sepsPyd){
			vessel->SetThrusterResource(th_main[4],NULL);
			PlayVesselWave(SShutS,NOLOOP,235);
			sepsPyd=true;
		}
		if (autopTime >=146 && !sepsPyd0){
		PlayVesselWave(Sctdw,NOLOOP,245);	
		sepsPyd0=true;
		}
		
		if(simt > 0.5 && (!autopilot||!RPswitch10)){
			AttitudeLaunch1(vessel);}
		if (autopilot){
		AutoPilot(vessel, autopTime);
		}
		if (vessel->GetFuelMass() == 0 && buildstatus > 7 && ignition_2time ==0)
		{
				
			ignition_2time = simt;
		}
		if ((simt-(2+ignition_2time))>=0 && ignition_2time !=0|| bManualSeparate){
			SeparateStage (vessel, stage);
			bManualSeparate=false;
			PlayVesselWave(SeparationS,NOLOOP,245);	
			stage = 1;
		} 
		if (vessel->GetEngineLevel(ENGINE_MAIN) > 0 ){
		LAUNCHIND[7]=true;
		ENGIND[5]=true;
		
		}else{
		LAUNCHIND[7]=false;
		ENGIND[5]=false;
		
		}
	}else if (stage == 1)
	{
			if(simt > 0.5 && (!autopilot||!RPswitch10)){
				AttitudeLaunch2(vessel);}
        int i;
		for (i = 0;i<5;i++){
		
			if (vessel->GetThrusterLevel(th_main[i]) > 0){
			ENGIND[i] =true;			
			}else{
			ENGIND[i] =false;			
			}
		}
		if (vessel->GetEngineLevel(ENGINE_MAIN) > 0 ){
		LAUNCHIND[7]=true;
		ENGIND[5]=true;
		ENGIND[6]=true;
		
		}else{
		LAUNCHIND[7]=false;
		ENGIND[5]=false;
		ENGIND[6]=false;
		
		
		}
        if (autopilot)
		AutoPilot(vessel, autopTime);
	    //sprintf(oapiDebugString(), "Autopilot Mission Clock %f", fabs(autopTime));	
		//DoThrustAdjust(vessel, ISP_SECOND_SL, ISP_SECOND_VAC);
		
		if ((simt-(6+ignition_2time))>=0 && startsep)
		{
		vessel->SetThrusterGroupLevel(thg_main, 1.0);
		startsep = false;
		}
		
		if ((simt-(6.5+ignition_2time))>=0 && stopsep)
		{
		vessel->SetThrusterGroupLevel(thg_ull,0.0);
		StopVesselWave(SepS);	
		stopsep =false;
		LAUNCHIND[6]=false;
		}
		//if ((simt-(26+ignition_2time))>=0  || bManualSeparate||vessel->GetFuelMass() == 0 )
		if (autopTime >= 182 || bManualSeparate||vessel->GetFuelMass() == 0 )
		{
			SeparateStage (vessel, stage);
			stage = 2;
			bManualSeparate=false;
			
		} 
		
	}else if (stage == 2)
	{
		if(simt > 0.5&& (!autopilot||!RPswitch10)){AttitudeLaunch2(vessel);}
		LAUNCHIND[6]=false;
		int i;
		for (i = 0;i<5;i++){
		
			if (vessel->GetThrusterLevel(th_main[i]) > 0){
			ENGIND[i] =true;			
			}else{
			ENGIND[i] =false;			
			}
		}
		if (vessel->GetEngineLevel(ENGINE_MAIN) > 0 ){
		LAUNCHIND[7]=true;
		ENGIND[5]=true;
		ENGIND[6]=false;
		}else{
		LAUNCHIND[7]=false;
		ENGIND[5]=false;
		ENGIND[6]=false;
		}
        if (autopilot){
			AutoPilot(vessel, autopTime);
	    	//DoThrustAdjust(vessel, ISP_SECOND_SL, ISP_SECOND_VAC);
		}else{
		//sprintf(oapiDebugString(), "", autopTime);	
		}
		
		//if ((simt-(33+ignition_2time))>=0  || bManualSeparate||vessel->GetFuelMass() == 0 )
		if (autopTime >= 185  || bManualSeparate||vessel->GetFuelMass() == 0 )
		{
			
			SeparateStage (vessel, stage);
			stage = 3;
			bManualSeparate=false;
			
		} 
		
		
	}else if (stage == 3)
	{	
		if(simt > 0.5 && (!autopilot||!RPswitch10)){AttitudeLaunch2(vessel);}
		LAUNCHIND[2]=true;
		int i;
		for (i = 0;i<5;i++){
		
			if (vessel->GetThrusterLevel(th_main[i]) > 0){
			ENGIND[i] =true;			
			}else{
			ENGIND[i] =false;			
			}
		}
		if (vessel->GetEngineLevel(ENGINE_MAIN) > 0 ){
		LAUNCHIND[7]=true;
		ENGIND[5]=true;
		ENGIND[6]=false;
		}else{
		LAUNCHIND[7]=false;
		ENGIND[5]=false;
		ENGIND[6]=false;
		}
		if (autopTime >=520 && !sepsPyd3){
		PlayVesselWave(Sctdw,NOLOOP,245);	
		sepsPyd3=true;
		}
		if (autopTime >=485 && !sepsPyd2){
			vessel->SetThrusterResource(th_main[4],NULL);
			PlayVesselWave(SShutS,NOLOOP,235);
			sepsPyd2=true;
		}

        if (autopilot){
			AutoPilot(vessel, autopTime);
	    	//DoThrustAdjust(vessel, ISP_SECOND_SL, ISP_SECOND_VAC);
			}else{
			//sprintf(oapiDebugString(), "Mission Time %d", int(autopTime));	
			}
		
		if (vessel->GetFuelMass() == 0  && ignition_3time==0){
			ignition_3time = simt;
		}
		if ((simt-(2+ignition_3time))>=0 && ignition_3time!=0||bManualSeparate||bAbort ){
			bManualSeparate=false;
			SeparateStage (vessel, stage);
			stage = 4;
				
		} 
			if (bAbort){
					SeparateStage (vessel, stage);
					stage = 5;
					SPSswitch=true;
					ABORT_IND = true;
					vessel->SetThrusterGroupLevel(thg_main, 1.0);
	
					bAbort = false;
					autopilot=false;
			}
		
	}else if (stage == 4)
	{
		if(RPswitch6){
		bStartS4B = true;
		}
		if (simt > 0.5 && (!autopilot||!RPswitch10)){AttitudeLaunch3(vessel); }
		
		if (vessel->GetEngineLevel(ENGINE_MAIN) > 0 ){
		LAUNCHIND[7]=true;
		ENGIND[5]=true;
		}else{
		ENGIND[5]=false;
		LAUNCHIND[7]=false;
		}   
        if (autopilot)
		AutoPilot(vessel, autopTime);
	    //sprintf(oapiDebugString(), "Autopilot Mission Clock %f", fabs(autopTime));	
		//DoThrustAdjust(vessel, ISP_SECOND_SL, ISP_SECOND_VAC);
		if (S4BStartTimer==0 && bStartS4B ){
			S4BStartTimer=simt;
			PlayVesselWave(Sctdw,NOLOOP,255);
		}
		if ((simt-(S4BStartTimer))>=0 && bStartS4B ){
			vessel->SetAttitudeLinLevel(2,1);
			PlayVesselWave(SepS,LOOP,255);
		}
		if ((simt-(22+S4BStartTimer))>=0 && !bStartS4B ){
		vessel->SetAttitudeLinLevel(2,0);
		}
		if ((simt-(10+S4BStartTimer))>=0 && bStartS4B ){
			vessel->SetThrusterResource(th_main[0],ph_3rd);
			RPswitch6=false;
			vessel->SetThrusterLevel(th_main[0],1.0);
			RPswitch1=false;RPswitch2=false;RPswitch3=true;RPswitch4=true;RPswitch5=true;
			bStartS4B =false;
			StopVesselWave(SepS);
			S4BStartTimer=0;
			
		}
		if(vessel->GetThrusterGroupLevel(thg_ver)>0){
			LAUNCHIND[6]=true;
		}else{
			LAUNCHIND[6]=false;
		}
		if ((simt-(6+ignition_3time))>=0 && !S4BStarted)
		{
		vessel->SetThrusterResource(th_main[0],ph_3rd);
		vessel->SetThrusterLevel(th_main[0], 1.0);
		S4BStarted=true;
		vessel->SetThrusterGroupLevel(thg_ver,1.0);
		StopVesselWave(SepS);
		}
		
		if ((simt-(8+ignition_3time))>=0 && !S4BStarted2)
		{
		StopVesselWave(SepS);
		AddRCS_S4B(vessel);
		vessel->SetThrusterGroupLevel(thg_ver,0.0);
		LAUNCHIND[6]=false;
		S4BStarted2=true;
		}else if(!S4BStarted2) {
			PlayVesselWave(SepS,LOOP,255);
					}
		if(Sswitch5){
		bManualSeparate =true;
		}
		if (bManualSeparate ||bAbort)
		{
			bManualSeparate=false;
			SeparateStage (vessel, stage);
			stage = 5;
			if (bAbort){
					SPSswitch=true;
					ABORT_IND = true;	
					vessel->SetThrusterGroupLevel(thg_main, 1.0);
	
					bAbort = false;
					autopilot=false;
			}
					
		} 
		if (vessel->GetNavmodeState(NAVMODE_KILLROT)){
			if (vessel->GetThrusterLevel(th_att_rot[2]) ==0 && vessel->GetThrusterLevel(th_att_rot[4]) ==0 && !RPswitch1 && !RPswitch2){
			vessel->DeactivateNavmode(NAVMODE_KILLROT);
			}
		}
		if(vessel->GetThrusterLevel(th_main[0]) < 0.2 && S4BStarted){
		vessel->SetThrusterResource(th_main[0],NULL);
					
		}
		
		if(RPswitch1){
			vessel->SetThrusterResource(th_att_rot[0],ph_3rd);
			vessel->SetThrusterResource(th_att_rot[1],ph_3rd);
		}else{
			vessel->SetThrusterResource(th_att_rot[0],NULL);
			vessel->SetThrusterResource(th_att_rot[1],NULL);
		}
		if(RPswitch3){
			vessel->SetThrusterResource(th_att_rot[2],ph_3rd);
			vessel->SetThrusterResource(th_att_rot[3],ph_3rd);
			vessel->SetThrusterResource(th_att_rot[4],ph_3rd);
			vessel->SetThrusterResource(th_att_rot[5],ph_3rd);
		}else{
			vessel->SetThrusterResource(th_att_rot[2],NULL);
			vessel->SetThrusterResource(th_att_rot[3],NULL);
			vessel->SetThrusterResource(th_att_rot[4],NULL);
			vessel->SetThrusterResource(th_att_rot[5],NULL);
		}
		if(RPswitch2){
			vessel->SetThrusterResource(th_att_rot[7],ph_3rd);
			vessel->SetThrusterResource(th_att_rot[6],ph_3rd);
			vessel->SetThrusterResource(th_att_rot[8],ph_3rd);
			vessel->SetThrusterResource(th_att_rot[9],ph_3rd);
		}else{
			vessel->SetThrusterResource(th_att_rot[6],NULL);
			vessel->SetThrusterResource(th_att_rot[7],NULL);
			vessel->SetThrusterResource(th_att_rot[8],NULL);
			vessel->SetThrusterResource(th_att_rot[9],NULL);
		}
		for (int i = 0;i<1;i++){
		
			if (vessel->GetThrusterLevel(th_main[i]) > 0){
			ENGIND[i+4] =true;			
			}else{
			ENGIND[i+4] =false;			
			}
		}

	}else if (stage == 5 )//|| stage == 6 && Apollo13 && dockstate == 3
	{
		if (vessel->GetNavmodeState(NAVMODE_KILLROT)&& !LPswitch1 && !LPswitch2){
			if (vessel->GetThrusterLevel(th_att_rot[10]) <0.00001 && vessel->GetThrusterLevel(th_att_rot[18]) <0.00001 ){
			vessel->DeactivateNavmode(NAVMODE_KILLROT);
			}
		}
		if(simt>0.5)AttitudeLaunch4(vessel);
		if(RPswitch13 && !HatchOpen){
		bToggleHatch = true;
		}else if(!RPswitch13 && HatchOpen){
		bToggleHatch = true;
		}
		if(RPswitch17 && RPswitch15){
		if (ActivateLEM){
					ActivateLEM=false;
				RPswitch17=false;
				RPswitch15=false;
				VESSEL *lmvessel;
				lmvessel=oapiGetVesselInterface(hLMV);
				lmvessel->SetEnableFocus(true);
				
				//oapiSetFocusObject(hLMV);

				}
		}
		if (RPswitch14 && HatchOpen){
					ToggleEva = true;
					RPswitch14=false;
				}

		if(!probeOn){
			if(vessel->GetDockStatus(vessel->GetDockHandle(0))!=NULL){
			vessel->Undock(0);
			PlayVesselWave(CrashBumpS,NOLOOP,150);			}
		}
		for (int i=0 ;i<6;i++){
			LAUNCHIND[i]=false;
		}

		if (hLMV && dockstate <5){
			if (vessel->GetDockStatus(vessel->GetDockHandle(0))==hLMV){
				ActivateLEM=true;
				VESSEL *lmvessel;
				dockstate=3;
				lmvessel=oapiGetVesselInterface(hLMV);
				lmvessel->SetEnableFocus(true);
				
			}else{
				VESSEL *lmvessel;
				lmvessel=oapiGetVesselInterface(hLMV);
				lmvessel->SetEnableFocus(true);
				ActivateLEM=false;
				dockstate=4;
			}
		}
		//sprintf(oapiDebugString(), "dockstate= %d",dockstate);
		if (hs4bM){
			if (vessel->GetDockStatus(vessel->GetDockHandle(0))==hLMV){
				ActivateLEM=true;
			}else{
				
			}
			if (vessel->GetDockStatus(vessel->GetDockHandle(0))==hs4bM){
				ActivateS4B=true;
			}else{
				ActivateS4B=false;
			}
		}
		if (Sswitch2){
		vessel->Undock(0);
		}
		if (Sswitch1){
				if (ActivateLEM){
				ProbeJetison=true;
				bManualUnDock = true;
				}
		}
		if (Sswitch3 && Sswitch4){
				bManualSeparate=true;
		}
		if (RPswitch15 && RPswitch16){
				bManualUnDock = true;
		}
		
		if (!ApolloExploded && autopTime >= 229400 && Apollo13 && autopTime < 232e3){
		double TimeW=0;
		TimeW = oapiGetTimeAcceleration ();
			if (TimeW>1){
			TimeW = 1;
			oapiSetTimeAcceleration (1);
			}
			PlayVesselWave(SExploded,NOLOOP,255);
			ApolloExploded=true;
			vessel->SetPropellantMass(ph_rcs0,0);
			vessel->SetPropellantMass(ph_sps,0);
			VESSELSTATUS vs13;
			vessel->GetStatus(vs13);
			vs13.vrot = _V(-1,-1,-1);
			vessel->DefSetState(&vs13);
		
		}
		
		if (autopTime >= 219400 && !Scorrec && autopTime < 228e3){
		double TimeW=0;
		TimeW = oapiGetTimeAcceleration ();
			if (TimeW>1){
			TimeW = 1;
			oapiSetTimeAcceleration (1);
			}
			PlayVesselWave(SCorrection,NOLOOP,255);
			Scorrec=true;
		
		}
		if (EVA_IP){
			if(!hEVA){
			ToggleEVA(vessel);
			}
		}
		if ((simt-(2+Release_time))>=0 && Resetjet){
			vessel->SetAttitudeLinLevel(_V(0.0,0.0,0.0));
			Resetjet =false;
			Release_time=0;
			}
		if (ToggleEva){
		ToggleEVA(vessel);
		}
		if (bToggleHatch){
		ToggelHatch(vessel);
		bToggleHatch=false;
		}
		if (stage ==5){
		SetView(vessel);
		}
		
		 
		
		if (bManualUnDock)
		{
			

			if (vessel->GetDockStatus(vessel->GetDockHandle(0))== hs4bM)//this check is for docking status if doked we cannot jetison ASTP
			{
			dockstate = 2;	
			Release_time = simt;
			Resetjet =true;
			DockStage (vessel, dockstate);
			bManualUnDock=false;
			}else if(vessel->GetDockStatus(vessel->GetDockHandle(0))==hLMV && dockstate ==3 && ProbeJetison){ 
			DockStage (vessel, dockstate);
			vessel->Undock(0);
			//sprintf(oapiDebugString(), "jetison probe");	
			bManualUnDock=false;
			}else{
			bManualUnDock=false;
			}
		}
	
		if (dockstate == 3 && !S4Shoot){
		AccelS4B(hs4bM,simt);
		}
		if(LPswitch1){
			vessel->SetThrusterResource(th_att_lin[0],ph_rcs0);
			vessel->SetThrusterResource(th_att_lin[1],ph_rcs0);
			vessel->SetThrusterResource(th_att_lin[2],ph_rcs0);
			vessel->SetThrusterResource(th_att_lin[3],ph_rcs0);
			vessel->SetThrusterResource(th_att_rot[0],ph_rcs0);
			vessel->SetThrusterResource(th_att_rot[1],ph_rcs0);
			vessel->SetThrusterResource(th_att_rot[2],ph_rcs0);
			vessel->SetThrusterResource(th_att_rot[3],ph_rcs0);
			
		}else{
			vessel->SetThrusterResource(th_att_lin[0],NULL);
			vessel->SetThrusterResource(th_att_lin[1],NULL);
			vessel->SetThrusterResource(th_att_lin[2],NULL);
			vessel->SetThrusterResource(th_att_lin[3],NULL);
			vessel->SetThrusterResource(th_att_rot[0],NULL);
			vessel->SetThrusterResource(th_att_rot[1],NULL);
			vessel->SetThrusterResource(th_att_rot[2],NULL);
			vessel->SetThrusterResource(th_att_rot[3],NULL);
		
		}	
		if(LPswitch2){
			vessel->SetThrusterResource(th_att_rot[4],ph_rcs0);
			vessel->SetThrusterResource(th_att_rot[5],ph_rcs0);
			vessel->SetThrusterResource(th_att_rot[7],ph_rcs0);
			vessel->SetThrusterResource(th_att_rot[6],ph_rcs0);
			vessel->SetThrusterResource(th_att_lin[4],ph_rcs0);
			vessel->SetThrusterResource(th_att_lin[5],ph_rcs0);
			vessel->SetThrusterResource(th_att_lin[7],ph_rcs0);
			vessel->SetThrusterResource(th_att_lin[6],ph_rcs0);
		
		}else{
			vessel->SetThrusterResource(th_att_rot[4],NULL);
			vessel->SetThrusterResource(th_att_rot[5],NULL);
			vessel->SetThrusterResource(th_att_rot[6],NULL);
			vessel->SetThrusterResource(th_att_rot[7],NULL);
			vessel->SetThrusterResource(th_att_lin[4],NULL);
			vessel->SetThrusterResource(th_att_lin[5],NULL);
			vessel->SetThrusterResource(th_att_lin[6],NULL);
			vessel->SetThrusterResource(th_att_lin[7],NULL);
		
		}
		if(LPswitch3){
			for(int i=8;i<24;i++){
				vessel->SetThrusterResource(th_att_rot[i],ph_rcs0);
				vessel->SetThrusterResource(th_att_lin[i],ph_rcs0);
			}
		}else{
			for(int i=8;i<24;i++){
				vessel->SetThrusterResource(th_att_rot[i],NULL);
				vessel->SetThrusterResource(th_att_lin[i],NULL);
			}
		}
				
		if( toggleRCS){
			if(LPswitch5){
			vessel->SetAttitudeMode(1);
			toggleRCS =false;
			}else if (!LPswitch5){
			vessel->SetAttitudeMode(2);
			toggleRCS =false;
			}
		}
		if (vessel->GetAttitudeMode()==2){
		LPswitch5=false;
		}else if (vessel->GetAttitudeMode()==1 ){
		LPswitch5=true;
		}
		if(LPswitch4 && RCS_Full){
		for(int i=0;i<24;i++){
				vessel->DelThruster(th_att_rot[i]);
				vessel->DelThruster(th_att_lin[i]);
		}
				vessel->DelThrusterGroup(THGROUP_ATT_PITCHUP,true);
				vessel->DelThrusterGroup(THGROUP_ATT_FORWARD,true);
				vessel->DelThrusterGroup(THGROUP_ATT_BACK,true);
				vessel->DelThrusterGroup(THGROUP_ATT_PITCHDOWN,true);
				vessel->DelThrusterGroup(THGROUP_ATT_PITCHUP,true);
				vessel->DelThrusterGroup(THGROUP_ATT_YAWRIGHT,true);
				vessel->DelThrusterGroup(THGROUP_ATT_YAWLEFT,true);
				AddRCSJets(vessel,-2.30,995);
		//sprintf(oapiDebugString(), "RCS HALF");	
		RCS_Full=false;
		}else if (!LPswitch4 && !RCS_Full){
		for(int i=0;i<24;i++){
				vessel->DelThruster(th_att_rot[i]);
				vessel->DelThruster(th_att_lin[i]);
		}
				vessel->DelThrusterGroup(THGROUP_ATT_PITCHUP,true);
				vessel->DelThrusterGroup(THGROUP_ATT_FORWARD,true);
				vessel->DelThrusterGroup(THGROUP_ATT_BACK,true);
				vessel->DelThrusterGroup(THGROUP_ATT_PITCHDOWN,true);
				vessel->DelThrusterGroup(THGROUP_ATT_PITCHUP,true);
				vessel->DelThrusterGroup(THGROUP_ATT_YAWRIGHT,true);
				vessel->DelThrusterGroup(THGROUP_ATT_YAWLEFT,true);
			
		AddRCSJets(vessel,-2.30,1990);
		RCS_Full=true;
		//sprintf(oapiDebugString(), "RCS FULL");	
		}
		if (SPSswitch){	
			vessel->SetThrusterResource(th_main[0],ph_sps);		
		}else{
			vessel->SetThrusterResource(th_main[0],NULL);		
		}
		if (bManualSeparate)
		{
			if (dockstate <=1||dockstate >= 3) {
			SeparateStage (vessel, stage);
			ignition_SMtime=simt;
			bManualSeparate=false;
			PlayVesselWave(SeparationS,NOLOOP,245);	
			setupSM(hSMJet);
			stage = 6;	
			}
			else{
			bManualSeparate=false;
			}
			
		}

	}else if (stage == 6 ){
		SetRCS_CM(vessel);
		ENGIND[7]=false;
		if (Sswitch1){
		vessel->Undock(0);
		}
		if (vessel->GetAtmPressure() > 300){//We 're looking wether the CM has burned or not
	
		
		SetRCS_CM(vessel);
		vessel->ClearMeshes();
		
		VECTOR3 mesh_dir=_V(0,0,0);
		vessel->AddMesh (hCMB, &mesh_dir);
		mesh_dir=_V(0.02,1.35,0.14);
		vessel->AddMesh (hFHC, &mesh_dir);
		// And the Crew
		mesh_dir=_V(0,0.15,-.15);
		vessel->AddMesh (hCMP, &mesh_dir);
		mesh_dir=_V(0,0.15,-.15);
		vessel->AddMesh (hCREW, &mesh_dir);
		stage = 13;
		Burned = true;

		}
	

		
	}
	else if (stage == 13 && vessel->GetAtmPressure() > 37680||stage == 6 && vessel->GetAtmPressure() > 38000)//20000 == 11000m
	{
		SetRCS_CM(vessel);
		vessel->DelPropellantResource(ph_rcs1);
		vessel->ClearMeshes();
		VECTOR3 mesh_dir=_V(0,0,-1);
			if (Burned){
			vessel->ClearMeshes();
			mesh_dir=_V(0,0,34.40-12.25-21.5);
			vessel->AddMesh (hCM2B, &mesh_dir);
			mesh_dir=_V(0.02,1.35,34.54-12.25-21.5);
			vessel->AddMesh (hFHC, &mesh_dir);
			// And the Crew
			mesh_dir=_V(0,0.15,34.25-12.25-21.5);
			vessel->AddMesh (hCMP, &mesh_dir);
			mesh_dir=_V(0,0.15,34.25-12.25-21.5);
			vessel->AddMesh (hCREW, &mesh_dir);
			}else{
			vessel->ClearMeshes();
			VECTOR3 mesh_dir=_V(0,0,34.40-12.25-21.5);
			vessel->AddMesh (hCM2, &mesh_dir);
			mesh_dir=_V(0.02,1.35,34.54-12.25-21.5);
			vessel->AddMesh (hFHC, &mesh_dir);
			// And the Crew
			mesh_dir=_V(0,0.15,34.25-12.25-21.5);
			vessel->AddMesh (hCMP, &mesh_dir);
			mesh_dir=_V(0,0.15,34.25-12.25-21.5);
			vessel->AddMesh (hCREW, &mesh_dir);
			}
		LAUNCHIND[1]=true;
		stage = 7;
		
	}else if (stage == 7 && vessel->GetAtmPressure() > 39000)//20000 == 11000m
	{
		SetChuteStage1(vessel);
		LAUNCHIND[3]=true;
		stage = 8;
	}else if (stage == 8 && vessel->GetAtmPressure() > 66000)//20000 == 11000m
	{
		SetChuteStage2(vessel);
		stage = 9;
	}else if (stage== 9 && vessel->GetAtmPressure() > 68000)//20000 == 11000m
	{
		SetChuteStage3(vessel);
		stage = 10;
	}else if (stage== 10 && vessel->GetAtmPressure() > 69000)//20000 == 11000m
	{
		SetChuteStage4(vessel);
		stage = 11;
		LAUNCHIND[5]=true;
	}else if (status == 11 && vessel->GetAltitude() < 2)//20000 == 11000m
	{
		PlayVesselWave(SplashS,NOLOOP,180);
		SetSplashStage(vessel);
		stage = 12;

	}else if (status == 12)//20000 == 11000m
	{
			if(RPswitch13 && !HatchOpen){
		bToggleHatch = true;
		}else if(!RPswitch13 && HatchOpen){
		bToggleHatch = true;
		}
		if (RPswitch14 && HatchOpen){
						bRecovery = true;
		}
		PlayVesselWave(Swater,LOOP,190);
		if (bToggleHatch){
		ToggelHatch2(vessel);
		bToggleHatch=false;
		}
		if (bRecovery){
		SetRecovery(vessel);
		bRecovery=false;
		status = 13;
		}
		

	}else  if (status== 14)

	{

		vessel->SetEngineLevel(ENGINE_MAIN,1);
		SetRCS_CM(vessel);
			ENGIND[7]=false;
		//sprintf(oapiDebugString(), "Mode Abort 1B%f", abortTimer);
		//if (bManualSeparate)
        if (vessel->GetFuelMass() == 0 && abortTimer == 0){
			LAUNCHIND[4]=true;
			abortTimer=simt;
		}
		if (abortTimer>0){
			if ((simt-(0.5+abortTimer))>=0){
	
		
				vessel->ActivateNavmode(NAVMODE_KILLROT);
			}
	
			if ((simt-(1+abortTimer))>=0){
				double pitch;
				pitch=vessel->GetPitch();
				if (pitch >0) {				
					vessel->SetPitchMomentScale (+5e-3);
					vessel->SetBankMomentScale (+5e-3);
					vessel->SetLiftCoeffFunc (0);
				}
			}

		
			if (simt-(20+abortTimer)>=0)
			{
				bManualSeparate=true;
				LAUNCHIND[2]=true;
				abortTimer = 0;
				 
			}
			bool altlow=false;
			
			double altitude=600;
			altitude=vessel->GetAltitude();
			if (altitude < 500 ){
				altlow = true;
			}
		if (bManualSeparate ||  altlow)
			{
				SeparateStage (vessel, stage);
				stage = 6;
				bManualSeparate=false;
				abortTimer = 0;
				 
			}
		}
			
	}

		
					
}
DLLCLBK void ovcLoadStateEx (VESSEL *vessel, FILEHANDLE scn, VESSELSTATUS *vs)

{
    char VNameApollo[256]="";
	char VNameRef13[256]="";
	char *line;
	float ftcp;
	int SwitchState = 0;
	while (oapiReadScenario_nextline (scn, line)) {

        if (!strnicmp (line, "CONFIGURATION", 13)) {
            sscanf (line+13, "%d", &status);

		} else if (!strnicmp (line, "TOALT", 5)) {
            int toalt;
			sscanf (line+5, "%d", &toalt);
			MIN_ALT=toalt;
		}else if (!strnicmp (line, "BUILDSTATUS", 11)) {
			sscanf (line+11, "%d", &buildstatus);
		}else if (!strnicmp (line, "CORRECTION", 10)) {
            
			Scorrec=true;

		}  else if (!strnicmp (line, "TOHDG", 5)) {
            int tohdg;
			sscanf (line+5, "%d", &tohdg);
			TO_HDG=tohdg;
		} else if (!strnicmp (line, "TCP", 3)) {
            sscanf (line+3, "%f", &ftcp);
			TCPO=ftcp;
		}else if (!strnicmp (line, "BURNED", 4)) {

			Burned = true;
		
		} else if (!strnicmp (line, "13EXP", 5)) {

			ApolloExploded = true;
	
		} else if (!strnicmp (line, "EVA", 3)) {

			EVA_IP = true;
			
		}else if (!strnicmp (line, "LEM_DISPLAY", 11)) {

			LEM_DISPLAY = true;
			
		} else if (!strnicmp (line, "RPS10", 5)) {
            SwitchState =0;
			sscanf (line+5, "%d", &SwitchState);
			if(SwitchState == 1) RPswitch10 = true;
			
		} else if (!strnicmp (line, "RPS11", 5)) {
            SwitchState =0;
			sscanf (line+5, "%d", &SwitchState);
			if(SwitchState == 1) RPswitch11 = true;
			
		} else if (!strnicmp (line, "AUTOPILOT", 9)) {
            SwitchState =0;
			sscanf (line+9, "%d", &SwitchState);
			if(SwitchState == 1) autopilot = true;
			
		} else if (!strnicmp (line, "DOCKSTATE", 9)) {
            sscanf (line+9, "%d", &dockstate);
		} else if (!strnicmp (line, "AUTOTIMER", 9)) {
            sscanf (line+9, "%d", &autoTimer);
			ignition_time= oapiGetSimTime()-autoTimer;
			autopTime = autopTime + autoTimer;
			if (autoTimer >0){
				clockMission = true;
				launchSound=true;
				LAUNCHIND[0]=true;
				}

			}else {
			            vessel->ParseScenarioLineEx (line, vs);
        }
    }
			switch (status) {
				case 0:
				stage=0;
			
			if (buildstatus <8){
				BuildFirstStage(vessel,buildstatus);
				double TCP=-101.5+STG0O+12;//-TCPO;
				vessel->SetTouchdownPoints (_V(0,-1.0,TCP), _V(-.7,.7,TCP), _V(.7,.7,TCP));
	
			}else{
				SetFirstStage(vessel);
				vessel->ShiftCentreOfMass (_V(0,0,STG0O));
			}
		
		
		if (vessel->GetEngineLevel(ENGINE_MAIN)>=0.5){
			vessel->SetMaxThrust (ENGINE_ATTITUDE, 8e5);
			launchSound=true;
		}
		
		levelCSM = true;
		break;
	case 1:
		stage=1;
		SetSecondStage(vessel);
		//SetSecondStage1(vessel);
		ignition_2time = 0;
		
		break;
	case 2:
		
		stage=2;
		SetSecondStage1(vessel);
		break;
	case 3:
		
		stage=3;
		SetSecondStage2(vessel);
		break;
	case 4:
		
		stage=4;
		SetThirdStage(vessel);
		AddRCS_S4B(vessel);
		ignition_3time = 0;
		break;
	case 5:
		stage=5;
		SetCSMStage(vessel);
		strcpy (VNameApollo, vessel->GetName());
		strcpy (VNameRef13, "AS-508");
		if (strcmp(VNameApollo,VNameRef13)==0){
		Apollo13 =true;
		}
		autopilot=false;
		switch (dockstate) {
		case 1:
				break;
		case 2:

				break;
		case 3:
			break;
		case 4:
			break;
		case 5:
			SetCSM2Stage(vessel);
			break;
		}
		if (EVA_IP){
		SetupEVA(vessel);
		}
		break;
	case 6:
		autopilot=false;
		stage=6;
		SetCSMStage(vessel);
		SetReentryStage(vessel);
		switch (dockstate) {
		case 1:
				break;
		case 2:
				break;
		case 3:
			TargetDocked=true;
			break;
		case 4:
			break;
		case 5:
			break;
		}
		break;
	case 7:
		autopilot=false;
		stage=7;
		SetCSMStage(vessel);
		SetReentryStage(vessel);
		break;
	case 8:
		autopilot=false;
		stage=8;
		SetCSMStage(vessel);
		SetChuteStage1(vessel);
		break;
	case 9:
		autopilot=false;
		stage=9;
		SetCSMStage(vessel);
		SetChuteStage2(vessel);
		break;
	case 10:
		autopilot=false;
		stage=10;
		SetCSMStage(vessel);
		SetChuteStage3(vessel);
		break;
	case 11:
		autopilot=false;
		stage=11;
		SetCSMStage(vessel);
		SetChuteStage4(vessel);
		
		break;
	case 12:
		autopilot=false;
		stage=12;
		SetCSMStage(vessel);
		SetSplashStage(vessel);
		break;
	case 13:
		autopilot=false;
		stage=13;
		SetCSMStage(vessel);
		SetSplashStage(vessel);
		break;
	case 14:
		autopilot=false;
		stage=14;
		SetCSMStage(vessel);
		SetAbortStage(vessel);
		break;

	
	}



	

}


DLLCLBK void ovcSaveState (VESSEL *vessel, FILEHANDLE scn)

{
	
	vessel->SaveDefaultState (scn);
	
	int i = 1;

	oapiWriteScenario_int (scn, "CONFIGURATION", status);
	oapiWriteScenario_int (scn, "DOCKSTATE", dockstate);
	oapiWriteScenario_int (scn, "AUTOTIMER", int(autopTime));
	oapiWriteScenario_int (scn, "TOALT", int(MIN_ALT));
	oapiWriteScenario_int (scn, "TOHDG", int(TO_HDG));
	oapiWriteScenario_float (scn, "TCP", TCPO);
	if (status == 0 && buildstatus < 8){
	oapiWriteScenario_int (scn, "BUILDSTATUS", buildstatus);
	}

	if (LEM_DISPLAY){
	oapiWriteScenario_int (scn, "LEM_DISPLAY", int(TO_EVA));
	}
	if (Scorrec){
	oapiWriteScenario_int (scn, "CORRECTION", int(TO_EVA));
	}
	if (EVA_IP){
	oapiWriteScenario_int (scn, "EVA", int(TO_EVA));
	}
	
	if (Burned){
	oapiWriteScenario_int (scn, "BURNED", int(TO_BURN));
	}
	if (ApolloExploded){
	oapiWriteScenario_int (scn, "13EXP", int(TO_BURN));
	}
	if (RPswitch10){
	oapiWriteScenario_int (scn, "RPS10",  i);
	}
	if (RPswitch11){
	oapiWriteScenario_int (scn, "RPS11",  i);
	}
	if (autopilot){
	oapiWriteScenario_int (scn, "AUTOPILOT",  i);
	}
		
}
